--
--	Grail Quests
--	Written by scott@mithrandir.com
--
--	Version History
--		001	Initial verison.
--		002	Added all the Lunar Festival and Harvest Festival quests.
--		003	Added the Love is in the Air quests except for the following which appear to have been removed from the game
--				[14488]={[0]="You've Been Served",[1]='HA L075 A:38208 T:36296 P:24792,24793'},
--				[24792]={[0]='Man on the Inside',[1]='HA FA L078 A:38066 T:38208'},
--				[24793]={[0]='Man on the Inside',[1]='HA FH L078 A:37172 T:38208'},
--		004	Added yearly markers to Lunar Festival quests.
--			Added Noblegarden quests, markers for Pilgrim's Bounty and Day of the Dead quests
--			Updated a couple starting Worgen quests.
--		005	Updated a bunch of quests.
--		006	Updated a bunch of quests.
--		007	Added a bunch of quests for the last remaining holidays.
--			Updated a bunch of quest information (primarily prerequisites) based on game play.
--			Started processing new quests added in game version 4.1.
--		008	Started putting in K codes.
--			Updated quest prerequisites, etc. based on game play.
--		009	Removed the cloth donation quests.
--			Updated a lot of Alliance Twilight Highlands based on game play.
--		010	More updates including some more level information.
--		011	Added more K codes for some low-level quests.
--			Put in some I:, P: and reputation requirements for Deepholm quests.
--			Converted A:0 to the Self alias NPCs that indicate probable zones for acceptance.
--			Added a bunch of Firelands quests.
--		012	Added a lot more K codes
--			Some updates to Firelands quests.
--		013	Updates to some Horde starting areas, Gilneas and a few tweaks to Firelands.
--		014 Put all the quests in numeric order instead of keeping some of the groups for processing purposes.
--			Many updates to zones noted in the Grail.lua file.
--			Horde cooking and fishing quests updated.
--			Converted the K codes for cooking/fishing/Brewfest quests to level 0 to indicate they are actually the level of the player accepting them.
--		015	Some minor updates after some massive ones previously.
--			Hallow's End updates.
--			Introduced a few new codes.	
--
--	Known issues
--		Not all quests are present.
--		Not all quest information is accurate.
--		Need start locations for 13483 and 13484 (partially done)
--		Need to update the Horde Children's Week quests.
--
--	UTF-8 file
--
--	Each of the Midsummer torch tossing/catching quests is marked as incompatible with the other
--	faction's same quest.  This is because this is what happens in the runtime when playing, even
--	though nowadays one cannot get the quest at the other faction's questgiver.
--
--	Entries in the quest table:
--		0	localized name of the quest
--		1	code string
--		2	cached type bit value
--		3	cached holiday bit value
--		4	cached obtainers bit value
--		5	achievement "map areas"
--		6	table of reputation changes when quest turned in
--
--	The code string can indicate any of the following information and should not be localized:
--		B#	where # is the number of the map area where this quest is Loremaster.  If the # is 0 then this class is not a Loremaster quest.
--			If there is no B code, then the map area for the quest giver is the map area for the Loremaster.
--		Y:questId	where questId represents the quest that this quest is an alias for
--		Cx	where x is the key to a required class (see classMapping). if no Cx is present any class can accept the quest
--		Xx	where x is the key to an excluded class (see classMapping).  if no Xx is present any class can accept the quest
--		Fx	where x is the key to a permitted faction (A for Alliance and H for Horde).  if no Fx is present any faction can accept the quest
--		Gx	where x is the key to a permitted gender (M for male and F for female).  if no Gx is present any gender can accept the quest
--		Pxyyy	where x is the key to a required profession and yyy is the minimum skill (see professionMapping).
--		Rx	where x is the key to a permitted race (see raceMapping).  if no Rx is present any race can accept the quest
--		Sx	where x is the key to an excluded race (see raceMapping).  if no Sx is present, any race can accept the quest
--		Vxxyyyyy where xx is the key to the required reputation and yyyyy is the minimum number of earned points in it (see reputationMapping).  note that you add 42000 to earned value.
--		Wxxyyyyy where xx is the key to the required reputation and yyyyy is the maximum number of earned points in it (see reputationMapping).  note that you add 42000 to earned value.
--			hated: 0   hostile: 35999   unfriendly: 38999
--			neutral: 41999   friendly: 44999   honored: 50999   revered: 62999   exalted: 83999
--		Lxxx	where xxx is the minimum level for the quest to be acceptable
--		Mxxx	where xxx is the maximum level for the quest to be acceptable
--		Hx	where x is the key to a specific holiday (see holidayMapping) when this quest is available.  if no Hx is present it should be available all the time.
--		++	quest is repeatable
--		+D	quest is a daily quest
--		+W	quest is a weekly quest
--		O:pat	where pat is a pattern (see below) of quests that are optional prerequisites
--		P:pat	where pat is a pattern (see below) of quests considered to be prerequisites
--		PL:pat	where pat is a pattern (see below) of quests considered to be prerequisites (required to be in the quest log, any state of completed)
--		PH:pat	where pat is a pattern (see below) of quests considered to be prerequisites (that have EVER been done) [basically should all be repeatable]
--		PC:pat	where pat is a pattern (see below) of quests considered to be prerequisites that are completed, but not yet turned in
--		PLT:pat	where pat is a pattern (see below) of quests considered to be prerequisites that are either in the log (any state of completed) or turned in
--		PCT:pat	where pat is a pattern (see below) of quests considered to be prerequisites that are either completed in the log or turned in
--		I:pat	where pat is a pattern (see below) of quests considered to invalidate the quest (they are mutually exclusive with this quest)  in other words, if the quest is in
--				the Blizzard quest log or has ever been completed
--		A:list	where list (see below) is the list of NPCs that give this quest to anyone
--		AA:list	where list (see below) is the list of NPCs that give this quest to Alliance only
--		AH:list	where list (see below) is the list of NPCs that give this quest to Horde only
--		AK:list where list (see below) is the list of NPCs that you can kill to automatically start the quest
--		AZ:zone	where zone is the zone ID of the zone that when entered automatically gives the quest
--		T:list	where list (see below) is the list of NPCs where the quest is turned in by anyone
--		TA:list	where list (see below) is the list of NPCs where the quest is turned in by Alliance only
--		TH:list where list (see below) is the list of NPCs where the quest is turned in by Horde only
--		SP	indicated the quest is a special one that never appears in the quest log
--		OAC:list where list (see below) is the list of quests that are marked complete once this quest is accepted (On Accept Complete)
--		OCC:list where list (see below) is the list of quests that are marked complete once this quest is marked complete in the quest log
--		OTC:pat where pat is a comma-separated list of plus-separated pairs where the first in the pair is an NPC ID and the second is the quest ID to complete
--		Kxxxyyy	where xxx is the level of the quest (or 000 if the quest has a changing quest level the same as the player level) and 
--			yyy is a number whose bits represent aspects of the quest:
--			1	repeatable
--			2	daily
--			4	weekly
--			8	monthly
--			16	yearly
--			32	escort
--			64	dungeon
--			128	raid
--			256	PVP
--			512	group
--			1024	heroic
--
--	Patterns for prerequisites and invalidations is a comma-separated list of quests, any of which match.  Within the comma-separated list there
--	can be plus-separated values that indicate each of them must match.  For example, the following code:
--		123,456,789+1122,3344
--	means any of the following quests would match the pattern:
--		123
--		456
--		both 789 and 1122 (together)
--		3344
--
--	Lists are just comma-separated values.
--
Grail_Quests_File_Version = 015

if Grail.questsVersionNumber < Grail_Quests_File_Version then
Grail.questsVersionNumber = Grail_Quests_File_Version
Grail.quests = {
[1]={[0]='Bogus Quest For Prerequisite Work',[1]='B0 '},
[2]={[0]="Sharptalon's Claw",[1]='B43 K0230 FH L019 A:100016305 T:12696'},
[11]={[0]='Riverpaw Gnoll Bounty',[1]='B0 K0100 FA L007 A:963 T:963 O:239'},
[16]={[0]='Give Gerard a Drink',[1]='B0 K0010 FA ++ A:255 T:255'},
[23]={[0]="Ursangous's Paw",[1]='B43 K0240 FH L019 A:100016303 T:12696,34559'},
[24]={[0]="Shadumbra's Head",[1]='B43 K0240 FH L019 A:100016304 T:12696,34359'},
[25]={[0]='Simmer Down Now',[1]='B43 K0250 FH L023 A:12737,34559 T:12737,34559'},
[35]={[0]='Further Concerns',[1]='B0 K0100 FA L007 A:240 T:261 P:40'},
[37]={[0]='Find the Lost Guards',[1]='B0 K0100 FA L007 A:261 T:1000055 P:35'},
[40]={[0]='A Fishy Peril',[1]='B0 K0100 FA L007 A:241 T:240'},
[45]={[0]="Discover Rolf's Fate",[1]='B0 K0100 FA L007 A:1000055 T:1000056 P:37'},
[46]={[0]='Bounty on Murlocs',[1]='B0 K0100 FA L007 A:1007125 T:261'},
[47]={[0]='Gold Dust Exchange',[1]='B0 K0070 FA L004 A:241 T:241'},
[52]={[0]='Protect the Frontier',[1]='B0 K0100 FA L007 A:261 T:261'},
[54]={[0]='Report to Goldshire',[1]='B0 FA K0050 A:197 T:240 P:26390'}, -- TODO: Determine what is I: because Saab did not get this offered
[59]={[0]='Cloth and Leather Armor',[1]='B0 K0100 FA L007 A:240,261 T:278 P:71'},
[60]={[0]='Kobold Candles',[1]='B0 K0070 FA L003 A:253 T:253'},
[62]={[0]='The Fargodeep Mine',[1]='B0 K0070 FA L004 A:240 T:240'},
[71]={[0]='Report to Thomas',[1]='B0 K0100 FA L007 A:1000056 T:261 P:45'},
[76]={[0]='The Jasperlode Mine',[1]='B0 K0100 FA L004 A:240 T:240 P:62'},
[83]={[0]='Fine Linen Goods',[1]='B0 FA K0100 L007 A:278 T:278'},
[84]={[0]='Back to Billy',[1]='B0 K0060 FA L005 A:246 T:247 P:86'},
[85]={[0]='Lost Necklace',[1]='B0 K0060 FA L005 A:246 T:247'},
[86]={[0]='Pie for Billy',[1]='B0 K0060 FA L005 A:247 T:246 P:85'},
[87]={[0]='Goldtooth',[1]='B0 K0080 FA L005 A:247 T:246 P:84'},
[88]={[0]='Princess Must Die!',[1]='B0 K0090 FA L006 A:244 T:244'},
[106]={[0]='Young Lovers',[1]='B0 K0060 FA L005 A:251 T:252 O:26150'},
[107]={[0]='Note to William',[1]='B0 K0060 FA L005 A:248 T:253 P:111'},
[111]={[0]='Speak with Gramma',[1]='B0 K0060 FA L005 A:252 T:248 P:106'},
[112]={[0]='Collecting Kelp',[1]='B0 K0070 FA L005 A:253 T:253 P:107'},
[114]={[0]='The Escape',[1]='B0 K0070 FA L005 A:253 T:251 P:112'},
[123]={[0]='The Collector',[1]='B0 K0100 FA L007 A:100001307 T:42256'},
[147]={[0]='Manhunt',[1]='B0 K0100 FA L007 A:42256 T:42256 P:123'},
[171]={[0]='A Warden of the Alliance',[1]='B0 HC FA L010 A:14305 T:51988 P:29117+29119'},
[172]={[0]="Children's Week",[1]='B0 HC FH L010 A:14451 T:4'},
[176]={[0]='Wanted:  "Hogger"',[1]='B0 K0110 FA L007 A:1000068,1025489 T:240'},
[182]={[0]='The Troll Menace',[1]='B0 FA K0040 A:786 T:786 P:24487'},
[184]={[0]="Furlbrow's Deed",[1]='B39 K0100 FA L009 A:1007126 T:42308 B39'},
[185]={[0]='Tiger Hunting',[1]='B37 K0250 L024 A:717 T:717,-37 P:583'},
[186]={[0]='Tiger Stalking',[1]='B37 K0260 L024 A:-37,717 T:-37,717 P:185'},
[187]={[0]='Tiger Prowess',[1]='B37 K0270 L024 A:-37,717 T:-37,717 P:186'},
[188]={[0]='Tiger Mastery',[1]='B37 K0280 L024 A:-37,717 T:717 P:187'},
[190]={[0]='Panther Hunting',[1]='B37 K0250 L024 A:718 T:718,-37 P:583'},
[191]={[0]='Panther Stalking',[1]='B37 K0260 L024 A:-37,718 T:-37,718 P:190'},
[192]={[0]='Panther Prowess',[1]='B37 K0270 L024 A:-37,718 T:-37,718 P:191'},
[193]={[0]='Panther Mastery',[1]='B37 K0280 L024 A:-37,718 T:718 P:192'},
[194]={[0]='Raptor Hunting',[1]='B37 K0250 L024 A:715 T:-37,715 P:583'},
[195]={[0]='Raptor Stalking',[1]='B37 K0260 L024 A:-37,715 T:-37,715 P:194'},
[196]={[0]='Raptor Prowess',[1]='B37 K0270 L024 A:-37,715 T:-37,715 P:195'},
[197]={[0]='Raptor Mastery',[1]='B37 K0280 L024 A:-37,715 T:715 P:196'},
[208]={[0]='Big Game Hunter',[1]='B37 K0290 L024 A:715 T:715 P:188+193+197'},
[216]={[0]='Between a Rock and a Thistlefur',[1]='B43 K0230 FH L021 A:12757 T:12757'},
[218]={[0]='Ice and Fire',[1]='B0 FA K0050 A:786 T:786 P:182+24489'},
[236]={[0]='Fueling the Demolishers',[1]='B0 K0800 +W FA L078 A:31108 T:31108'},
[239]={[0]='Westbrook Garrison Needs Help!',[1]='B0 K0100 FA L007 A:240 T:963'},
--[256]={[0]="WANTED: Chok'sul",[1]='K0220 FA L009 A:1000256 T:1139'},
[264]={[0]='Until Death Do Us Part',[1]='B0 K0150 FH L012 A:5543 T:1024776'},
--[270]={[0]='The Doomed Fleet',[1]='K0290 FA L020 A:1212 T:1217'},
--[273]={[0]='Resupplying the Excavation',[1]='K0150 FA L010 A:1105 T:2057 P:302'},
--[287]={[0]='Frostmane Hold',[1]='K0090 FA L007 A:1252 T:1252'},
--[291]={[0]='The Reports',[1]='K0100 FA A:1252 T:1274 P:287'},
--[298]={[0]='Excavation Progress Report',[1]='K0150 FA L010 A:1344 T:1105'},
--[301]={[0]='Report to Ironforge',[1]='K0150 FA L010 A:1105 T:1356 P:298'},
--[302]={[0]='Powder to Ironband',[1]='K0150 FA L010 A:1356 T:1105 P:301'},
--[308]={[0]='Distracting Jarven',[1]='K0070 FA ++ A:1373 T:1373'},
[309]={[0]='Protecting the Shipment',[1]='B35 K0150 FA L012 A:2057 T:1344 P:13639'},
--[310]={[0]='Bitter Rivals',[1]='K0060 FA L005 A:1375 T:1000270'},
--[311]={[0]='Return to Marleth',[1]='K0070 FA L002 A:1000270 T:1375'},
--[312]={[0]="Tundra MacGrann's Stolen Stash",[1]='K0120 FA L007 A:1266 T:1266'},
[313]={[0]='Forced to Watch from Afar',[1]='B0 FA K0070 L005 A:1377,40950 T:1377,40950 P:25724'},
[314]={[0]='Protecting the Herd',[1]='B0 K0080 FA L006 A:1265 T:1265 P:25932'},
[315]={[0]='The Perfect Stout',[1]='B0 FA K0060 L005 A:1374 T:1374'},
--[317]={[0]='Stocking Jetsteam',[1]='K0060 FA L002 A:1378 T:1378'},
--[318]={[0]='Evershine',[1]='K0070 FA L002 A:1378 T:1374 P:317'},
--[319]={[0]='A Favor for Evershine',[1]='K0080 FA L002 A:1374 T:1374 P:318'},
--[320]={[0]='Return to Bellowfiz',[1]='K0080 FA L002 A:1374 T:1378 P:319'},
--[325]={[0]='Armed and Ready',[1]='K0290 FA L020 A:1416 T:311'},
[332]={[0]='Wine Shop Advert',[1]='B0 FA K0020 A:1432 T:1431'},
[333]={[0]='Harlan Needs a Resupply',[1]='B0 FA K0020 A:1427 T:1428'},
[334]={[0]='Package for Thurman',[1]='B0 FA K0020 A:1428 T:1429'},
[351]={[0]='Find OOX-17/TN!',[1]='B161 K0480 L043 A:100008623 T:7784'},
[353]={[0]="Stormpike's Delivery",[1]='B0 K0150 FA L009 A:1416 T:1343 O:1097'},
[384]={[0]='Beer Basted Boar Ribs',[1]='B0 FA K0060 L005 A:1267 T:1267'},
--[400]={[0]='Tools for Steelgrill',[1]='K0050 FA L002 A:1872 T:1376'},
[412]={[0]='Operation Recombobulation',[1]='B0 FA K0060 L005 A:1269 T:1269 P:313+25667'},
--[413]={[0]='Shimmer Stout',[1]='K0100 FA L008 A:1374 T:1959 O:415'},
--[414]={[0]='Stout to Kadrell',[1]='K0100 FA L008 A:1959 T:1340 P:413'},
--[415]={[0]="Rejold's New Brew",[1]='B0 FA K0100 L008 A:1378 T:1374 I:413,315'},
[432]={[0]='Those Blasted Troggs!',[1]='B0 K0090 FA L006 A:1254 T:1254'},
[433]={[0]='The Public Servant',[1]='B0 K0100 FA L007 A:1977 T:1977'},
--[454]={[0]='After the Ambush',[1]='K0150 FA L010 A:2057 T:1379 P:273'},
[475]={[0]='A Troubling Breeze',[1]='B0 FA K0060 L004 A:2107 T:2107'},
[476]={[0]='Gnarlpine Corruption',[1]='B0 FA K0060 L004 A:2107 T:2078 P:475'},
[483]={[0]='The Relics of Wakening',[1]='B0 FA K0080 L004 A:2078 T:2078 P:476'},
[485]={[0]='Find OOX-09/HL!',[1]='B26 K0350 L030 A:100008704 T:7806'},
[486]={[0]='Ursal the Mauler',[1]='B0 FA K0090 L004 A:2078 T:2078 P:483'},
[487]={[0]='The Road to Darnassus',[1]='B0 FA K0090 L005 A:2151 T:2151 P:483'},
[488]={[0]="Zenn's Bidding",[1]='B0 FA K0050 L004 A:2150 T:2150'},
[489]={[0]='Seek Redemption!',[1]='B0 FA K0060 L004 A:2083 T:2150 P:488'},
[495]={[0]='The Crown of Will',[1]='B0 K0390 FH L034 A:2227 T:2278'},
--[525]={[0]='Further Mysteries',[1]='K0340 FA L030 A:1356 T:2276'},
[543]={[0]='The Perenolde Tiara',[1]='B0 K0400 FA L030 A:2285 T:2285'},
[583]={[0]='Welcome to the Jungle',[1]='B37 K0250 L024 A:716 T:715'}, -- P:26340 was totally wrong
--[637]={[0]="Sully Balloo's Letter",[1]='K0300 FA L025 A:100004433 T:2695'},
--[647]={[0]="MacKreel's Moonshine",[1]='K0300 FA L028 A:2696 T:2705'},
[648]={[0]='Rescue OOX-17/TN!',[1]='B161 K0480 L043 A:7784 T:7406 P:351 B673'},
--[683]={[0]="Sara Balloo's Plea",[1]='K0300 FA L025 A:2695 T:2784'},
--[686]={[0]="A King's Tribute",[1]='K0300 FA L025 A:2784 T:2790'},
--[700]={[0]="A King's Tribute",[1]='K0310 FA L025 A:2790 T:2784'},
[743]={[0]='Dangers of the Windfury',[1]='B0 K0080 FH L006 A:2985 T:2985'},
[744]={[0]='Preparation for Ceremony',[1]='B0 K0100 FH L008 A:2987 T:2987'},
--[746]={[0]='Dwarven Digging',[1]='B0 K0080 FH L006 A:2993 T:2993'},
[749]={[0]='The Ravaged Caravan',[1]='B0 K0080 FH L005 A:2988 T:1002908 O:24459'},
[751]={[0]='The Ravaged Caravan',[1]='B0 K0080 FH L005 A:1002908 T:2988 P:749'},
[761]={[0]='Swoop Hunting',[1]='B0 K0060 FH L004 A:2947 T:2947'},
--[764]={[0]='The Venture Co.',[1]='B0 K0100 FH L005 A:2988 T:2988'},
--[765]={[0]='Supervisor Fizsprocket',[1]='B0 K0120 FH L005 A:2988 T:2988'},
[768]={[0]='Gathering Leather',[1]='B0 K0080 FH L004 A:3050 T:3050 PS001'},
[769]={[0]='Kodo Hide Bag',[1]='B0 K0100 FH L004 A:3050 T:3050 PL010'},
[770]={[0]='The Demon Scarred Cloak',[1]='B0 K0120 FH L006 A:100004854 T:3052'},
[773]={[0]='Rite of Wisdom',[1]='B0 K0100 FH RT RB L003 A:2984,3233 T:2994 P:20441'},
--[775]={[0]='Journey into Thunder Bluff',[1]='B0 K0100 FH L003 A:2994 T:3057'},
[824]={[0]="Je'neu of the Earthen Ring",[1]='B43 K0270 FH L023 A:12737 T:12736 P:1918'},
[833]={[0]='A Sacred Burial',[1]='B0 K0100 FH RT RL RB L007 A:3233 T:3233'},
[834]={[0]='Winds in the Desert',[1]='B0 K0090 L007 A:3293 T:3293'},
[835]={[0]='Securing the Lines',[1]='B0 K0090 L007 A:3293 T:3293'},
[836]={[0]='Rescue OOX-09/HL!',[1]='B26 K0350 L030 A:7806 T:7406 P:485 B673'},
[840]={[0]='Conscript of the Horde',[1]='B0 K0100 FH L010 A:3336 T:3337 I:26642,28494'},
[844]={[0]='Plainstrider Menace',[1]='B11 K0120 FH L009 A:3338,34258 T:3338,34258'},
[845]={[0]='The Zhevra',[1]='B11 K0130 FH L010 A:3338 T:3338'},
[848]={[0]='Fungal Spores',[1]='B11 K0150 FH L010 A:3390 T:3390'},
[850]={[0]='Kolkar Leaders',[1]='B11 K0140 FH L011 A:3389,34841 T:3389,34841'},
[851]={[0]='Verog the Dervish',[1]='B11 K0160 FH L013 A:3389,34638 T:3389,34638 P:14072'},
[852]={[0]='Hezrul Bloodmark',[1]='B11 K0190 FH L015 A:3389 T:3389 P:14073'},
[855]={[0]='Centaur Bracers',[1]='B11 K0180 FH L015 A:3389 T:3389'},
[858]={[0]='Ignition',[1]='B11 K0180 FH L013 A:3439 T:3439'},
[861]={[0]="The Hunter's Way",[1]='B0 K0100 FH RT RL RB L008 A:3052 T:3052,3441'},
[863]={[0]='The Escape',[1]='B11 K0180 FH L013 A:3439 T:3442'},
[865]={[0]="It's Gotta be the Horn",[1]='B11 K0180 L014 A:3446 T:3446'},
[866]={[0]='Root Samples',[1]='B0 K0160 FH L009 A:3446 T:3446'},
[867]={[0]='Harpy Raiders',[1]='B11 K0170 FH L012 A:3449 T:3449 P:28877'},
[869]={[0]='To Track a Thief',[1]='B11 K0150 +W FH L013 A:3464 T:3464 P:14066'},
[870]={[0]='The Forgotten Pools',[1]='B11 K0130 FH L010 A:3448 T:3448'},
[871]={[0]='In Defense of Far Watch',[1]='B11 K0120 FH L009 A:3337,3429 T:3337,3429 P:840,26642,28494'},
[872]={[0]='The Far Watch Offensive',[1]='B11 K0120 FH L009 A:3337,3429 T:3337,3429 P:871'},
[875]={[0]='Harpy Lieutenants',[1]='B11 K0160 FH L012 A:3449 T:3449 P:867'},
[876]={[0]='Serena Bloodfeather',[1]='B11 K0180 FH L012 A:3449 T:3449 P:875'},
[877]={[0]='The Stagnant Oasis',[1]='B11 K0160 FH L010 A:3448,34626 T:3448 P:13988'},
[880]={[0]='Altered Beings',[1]='B11 K0140 FH L010 A:3448,34626 T:3448'},
[881]={[0]='Echeyakee',[1]='B11 K0130 FH L010 A:3338 T:3338'},
[887]={[0]='Southsea Freebooters',[1]='B11 K0160 FH L014 A:3391,3453 T:3391,3453'},
[891]={[0]="A Captain's Vengeance",[1]='B11 K0150 FH L013 A:3339 T:3339'},
--[894]={[0]='Samophlange',[1]='FH L010 A:3442 T:1004141'},
[895]={[0]="WANTED: Cap'n Garvey",[1]='B11 K0160 L014 A:1003972 T:3391'},
[896]={[0]="Miner's Fortune",[1]='B11 K0160 FH L010 A:3453,34674 T:3453,34674'},
[899]={[0]='Consumed by Hatred',[1]='B11 K0120 FH L010 A:3432 T:3432'},
--[900]={[0]='Samophlange',[1]='L010 A:1004141 T:1004141 P:894'},
--[901]={[0]='Samophlange',[1]='L010 A:1004141 T:1004141 P:900'},
--[902]={[0]='Samophlange',[1]='FH L010 A:1004141 T:3442 P:901'},
[903]={[0]='Hunting the Huntress',[1]='B11 K0130 FH L010 A:3338 T:3338'},
[905]={[0]="Into the Raptor's Den",[1]='B11 K0140 FH L010 A:3338 T:3338 P:881'},
[910]={[0]='Down at the Docks',[1]='B0 HC FH L010 A:4 T:4 P:172'},
[911]={[0]='Gateway to the Frontier',[1]='B0 HC FH L010 A:4 T:4 P:172'},
[915]={[0]='You Scream, I Scream...',[1]='B0 HC FH L010 A:4 T:4 P:911+910+1800'},
[918]={[0]='Timberling Seeds',[1]='B0 FA K0090 L004 A:2080 T:2080 P:997'},
[919]={[0]='Timberling Sprouts',[1]='B0 FA K0090 L004 A:2080 T:2080,502080 P:997'},
[922]={[0]='Rellian Greenspyre',[1]='B0 FA K0090 L004 A:2080 T:3517 P:918'},
[923]={[0]='Mossy Tumors',[1]='B0 FA K0090 L004 A:3517 T:3517 P:922'},
[927]={[0]='The Moss-twined Heart',[1]='B0 FA K0120 L005 A:100005179 T:2080'},
[929]={[0]='Teldrassil: The Refusal of the Aspects',[1]='B0 FA RE K0060 A:3515 T:3515 P:28731'},
[930]={[0]='The Glowing Fruit',[1]='B0 FA K0090 L004 A:1006751 T:2080'},
[931]={[0]='The Shimmering Frond',[1]='B0 FA K0090 L004 A:1006752 T:2080,502080'},
[932]={[0]='Twisted Hatred',[1]='B0 FA K0070 L004 A:3567 T:3567 P:476+489'},
[933]={[0]='Teldrassil: The Coming Dawn',[1]='B0 FA K0090 A:503515 T:1992 P:7383'},
[935]={[0]='The Waters of Teldrassil',[1]='B0 FA K0110 A:1992 T:503515 P:14005'},
[937]={[0]='The Enchanted Glade',[1]='B0 K0100 FA L006 A:3519 T:3519'},
[938]={[0]='Mist',[1]='B0 FA K01032 L007 A:3568 T:3519'},
[941]={[0]='Planting the Heart',[1]='B0 FA K0120 L009 A:2080 T:1007923 P:927'},
--[959]={[0]='Trouble at the Docks',[1]='K0180 L014 A:3665 T:3665'},
--[976]={[0]='Supplies to Auberdine',[1]='K0240 FA L019 A:4484 T:3663'},
[996]={[0]='Corrupted Windblossom',[1]='B0 K0550 ++ L048 A:1164887 T:1164887'},
[997]={[0]="Denalan's Earth",[1]='B0 FA K0090 L004 A:2083 T:2080 P:486'},
[998]={[0]='Corrupted Windblossom',[1]='B0 K0550 ++ L048 A:1164887 T:1164887 P:996'},
[1036]={[0]='Avast Ye, Scallywag',[1]='B37 K0600 L055 A:2545 T:2546 I:4621,9272 W1935999'},
[1097]={[0]="Elmore's Task",[1]='B0 K0150 FA L009 A:514 T:1416 I:353'},
[1168]={[0]='Army of the Black Dragon',[1]='B141 K0410 FH L037 A:4502 T:4502'},
[1201]={[0]='Theramore Spies',[1]='B141 K0350 FH L030 A:4791 T:4791'},
[1202]={[0]='The Theramore Docks',[1]='B141 K0350 FH L030 A:4791 T:4791 P:1201'},
[1204]={[0]='Mudrock Soup and Bugs',[1]='B141 K0360 FA L033 A:4794 T:4794'},
[1205]={[0]='Deadmire',[1]='B141 K0410 FH L035 A:3441 T:3441'},
[1222]={[0]="Stinky's Escape",[1]='B141 K0370 FA L030 A:4880 T:4794'},
[1258]={[0]='... and Bugs',[1]='B141 K0360 FA L033 A:4794 T:4794 P:1204'},
[1270]={[0]="Stinky's Escape",[1]='B141 K0370 FH L030 A:4880 T:3446'},
[1271]={[0]='Feast at the Blue Recluse',[1]='B141 K0370 FA L030 A:1141 T:1141 P:1222 B141'},
--[1338]={[0]="Stormpike's Order",[1]='K0140 FA L009 A:1343 T:5413'},
[1362]={[0]='The Kolkar of Desolace',[1]='B0 K0320 FH L030 A:3389 T:5395'},
[1368]={[0]='Gelkis Alliance',[1]='B0 K0330 FH L030 A:5412 T:5397'},
--[1369]={[0]='Broken Tears',[1]='K0330 L030 A:5398 T:5398 P:1386'},
[1370]={[0]='Stealing Supplies',[1]='B0 K0350 L030 A:5397 T:5397 P:1368,1384'},
--[1371]={[0]='Gizmo for Warug',[1]='K0350 L030 A:5398 T:5398 P:1369'},
[1373]={[0]='Ongeku',[1]='B0 K0370 L030 A:5397 T:5397 P:1370'},
[1374]={[0]='Khan Jehn',[1]='B0 K0370 L030 A:5397 T:5397 P:1373'},
--[1375]={[0]='Khan Shaka',[1]='K0370 L030 A:5398 T:5398'},
[1380]={[0]='Khan Hratha',[1]='B0 K0420 L030 A:5397 T:5397 P:1374'},
--[1381]={[0]='Khan Hratha',[1]='K0420 L030 A:5398 T:5398 P:1375'},
[1384]={[0]='Raid on the Kolkar',[1]='B0 K0320 FA L030 A:5397 T:5397 P:1368'},
--[1386]={[0]='Assault on the Kolkar',[1]='K0320 FA L030 A:5398 T:5398'},
--[1392]={[0]='Noboru the Cudgel',[1]='K0390 L029 A:100006196 T:1776'},
--[1393]={[0]="Galen's Escape",[1]='K0380 L030 A:5391 T:1032569'},
[1431]={[0]='Alliance Relations',[1]='B0 K0300 FH L030 A:5639 T:5640'},
[1432]={[0]='Alliance Relations',[1]='B0 K0300 FH L030 A:5640 T:5641 P:1431'},
[1433]={[0]='Alliance Relations',[1]='B0 K0330 FH L030 A:5641 T:4498'},
[1434]={[0]='Befouled by Satyr',[1]='B0 K0330 FH L025 A:5641 T:5641'},
[1436]={[0]='Alliance Relations',[1]='B0 K0330 FH L030 A:5641 T:5640'},
[1453]={[0]="Reclaimers' Business in Desolace",[1]='B0 K0300 FA L027 A:5637 T:5638 I:1454'},
[1454]={[0]='The Karnitol Shipwreck',[1]='B0 K0300 FA L027 A:5638 T:1035251 P:14354 O:1453'},
[1455]={[0]='The Karnitol Shipwreck',[1]='B0 K0300 FA L027 A:1035251 T:5638 P:1454'},
[1456]={[0]='The Karnitol Shipwreck',[1]='B0 K0300 FA L027 A:5638 T:5638 P:1455'},
--[1467]={[0]='Reagents for Reclaimers Inc.',[1]='K0400 FA L030 A:5638 T:5637'},
[1468]={[0]="Children's Week",[1]='B0 HC FA L010 A:14450,51988 T:14305'},
[1514]={[0]='Corrupted Windblossom',[1]='B0 K0550 FA L048 A:1173327 T:1173327'},
[1578]={[0]='Supplying the Front',[1]='B0 K0120 L005 FA A:6031 T:6030 PB030'},
[1581]={[0]='Elixirs for the Bladeleafs',[1]='B0 FA K0080 L004 PA020 A:2083 T:2083'},
[1582]={[0]='Moonglow Vest',[1]='B0 FA K0180 L008 PL070 A:6034 T:6034'},
[1618]={[0]='Gearing Redridge',[1]='B0 FA K0160 PB070 A:6031 T:415'},
--[1789]={[0]='The Symbol of Life',[1]='FA CP ++ L012 A:6179 T:6179'},
--[1790]={[0]='The Symbol of Life',[1]='FA CP ++ L012 A:6171 T:6171'},
[1800]={[0]='Lordaeron Throne Room',[1]='B0 HC FH L010 A:4 T:4 P:172'},
[1918]={[0]='The Befouled Element',[1]='B43 K0270 FH L023 A:100016408 T:12737'},
[2039]={[0]='Find Bingles',[1]='B0 FA K0150 L012 A:6569 T:6577'},
[2158]={[0]='Rest and Relaxation',[1]='B0 FA K0050 A:6774 T:295'},
[2159]={[0]='Dolanaar Delivery',[1]='B0 FA K0050 L003 A:6780 T:6736'},
[2199]={[0]='Lore for a Price',[1]='B504956 K0410 FA L037 A:6826 T:6826'},
[2278]={[0]='The Platinum Discs',[1]='B504956 K0400 L037 A:1131474 T:1131474'},
[2280]={[0]='The Platinum Discs',[1]='B0 K0400 L037 A:1131474 TA:46234 TH:3978,46236'},
[2383]={[0]='Simple Parchment',[1]='B0 K0030 FH RO CW L003 A:3143 T:3153'},
[2399]={[0]='The Sprouted Fronds',[1]='B0 SP K0100 FA L004 A:1007510 T:1007510 P:931'},	-- seems to be timed so the quest givers only remain for a limited time...then can not get quest at all
[2438]={[0]='The Emerald Dreamcatcher',[1]='B0 +W FA K0060 A:3567 T:3567'},
[2459]={[0]='Ferocitas the Dream Eater',[1]='B0 K0060 FA A:3567 T:3567 P:2438'},
[2499]={[0]='Oakenscowl',[1]='B0 FA K0100 L004 A:2080,502080 T:2080 P:923'},
[2518]={[0]='Tears of the Moon',[1]='B0 K0100 FA L005 A:7313 T:7313'},
[2523]={[0]='Corrupted Songflower',[1]='B0 K0550 ++ L048 A:1164886 T:1164886'},
[2541]={[0]='The Sleeping Druid',[1]='B0 FA K0080 L003 A:7317 T:7317'},
[2561]={[0]='Druid of the Claw',[1]='B0 FA K0100 L003 A:7317 T:7317 P:2541'},
[2751]={[0]='Barbaric Battlements',[1]='B0 K0320 FH L032 A:7790 T:7790'},
[2752]={[0]='On Iron Pauldrons',[1]='B0 K0320 FH L032 A:7790 T:7790'},
[2753]={[0]='Trampled Under Foot',[1]='B0 K0360 FH L032 A:7790 T:7790'},
[2754]={[0]='Horns of Frenzy',[1]='B0 K0360 FH L032 A:7790 T:7790'},
[2755]={[0]='Joys of Omosh',[1]='B0 K0360 FH L032 A:7790 T:7790'},
--[2847]={[0]='Wild Leather Armor',[1]='K0450 FA L030 A:7852 T:7852'},
--[2850]={[0]='Wild Leather Helmet',[1]='K0450 FA L030 A:7852'},
--[2854]={[0]='Wild Leather Armor',[1]='K0450 FH L030 A:7854 T:7854'},
[2855]={[0]='Wild Leather Shoulders',[1]='B0 K0450 FH L030 A:7854 T:7854'},
[2856]={[0]='Wild Leather Vest',[1]='B0 K0450 FH L030 A:7854'},
--[2857]={[0]='Wild Leather Helmet',[1]='K0450 FH L030 A:7854 T:7854'},
[2878]={[0]='Corrupted Songflower',[1]='B0 K0550 FA L048 A:1174594 T:1174594'},
[2945]={[0]='Grime-Encrusted Ring',[1]='B0 K0340 L024 A:100009326 T:1142487'},
[2947]={[0]='Return of the Ring',[1]='B0 K0340 FA L024 A:1142487 T:6826'},
[2948]={[0]='Gnome Improvement',[1]='B0 K0350 FA L024 A:6826 T:6826 P:2947'},
[2949]={[0]='Return of the Ring',[1]='B0 K0340 FH L024 A:1142487 T:3412'},
[2950]={[0]="Nogg's Ring Redo",[1]='B0 K0350 FH L024 A:3412 T:3412 P:2949'},
[2951]={[0]='The Sparklematic 5200!',[1]='B0 K0300 L025 A:1142487 T:1142487'},
[2952]={[0]='The Sparklematic 5200!',[1]='B0 K0300 L025 A:1142487 T:1142487'},
[2953]={[0]='More Sparklematic Action',[1]='B0 K0300 ++ L025 A:1142487 T:1142487'},
[2963]={[0]='Portents of Uldum',[1]='B0 K0500 FA L045 A:5387,24473 T:2916'},
[2965]={[0]='Portents of Uldum',[1]='B0 K0500 FH L045 A:3978 T:5770'},
[3087]={[0]='Etched Parchment',[1]='B0 K0030 FH RO CH L003 A:3143 T:3154,39214'},
[3088]={[0]='Encrypted Parchment',[1]='B0 K0030 FH RO CR L003 A:3143 T:3155'},
[3089]={[0]='Rune-Inscribed Parchment',[1]='B0 K0030 FH RO CS L003 A:3143 T:3157'},
[3090]={[0]='Tainted Parchment',[1]='B0 K0030 FH RO RL CL L003 A:3143 T:3156'},
[3091]={[0]='Simple Note',[1]='B0 K0030 FH RT CW L003 A:2980,44927 T:3059'},
[3092]={[0]='Etched Note',[1]='B0 K0030 FH RT RL CH L003 A:44927 T:3061'},
[3093]={[0]='Rune-Inscribed Note',[1]='B0 K0030 FH RT CS L003 A:2980,44927 T:3062'},
[3094]={[0]='Verdant Note',[1]='B0 K0030 FH RT RL CD L003 A:2980,44927 T:3060'},
[3095]={[0]='Simple Scroll',[1]='B0 K0030 FH RU CW L003 A:1569 T:2119 P:26801'},
[3096]={[0]='Encrypted Scroll',[1]='B0 K0030 FH RU CR L003 A:1569 T:2122 P:26801'},
[3097]={[0]='Hallowed Scroll',[1]='B0 K0030 FH RU CT L003 A:1569 T:2123 P:26801'},
[3098]={[0]='Glyphic Scroll',[1]='B0 K0030 FH RU CM L003 A:1569 T:2124 P:26801'},
[3099]={[0]='Tainted Scroll',[1]='B0 K0030 FH RU CL L003 A:1569 T:2126 P:26801'},
[3100]={[0]='Simple Letter',[1]='B0 FA CW K0030 L003 A:197 T:911 P:28774'},
[3101]={[0]='Consecrated Letter',[1]='B0 FA CP K0030 L003 A:197 T:925 P:28770'},
[3102]={[0]='Encrypted Letter',[1]='B0 FA CR K0030 L003 A:197 T:915 P:28772'},
[3103]={[0]='Hallowed Letter',[1]='B0 FA CT K0030 L003 A:197 T:375 P:28771'},
[3104]={[0]='Glyphic Letter',[1]='B0 FA CM K0030 L003 A:197 T:198 P:28769'},
[3105]={[0]='Tainted Letter',[1]='B0 FA CL K0030 L003 A:197 T:459 P:28773'},
[3106]={[0]='Simple Rune',[1]='B0 K0030 FA RF CW L003 A:37087 T:912'},
[3107]={[0]='Consecrated Rune',[1]='B0 K0030 FA RF CP L003 A:37087 T:926'},
[3108]={[0]='Etched Rune',[1]='B0 K0030 FA RF CH L003 A:658,37087 T:895'},
[3109]={[0]='Encrypted Rune',[1]='B0 K0030 FA RF CR L003 A:658,37087 T:916'},
[3110]={[0]='Hallowed Rune',[1]='B0 K0030 FA RF CT L003 A:37087 T:837'},
[3115]={[0]='Tainted Rune',[1]='B0 K0030 FA RF RN CL L003 A:658,37087 T:43455'},
[3116]={[0]='Simple Sigil',[1]='B0 FA RE CW K0030 L003 A:2077,502079 T:3593 P:28714+28715'},
[3117]={[0]='Etched Sigil',[1]='B0 FA RE CH K0030 L003 A:2077,502079 T:3596 P:28714+28715'},
[3118]={[0]='Encrypted Sigil',[1]='B0 FA RE CR K0030 L003 A:2077,502079 T:3594 P:28714+28715'},
[3119]={[0]='Hallowed Sigil',[1]='B0 FA RE CT K0030 L003 A:2077,502079 T:3595 P:28714+28715'},
[3120]={[0]='Verdant Sigil',[1]='B0 FA RE CD K0030 L003 A:2077,502079 T:3597 P:28714+28715'},
[3361]={[0]="A Refugee's Quandary",[1]='B0 FA K0030 A:8416 T:8416 P:24487'},
[3363]={[0]='Corrupted Songflower',[1]='B0 K0550 ++ L048 A:1164886 T:1164886 P:2523'},
--[3382]={[0]='A Crew Under Fire',[1]='B0 K0570 ++ L048 A:8380 T:8380'},
--[3421]={[0]='Return Trip',[1]='B0 K0550 ++ L045 A:8399 T:8399'},
--[3503]={[0]='Meeting with the Master',[1]='B0 K0550 ++ L045 A:8395 T:8395'},
--[3506]={[0]='Betrayed',[1]='B0 K0560 FH L044 A:1151286 T:8576'},
--[3517]={[0]='Stealing Knowledge',[1]='B0 K0520 FH L045 A:8587 T:8587'},
--[3518]={[0]='Delivery to Magatha',[1]='B0 K0520 FH L045 A:8587 T:4046'},
[3526]={[0]='Goblin Engineering',[1]='B0 FH K0850 L010 PN200 A:4586 T:8126'},
[3541]={[0]="Delivery to Jes'rimon",[1]='B0 K0520 FH L045 A:8587 T:8659'},
--[3542]={[0]='Delivery to Andron Gant',[1]='B0 K0520 FH L045 A:8587 T:6522'},
[3561]={[0]='Delivery to Archmage Xylem',[1]='B0 K0520 FH L045 A:8587 T:8379'},
[3563]={[0]="Jes'rimon's Payment to Jediga",[1]='B0 K0520 FH L045 A:8659 T:8587'},
--[3564]={[0]="Andron's Payment to Jediga",[1]='B0 K0520 FH L045 A:6522 T:8587'},
[3565]={[0]="Xylem's Payment to Jediga",[1]='B0 K0520 FH L045 A:8379 T:8587'},
[3601]={[0]="Kim'jael Indeed!",[1]='B0 K0530 L047 A:8420 T:8420'},
[3629]={[0]='Goblin Engineering',[1]='B0 FA K0850 L010 PN200 A:5518 T:8126 I:3633,4181'},
[3630]={[0]='Gnome Engineering',[1]='B0 FA K0850 L010 PN200 A:5518 T:7944'},
[3632]={[0]='Gnome Engineering',[1]='B0 FA K0850 L010 PN200 A:5174 T:7944'},
[3633]={[0]='Goblin Engineering',[1]='B0 K0850 L010 PN200 A:3494 T:8126 I:3629,4181'},
[3635]={[0]='Gnome Engineering',[1]='B0 FH K0850 L010 PN200 A:3494 T:7406'},
[3637]={[0]='Gnome Engineering',[1]='B0 FH K0850 L010 PN200 A:4586 T:7406 P:3635'},
[3639]={[0]='Show Your Work',[1]='B0 K0800 L010 PN200 A:8126 T:8126'},
[3641]={[0]='Show Your Work',[1]='B0 FA L010 PN200 A:7944 T:7944'},
[3642]={[0]='The Pledge of Secrecy',[1]='B0 K0470 FA L030 A:7406 T:7406 P:3635,3637'},
[3643]={[0]='Show Your Work',[1]='B0 L010 A:7406 T:7406 P:3642'},
[3721]={[0]='An OOX of Your Own',[1]='B0 K0500 L040 A:7406 T:7406 P:648+836+25476'},
[3861]={[0]='CLUCK!',[1]='B39 K0010 ++ A:620 T:620'},
[3921]={[0]='Wenikee Boltbucket',[1]='B11 K0140 FH L010 A:3442,34674 T:9316'},
[3922]={[0]='Nugget Slugs',[1]='B11 K0150 FH L010 A:9316 T:9316 P:3921'},
[4021]={[0]='Counterattack!',[1]='B11 K0200 FH L011 A:3389 T:3389'},
[4083]={[0]='The Spectral Chalice',[1]='B0 K0550 L040 A:1164869 T:1164869'},
[4103]={[0]='Salve via Hunting',[1]='B0 K0550 FA ++ L048 A:9528 T:9528'},
[4104]={[0]='Salve via Mining',[1]='B0 K0550 FA ++ L048 A:9528 T:9528'},
[4105]={[0]='Salve via Gathering',[1]='B0 K0550 FA ++ L048 A:9528 T:9528'},
[4106]={[0]='Salve via Skinning',[1]='B0 K0550 FA ++ L048 A:9528 T:9528'},
[4107]={[0]='Salve via Disenchanting',[1]='B0 K0550 FA ++ L048 A:9528 T:9528'},
[4108]={[0]='Salve via Hunting',[1]='B0 K0550 FA ++ L048 A:9528 T:9528 P:4103'},
[4109]={[0]='Salve via Mining',[1]='B0 K0550 FA ++ L048 A:9528 T:9528 P:4104'},
[4110]={[0]='Salve via Gathering',[1]='B0 K0550 FA ++ L048 A:9528 T:9528 P:4105'},
[4111]={[0]='Salve via Skinning',[1]='B0 K0550 FA ++ L048 A:9528 T:9528 P:4106'},
[4112]={[0]='Salve via Disenchanting',[1]='B0 K0550 FA ++ L048 A:9528 T:9528 P:4107'},
[4113]={[0]='Corrupted Songflower',[1]='B0 K0550 FA L048 A:1164886 T:1164886'},
[4114]={[0]='Corrupted Songflower',[1]='B0 K0550 FA L048 A:1174596 T:1174596'},
[4115]={[0]='Corrupted Windblossom',[1]='B0 K0550 FA L048 A:1164887 T:1164887'},
[4116]={[0]='Corrupted Songflower',[1]='B0 K0550 FH L048 A:1174597 T:1174597'},
[4117]={[0]='Corrupted Whipper Root',[1]='B0 K0550 ++ L048 A:1164888 T:1164888'},
[4118]={[0]='Corrupted Songflower',[1]='B0 K0550 FH L048 A:1174598 T:1174598'},
[4119]={[0]='Corrupted Night Dragon',[1]='B0 K0550 ++ L048 A:1164885 T:1164885'},
[4181]={[0]='Goblin Engineering',[1]='B0 FA K0850 L010 PN200 A:5174 T:8126 I:3629,3633'},
[4221]={[0]='Corrupted Windblossom',[1]='B0 K0550 L048 A:1174604 T:1174604'},
[4295]={[0]="Rocknot's Ale",[1]='B0 K0010 ++ A:9503 T:9503'},
[4401]={[0]='Corrupted Songflower',[1]='B0 K0550 L048 A:1171939 T:1171939'},
[4443]={[0]='Corrupted Whipper Root',[1]='B0 K0550 ++ L048 A:1164888 T:1164888 P:4117'},
[4447]={[0]='Corrupted Night Dragon',[1]='B0 K0550 ++ L048 A:1164885 T:1164885 P:4119'},
[4461]={[0]='Corrupted Whipper Root',[1]='B0 K0550 FA L048 A:1174686 T:1174686'},
[4462]={[0]='Corrupted Night Dragon',[1]='B0 K0550 L048 A:1174684 T:1174684'},
[4464]={[0]='Corrupted Songflower',[1]='B0 K0550 FH L048 A:1174712 T:1174712'},
[4466]={[0]='Corrupted Windblossom',[1]='B0 K0550 FH L048 A:1174708 T:1174708'},
[4467]={[0]='Corrupted Windblossom',[1]='B0 K0550 FA L048 A:1174709 T:1174709'},
--[4481]={[0]='Libram of Constitution',[1]='K0550 FA ++ L050 A:9836 T:9836'},
--[4484]={[0]='Libram of Voracity',[1]='K0550 FA ++ L050 A:9836 T:9836'},
--[4493]={[0]='March of the Silithid',[1]='K0530 FA L050 A:7740 T:5594'},
--[4494]={[0]='March of the Silithid',[1]='K0530 FH L050 A:7010 T:5594'},
--[4510]={[0]='Calm Before the Storm',[1]='K0540 FA L050 A:7740 T:4155'},
--[4511]={[0]='Calm Before the Storm',[1]='K0540 FH L050 A:7010 T:3309'},
[4512]={[0]='A Little Slime Goes a Long Way',[1]='B0 K0520 FA L048 A:9616 T:9616'},
[4513]={[0]='A Little Slime Goes a Long Way',[1]='B0 K0540 FA L048 A:9616 T:9616'},
[4601]={[0]='The Sparklematic 5200!',[1]='B504956 K0300 L025 A:1175084 T:1175084'},
[4602]={[0]='The Sparklematic 5200!',[1]='B504956 K0300 L025 A:1175085 T:1175085'},
[4603]={[0]='More Sparklematic Action',[1]='B0 K0300 ++ L025 A:1175084 T:1175084'},
[4604]={[0]='More Sparklematic Action',[1]='B0 K0300 ++ L025 A:1175085 T:1175085'},
[4605]={[0]='The Sparklematic 5200!',[1]='B0 K0300 L025 A:1175084 T:1175084'},
[4606]={[0]='The Sparklematic 5200!',[1]='B0 K0300 L025 A:1175085 T:1175085'},
[4621]={[0]='Avast Ye, Admiral!',[1]='B37 K0600 L055 A:2546 T:2546 O:1036 P:1'},
[4970]={[0]='Frostsaber Provisions',[1]='B0 K0600 FA ++ L058 A:10618 T:10618'},
[5041]={[0]='Supplies for the Crossroads',[1]='B11 K0120 FH L009 A:3429,34258 T:3429,34258'},
[5201]={[0]='Winterfall Intrusion',[1]='B0 FA ++ K0600 L058 A:10618 T:10618'},
[5421]={[0]='Fish in a Bucket',[1]='B0 K0340 FH ++ L030 A:11317 T:11317'},
[5501]={[0]='Bone Collector',[1]='B0 K0320 L029 A:11438 T:11438'},
[5502]={[0]='A Warden of the Horde',[1]='B0 HC FH L010 A:4 T:14451 P:915+14441'},
[5534]={[0]="Kim'jael's \"Missing\" Equipment",[1]='B0 K0530 L047 A:8420 T:8420'},
[5535]={[0]='Spiritual Unrest',[1]='B0 K0470 L045 A:11548 T:11548'},
[5536]={[0]='A Land Filled with Hatred',[1]='B0 K0470 L045 A:11548 T:11548'},
[5545]={[0]='A Bundle of Trouble',[1]='B0 K0100 FA L007 A:10616 T:10616'},
[5561]={[0]='Kodo Roundup',[1]='B0 K0340 L030 A:11596 T:11596'},
[5581]={[0]='Portals of the Legion',[1]='B0 K0350 FH L031 A:5395 T:5395,11624'},
[5713]={[0]='One Shot.  One Kill.',[1]='B42 FA K0150 L010 A:11711 T:11806'},
--[5741]={[0]='Sceptre of Light',[1]='K0330 L030 A:11863 T:11863'},
[5805]={[0]='Welcome!',[1]='B0 K0010 A:100014646'},
[5821]={[0]='Bodyguard for Hire',[1]='B0 K0330 L028 A:11625 T:11596'}, -- once caravan moves quest cannot be obtained.  how to detect this?
[5843]={[0]='Welcome!',[1]='B0 K0010 FH A:100014649 T:11943'},
[5882]={[0]='Salve via Hunting',[1]='B0 K0550 FH L048 A:9529 T:9529'},
[5883]={[0]='Salve via Mining',[1]='B0 K0550 FH L048 A:9529 T:9529'},
[5884]={[0]='Salve via Gathering',[1]='B0 K0550 FH L048 A:9529 T:9529'},
[5885]={[0]='Salve via Skinning',[1]='B0 K0550 FH L048 A:9529 T:9529'},
[5886]={[0]='Salve via Disenchanting',[1]='B0 K0550 FH L048 A:9529 T:9529'},
[5887]={[0]='Salve via Hunting',[1]='B0 K0550 FH L048 A:9529 T:9529 P:5882'},
[5888]={[0]='Salve via Mining',[1]='B0 K0550 FH L048 A:9529 T:9529 P:5883'},
[5889]={[0]='Salve via Gathering',[1]='B0 K0550 FH L048 A:9529 T:9529 P:5884'},
[5890]={[0]='Salve via Skinning',[1]='B0 K0550 FH L048 A:9529 T:9529 P:5885'},
[5891]={[0]='Salve via Disenchanting',[1]='B0 K0550 FH L048 A:9529 T:9529 P:5886'},
[5892]={[0]='Irondeep Supplies',[1]='B0 FA L051 A:12096 T:12096'},
[5893]={[0]='Coldtooth Supplies',[1]='B0 FH L051 A:12097 T:12097'},
[5926]={[0]='Heeding the Call',[1]='B0 FH CD L010 A:3064 T:3033 I:5927,5928'},
[5927]={[0]='Heeding the Call',[1]='B0 FH CD L010 A:6929 T:3033 I:5926,5928'},
[5928]={[0]='Heeding the Call',[1]='B0 FH CD L010 A:16655 T:3033 I:5926,5927'},
[5943]={[0]='Gizelton Caravan',[1]='B0 K0350 L029 A:11626 T:11596'}, -- once caravan moves quest cannot be obtained.  how to detect this?
[5981]={[0]='Rampaging Giants',[1]='B0 K0600 FA ++ L058 A:10618 T:10618'},
--[6027]={[0]='Book of the Ancients',[1]='K0380 L030 A:11863 T:11863 P:5741'},
[6031]={[0]='Runecloth',[1]='B182 K0550 L050 A:11557 T:11557'},
[6032]={[0]='Sacred Cloth',[1]='B0 K0550 L050 A:11557 T:11557'},
[6132]={[0]='Get Me Out of Here!',[1]='B0 K0340 L030 A:12277 T:6019'},
[6134]={[0]='Ghost-o-plasm Round Up',[1]='B0 K0390 L034 A:6019 T:6019'},
[6142]={[0]='Clam Bait',[1]='B0 K0350 FH L031 A:12031 T:12031'},
[6143]={[0]='Other Fish to Fry',[1]='B0 K0360 FH L032 A:12340 T:12340'},
[6321]={[0]='Supplying Brill',[1]='B0 K0070 FH RU RL L005 A:1745 T:43124'},
[6322]={[0]='Michael Garrett',[1]='B0 K0070 FH RU RL L005 A:4556 T:4551 P:6323'},
[6323]={[0]='Ride to the Undercity',[1]='B0 K0070 FH RU RL L005 A:43124 T:4556 P:6321'},
[6324]={[0]='Return to Morris',[1]='B0 K0070 FH RU RL L005 A:4551 T:1745 P:6322'},
[6341]={[0]='To Darnassus',[1]='B0 FA RE K0070 L005 A:40553 T:7316 P:6344'},
[6342]={[0]='An Unexpected Gift',[1]='B0 FA RE K0070 L005 A:7316 T:40552 P:6341'},
[6343]={[0]='Return to Nyoma',[1]='B0 FA RE K0070 L005 A:40552 T:4265 P:6342'},
[6344]={[0]='Reminders of Home',[1]='B0 FA RE K0070 L005 A:4265 T:40553'},
[6361]={[0]='A Bundle of Hides',[1]='B0 K0070 FH RT RB L005 A:3079 T:40809'},
[6362]={[0]='Ride to Thunder Bluff',[1]='B0 K0070 FH RT RB L005 A:40809 T:8359 P:6361'},
[6363]={[0]='Tal the Wind Rider Master',[1]='B0 K0070 FH RT RB L005 A:8359 T:2995 P:6362'},
[6364]={[0]='Return to Varg',[1]='B0 K0070 FH RT RB L005 A:2995 T:3079 P:6363'},
[6365]={[0]='Meats to Orgrimmar',[1]='B0 K0070 FH RO RT RL L005 A:3489,3881 T:3615,41140'},
[6384]={[0]='Ride to Orgrimmar',[1]='B0 K0070 FH RO RT RL L005 A:3615,41140 T:6929 P:6365'},
[6385]={[0]='Doras the Wind Rider Master',[1]='B0 K0070 FH RO RT RL L005 A:6929 T:3310 P:6384'},
[6386]={[0]='Return to Razor Hill',[1]='B0 K0070 FH RO RT RL L005 A:3310 T:3881 P:6385'},
[6387]={[0]='Honor Students',[1]='B0 K0070 FA RF RN L005 A:1681 T:1572'},
[6388]={[0]='Gryth Thurden',[1]='B0 K0070 FA RF RN L005 A:4256 T:1573 P:6391'},
[6391]={[0]='Ride to Ironforge',[1]='B0 K0070 FA RF RN L005 A:1572 T:4256 P:6387'},
[6392]={[0]='Return to Gremlock',[1]='B0 K0070 FA RF RN L005 A:1573 T:1681 P:6388'},
[6441]={[0]='Satyr Horns',[1]='B43 K0220 FH L019 A:12724 T:12724'},
[6442]={[0]='Naga at the Zoram Strand',[1]='B43 K0190 FH L014 A:12719 T:12719'},
[6462]={[0]='Troll Charm',[1]='B43 K0230 FH L021 A:12721 T:12721'},
[6482]={[0]='Freedom to Ruul',[1]='B43 K0240 FH L019 A:12818 T:12837'},
[6503]={[0]='Ashenvale Outrunners',[1]='B43 K0210 FH L019 A:12867 T:12867'},
[6504]={[0]='The Lost Pages',[1]='B43 K0300 FH L023 A:12718 T:12718'},
[6543]={[0]='The Warsong Reports',[1]='B0 K0190 FH L017 A:8582 T:8582'},
[6544]={[0]="Torek's Assault",[1]='B43 K0240 FH L020 A:12858 T:12877'},
[6545]={[0]='Warsong Runner Update',[1]='B0 K0190 FH ++ L017 A:12863 T:12863'},
[6546]={[0]='Warsong Outrider Update',[1]='B0 K0250 FH ++ L017 A:12864 T:12864'},
[6547]={[0]='Warsong Scout Update',[1]='B0 K0210 FH ++ L017 A:12862 T:12862'},
[6563]={[0]="The Essence of Aku'Mai",[1]='B0 K0220 FH L017 A:12736 T:12736'},
[6607]={[0]='Nat Pagle, Angler Extreme',[1]='B0 K0450 L034 A:12919 T:12919 PF225 O:6608,6609'},
--[6608]={[0]='You Too Good.',[1]='K0450 FH L034 A:3332 T:12919 PF225 I:6607'},
--[6609]={[0]="I Got Nothin' Left!",[1]='K0450 FA L034 A:5161 T:12919 PF225 I:6607'},
[6610]={[0]='Clamlette Surprise',[1]='B0 K0450 L035 A:40589 T:40589 O:6611,6612'},
[6611]={[0]='To Gadgetzan You Go!',[1]='B0 K0450 FH L035 A:3399 T:40589 I:6610'},
[6612]={[0]='I Know A Guy...',[1]='B0 K0450 FA L035 A:5159 T:40589 I:6610'},
[6621]={[0]='King of the Foulweald',[1]='B43 K0250 FH L023 A:12696,12757 T:12696,12757 P:13967'},
[6622]={[0]='Triage',[1]='B0 FH K0850 L035 A:12920 T:12920 P+225 O:6623'},
[6623]={[0]='Horde Trauma',[1]='B0 K0450 FH L035 A:45540 T:12920 P+225 I:6622'},
[6624]={[0]='Triage',[1]='B0 FA K0850 L035 A:12939 T:12939 P+225 O:6625'},
[6625]={[0]='Alliance Trauma',[1]='B0 K0450 FA L035 A:5150 T:12939 P+225 I:6624'},
[6641]={[0]='Vorsha the Lasher',[1]='B43 K0230 FH L019 A:12717 T:12863'},
[6642]={[0]='Favor Amongst the Brotherhood, Dark Iron Ore',[1]='B0 K0600 ++ L060 A:12944 T:12944'},
[6643]={[0]='Favor Amongst the Brotherhood, Fiery Core',[1]='B0 K0600 ++ L060 A:12944 T:12944'},
[6644]={[0]='Favor Amongst the Brotherhood, Lava Core',[1]='B0 K0600 ++ L060 A:12944 T:12944'},
[6645]={[0]='Favor Amongst the Brotherhood, Core Leather',[1]='B0 K0600 ++ L060 A:12944 T:12944'},
[6646]={[0]='Favor Amongst the Brotherhood, Blood of the Mountain',[1]='B0 K0600 ++ L060 A:12944 T:12944'},
[6661]={[0]='Deeprun Rat Roundup',[1]='B0 FA K0120 L010 A:12997 T:12997'},
[6662]={[0]='Me Brother, Nipsy',[1]='B0 K0120 FA L010 A:12997 T:13018 P:6661'},
--[6701]={[0]='Syndicate Emblems',[1]='B0 K0600 FH CR ++ L024 A:6766 T:6766'},
[6741]={[0]='More Booty!',[1]='B0 FH ++ L051 A:13176 T:13176'},
[6781]={[0]='More Armor Scraps',[1]='B0 FA ++ L051 A:13257 T:13257'},
[6801]={[0]='Lokholar the Ice Lord',[1]='B0 FH ++ L051 A:13236 T:13236'},
[6805]={[0]='Stormers and Rumblers',[1]='B0 K0570 L055 A:13278 T:13278'},
--[6824]={[0]='Hands of the Enemy',[1]='K0600 FH L055 A:13278 T:13278 P:6823'},
[6825]={[0]="Call of Air - Guse's Fleet",[1]='B0 FH ++ L051 A:13179 T:13179'},
[6826]={[0]="Call of Air - Jeztor's Fleet",[1]='B0 FH ++ L051 A:13180 T:13180'},
[6827]={[0]="Call of Air - Mulverick's Fleet",[1]='B0 FH ++ L051 A:13181 T:13181'},
[6881]={[0]='Ivus the Forest Lord',[1]='B0 FA ++ L051 A:13442 T:13442'},
[6922]={[0]='Baron Aquanis',[1]='B0 K0300 FH L021 A:100016782 T:12736'},
[6941]={[0]="Call of Air - Vipore's Fleet",[1]='B0 FA ++ L051 A:13439 T:13439'},
[6942]={[0]="Call of Air - Slidore's Fleet",[1]='B0 FA ++ L051 A:13438 T:13438'},
[6943]={[0]="Call of Air - Ichman's Fleet",[1]='B0 FA ++ L051 A:13437 T:13437'},
[6961]={[0]='Great-father Winter is Here!',[1]='B0 FH HV L010 A:13418 T:13445'},
[6962]={[0]='Treats for Great-father Winter',[1]='B0 FH HV L010 A:13445 T:13445'},
[6963]={[0]='Stolen Winter Veil Treats',[1]='B0 HV FH L030 A:13418 T:13636'},
[6964]={[0]='The Reason for the Season',[1]='B0 HV FH L010 A:9550 T:13417'},
[6982]={[0]='Coldtooth Supplies',[1]='B0 FA L051 A:12096 T:12096'},
[6983]={[0]="You're a Mean One...",[1]='B0 HV FH L030 A:13636 T:13418 P:6963'},
[6984]={[0]="A Smokywood Pastures' Thank You!",[1]='B0 HV FH L030 A:13418 T:13445 P:6983'},
[6985]={[0]='Irondeep Supplies',[1]='B0 FH ++ L051 A:12097 T:12097'},
[7001]={[0]='Empty Stables',[1]='B0 FH ++ L051 A:13616 T:13616'},
[7021]={[0]='Great-father Winter is Here!',[1]='B0 FH HV L010 A:13431 T:13445'},
[7022]={[0]='Greatfather Winter is Here!',[1]='B0 FA HV L010 A:13433 T:13444'},
[7023]={[0]='Greatfather Winter is Here!',[1]='B0 FA HV L010 A:13435,23010 T:13444'},
[7024]={[0]='Great-father Winter is Here!',[1]='B0 FH HV L010 A:13429 T:13445'},
[7025]={[0]='Treats for Greatfather Winter',[1]='B0 FA HV L010 A:13444 T:13444'},
[7027]={[0]='Empty Stables',[1]='B0 FA ++ L051 A:13617 T:13617'},
[7042]={[0]='Stolen Winter Veil Treats',[1]='B0 HV FA L030 A:13434 T:13636'},
[7043]={[0]="You're a Mean One...",[1]='B0 HV FA L030 A:13636 T:13433 P:7042'},
[7045]={[0]="A Smokywood Pastures' Thank You!",[1]='B0 HV FA L030 A:13433 T:13444 P:7043'},
[7061]={[0]='The Feast of Winter Veil',[1]='B0 HV FH L010 A:13417 T:3057 P:6964'},
[7062]={[0]='The Reason for the Season',[1]='B0 HV FA L010 A:1365 T:2916'},
[7063]={[0]='The Feast of Winter Veil',[1]='B0 HV FA L010 A:2916 T:42928 P:7062'},
[7081]={[0]='Alterac Valley Graveyards',[1]='B0 FA K0600 L051 A:13777 T:13777'},
[7082]={[0]='The Graveyards of Alterac',[1]='B0 FH K0600 L051 A:13776 T:13776'},
[7101]={[0]='Towers and Bunkers',[1]='B0 FH K0600 L051 A:13776 T:13776'},
[7102]={[0]='Towers and Bunkers',[1]='B0 FA K0600 L051 A:13777 T:13777'},
[7121]={[0]='The Quartermaster',[1]='B0 FA L051 A:13797 T:12096'},
[7122]={[0]='Capture a Mine',[1]='B0 FA K0600 L051 A:13777 T:13777'},
[7123]={[0]='Speak with our Quartermaster',[1]='B0 FH L051 A:13798 T:12097'},
[7124]={[0]='Capture a Mine',[1]='B0 FH K0600 L051 A:12097,13776 T:13776'},
[7141]={[0]='The Battle of Alterac',[1]='B0 FA K0600 L051 A:13816 T:13816'},
[7142]={[0]='The Battle for Alterac',[1]='B0 FH K0600 L051 A:13817 T:13817'},
[7161]={[0]='Proving Grounds',[1]='B0 FH K0600 L051 A:13840 T:13840'},
[7162]={[0]='Proving Grounds',[1]='B0 FA K0600 L051 A:13841 T:13841'},
[7163]={[0]='Rise and Be Recognized',[1]='B0 FH K0600 L051 A:13840 T:13840 P:7161 V1744999'},
[7164]={[0]='Honored Amongst the Clan',[1]='B0 FH K0600 L051 A:13840 T:13840 P:7163 V1750999'},
[7165]={[0]='Earned Reverence',[1]='B0 FH K0600 L051 A:13840 T:13840 P:7164 V1762999'},
[7166]={[0]='Legendary Heroes',[1]='B0 FH K0600 L051 A:13840 T:13840 P:7165 V1783999'},
[7167]={[0]='The Eye of Command',[1]='B0 FH K0600 L051 A:13840 T:13840 P:7166 V1784998'},
[7168]={[0]='Rise and Be Recognized',[1]='B0 FA K0600 L051 A:13841 T:13841 P:7162 V1544999'},
[7169]={[0]='Honored Amongst the Guard',[1]='B0 FA K0600 L051 A:13841 T:13841 P:7168 V1550999'},
[7170]={[0]='Earned Reverence',[1]='B0 FA K0600 L051 A:13841 T:13841 P:7169 V1562999'},
[7171]={[0]='Legendary Heroes',[1]='B0 FA K0600 L051 A:13841 T:13841 P:7170 V1583999'},
[7172]={[0]='The Eye of Command',[1]='B0 FA K0600 L051 A:13841 T:13841 P:7171 V1584998'},
[7223]={[0]='Armor Scraps',[1]='B0 FA L051 A:13257 T:13257'},
[7224]={[0]='Enemy Booty',[1]='B0 FH L051 A:13176 T:13176'},
[7383]={[0]='Teldrassil: The Burden of the Kaldorei',[1]='B0 FA K0090 A:3515 T:503515 P:918+919'},
[7385]={[0]='A Gallon of Blood',[1]='B0 FH ++ L051 A:13236 T:13236'},
[7386]={[0]='Crystal Cluster',[1]='B0 FA ++ L051 A:13442 T:13442'},
[7486]={[0]="A Hero's Reward",[1]='B0 K0600 FH L055 A:13278 T:1179551'},
[7493]={[0]='The Journey Has Just Begun',[1]='B0 K0600 FH PL001 L060 A:14392 T:14392 P:24429'},
[7497]={[0]='The Journey Has Just Begun',[1]='B0 K0600 FA PL001 L060 A:14394 T:14394 P:24428'},
[7498]={[0]='Garona: A Study on Stealth and Treachery',[1]='B504956 K0600 L054 A:100018356 T:14383'},
[7499]={[0]='Codex of Defense',[1]='B504956 K0600 L054 A:100018357 T:14383'},
[7500]={[0]="The Arcanist's Cookbook",[1]='B0 K0600 L054 A:100018358 T:14383'},
[7501]={[0]='The Light and How To Swing It',[1]='B504956 K0600 CP L054 A:100018359 T:14382'},
[7502]={[0]='Harnessing Shadows',[1]='B504956 K0600 FH CL L054 A:100018360 T:14382'},
[7503]={[0]='The Greatest Race of Hunters',[1]='B504956 K0600 L054 A:100018361 T:14382'},
[7504]={[0]="Holy Bologna: What the Light Won't Tell You",[1]='B0 K0600 FH CT L054 A:100018362 T:14381'},
[7505]={[0]='Frost Shock and You',[1]='B0 K0600 L054 A:100018363'},
[7506]={[0]='The Emerald Dream...',[1]='B0 K0600 FA L054 A:100018364 T:14381'},
[7604]={[0]='A Binding Contract',[1]='B504956 K0600 L060 A:100018628 T:12944'},
[7649]={[0]='Enchanted Thorium Platemail: Volume I',[1]='B0 K0350 A:100018769 T:14368'},
[7650]={[0]='Enchanted Thorium Platemail: Volume II',[1]='B0 K0350 A:100018770 T:14368'},
[7651]={[0]='Enchanted Thorium Platemail: Volume III',[1]='B0 K0350 A:100018771 T:14368'},
--[7660]={[0]='Wolf Swapping - Arctic Wolf',[1]='B0 K0010 FH ++ L060 A:3362 T:3362'},
--[7661]={[0]='Wolf Swapping - Red Wolf',[1]='B0 K0010 FH ++ L060 A:3362 T:3362'},
--[7662]={[0]='New Kodo - Teal',[1]='B0 K0010 FH ++ L060 A:3685 T:3685'},
--[7663]={[0]='New Kodo - Green',[1]='B0 K0010 FH ++ L060 A:3685 T:3685'},
--[7664]={[0]='Ivory Raptor Replacement',[1]='B0 K0010 FH ++ L060 A:7952 T:7952'},
--[7665]={[0]='Red Raptor Replacement',[1]='B0 K0010 FH ++ L060 A:7952 T:7952'},
--[7671]={[0]='Frostsaber Replacement',[1]='B0 K0010 ++ L060 A:4730 T:4730'},
--[7672]={[0]='Nightsaber Replacement',[1]='B0 K0010 ++ L060 A:4730 T:4730'},
--[7673]={[0]='Frost Ram Exchange',[1]='B0 K0010 FA L060 A:1261 T:1261'},
--[7674]={[0]='Black Ram Exchange',[1]='B0 K0010 FA L060 A:1261 T:1261'},
--[7675]={[0]='Icy Blue Mechanostrider Replacement',[1]='B0 K0300 FA L030 A:7955 T:7955'},
--[7676]={[0]='White Mechanostrider Replacement',[1]='B0 K0300 FA L030 A:7955 T:7955'},
--[7677]={[0]='White Stallion Exchange',[1]='K0010 FA ++ L060 A:384 T:384'},
--[7678]={[0]='Palomino Exchange',[1]='K0010 FA ++ L060 A:384 T:384'},
[7737]={[0]='Gaining Even More Acceptance',[1]='B0 K0500 ++ L046 A:14624 T:14624 P:28064 W7583999'},
[7761]={[0]="Blackhand's Command",[1]='B504956 K0600 L055 A:100018987 T:1179880'},
[7781]={[0]='The Lord of Blackrock',[1]='B0 K0600 FA L060 A:100019003 T:29611'},
[7782]={[0]='The Lord of Blackrock',[1]='B0 K0600 FA L060 A:29611 T:14721 P:7781'},
[7783]={[0]='The Lord of Blackrock',[1]='B0 K0600 FH L060 A:100019002 T:39605,45530'},
[7784]={[0]='The Lord of Blackrock',[1]='B0 K0600 FH L060 A:4949 T:14392 P:7783'},
[7785]={[0]='Examine the Vessel',[1]='B0 K0600 L060 A:100019016 T:14347'},
[7786]={[0]='Thunderaan the Windseeker',[1]='B0 K0600 L060 A:14347 T:14347 P:7785'},
[7787]={[0]='Rise, Thunderfury!',[1]='B0 K0600 L060 A:100019018 T:14347'},
[7810]={[0]='Arena Master',[1]='B0 K001256 A:100018706 T:14508'},
[7838]={[0]='Arena Grandmaster',[1]='B37 K0550 ++ A:14508 T:14508'},
[7848]={[0]='Attunement to the Core',[1]='B0 K0600 L055 A:14387 T:14387'},
[7863]={[0]='Sentinel Basic Care Package',[1]='B43 K0340 FA L025 A:14753 T:14753 V1444999'},
[7865]={[0]='Sentinel Advanced Care Package',[1]='B43 K0700 FA L045 A:14753 T:14753 V1444999'},
[7866]={[0]='Outrider Basic Care Package',[1]='B0 K0340 FH L025 A:14754 T:14754'},
[7868]={[0]='Outrider Advanced Care Package',[1]='B0 K0700 FH L045 A:14754 T:14754'},
--[7881]={[0]='Carnival Boots',[1]='B0 HF A:14833 T:14833'},
--[7882]={[0]='Carnival Jerkins',[1]='B0 HF FH L010 A:14833 T:14833'},
--[7883]={[0]="The World's Largest Gnome!",[1]='B0 HF L020 A:14833 T:14833'},
--[7884]={[0]='Crocolisk Boy and the Bearded Murloc',[1]='B0 HF L030 A:14833 T:14833'},
--[7885]={[0]='Armor Kits',[1]='B0 HF ++ L040 A:14833 T:14833'},
--[7889]={[0]='Coarse Weightstone',[1]='B0 HF A:14832 T:14832'},
--[7890]={[0]='Heavy Grinding Stone',[1]='B0 HF L010 A:14832 T:14832'},
--[7891]={[0]='Green Iron Bracers',[1]='B0 HF L020 A:14832 T:14832'},
--[7892]={[0]='Big Black Mace',[1]='B0 HF ++ L030 A:14832 T:14832'},
--[7893]={[0]='Rituals of Strength',[1]='B0 HF L040 A:14832 T:14832'},
--[7894]={[0]='Copper Modulator',[1]='B0 HF A:14841 T:14841'},
--[7895]={[0]='Whirring Bronze Gizmo',[1]='B0 HF L010 A:14841 T:14841'},
--[7896]={[0]='Green Fireworks',[1]='B0 HF L020 A:14841 T:14841'},
--[7897]={[0]='Mechanical Repair Kits',[1]='B0 HF L030 A:14841 T:14841'},
--[7898]={[0]='Thorium Widget',[1]='B0 HF L040 A:14841 T:14841'},
--[7899]={[0]='Small Furry Paws',[1]='B0 HF A:14829 T:14829'},
--[7900]={[0]='Torn Bear Pelts',[1]='B0 HF L010 A:14829 T:14829'},
--[7901]={[0]='Soft Bushy Tails',[1]='B0 HF L020 A:14829 T:14829'},
--[7902]={[0]='Vibrant Plumes',[1]='B0 HF L030 A:14829 T:14829'},
--[7903]={[0]='Evil Bat Eyes',[1]='B0 HF L040 A:14829 T:14829'},
[7905]={[0]='The Darkmoon Faire',[1]='B0 HF FA L006 A:54334 T:14828'},
[7907]={[0]='Darkmoon Beast Deck',[1]='B0 A:100019228 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[7926]={[0]='The Darkmoon Faire',[1]='HF B0 L006 A:55382 T:14828'},
[7927]={[0]='Darkmoon Portals Deck',[1]='B0 A:100019277 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[7928]={[0]='Darkmoon Warlords Deck',[1]='B0 A:100019257 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[7929]={[0]='Darkmoon Elementals Deck',[1]='B0 A:100019267 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
--[7930]={[0]='5 Tickets - Darkmoon Flower',[1]='B0 HF L006 A:14828 T:14828'},
--[7931]={[0]='5 Tickets - Minor Darkmoon Prize',[1]='B0 HF L015 A:14828 T:14828'},
--[7932]={[0]='12 Tickets - Lesser Darkmoon Prize',[1]='B0 HF L030 A:14828 T:14828'},
--[7933]={[0]='40 Tickets - Greater Darkmoon Prize',[1]='B0 HF L045 A:14828 T:14828'},
--[7934]={[0]='50 Tickets - Darkmoon Storage Box',[1]='B0 HF L006 A:14828 T:14828'},
--[7935]={[0]="10 Tickets - Last Month's Mutton",[1]='B0 HF L025 A:14828 T:14828'},
--[7936]={[0]="50 Tickets - Last Year's Mutton",[1]='B0 HF L045 A:14828 T:14828'},
--[7937]={[0]='Your Fortune Awaits You...',[1]='B0 HF L010 A:100019423 T:1180025'},
--[7938]={[0]='Your Fortune Awaits You...',[1]='B0 HF L010 A:100019424'},
--[7939]={[0]='More Dense Grinding Stones',[1]='B0 HF ++ L040 A:14832 T:14832'},
--[7940]={[0]='1200 Tickets - Orb of the Darkmoon',[1]='B0 HF L055 A:14828 T:14828'},
--[7941]={[0]='More Armor Kits',[1]='B0 HF ++ L040 A:14833 T:14833'},
--[7942]={[0]='More Thorium Widgets',[1]='B0 HF ++ L040 A:14841 T:14841'},
--[7943]={[0]='More Bat Eyes',[1]='B0 HF ++ L040 A:14829 T:14829'},
--[7944]={[0]='Your Fortune Awaits You...',[1]='B0 HF L010 A:100019443 T:1180055'},
--[7945]={[0]='Your Fortune Awaits You...',[1]='B0 HF L010 A:100019452 T:1180056'},
[7946]={[0]='Spawn of Jubjub',[1]='B0 HF SP ++ A:14871 T:14871'},
--[7981]={[0]='1200 Tickets - Amulet of the Darkmoon',[1]='B0 HF L055 A:14828 T:14828'},
[8041]={[0]='Strength of Mount Mugamba',[1]='B0 K0600 L058 A:14902 T:14902'},
[8042]={[0]='Strength of Mount Mugamba',[1]='B0 K0600 L058 A:14902 T:14902'},
[8043]={[0]='Strength of Mount Mugamba',[1]='B0 K0600 L058 A:14902 T:14902'},
[8044]={[0]='The Rage of Mugamba',[1]='B0 K0600 L058 A:14902 T:14902'},
[8045]={[0]="The Heathen's Brand",[1]='B0 K0600 L058 A:14902 T:14902'},
[8046]={[0]="The Heathen's Brand",[1]='B0 K0600 L058 A:14902 T:14902'},
[8047]={[0]="The Heathen's Brand",[1]='B0 K0600 L058 A:14902 T:14902'},
[8048]={[0]="The Hero's Brand",[1]='B0 K0600 L058 A:14902 T:14902'},
[8049]={[0]='The Eye of Zuldazar',[1]='B0 K0600 L058 A:14903 T:14903'},
[8050]={[0]='The Eye of Zuldazar',[1]='B0 K0600 L058 A:14903 T:14903'},
[8051]={[0]='The Eye of Zuldazar',[1]='B0 K0600 L058 A:14903 T:14903'},
[8052]={[0]='The All-Seeing Eye of Zuldazar',[1]='B0 K0600 L058 A:14903 T:14903'},
[8053]={[0]="Paragons of Power: The Freethinker's Armguards",[1]='B0 K0600 L058 A:14902 T:14902'},
[8054]={[0]="Paragons of Power: The Freethinker's Belt",[1]='B0 K0600 L058 A:14902 T:14902'},
[8055]={[0]="Paragons of Power: The Freethinker's Breastplate",[1]='B0 K0600 L058 A:14902 T:14902'},
[8056]={[0]="Paragons of Power: The Augur's Bracers",[1]='B0 K0600 L058 A:14904 T:14904'},
[8057]={[0]="Paragons of Power: The Haruspex's Bracers",[1]='B0 K0600 L058 A:14904 T:14904'},
[8058]={[0]="Paragons of Power: The Vindicator's Armguards",[1]='B0 K0600 FH L058 A:14902 T:14902'},
[8059]={[0]="Paragons of Power: The Demoniac's Wraps",[1]='B0 K0600 L058 A:14903 T:14903'},
[8060]={[0]="Paragons of Power: The Illusionist's Wraps",[1]='B0 K0600 L058 A:14903 T:14903'},
[8061]={[0]="Paragons of Power: The Confessor's Wraps",[1]='B0 K0600 L058 A:14903 T:14903'},
[8062]={[0]="Paragons of Power: The Predator's Bracers",[1]='B0 K0600 L058 A:14905 T:14905'},
[8064]={[0]="Paragons of Power: The Haruspex's Belt",[1]='B0 K0600 L058 A:14904 T:14904'},
[8065]={[0]="Paragons of Power: The Haruspex's Tunic",[1]='B0 K0600 L058 A:14904 T:14904'},
[8066]={[0]="Paragons of Power: The Predator's Belt",[1]='B0 K0600 L058 A:14905 T:14905'},
[8067]={[0]="Paragons of Power: The Predator's Mantle",[1]='B0 K0600 L058 A:14905 T:14905'},
[8068]={[0]="Paragons of Power: The Illusionist's Mantle",[1]='B0 K0600 L058 A:14903 T:14903'},
[8069]={[0]="Paragons of Power: The Illusionist's Robes",[1]='B0 K0600 L058 A:14903'},
[8070]={[0]="Paragons of Power: The Confessor's Bindings",[1]='B0 K0600 L058 A:14903 T:14903'},
[8071]={[0]="Paragons of Power: The Confessor's Mantle",[1]='B0 K0600 L058 A:14903 T:14903'},
[8073]={[0]="Paragons of Power: The Madcap's Tunic",[1]='B0 K0600 L058 A:14905 T:14905'},
[8074]={[0]="Paragons of Power: The Augur's Belt",[1]='B0 K0600 L058 A:14904 T:14904'},
[8075]={[0]="Paragons of Power: The Augur's Hauberk",[1]='B0 K0600 L058 A:14904 T:14904'},
[8076]={[0]="Paragons of Power: The Demoniac's Mantle",[1]='B0 K0600 L058 A:14903 T:14903'},
[8077]={[0]="Paragons of Power: The Demoniac's Robes",[1]='B0 K0600 L058 A:14903 T:14903'},
[8078]={[0]="Paragons of Power: The Vindicator's Belt",[1]='B0 K0600 L058 A:14902 T:14902'},
[8079]={[0]="Paragons of Power: The Vindicator's Breastplate",[1]='B0 K0600 L058 A:14902 T:14902'},
[8101]={[0]='The Pebble of Kajaro',[1]='B0 K0600 L058 A:14903 T:14903'},
[8102]={[0]='The Pebble of Kajaro',[1]='B0 K0600 L058 A:14903 T:14903'},
[8103]={[0]='The Pebble of Kajaro',[1]='B0 K0600 L058 A:14903 T:14903'},
[8104]={[0]='The Jewel of Kajaro',[1]='B0 K0600 FH L058 A:14903 T:14903'},
[8105]={[0]='The Battle for Arathi Basin!',[1]='B0 K0550 FA L050 A:14983 T:14983'},
[8106]={[0]="Kezan's Taint",[1]='B0 K0600 L058 A:14903 T:14903'},
[8107]={[0]="Kezan's Taint",[1]='B0 K0600 L058 A:14903 T:14903'},
[8108]={[0]="Kezan's Taint",[1]='B0 K0600 L058 A:14903 T:14903'},
[8109]={[0]="Kezan's Unstoppable Taint",[1]='B0 K0600 FH L058 A:14903 T:14903'},
[8110]={[0]='Enchanted South Seas Kelp',[1]='B0 K0600 L058 A:14904 T:14904'},
[8111]={[0]='Enchanted South Seas Kelp',[1]='B0 K0600 L058 A:14904 T:14904'},
[8112]={[0]='Enchanted South Seas Kelp',[1]='B0 K0600 L058 A:14904 T:14904'},
[8113]={[0]='Pristine Enchanted South Seas Kelp',[1]='B0 K0600 L058 A:14904 T:14904'},
[8114]={[0]='Control Four Bases',[1]='B0 K0600 FA L060 A:14983 T:14983'},
[8115]={[0]='Control Five Bases',[1]='B0 K0600 FA L060 A:14983 T:14983'},
[8116]={[0]='Vision of Voodress',[1]='B0 K0600 L058 A:14904 T:14904'},
[8117]={[0]='Vision of Voodress',[1]='B0 K0600 L058 A:14904 T:14904'},
[8118]={[0]='Vision of Voodress',[1]='B0 K0600 L058 A:14904 T:14904'},
[8119]={[0]='The Unmarred Vision of Voodress',[1]='B0 K0600 L058 A:14904 T:14904'},
[8120]={[0]='The Battle for Arathi Basin!',[1]='B0 K0550 FH L050 A:15021 T:15021'},
[8121]={[0]='Take Four Bases',[1]='B0 K0600 FH L060 A:15021 T:15021'},
[8122]={[0]='Take Five Bases',[1]='B0 K0600 FH L060 A:15021 T:15021'},
[8141]={[0]='Zandalarian Shadow Talisman',[1]='B0 K0600 L058 A:14905 T:14905'},
[8142]={[0]='Zandalarian Shadow Talisman',[1]='B0 K0600 L058 A:14905 T:14905'},
[8143]={[0]='Zandalarian Shadow Talisman',[1]='B0 K0600 L058 A:14905 T:14905'},
[8144]={[0]='Zandalarian Shadow Mastery Talisman',[1]='B0 K0600 FH L058 A:14905 T:14905'},
[8145]={[0]="The Maelstrom's Tendril",[1]='B0 K0600 L058 A:14905 T:14905'},
[8146]={[0]="The Maelstrom's Tendril",[1]='B0 K0600 L058 A:14905 T:14905'},
[8147]={[0]="The Maelstrom's Tendril",[1]='B0 K0600 L058 A:14905 T:14905'},
[8148]={[0]="Maelstrom's Wrath",[1]='B0 K0600 L058 A:14905 T:14905'},
[8149]={[0]='Honoring a Hero',[1]='B0 HH FA L030 A:15011 T:15011'},
[8150]={[0]='Honoring a Hero',[1]='B0 HH FH L030 A:15012 T:15012'},
[8166]={[0]='The Battle for Arathi Basin!',[1]='B0 K0450 FA L040 A:14983 T:14983'},
[8167]={[0]='The Battle for Arathi Basin!',[1]='B0 K0350 FA L030 A:14983 T:14983'},
[8168]={[0]='The Battle for Arathi Basin!',[1]='B0 K0250 FA L020 A:14983 T:14983'},
[8169]={[0]='The Battle for Arathi Basin!',[1]='B0 K0450 FH L040 A:15021 T:15021'},
[8170]={[0]='The Battle for Arathi Basin!',[1]='B0 K0350 FH L030 A:15021 T:15021'},
[8171]={[0]='The Battle for Arathi Basin!',[1]='B0 K0250 FH L020 A:15021 T:15021'},
[8183]={[0]='The Heart of Hakkar',[1]='B504956 K0600 L058 A:100019802 T:14875'},
[8184]={[0]='Presence of Might',[1]='B504956 K0600 ++ L058 A:15042 T:15042'},
[8185]={[0]="Syncretist's Sigil",[1]='B504956 K0600 ++ L058 A:15042 T:15042'},
[8186]={[0]="Death's Embrace",[1]='B0 K0600 FH ++ L058 A:15042 T:15042'},
[8187]={[0]="Falcon's Call",[1]='B504956 K0600 ++ L058 A:15042 T:15042'},
[8188]={[0]="Vodouisant's Vigilant Embrace",[1]='B0 K0600 ++ L058 A:15042 T:15042'},
[8189]={[0]='Presence of Sight',[1]='B504956 K0600 ++ L058 A:15042 T:15042'},
[8190]={[0]='Hoodoo Hex',[1]='B0 K0600 FH ++ L058 A:15042 T:15042'},
[8191]={[0]='Prophetic Aura',[1]='B504956 K0600 ++ L058 A:15042 T:15042'},
[8192]={[0]="Animist's Caress",[1]='B504956 K0600 ++ L058 A:15042 T:15042'},
[8193]={[0]='Master Angler',[1]='B0 ++ A:15077 T:15077'},
[8194]={[0]='Apprentice Angler',[1]='B0 ++ A:15078 T:15078'},
[8195]={[0]='Zulian, Razzashi, and Hakkari Coins',[1]='B0 K0600 ++ L058 A:15070 T:15070'},
[8196]={[0]='Essence Mangoes',[1]='B0 K0600 ++ L058 A:14921 T:14921'},
[8201]={[0]='A Collection of Heads',[1]='B0 K0600 L058 A:14910 T:14910'},
[8221]={[0]="Rare Fish - Keefer's Angelfish",[1]='B0 ++ A:15079 T:15079'},
--[8222]={[0]='Glowing Scorpid Blood',[1]='B0 HF L040 A:14829 T:14829'},
--[8223]={[0]='More Glowing Scorpid Blood',[1]='B0 HF FA ++ L040 A:14829 T:14829'},
[8224]={[0]='Rare Fish - Dezian Queenfish',[1]='B0 ++ A:15079 T:15079'},
[8225]={[0]="Rare Fish - Brownell's Blue Striped Racer",[1]='B0 ++ A:15079 T:15079'},
[8227]={[0]="Nat's Measuring Tape",[1]='B504956 K0600 L058 A:1180366 T:12919'},
[8228]={[0]='Could I get a Fishing Flier?',[1]='B0 FH ++ L035 A:15116 T:15116'},
[8229]={[0]='Could I get a Fishing Flier?',[1]='B0 FA ++ L035 A:15119 T:15119'},
[8238]={[0]='Gurubashi, Vilebranch, and Witherbark Coins',[1]='B0 K0600 ++ L058 A:15070 T:15070'},
[8239]={[0]='Sandfury, Skullsplitter, and Bloodscalp Coins',[1]='B0 K0600 ++ L058 A:15070 T:15070'},
[8240]={[0]='A Bijou for Zanza',[1]='B0 K0600 L058 A:15070 T:15070'},
[8243]={[0]="Zanza's Potent Potables",[1]='B0 K0600 ++ L058 A:14921 T:14921'},
[8246]={[0]='Signets of the Zandalar',[1]='B0 K0600 ++ L058 A:14921 T:14921'},
[8249]={[0]='Junkboxes Needed',[1]='B0 K0600 ++ L050 A:6707 T:6707'},
[8262]={[0]='Arathor Advanced Care Package',[1]='B0 K0700 FA L045 A:15127 T:15127'},
[8265]={[0]="Defiler's Advanced Care Package",[1]='B0 K0700 FH L045 A:15126 T:15126'},
[8271]={[0]='Hero of the Stormpike',[1]='B0 FA K0600 L051 A:13816 T:13816 P:7141'},
[8272]={[0]='Hero of the Frostwolf',[1]='B0 FH K0600 L051 A:13817 T:13817 P:7142'},
[8277]={[0]='Deadly Desert Venom',[1]='B261 K0550 L054 A:15189 T:15189'},
[8278]={[0]="Noggle's Last Hope",[1]='B261 K0560 L054 A:15189 T:15189'},
[8279]={[0]='The Twilight Lexicon',[1]='B261 K0560 L054 A:15194 T:15194 P:8285'},
[8280]={[0]='Securing the Supply Lines',[1]='B261 K0550 L054 A:15191 T:15191 P:28527,28528,28856,28859'},
[8281]={[0]='Stepping Up Security',[1]='B261 K0560 L054 A:15191 T:15191 P:8280'},
[8282]={[0]="Noggle's Lost Satchel",[1]='B261 K0560 L054 A:15190 T:15190'},
[8283]={[0]='Wanted - Deathclasp, Terror of the Sands',[1]='B261 K0560 L054 A:1180448 T:15182'},
[8284]={[0]='The Twilight Mystery',[1]='B261 K0560 L054 A:15183 T:15183'},
[8285]={[0]='The Deserter',[1]='B261 K0560 L054 A:15183 T:15194 P:8284'},
[8287]={[0]='A Terrible Purpose',[1]='B261 K0560 L054 A:15194 T:15181 P:8279'},
[8304]={[0]='Dearest Natalia',[1]='B261 K0560 L054 A:15181 T:15181'},
[8306]={[0]='Into The Maw of Madness',[1]='B261 K0560 L054 A:15181 T:15181 P:8304'},
[8307]={[0]='Desert Recipe',[1]='B0 K0560 L054 A:15174 T:1180503'},
[8308]={[0]="Brann Bronzebeard's Lost Letter",[1]='B261 K0560 L054 A:100020461 T:15170'},
[8309]={[0]='Glyph Chasing',[1]='B261 K0560 L054 A:15170 T:15170'},
[8310]={[0]='Breaking the Code',[1]='B261 K0560 L054 A:15171 T:15171'},
[8311]={[0]="Hallow's End Treats for Jesper!",[1]='B0 HW FA K0000 L010 A:15310 T:15310 I:8312'},
[8312]={[0]="Hallow's End Treats for Spoops!",[1]='B0 HW FH K0000 L010 A:15309 T:15309 I:8311'},
[8313]={[0]='Sharing the Knowledge',[1]='B0 K0560 L054 A:1180503 T:15174 P:8307'},
[8314]={[0]='Unraveling the Mystery',[1]='B261 K0560 L054 A:15170 T:15183'},
[8315]={[0]='The Calling',[1]='B261 K0560 L054 A:15183 T:15183 P:8314'},
[8316]={[0]='Armaments of War',[1]='B261 K0560 CW L054 A:15183 T:15183'},
[8317]={[0]='Kitchen Assistance',[1]='B0 K0560 L054 A:15174 T:15174 P:8313'},
[8318]={[0]='Secret Communication',[1]='B261 K0560 L054 A:15306 T:15306'},
[8319]={[0]='Encrypted Twilight Texts',[1]='B0 K0560 ++ L054 A:15306 T:15306'},
[8320]={[0]='Twilight Geolords',[1]='B261 K0560 L054 A:15270 T:15270'},
[8321]={[0]='Vyral the Vile',[1]='B261 K0560 L054 A:15270 T:15270 P:8320'},
[8323]={[0]='True Believers',[1]='B261 K0560 L054 A:15194 T:15194'},
[8324]={[0]='Still Believing',[1]='B0 K0560 ++ L054 A:15194 T:15194'},
[8325]={[0]='Reclaiming Sunstrider Isle',[1]='B0 K0010 FH RB A:15278 T:15278'},
[8326]={[0]='Unfortunate Measures',[1]='B0 K0030 FH RB К0030 A:15278 T:15278 P:8325'},
[8327]={[0]='Report to Lanthan Perilon',[1]='B0 K0030 FH RB A:15278 T:15281 P:8326'},
[8328]={[0]='Mage Training',[1]='B0 K0030 FH RB CM L003 A:15278 T:15279 P:8325'},
[8329]={[0]='Warrior Training',[1]='B0 K0030 FH RB CW L003 A:15278 T:43010 P:8325'},
[8330]={[0]="Solanian's Belongings",[1]='B0 K0040 FH RB L002 A:15295 T:15295'},
[8334]={[0]='Aggression',[1]='B0 K0040 FH RB A:15281 T:15281 P:8326'},
[8335]={[0]='Felendren the Banished',[1]='B0 K0050 FH RB A:15281 T:15281 P:8334'},
[8336]={[0]='A Fistful of Slivers',[1]='B0 K0040 FH RB L002 A:15296 T:15296'},
[8338]={[0]='Tainted Arcane Sliver',[1]='B0 K0040 FH RB A:100020483 T:15297'},
[8345]={[0]="The Shrine of Dath'Remar",[1]='B0 K0040 FH RB L002 A:15295 T:15295'},
[8346]={[0]='Thirst Unending',[1]='B0 K0030 FH RB L002 A:15297 T:15297'},
[8347]={[0]='Aiding the Outrunners',[1]='B0 K0050 FH RB L004 A:15281 T:15301 P:8335 I:9704'},
[8350]={[0]='Completing the Delivery',[1]='B0 K0050 FH L004 A:15301 T:15433 P:9705'},
[8353]={[0]='Chicken Clucking for a Mint',[1]='B0 HW FA K0000 L010 A:5111 T:5111 PL:8311'},
[8354]={[0]='Chicken Clucking for a Mint',[1]='B0 HW FH K0000 L010 A:6741 T:6741 PL:8312'},
[8355]={[0]='Incoming Gumdrop',[1]='B0 HW FA K0000 L010 A:6826 T:6826 PL:8311'},
[8356]={[0]='Flexing for Nougat',[1]='B0 HW FA K0000 L010 A:6740 T:6740 PL:8311'},	-- note that this will still be available during the duration, even after completing
[8357]={[0]='Dancing for Marzipan',[1]='B0 HW FA K0000 L010 A:6735 T:6735 PL:8311'},
[8358]={[0]='Incoming Gumdrop',[1]='B0 HW FH K0000 L010 A:11814 T:11814 PL:8312'},
[8359]={[0]='Flexing for Nougat',[1]='B0 HW FH K0000 L010 A:6929 T:6929 PL:8312'},
[8360]={[0]='Dancing for Marzipan',[1]='B0 HW FH K0000 L010 A:6746 T:6746 PL:8312'},
[8376]={[0]='Armaments of War',[1]='B261 K0560 CP L054 A:15183 T:15183'},
[8377]={[0]='Armaments of War',[1]='B261 K0560 CH L054 A:15183 T:15183'},
[8378]={[0]='Armaments of War',[1]='B261 K0560 CR L054 A:15183 T:15183'},
[8379]={[0]='Armaments of War',[1]='B261 K0560 CT L054 A:15183 T:15183'},
[8380]={[0]='Armaments of War',[1]='B261 K0560 CS L054 A:15183 T:15183'},
[8381]={[0]='Armaments of War',[1]='B261 K0560 CM CL L054 A:15183 T:15183'},
[8382]={[0]='Armaments of War',[1]='B261 K0560 CD L054 A:15183 T:15183'},
[8446]={[0]='Shrouded in Nightmare',[1]='B0 K0600 L060 A:100020644 T:11832'},
[8447]={[0]='Waking Legends',[1]='B0 K0600 L060 A:11832 T:11832 P:8446'},
[8463]={[0]='Unstable Mana Crystals',[1]='B0 K0050 FH L004 A:15403 T:15403'},
[8468]={[0]='Wanted: Thaelis the Hungerer',[1]='B0 K0060 FH L004 A:1049846 T:16924'},
[8470]={[0]='Deadwood Ritual Totem',[1]='B182 K0550 L045 A:100020741 T:11558'},
[8472]={[0]='Major Malfunction',[1]='B0 K0050 FH L004 A:15418 T:15418'},
[8473]={[0]='A Somber Task',[1]='B0 K0090 FH L006 A:15398 T:15398 O:9258'},
[8474]={[0]="Old Whitebark's Pendant",[1]='B0 K0100 FH L007 A:100023228 T:15398'},
[8475]={[0]='The Dead Scar',[1]='B0 K0060 FH L004 A:15416 T:15416'},
[8476]={[0]='Amani Encroachment',[1]='B0 K0100 FH L007 A:15399 T:15399 O:9359'},
[8477]={[0]="The Spearcrafter's Hammer",[1]='B0 K0100 FH L007 A:15400 T:15400'},
[8479]={[0]="Zul'Marosh",[1]='B0 K0110 FH L008 A:15406 T:15406'},
[8480]={[0]='Lost Armaments',[1]='B0 K0070 FH L005 A:15404 T:15404'},
[8481]={[0]='The Root of All Evil',[1]='B0 K0550 L045 A:11555 T:11555'},
[8482]={[0]='Incriminating Documents',[1]='B0 K0060 FH L004 A:100020765 T:15403'},
[8483]={[0]='The Dwarven Spy',[1]='B0 K0070 FH L004 A:15403 T:15403 P:8482'},
[8486]={[0]='Arcane Instability',[1]='B0 K0060 FH L004 A:15401 T:15401 P:9119'},
[8487]={[0]='Corrupted Soil',[1]='B0 K0090 FH L007 A:15402 T:15402 O:9254'},
[8488]={[0]='Unexpected Results',[1]='B0 K0090 FH L007 A:15402 T:15402 P:8487'}, -- 7 seconds later
[8490]={[0]='Powering our Defenses',[1]='B0 K0100 FH L008 A:16362 T:16362 O:9253'},
[8491]={[0]='Pelt Collection',[1]='B0 K0070 FH L004 A:15417 T:15417'},
[8501]={[0]="Target: Hive'Ashi Stingers",[1]='B0 K0560 L054 A:100020941 T:15181'},
[8502]={[0]="Target: Hive'Ashi Workers",[1]='B0 K0560 L054 A:100020942 T:15181'},
[8539]={[0]="Target: Hive'Zora Hive Sisters",[1]='B0 K0560 L054 A:100021249 T:15181'},
[8544]={[0]="Conqueror's Spaulders",[1]='B0 K0600 CW ++ L060 A:15502 T:15502'},
[8556]={[0]='Signet of Unyielding Strength',[1]='B0 K0600 CW L060 A:15498 T:15498'},
[8557]={[0]='Drape of Unyielding Strength',[1]='B0 K0600 CW L060 A:15500 T:15500'},
[8558]={[0]='Sickle of Unyielding Strength',[1]='B0 K0600 CW L060 A:15499'},
[8559]={[0]="Conqueror's Greaves",[1]='B0 K0600 CW ++ L060 A:15503 T:15503'},
[8560]={[0]="Conqueror's Legguards",[1]='B0 K0600 CW ++ L060 A:15503 T:15503'},
[8561]={[0]="Conqueror's Crown",[1]='B0 K0600 CW ++ L060 A:15502 T:15502'},
[8562]={[0]="Conqueror's Breastplate",[1]='B0 K0600 CW ++ L060 A:15504 T:15504'},
[8563]={[0]='Warlock Training',[1]='B0 K0030 FH RB CL L003 A:15278 T:15283 P:8325'},
[8564]={[0]='Priest Training',[1]='B0 K0030 FH RB CT L003 A:15278 T:15284 P:8325'},
[8579]={[0]='Mortal Champions',[1]='B0 K0600 L060 A:15503 T:15503'},
[8592]={[0]='Tiara of the Oracle',[1]='B0 K0600 ++ L060 A:15502 T:15502'},
[8593]={[0]='Trousers of the Oracle',[1]='B0 K0600 CT ++ L060 A:15503 T:15503'},
[8594]={[0]='Mantle of the Oracle',[1]='B0 K0600 CT ++ L060 A:15502 T:15502'},
[8595]={[0]='Mortal Champions',[1]='B0 K0600 ++ L060 A:15503 T:15503'},
[8596]={[0]='Footwraps of the Oracle',[1]='B0 K0600 ++ L060 A:15503 T:15503'},
[8602]={[0]="Stormcaller's Pauldrons",[1]='B0 K0600 ++ L060 A:15502 T:15502'},
[8603]={[0]='Vestments of the Oracle',[1]='B0 K0600 CT ++ L060 A:15504 T:15504'},
[8619]={[0]='Morndeep the Elder',[1]='B0 SP HL +Y A:15549 T:15549'},
[8621]={[0]="Stormcaller's Footguards",[1]='B0 K0600 ++ L060 A:15503 T:15503'},
[8622]={[0]="Stormcaller's Hauberk",[1]='B0 K0600 L060 A:15504 T:15504'},
[8623]={[0]="Stormcaller's Diadem",[1]='B0 K0600 ++ L060 A:15502 T:15502'},
[8624]={[0]="Stormcaller's Leggings",[1]='B0 K0600 ++ L060 A:15503 T:15503'},
[8625]={[0]='Enigma Shoulderpads',[1]='B0 K0600 CM ++ L060 A:15502 T:15502'},
[8626]={[0]="Striker's Footguards",[1]='B0 K0600 CH ++ L060 A:15503 T:15503'},
[8627]={[0]="Avenger's Breastplate",[1]='B0 K0600 CP ++ L060 A:15504 T:15504'},
[8628]={[0]="Avenger's Crown",[1]='B0 K0600 CP ++ L060 A:15502 T:15502'},
[8629]={[0]="Avenger's Legguards",[1]='B0 K0600 CP ++ L060 A:15503 T:15503'},
[8630]={[0]="Avenger's Pauldrons",[1]='B0 K0600 CP ++ L060 A:15502 T:15502'},
[8631]={[0]='Enigma Leggings',[1]='B0 K0600 CM L060 A:15503 T:15503'},
[8632]={[0]='Enigma Circlet',[1]='B0 K0600 CM ++ L060 A:15502 T:15502'},
[8633]={[0]='Enigma Robes',[1]='B0 K0600 L060 A:15504 T:15504'},
[8634]={[0]='Enigma Boots',[1]='B0 K0600 CM ++ L060 A:15503 T:15503'},
[8635]={[0]='Splitrock the Elder',[1]='B0 SP HL +Y A:15556 T:15556'},
[8636]={[0]='Rumblerock the Elder',[1]='B0 SP HL +Y A:15557 T:15557'},
[8637]={[0]="Deathdealer's Boots",[1]='B0 K0600 CR L060 A:15503 T:15503'},
[8638]={[0]="Deathdealer's Vest",[1]='B0 K0600 CR L060 A:15504 T:15504'},
[8639]={[0]="Deathdealer's Helm",[1]='B0 K0600 CR L060 A:15502 T:15502'},
[8640]={[0]="Deathdealer's Leggings",[1]='B0 K0600 CR L060 A:15503 T:15503'},
[8641]={[0]="Deathdealer's Spaulders",[1]='B0 K0600 CR ++ L060 A:15502 T:15502'},
[8642]={[0]='Silvervein the Elder',[1]='B0 SP HL +Y A:15558 T:15558'},
[8643]={[0]='Highpeak the Elder',[1]='B0 SP HL +Y A:15559 T:15559'},
[8644]={[0]='Stonefort the Elder',[1]='B0 SP HL +Y A:15560 T:15560'},
[8645]={[0]='Obsidian the Elder',[1]='B0 SP HL +Y A:15561 T:15561'},
[8646]={[0]='Hammershout the Elder',[1]='B0 SP HL +Y A:15562 T:15562'},
[8647]={[0]='Bellowrage the Elder',[1]='B0 SP HL +Y A:15563 T:15563'},
[8648]={[0]='Darkcore the Elder',[1]='B0 SP HL +Y A:15564 T:15564'},
[8649]={[0]='Stormbrow the Elder',[1]='B0 SP HL +Y A:15565 T:15565'},
[8650]={[0]='Snowcrown the Elder',[1]='B0 SP HL +Y A:15566 T:15566'},
[8651]={[0]='Ironband the Elder',[1]='B0 SP HL +Y A:15567 T:15567'},
[8652]={[0]='Graveborn the Elder',[1]='B0 SP HL +Y A:15568 T:15568'},
[8653]={[0]='Goldwell the Elder',[1]='B0 SP HL +Y A:15569 T:15569'},
[8654]={[0]='Primestone the Elder',[1]='B0 SP HL +Y A:15570 T:15570'},
[8655]={[0]="Avenger's Greaves",[1]='B0 K0600 CP ++ L060 A:15503 T:15503'},
[8656]={[0]="Striker's Hauberk",[1]='B0 K0600 CH ++ L060 A:15504 T:15504'},
[8657]={[0]="Striker's Diadem",[1]='B0 K0600 CH ++ L060 A:15502 T:15502'},
[8658]={[0]="Striker's Leggings",[1]='B0 K0600 CH ++ L060 A:15503 T:15503'},
[8659]={[0]="Striker's Pauldrons",[1]='B0 K0600 CH ++ L060 A:15502 T:15502'},
[8660]={[0]="Doomcaller's Footwraps",[1]='B0 K0600 ++ L060 A:15503 T:15503'},
[8661]={[0]="Doomcaller's Robes",[1]='B0 K0600 CL ++ L060 A:15504 T:15504'},
[8662]={[0]="Doomcaller's Circlet",[1]='B0 K0600 ++ L060 A:15502 T:15502'},
[8663]={[0]="Doomcaller's Trousers",[1]='B0 K0600 ++ L060 A:15503 T:15503'},
[8664]={[0]="Doomcaller's Mantle",[1]='B0 K0600 ++ L060 A:15502 T:15502'},
[8665]={[0]='Genesis Boots',[1]='B0 K0600 CD ++ L060 A:15503 T:15503'},
[8666]={[0]='Genesis Vest',[1]='B0 K0600 RE RT RL CD ++ L060 A:15504 T:15504'},
[8667]={[0]='Genesis Helm',[1]='B0 K0600 CD ++ L060 A:15502 T:15502'},
[8668]={[0]='Genesis Trousers',[1]='B0 K0600 CD ++ L060 A:15503 T:15503'},
[8669]={[0]='Genesis Shoulderpads',[1]='B0 K0600 CD L060 A:15502 T:15502'},
[8670]={[0]='Runetotem the Elder',[1]='B0 SP HL +Y A:15572 T:15572'},
[8671]={[0]='Ragetotem the Elder',[1]='B0 SP HL +Y A:15573 T:15573'},
[8672]={[0]='Stonespire the Elder',[1]='B0 SP HL +Y A:15574 T:15574'},
[8673]={[0]='Bloodhoof the Elder',[1]='B0 SP HL +Y A:15575 T:15575'},
[8674]={[0]='Winterhoof the Elder',[1]='B0 SP HL +Y A:15576 T:15576'},
[8675]={[0]='Skychaser the Elder',[1]='B0 SP HL +Y A:15577 T:15577'},
[8676]={[0]='Wildmane the Elder',[1]='B0 SP HL +Y A:15578 T:15578'},
[8677]={[0]='Darkhorn the Elder',[1]='B0 SP HL +Y A:15579 T:15579'},
[8678]={[0]='Wheathoof the Elder',[1]='B0 SP HL +Y A:15580 T:15580'},
[8679]={[0]='Grimtotem the Elder',[1]='B0 SP HL +Y A:15581 T:15581'},
[8680]={[0]='Windtotem the Elder',[1]='B0 SP HL +Y A:15582 T:15582'},
[8681]={[0]='Thunderhorn the Elder',[1]='B0 SP HL +Y A:15583 T:15583'},
[8682]={[0]='Skyseer the Elder',[1]='B0 SP HL +Y A:15584 T:15584'},
[8683]={[0]='Dawnstrider the Elder',[1]='B0 SP HL +Y A:15585 T:15585'},
[8684]={[0]='Dreamseer the Elder',[1]='B0 SP HL +Y A:15586 T:15586'},
[8685]={[0]='Mistwalker the Elder',[1]='B0 SP HL +Y A:15587 T:15587'},
[8686]={[0]='High Mountain the Elder',[1]='B0 SP HL +Y A:15588 T:15588'},
[8687]={[0]="Target: Hive'Zora Tunnelers",[1]='B0 K0560 L054 A:100021251 T:15181'},
[8688]={[0]='Windrun the Elder',[1]='B0 SP HL +Y A:15592 T:15592'},
[8689]={[0]='Shroud of Infinite Wisdom',[1]='B0 K0600 CT L060 A:15500'},
[8690]={[0]='Cloak of the Gathering Storm',[1]='B0 K0600 CS L060 A:15500'},
[8691]={[0]='Drape of Vaulted Secrets',[1]='B0 K0600 L060 A:15500'},
[8692]={[0]='Cloak of Unending Life',[1]='B0 K0600 CD L060 A:15500 T:15500'},
[8693]={[0]='Cloak of Veiled Shadows',[1]='B0 K0600 L060 A:15500 T:15500'},
[8694]={[0]='Shroud of Unspoken Names',[1]='B0 K0600 CL L060 A:15500'},
[8695]={[0]='Cape of Eternal Justice',[1]='B0 K0600 CP L060 A:15500 T:15500'},
[8696]={[0]='Cloak of the Unseen Path',[1]='B0 K0600 CH L060 A:15500 T:15500'},
[8697]={[0]='Ring of Infinite Wisdom',[1]='B0 K0600 CT L060 A:15498'},
[8698]={[0]='Ring of the Gathering Storm',[1]='B0 K0600 L060 A:15498'},
[8699]={[0]='Band of Vaulted Secrets',[1]='B0 K0600 CM L060 A:15498 T:15498'},
[8700]={[0]='Band of Unending Life',[1]='B0 K0600 CD L060 A:15498 T:15498'},
[8701]={[0]='Band of Veiled Shadows',[1]='B0 K0600 L060 A:15498 T:15498'},
[8702]={[0]='Ring of Unspoken Names',[1]='B0 K0600 CL L060 A:15498 T:15498'},
[8703]={[0]='Ring of Eternal Justice',[1]='B0 K0600 CP L060 A:15498 T:15498'},
[8704]={[0]='Signet of the Unseen Path',[1]='B0 K0600 CH L060 A:15498'},
[8705]={[0]='Gavel of Infinite Wisdom',[1]='B0 K0600 CT L060 A:15499 T:15499'},
[8706]={[0]='Hammer of the Gathering Storm',[1]='B0 K0600 L060 A:15499 T:15499'},
[8707]={[0]='Blade of Vaulted Secrets',[1]='B0 K0600 CM L060 A:15499'},
[8708]={[0]='Mace of Unending Life',[1]='B0 K0600 CD L060 A:15499 T:15499'},
[8709]={[0]='Dagger of Veiled Shadows',[1]='B0 K0600 L060 A:15499'},
[8710]={[0]='Kris of Unspoken Names',[1]='B0 K0600 L060 A:15499 T:15499'},
[8711]={[0]='Blade of Eternal Justice',[1]='B0 K0600 CP L060 A:15499 T:15499'},
[8712]={[0]='Scythe of the Unseen Path',[1]='B0 K0600 CH L060 A:15499 T:15499'},
[8713]={[0]='Starsong the Elder',[1]='B0 SP HL +Y A:15593 T:15593'},
[8714]={[0]='Moonstrike the Elder',[1]='B0 SP HL +Y A:15594 T:15594'},
[8715]={[0]='Bladeleaf the Elder',[1]='B0 SP HL +Y A:15595 T:15595'},
[8716]={[0]='Starglade the Elder',[1]='B0 SP HL +Y A:15596 T:15596'},
[8717]={[0]='Moonwarden the Elder',[1]='B0 SP HL +Y A:15597 T:15597'},
[8718]={[0]='Bladeswift the Elder',[1]='B0 SP HL +Y A:15598 T:15598'},
[8719]={[0]='Bladesing the Elder',[1]='B0 SP HL +Y A:15599 T:15599'},
[8720]={[0]='Skygleam the Elder',[1]='B0 SP HL +Y A:15600 T:15600'},
[8721]={[0]='Starweave the Elder',[1]='B0 SP HL +Y A:15601 T:15601'},
[8722]={[0]='Meadowrun the Elder',[1]='B0 SP HL +Y A:15602 T:15602'},
[8723]={[0]='Nightwind the Elder',[1]='B0 SP HL +Y A:15603 T:15603'},
[8724]={[0]='Morningdew the Elder',[1]='B0 SP HL +Y A:15604 T:15604'},
[8725]={[0]='Riversong the Elder',[1]='B0 SP HL +Y A:15605 T:15605'},
[8726]={[0]='Brightspear the Elder',[1]='B0 SP HL +Y A:15606 T:15606'},
[8727]={[0]='Farwhisper the Elder',[1]='B0 SP HL +Y A:15607 T:15607'},
[8744]={[0]='A Carefully Wrapped Present',[1]='B0 HV A:1180743 T:1180743'},
[8746]={[0]='Metzen the Reindeer',[1]='B0 HV FH L040 A:13418 T:13418'},
[8747]={[0]='The Path of the Protector',[1]='B0 K0600 L060 A:15192 T:15192 P:1'},
[8748]={[0]='The Path of the Protector',[1]='B161 K0600 L060 A:15192 T:15192 P:8747'},
[8749]={[0]='The Path of the Protector',[1]='B161 K0600 L060 A:15192 T:15192 P:8748'},
[8750]={[0]='The Path of the Protector',[1]='B0 K0600 L060 A:15192 T:15192 P:8749'},
[8751]={[0]='The Protector of Kalimdor',[1]='B0 K0600 L060 A:15192 T:15192 P:8750'},
[8752]={[0]='The Path of the Conqueror',[1]='B0 K0600 L060 A:15192 T:15192 P:1'},
[8753]={[0]='The Path of the Conqueror',[1]='B0 K0600 L060 A:15192 T:15192 P:8752'},
[8754]={[0]='The Path of the Conqueror',[1]='B0 K0600 L060 A:15192 T:15192 P:8753'},
[8755]={[0]='The Path of the Conqueror',[1]='B0 K0600 L060 A:15192 T:15192 P:8754'},
[8756]={[0]='The Qiraji Conqueror',[1]='B0 K0600 L060 A:15192 T:15192 P:8755'},
[8757]={[0]='The Path of the Invoker',[1]='B0 K0600 L060 A:15192 T:15192 P:1'},
[8758]={[0]='The Path of the Invoker',[1]='B161 K0600 L060 A:15192 T:15192 P:8757'},
[8759]={[0]='The Path of the Invoker',[1]='B161 K0600 L060 A:15192 T:15192 P:8758'},
[8760]={[0]='The Path of the Invoker',[1]='B0 K0600 L060 A:15192 T:15192 P:8759'},
[8761]={[0]='The Grand Invoker',[1]='B0 K0600 L060 A:15192 T:15192 P:8760'},
[8762]={[0]='Metzen the Reindeer',[1]='B0 HV FA L040 A:13433 T:13433'},
[8763]={[0]='The Hero of the Day',[1]='B0 HV FA L040 A:13433 T:1180715'},
[8767]={[0]='A Gently Shaken Gift',[1]='B0 HV A:1180746 T:1180746'},
[8768]={[0]='A Gaily Wrapped Present',[1]='B0 HV L020 A:1180747 T:1180747'},
[8769]={[0]='A Ticking Present',[1]='B0 HV L040 A:1180748 T:1180748'},
[8770]={[0]="Target: Hive'Ashi Defenders",[1]='B0 K0560 L054 A:100021749 T:15181'},
[8771]={[0]="Target: Hive'Ashi Sandstalkers",[1]='B0 K0560 L054 A:100021750 T:15181'},
[8772]={[0]="Target: Hive'Zora Waywatchers",[1]='B0 K0560 L054 A:100021250 T:15181'},
[8773]={[0]="Target: Hive'Zora Reavers",[1]='B0 K0560 L054 A:100021248 T:15181'},
[8774]={[0]="Target: Hive'Regal Ambushers",[1]='B0 K0560 L054 A:100021252 T:15181'},
[8775]={[0]="Target: Hive'Regal Spitfires",[1]='B0 K0560 L054 A:100021253 T:15181'},
[8776]={[0]="Target: Hive'Regal Slavemakers",[1]='B0 K0560 L054 A:100021255 T:15181'},
[8777]={[0]="Target: Hive'Regal Burrowers",[1]='B0 K0560 L054 A:100021256 T:15181'},
[8784]={[0]='Secrets of the Qiraji',[1]='B0 K0600 ++ L060 A:100021230 T:15502'},
[8788]={[0]='A Gently Shaken Gift',[1]='B0 HV A:1180746 T:1180746'},
[8789]={[0]='Imperial Qiraji Armaments',[1]='B0 K0600 ++ L060 A:15380'},
[8790]={[0]='Imperial Qiraji Regalia',[1]='B0 K0600 ++ L060 A:15378 T:15378'},
[8791]={[0]='The Fall of Ossirian',[1]='B0 K0600 L060 A:100021220 T:15181'},
[8799]={[0]='The Hero of the Day',[1]='B0 HV FH L040 A:13418 T:1180715'},
[8801]={[0]="C'Thun's Legacy",[1]='B0 K0600 L060 A:100021221 T:15379'},
[8802]={[0]='The Savior of Kalimdor',[1]='B0 K0600 L060 A:15379 T:15192 P:8801'},
[8803]={[0]='A Festive Gift',[1]='B0 HV L010 A:1180793 T:1180793'},
[8827]={[0]="Winter's Presents",[1]='B0 HV FA A:15732 T:13444'},
[8828]={[0]="Winter's Presents",[1]='B0 HV FH A:515732 T:13445'},
[8860]={[0]='New Year Celebrations!',[1]='B0 FA HU A:15732 T:6740'},
[8861]={[0]='New Year Celebrations!',[1]='B0 FH HU A:515732 T:6746'},
[8866]={[0]='Bronzebeard the Elder',[1]='B0 SP HL +Y A:15871 T:15871'},
[8867]={[0]='Lunar Fireworks',[1]='B0 HL +Y A:15895 T:15895 O:8870,8871'},
[8868]={[0]="Elune's Blessing",[1]='B0 HL +Y A:15864 T:15864'},
[8870]={[0]='The Lunar Festival',[1]='B0 HL FA +Y A:15892 T:15895 I:8867'},
[8871]={[0]='The Lunar Festival',[1]='B0 HL FA +Y A:15892 T:15895 I:8867'},
[8872]={[0]='The Lunar Festival',[1]='B0 HL FA +Y A:15892 T:15895 I:8867'},
[8873]={[0]='The Lunar Festival',[1]='B0 HL FH +Y A:15891 T:15895 I:8867'},
[8874]={[0]='The Lunar Festival',[1]='B0 HL FH +Y A:15891 T:15895 I:8867'},
[8875]={[0]='The Lunar Festival',[1]='B0 HL FH +Y A:15891 T:15895 I:8867'},
[8883]={[0]='Valadar Starsong',[1]='B0 HL +Y A:15895 T:15864 P:8867'},
[8884]={[0]='Fish Heads, Fish Heads...',[1]='B0 K0070 FH L005 A:15920 T:15920'},
[8885]={[0]='The Ring of Mmmrrrggglll',[1]='B0 K0090 FH L005 A:15920 T:15920 P:8884'},
[8886]={[0]='Grimscale Pirates!',[1]='B0 K0080 FH L005 A:15921 T:15921'},
[8887]={[0]="Captain Kelisendra's Lost Rutters",[1]='B0 K0080 FH L005 A:100021776 T:15921'},
[8888]={[0]="The Magister's Apprentice",[1]='B0 K0100 FH L008 A:15951 T:15924 I:8889'},
[8889]={[0]='Deactivating the Spire',[1]='B0 K0100 FH L008 A:15924 T:15924 O:8888'},
[8890]={[0]='Word from the Spire',[1]='B0 K0100 FH L008 A:15924 T:15951 P:8889'},
[8891]={[0]='Abandoned Investigations',[1]='B0 K0100 FH L008 A:1181011 T:15951'},
[8892]={[0]='Situation at Sunsail Anchorage',[1]='B0 K0070 FH L005 A:15939 T:15939 O:9256'},
[8894]={[0]='Cleaning up the Grounds',[1]='B0 K0100 FH L008 A:15969 T:15969 O:9394'},
[8895]={[0]='Delivery to the North Sanctum',[1]='B0 K0060 FH L004 A:15418 T:15405 P:8472'},
[9035]={[0]='Roadside Ambush',[1]='B0 K0060 FH L004 A:15941 T:15945 I:9062'},
[9062]={[0]='Soaked Pages',[1]='B0 K0060 FH L004 A:15945 T:15945 O:9035'},
[9064]={[0]='Taking the Fall',[1]='B0 K0060 FH L004 A:15945 T:15970 P:9062'},
[9066]={[0]='Swift Discipline',[1]='B0 K0060 FH L004 A:15970 T:15970 P:9064'},
[9067]={[0]='The Party Never Ends',[1]='B0 K0090 FH L007 A:16144 T:16144 O:9395'},
[9076]={[0]='Wretched Ringleader',[1]='B0 K0080 FH L005 A:15404 T:15404 P:8480'},
[9119]={[0]='Malfunction at the West Sanctum',[1]='B0 K0050 FH L004 A:15405 T:15401 P:8895'},
[9130]={[0]='Goods from Silvermoon City',[1]='B0 K0070 FH RB L005 A:16261 T:44036'},
[9133]={[0]='Fly to Silvermoon City',[1]='B0 K0070 FH RB L005 A:44036 T:16191 P:9130'},
[9134]={[0]='Skymistress Gloaming',[1]='B0 K0070 FH RB L005 A:16191 T:16192 P:9133'},
[9135]={[0]='Return to Sathiel',[1]='B0 K0070 FH RB L005 A:16192 T:16261 P:9134'},
[9138]={[0]='Suncrown Village',[1]='B463 K0100 FH L009 A:16197 T:16197 P:9758'},
[9139]={[0]='Goldenmist Village',[1]='B463 K0110 FH L009 A:16197 T:16197 P:9138'},
[9140]={[0]='Windrunner Village',[1]='B463 K0140 FH L009 A:16197 T:16197 P:9139'},
[9143]={[0]="Dealing with Zeb'Sora",[1]='B463 K0120 FH L009 A:16219 T:16219 O:9145'},
[9144]={[0]='Missing in the Ghostlands',[1]='B0 K0100 FH L010 A:16210 T:16183 I:28560'},
[9145]={[0]='Help Ranger Valanna!',[1]='B463 K0120 FH L009 A:16213 T:16219 I:9143 V7744999'},
[9146]={[0]='Report to Captain Helios',[1]='B463 K0120 FH L009 A:16219 T:16220 P:9143'},
[9147]={[0]='The Fallen Courier',[1]='B463 K0100 FH L009 A:16196 T:16196 O:9144,28560'},
[9148]={[0]='Delivery to Tranquillien',[1]='B463 K0100 FH L009 A:16183 T:16197 P:9147'},
[9149]={[0]='The Plagued Coast',[1]='B463 K0130 FH L010 A:16198 T:16198 P:9327,9329'},
[9150]={[0]='Salvaging the Past',[1]='B463 K0120 FH L009 A:16199 T:16199 V7744999'},
[9151]={[0]='The Sanctum of the Sun',[1]='B463 K0200 FH L017 A:16199 T:16204 I:9220'},
[9152]={[0]="Tomber's Supplies",[1]='B463 K0110 FH L009 A:16224 T:16224 P:9327,9329'},
[9155]={[0]='Down the Dead Scar',[1]='B463 K0140 FH L010 A:16200 T:16200 V7744999'},
[9156]={[0]='Wanted: Knucklerot and Luzran',[1]='B463 K0210 FH L009 A:1181147 T:16200'},
[9157]={[0]='Forgotten Rituals',[1]='B463 K0120 FH L009 A:16201 T:16201'},
[9158]={[0]='Bearers of the Plague',[1]='B463 K0140 FH L011 A:16202 T:16202'},
[9159]={[0]='Curbing the Plague',[1]='B463 K0150 FH L011 A:16202 T:16202 P:9158'},
[9160]={[0]="Investigate An'daroth",[1]='B463 K0110 FH L011 A:16231 T:16231 V7744999'},
[9161]={[0]="The Traitor's Shadow",[1]='B463 K0160 FH L015 A:16203 T:1181150 O:9282'},
[9162]={[0]='Hints of the Past',[1]='B463 K0160 FH L015 A:1181150 T:16203 P:9161'},
[9163]={[0]='Into Occupied Territory',[1]='B463 K0140 FH L011 A:16231 T:16231 P:9160'},
[9164]={[0]='Captives at Deatholme',[1]='B463 K0200 FH L017 A:16198 T:16240 P:9877'},
[9166]={[0]="Deliver the Plans to An'telas",[1]='B463 K0160 FH L011 A:16231 T:16237 P:9163'},
[9167]={[0]="The Traitor's Destruction",[1]='B463 K0210 FH L015 A:16239 T:16239 P:9176'},
[9169]={[0]="Deactivate An'owyn",[1]='B463 K0160 FH L011 A:16237 T:16237 P:9166'},
[9170]={[0]="Dar'Khan's Lieutenants",[1]='B463 K0200 FH L017 A:16204 T:16204 P:9220'},
[9171]={[0]='Culinary Crunch',[1]='B463 K0150 FH L012 A:16253 T:16253 V7744999'},
[9172]={[0]='Report to Magister Kaendris',[1]='B463 K0160 FH L015 A:16203 T:16239 P:9162'},
[9173]={[0]='Retaking Windrunner Spire',[1]='B463 K0150 FH L015 A:16252 T:16252 V7750999'},
[9174]={[0]='Vanquishing Aquantion',[1]='B463 K0130 FH L009 A:16201 T:16201 P:9157'},
[9175]={[0]="The Lady's Necklace",[1]='B463 K0150 FH L015 A:100022597 T:16252'},
[9176]={[0]='The Twin Ziggurats',[1]='B463 K0170 FH L015 A:16239 T:16239 P:9172'},
[9177]={[0]='Journey to Undercity',[1]='B0 K0150 FH SB L015 A:16252 T:10181 P:9175'},
[9180]={[0]='Journey to Undercity',[1]='B0 K0150 FH RB L015 A:16252 T:10181 P:9175'},
[9192]={[0]='Trouble at the Underlight Mines',[1]='B463 K0140 FH L011 A:16251 T:16251 V7744999'},
[9193]={[0]='Investigate the Amani Catacombs',[1]='B463 K0170 FH L014 A:16289 T:16289'},
[9199]={[0]='Troll Juju',[1]='B463 K0170 FH L014 A:16251 T:16251'},
[9207]={[0]='Underlight Ore Samples',[1]='B463 K0140 FH L011 A:16293 T:16291 V7744999'},
[9208]={[0]='The Savage Guard - Arcanum of Protection',[1]='B0 K0600 ++ L058 A:15042 T:15042'},
[9209]={[0]='The Savage Guard - Arcanum of Rapidity',[1]='B0 K0600 ++ L058 A:15042 T:15042'},
[9210]={[0]='The Savage Guard - Arcanum of Focus',[1]='B0 K0600 ++ L058 A:15042 T:15042'},
[9212]={[0]='Escape from the Catacombs',[1]='B463 K0170 FH L014 A:16295 T:16220'},
[9214]={[0]='Shadowpine Weaponry',[1]='B463 K0180 FH L015 A:16220 T:16220'},
[9215]={[0]="Bring Me Kel'gash's Head!",[1]='B463 K0200 FH L009 A:1181153 T:16220'},
[9216]={[0]='Rotting Hearts',[1]='B463 K0160 FH L015 A:16205 T:16205'},
[9217]={[0]='More Rotting Hearts',[1]='B463 K0160 FH ++ L015 A:16205 T:16205 P:9216'},
[9218]={[0]='Spinal Dust',[1]='B463 K0180 FH L015 A:16205 T:16205'},
[9219]={[0]='More Spinal Dust',[1]='B0 K0180 FH ++ L015 A:16205 T:16205 P:9218'},
[9220]={[0]='War on Deatholme',[1]='B463 K0200 FH L017 A:16204 T:16204 O:9151'},
--[9249]={[0]='40 Tickets - Schematic: Steam Tonk Controller',[1]='B0 HF L045 A:14828 T:14828'},
[9250]={[0]='Frame of Atiesh',[1]='B0 K0600 L060 A:100022727 T:15192'},
[9251]={[0]='Atiesh, the Befouled Greatstaff',[1]='B0 K0600 L060 A:15192 T:15192 P:9250'},
[9252]={[0]='Defending Fairbreeze Village',[1]='B0 K0090 FH L007 A:15942 T:15942 O:9358'},
[9253]={[0]='Runewarden Deryan',[1]='B0 K0100 FH L008 A:15942 T:16362 P:9252 I:8490'},
[9254]={[0]='The Wayward Apprentice',[1]='B0 K0090 FH L007 A:16210 T:15402 I:8487'},
[9255]={[0]='Research Notes',[1]='B0 K0090 FH L007 A:15402 T:16210 P:8488'},
[9256]={[0]='Fairbreeze Village',[1]='B0 K0070 FH L006 A:15403 T:15939 P:8483 I:8892'},
[9257]={[0]='Atiesh, Greatstaff of the Guardian',[1]='B0 K0600 CT L060 A:15192 T:15192'},
[9258]={[0]='The Scorched Grove',[1]='B0 K0100 FH L008 A:16397 T:15398 I:8473'},
[9259]={[0]='Traitor to the Bloodsail',[1]='B0 ++ L030 A:16399 T:16399'},
[9266]={[0]='Making Amends',[1]='B0 ++ L040 A:16416 T:16416'},
[9267]={[0]='Mending Old Wounds',[1]='B0 ++ L015 A:16418 T:16418 W2241999'},
[9268]={[0]='War at Sea',[1]='B0 ++ L040 A:16417 T:16417'},
[9269]={[0]='Atiesh, Greatstaff of the Guardian',[1]='B0 K0600 CD L060 A:15192 T:15192'},
[9270]={[0]='Atiesh, Greatstaff of the Guardian',[1]='B0 K0600 CM L060 A:15192 T:15192'},
[9271]={[0]='Atiesh, Greatstaff of the Guardian',[1]='B0 K0600 CL L060 A:15192 T:15192'},
[9272]={[0]='Dressing the Part',[1]='B37 K0550 FH L049 A:2546 T:2546 I:1036'},
[9274]={[0]='Spirits of the Drowned',[1]='B463 K0120 FH L009 A:16462 T:16462'},
[9275]={[0]='A Little Dash of Seasoning',[1]='B463 K0190 FH L016 A:16464 T:16464'},
[9276]={[0]="Attack on Zeb'Tela",[1]='B463 K0180 FH L015 A:16463 T:16463'},
[9277]={[0]="Assault on Zeb'Nowa",[1]='B463 K0190 FH L015 A:16463 T:16463 P:9276'},
[9279]={[0]='You Survived!',[1]='B0 K0010 FA RD A:16475 T:16477'},
[9280]={[0]='Replenishing the Healing Crystals',[1]='B0 K0010 FA RD A:16477 T:16477 P:9279 I:9369'},
[9281]={[0]='Clearing the Way',[1]='B463 K0180 FH L015 A:16480 T:16480'},
[9282]={[0]='The Farstrider Enclave',[1]='B463 K0160 FH L015 A:16239 T:16203 I:9161'},
[9283]={[0]='Rescue the Survivors!',[1]='B0 K0020 FA RD A:16502 T:16502'},
[9287]={[0]='Paladin Training',[1]='B0 K0030 FA CP RD L003 A:16501 T:16501 P:9409'},
[9288]={[0]='Hunter Training',[1]='B0 K0030 FA CH RD L003 A:16499 T:16499 P:9409'},
[9289]={[0]='Warrior Training',[1]='B0 K0030 FA CW RD L003 A:16503 T:16503 P:9409'},
[9290]={[0]='Mage Training',[1]='B0 K0030 FA CM RD L003 A:16500 T:16500 P:9409'},
[9291]={[0]='Priest Training',[1]='B0 K0030 FA CT RD L003 A:16502 T:16502 P:9409'},
[9293]={[0]='What Must Be Done...',[1]='B0 K0020 FA A:16514 T:16514 P:10302'},
[9294]={[0]='Healing the Lake',[1]='B0 K0030 FA A:16514 T:16514 P:9293'},
[9303]={[0]='Inoculation',[1]='B0 K0040 FA L002 A:16535 T:16535 P:9409 O:10304'},
[9305]={[0]='Spare Parts',[1]='B0 K0040 FA L002 A:17071 T:17071 P:9409'},
[9309]={[0]='The Missing Scout',[1]='B0 K0050 FA L002 A:16535 T:16546 P:9303'},
[9311]={[0]='Blood Elf Spy',[1]='B0 K0050 FA L002 A:16546 T:16535 P:10303'},
[9312]={[0]='The Emitter',[1]='B0 K0050 FA L003 A:16535 T:17071 P:9305+9311'},
[9313]={[0]='Travel to Azure Watch',[1]='B0 K0050 FA L002 A:17071 T:16551 P:9312'},
[9314]={[0]='Word from Azure Watch',[1]='B0 K0050 FA A:16554 T:16553'},
[9315]={[0]="Anok'suten",[1]='B463 K0110 FH L009 A:16601 T:16197 P:9327,9329'},
[9324]={[0]="Stealing Orgrimmar's Flame",[1]='B0 HM FA'},
[9325]={[0]="Stealing Thunder Bluff's Flame",[1]='B0 HM FA'},
[9326]={[0]="Stealing the Undercity's Flame",[1]='B0 HM FA'},
[9327]={[0]='The Forsaken',[1]='B463 K0100 FH RB L009 A:16197 T:16252 O:9144,28560'},
[9328]={[0]="Hero of the Sin'dorei",[1]='B463 K0210 FH RB L015 A:16239 T:16802 P:9167'},
[9329]={[0]='The Forsaken',[1]='B463 K0100 FH SB L009 A:16197 T:16252 O:9144,28560'},
[9330]={[0]="Stealing Stormwind's Flame",[1]='B0 HM FH'},
[9331]={[0]="Stealing Ironforge's Flame",[1]='B0 HM FH'},
[9332]={[0]="Stealing Darnassus's Flame",[1]='B0 HM FH'},
[9339]={[0]="A Thief's Reward",[1]='B0 HM FH SP A:16818 T:16818'},
[9340]={[0]='The Great Fissure',[1]='B465 K0620 FH L060 A:16789 T:16789 O:9498,9499'},
[9345]={[0]='Preparing the Salve',[1]='B465 K0610 FH L058 A:16858 T:16858'},
[9349]={[0]='Ravager Egg Roundup',[1]='B465 K0610 L058 A:19344 T:19344'},
[9351]={[0]='Voidwalkers Gone Wild',[1]='B465 K0610 L058 A:19367 T:19367 P:10161'},
[9352]={[0]='Darnassian Intrusions',[1]='B0 K0060 FH L004 A:15403 T:15401 P:8463'},
[9355]={[0]='A Job for an Intelligent Man',[1]='B465 FA K0610 L058 A:16837 T:16837'},
[9356]={[0]='Smooth as Butter',[1]='B465 K0610 L058 A:19344 T:19344 P:9361'},
[9358]={[0]='Ranger Sareyn',[1]='B0 K0090 FH L008 A:15397 T:15942 I:9252'},
[9359]={[0]='Farstrider Retreat',[1]='B0 K0100 FH L008 A:15939 T:15399 P:8892 I:8476'},
[9360]={[0]='Amani Invasion',[1]='B0 K0110 FH L008 A:100023249 T:15399'},
[9361]={[0]='Helboar, the Other White Meat',[1]='B465 K0610 L058 A:19344 T:19344 P:9349'},
[9363]={[0]='Warning Fairbreeze Village',[1]='B0 K0110 FH L008 A:15399 T:15939 P:9360'},
[9365]={[0]="A Thief's Reward",[1]='B0 HM FA SP A:16817 T:16817'},
[9366]={[0]='In Need of Felblood',[1]='B465 K0620 FH L060 A:16791 T:16791'},
[9369]={[0]='Replenishing the Healing Crystals',[1]='B0 K0010 FA SD A:16477 T:16477 I:9280'},
[9370]={[0]='The Cleansing Must Be Stopped',[1]='B465 K0620 FH L060 A:16791 T:16791 P:9366'},
[9371]={[0]='Botanist Taerix',[1]='B0 K0020 FA A:16477 T:16514 P:9409 I:10302'},
[9372]={[0]='Demonic Contamination',[1]='B465 K0630 L061 A:16991 T:16991 P:10442,10443'},
[9373]={[0]='Missing Missive',[1]='B465 K0610 L058 A:100023338 T:16991'},
[9374]={[0]="Arelion's Journal",[1]='B465 K0620 FH L060 A:16793 T:16793'},
[9375]={[0]='The Road to Falcon Watch',[1]='B465 K0630 FH L061 A:16993 T:17015'},
[9376]={[0]="A Pilgrim's Plight",[1]='B465 K0630 FH L061 A:17015 T:17015 P:9375'},
[9381]={[0]='Trueflight Arrows',[1]='B465 K0630 FH L061 A:16790 T:16790'},
[9383]={[0]='An Ambitious Plan',[1]='B465 FA K0630 L061 A:17006 T:17006'},
[9385]={[0]='Rampaging Ravagers',[1]='B465 FA K0630 L060 A:16850 T:16850'},
[9387]={[0]='Source of the Corruption',[1]='B465 K0630 FH L060 A:16794 T:16794'},
[9390]={[0]='In Search of Sedai',[1]='B465 FA K0620 L060 A:16834 T:16852'},
[9391]={[0]='Marking the Path',[1]='B465 K0620 FH L060 A:16789 T:16789 P:9340'},
[9392]={[0]='Rogue Training',[1]='B0 K0030 FH RB CR L003 A:15278 T:15285 P:8325'},
[9393]={[0]='Hunter Training',[1]='B0 K0030 FH RB CH L003 A:15278 T:15513 P:8325'},
[9394]={[0]="Where's Wyllithen?",[1]='B0 K0100 FH L008 A:15924 T:15969 I:8894'},
[9395]={[0]="Saltheril's Haven",[1]='B0 K0090 FH L008 A:16210 T:16144 I:9067'},
[9396]={[0]='Magic of the Arakkoa',[1]='B465 K0620 FH L060 A:16792 T:16792'},
[9397]={[0]='Birds of a Feather',[1]='B465 K0620 FH L060 A:16790 T:16790'},
[9398]={[0]='Deadly Predators',[1]='B465 FA K0620 L060 A:16797 T:16797'},
[9399]={[0]='Cruel Taskmasters',[1]='B465 FA K0630 L060 A:16799 T:16799'},
[9400]={[0]='The Assassin',[1]='B465 K0620 FH L060 A:3230 T:17062'},
[9401]={[0]='A Strange Weapon',[1]='B465 K0620 FH L060 A:17062 T:3230 P:9400'},
--[9402]={[0]='Fetch!',[1]='B0 K0100 FH CM L010 A:15970 T:15970'},
--[9403]={[0]='The Purest Water',[1]='B0 K0100 FH RL RB CM L010 A:15970 T:15970 P:9402'},
--[9404]={[0]='Recently Living',[1]='B0 K0100 FH CM L010 A:15970 T:15970 P:9403'},
[9405]={[0]="The Warchief's Mandate",[1]='B465 K0620 FH L060 A:3230 T:16574 P:9401'},
[9406]={[0]="The Mag'har",[1]='B465 K0620 FH L060 A:16845 T:3230 P:9410'},
[9407]={[0]='Through the Dark Portal',[1]='B465 K0610 FH L058 A:19254 T:19253'},
[9409]={[0]='Urgent Delivery!',[1]='B0 K0020 FA A:16477 T:16502 P:9280,9369'},
[9410]={[0]='A Spirit Guide',[1]='B465 K0620 FH L060 A:16574 T:16845 P:9405'},
[9415]={[0]='Report to Marshal Bluewall',[1]='B261 FA K0560 L054 A:17082 T:17080'},
[9416]={[0]='Report to General Kirika',[1]='B261 K0560 FH L054 A:17081 T:17079'},
[9417]={[0]='The Arakkoa Threat',[1]='B465 FA K0630 L060 A:16850 T:16850 P:9558'},
[9418]={[0]="Avruu's Orb",[1]='B465 K0630 L060 A:100023580 T:17085'},
[9419]={[0]='Scouring the Desert',[1]='B261 K0560 FA L054 A:17080 T:17080 P:9415'},
[9420]={[0]='The Finest Down',[1]='B465 FA K0620 L060 A:16851 T:16851 P:9563'},
[9421]={[0]='Shaman Training',[1]='B0 K0030 FA CS RD L003 A:17089 T:17089 P:9409'},
[9422]={[0]='Scouring the Desert',[1]='B261 K0560 FH L054 A:17079 T:17079 P:9416'},
[9423]={[0]='Return to Obadei',[1]='B465 FA K0620 L060 A:16852 T:16834 P:9390'},
[9424]={[0]="Makuru's Vengeance",[1]='B465 FA K0630 L060 A:16833 T:16833'},
[9426]={[0]='The Pools of Aggonar',[1]='B465 FA K0620 L060 A:16796 T:16796'},
[9427]={[0]='Cleansing the Waters',[1]='B465 FA K0620 L060 A:16796 T:16796 P:9426'},
[9430]={[0]="Sha'naar Relics",[1]='B465 FA K0630 L060 A:16796 T:16796 P:9543'},
[9436]={[0]='Bloodscalp Insight',[1]='B37 K0260 FH L024 A:17094 T:17094'},
[9437]={[0]='Twilight of the Dawn Runner',[1]='B141 K0370 FH L033 A:17095 T:17095'},
[9442]={[0]='A Debilitating Sickness',[1]='B465 K0630 FH L060 A:17123 T:17123'},
[9447]={[0]='Administering the Salve',[1]='B465 K0630 FH L060 A:17123 T:17123 P:9442'},
[9452]={[0]='Red Snapper - Very Tasty!',[1]='B0 K0060 FA L004 A:17101 T:17101'},
[9453]={[0]='Find Acteon!',[1]='B0 K0060 FA L004 A:17101 T:17110 P:9452'},
[9454]={[0]='The Great Moongraze Hunt',[1]='B0 K0060 FA L004 A:17110 T:17110'},
[9455]={[0]='Strange Findings',[1]='B0 K0070 FA L005 A:100023678 T:17116'},
[9456]={[0]='Nightstalker Clean Up, Isle 2...',[1]='B0 K0080 FA L005 A:17116 T:17116 P:9455'},
[9457]={[0]='An Unusual Patron',[1]='B37 K0260 FH L024 A:17094 T:17094 P:9436'},
[9463]={[0]='Medicinal Purpose',[1]='B0 K0060 FA RD L004 A:17214 T:17214'},
[9466]={[0]='Wanted: Blacktalon the Savage',[1]='B465 K0630 FH L058 A:1181638 T:16789'},
[9472]={[0]="Arelion's Mistress",[1]='B0 K0620 FH L060 A:16793 T:16793 P:10287'},
[9473]={[0]='An Alternative Alternative',[1]='B0 K0080 FA RD L005 A:17215 T:17215 P:9463'},
[9483]={[0]="Life's Finer Pleasures",[1]='B465 K0620 FH ++ L060 A:17226 T:17226'},
--[9487]={[0]='Arcane Reavers',[1]='B0 K0160 FH RB CM L015 A:16197 T:16197'},
--[9488]={[0]='A Simple Robe',[1]='B0 K0160 FH CM L015 A:16197 T:16197 P:9487'},
[9490]={[0]='The Rock Flayer Matriarch',[1]='B465 FA K0630 L060 A:16799 T:16799'},
[9492]={[0]='Turning the Tide',[1]='B0 K0700 FA L067 A:16819 T:16819'},
[9493]={[0]='Pride of the Fel Horde',[1]='B0 K0700 FA L066 A:16830 T:16830'},
[9494]={[0]='Fel Embers',[1]='B0 K0700 FA L067 A:16829 T:16829'},
[9495]={[0]='The Will of the Warchief',[1]='B0 K0700 FH L067 A:3230 T:3230'},
[9496]={[0]='Pride of the Fel Horde',[1]='B0 K0700 FH L066 A:16575 T:16575'},
[9498]={[0]='Falcon Watch',[1]='B465 K0620 FH SB L060 A:16577 T:16789 I:9340'},
[9499]={[0]='Falcon Watch',[1]='B465 K0620 FH RB L060 A:16577 T:16789 I:9340'},
[9505]={[0]='The Prophecy of Velen',[1]='B0 K0080 FA RD L005 A:17215 T:17240 P:9473 I:9506'},
[9506]={[0]='A Small Start',[1]='B0 K0070 FA L005 A:17240 T:17240 O:9505'},
[9512]={[0]="Cookie's Jumbo Gumbo",[1]='B0 K0070 FA L005 A:17246 T:17246'},
[9513]={[0]='Reclaiming the Ruins',[1]='B0 K0080 FA L006 A:17241 T:17241 P:9506,9512'},
[9514]={[0]='Rune Covered Tablet',[1]='B0 K0080 FA L006 A:100023759 T:17241 PLT:9506'},
[9515]={[0]="Warlord Sriss'tiz",[1]='B0 K0100 FA L006 A:17241 T:17241 P:9514'},
[9523]={[0]='Precious and Fragile Things Need Special Handling',[1]='B0 K0080 FA L006 A:17242 T:17242 P:9506,9512'},
[9524]={[0]='Imprisoned in the Citadel',[1]='B504956 K0700 FA L067 A:17288 T:17290'},
[9525]={[0]='Imprisoned in the Citadel',[1]='B504956 K0700 FH L067 A:17294 T:17296'},
[9527]={[0]='All That Remains',[1]='B0 K0100 FA L006 A:17311 T:17311 O:10428'},
[9528]={[0]='A Cry For Help',[1]='B0 FA K010544 L006 A:17312 T:17311'},
--[9529]={[0]='The Stone',[1]='B0 FH CL L010 A:16647 T:1181698 P:10788'},
[9530]={[0]="I've Got a Plant",[1]='B0 K0090 FA L005 A:17240 T:17240 P:9506'},
[9531]={[0]="Tree's Company",[1]='B0 K0090 FA L005 A:17240 T:17240 P:9530'},
[9537]={[0]='Show Gnomercy',[1]='B0 K0090 FA L005 A:17240 T:17240 P:9531'},
[9538]={[0]='Learning the Language',[1]='B0 K0080 FA L008 A:17232 T:17360'},
[9539]={[0]='Totem of Coo',[1]='B0 K0100 FA L008 A:17360 T:17361 P:9538'},
[9540]={[0]='Totem of Tikti',[1]='B0 K0100 FA L008 A:17361 T:17362 P:9539'},
[9541]={[0]='Totem of Yor',[1]='B0 K0100 FA L008 A:17362 T:17363 P:9540'},
[9542]={[0]='Totem of Vark',[1]='B0 K0100 FA L008 A:17363 T:17364 P:9541'},
[9543]={[0]='Atonement',[1]='B465 FA K0630 L060 A:16834 T:16796'},
[9544]={[0]='The Prophecy of Akida',[1]='B0 K0100 FA L008 A:17364 T:17114 P:9542'},
[9545]={[0]="The Seer's Relic",[1]='B465 FA K0630 L060 A:16796 T:16796 P:9430'},
[9548]={[0]='Pilfered Equipment',[1]='B476 K0170 FA L013 A:17421 T:17421'},
[9549]={[0]='Artifacts of the Blacksilt',[1]='B476 K0170 FA L013 A:17421 T:17421 O:10063'},
[9550]={[0]='A Map to Where?',[1]='B476 K0160 FA L013 A:100023837 T:1181756 P:9549'},
[9557]={[0]='Deciphering the Book',[1]='B476 K0160 FA L013 A:1181756 T:17424 P:9550'},
[9558]={[0]='The Longbeards',[1]='B465 FA K0620 L060 A:16826 T:16850'},
[9559]={[0]='Stillpine Hold',[1]='B0 K0100 FA L007 A:17114 T:17440 P:9544'},
[9560]={[0]='Beasts of the Apocalypse!',[1]='B0 K0100 FA L007 A:17442 T:17442 P:9544'},
[9561]={[0]="Nolkai's Words",[1]='B476 K0160 FA L013 A:17424 T:1181758 P:9557'}, -- about 10 second wait
[9562]={[0]='Murlocs... Why Here? Why Now?',[1]='B0 K0100 FA L007 A:17441 T:17441 P:9544'},
[9563]={[0]="Gaining Mirren's Trust",[1]='B465 FA K0620 L060 A:16851 T:16851'},
[9564]={[0]="Gurf's Dignity",[1]='B0 K0110 FA L007 A:100023850 T:17441 PL:9560,9562'},
[9565]={[0]='Search Stillpine Hold',[1]='B0 K0100 FA L007 A:17440 T:1181748 P:9560,9562'},
[9566]={[0]='Blood Crystals',[1]='B0 K0100 FA L007 A:1181748 T:17440 P:9565'},
[9567]={[0]='Know Thine Enemy',[1]='B476 K0140 FA L013 A:17433 T:17433'},
[9569]={[0]='Containing the Threat',[1]='B476 K0180 FA L013 A:17433 T:17433 P:9567'}, -- about a 15 second delay
[9570]={[0]="The Kurken is Lurkin'",[1]='B0 K0120 FA L007 A:17443 T:17443 PC:9566,9573'},
[9571]={[0]="The Kurken's Hide",[1]='B0 K0100 FA L007 A:17443 T:17442 P:9570'},
[9572]={[0]='Weaken the Ramparts',[1]='B504956 K0620 FH L059 A:17493 T:17558'},
[9573]={[0]='Chieftain Oomooroo',[1]='B0 K0110 FA L007 A:17445 T:17445 P:9560,9562'},
[9574]={[0]='Victims of Corruption',[1]='B476 K0140 FA L010 A:17434 T:17434 P:9629'},
[9575]={[0]='Weaken the Ramparts',[1]='B504956 K0620 FA L059 A:17557 T:17479'},
[9576]={[0]="Cruelfin's Necklace",[1]='B476 K0120 FA L009 A:100023870 T:17434'},
[9578]={[0]='Searching for Galaen',[1]='B476 K0180 FA L015 A:17434 T:17508'},
[9579]={[0]="Galaen's Fate",[1]='B476 K0180 FA L015 A:17508 T:17434 P:9578'},
[9580]={[0]='The Bear Necessities',[1]='B476 K0160 FA L014 A:17642 T:17642'},
[9581]={[0]='Learning from the Crystals',[1]='B476 K0110 FA L010 A:17423 T:17423'},
[9582]={[0]='Strength of One',[1]='B0 K0100 FA CW L010 A:17480 T:17480'},
[9584]={[0]='The Second Sample',[1]='B476 K0140 FA L010 A:17423 T:17423 P:9628'},
[9585]={[0]='The Final Sample',[1]='B476 K0180 FA L010 A:17423 T:17423 P:9584'},
[9587]={[0]='Dark Tidings',[1]='B465 K0620 FA L059 A:100023890 T:16819'},
[9588]={[0]='Dark Tidings',[1]='B465 K0620 FH L059 A:100023892 T:3230'},
[9589]={[0]='The Blood is Life',[1]='B504956 K0630 FA L059 A:17479 T:17479 P:9587'},
[9590]={[0]='The Blood is Life',[1]='B504956 K0630 FH L059 A:17558 T:17558 P:9588'},
[9594]={[0]='Signs of the Legion',[1]='B476 K0140 FA L010 A:100023900 T:17433'},
[9602]={[0]='Deliver Them From Evil...',[1]='B0 K0090 FA L005 A:17240 T:17116 P:9537'},
[9603]={[0]='Beds, Bandages, and Beyond',[1]='B0 K0070 FA RD L005 A:16553 T:43991'},
[9604]={[0]='On the Wings of a Hippogryph',[1]='B0 K0070 FA RD L005 A:43991 T:16768 P:9603'},
[9605]={[0]='Hippogryph Master Stephanos',[1]='B0 FA RD K0070 L005 A:16768 T:17555 P:9604'},
[9606]={[0]='Return to Caregiver Chellan',[1]='B0 FA RD K0070 L005 A:17555 T:16553 P:9605'},
[9607]={[0]='Heart of Rage',[1]='B0 K0630 FA L059 A:17479 T:16819 P:9575'},
[9608]={[0]='Heart of Rage',[1]='B504956 K0630 FH L059 A:17558 T:3230 P:9572'},
[9612]={[0]='A Hearty Thanks!',[1]='B0 K0080 FA RD L005 A:17587 T:17116'},
[9616]={[0]='Bandits!',[1]='B0 K0070 FA L005 A:100023910 T:17116'},
[9620]={[0]='The Missing Survey Team',[1]='B476 K0140 FA L010 A:17423 T:17600 P:9581'},
[9621]={[0]='Envoy to the Horde',[1]='B0 K0210 FH RB L015 A:16802 T:10181 P:9328'},
[9622]={[0]='Warn Your People',[1]='B0 K0110 FA L007 A:17440 T:17116 P:9566+9570+9573'},
[9623]={[0]='Coming of Age',[1]='B0 K0110 FA L010 A:17116 T:17584'},
[9624]={[0]='A Favorite Treat',[1]='B476 K0120 FA L009 A:17599 T:17599'},
[9625]={[0]='Elekks Are Serious Business',[1]='B0 FA K0110 L010 A:17584 T:17586 P:9623 I:9634,28559'},
[9626]={[0]='Meeting the Warchief',[1]='B0 K0210 FH RB L015 A:10181 T:39605 P:9621'},
[9627]={[0]='Allegiance to the Horde',[1]='B0 K0210 FH RB L015 A:39605 T:16802 P:9626'},
[9628]={[0]='Salvaging the Data',[1]='B476 K0140 FA L010 A:17600 T:17423 P:9620'},
[9629]={[0]='Catch and Release',[1]='B476 K0130 FA L010 A:17434 T:17434'},
[9630]={[0]="Medivh's Journal",[1]='B0 K0700 L070 A:17613 T:16813'},
[9631]={[0]="A Colleague's Aid",[1]='B0 K0700 L070 A:17613 T:17636 P:9680'},
[9632]={[0]='Newfound Allies',[1]='B476 K0150 FA L015 A:17424 T:17614'},
[9634]={[0]='Alien Predators',[1]='B476 K0110 FA L008 A:17586 T:17586 O:9625,28559'},
[9635]={[0]='The Zapthrottle Mote Extractor!',[1]='B0 K0600 FH L058 A:17637 T:17637'},
[9636]={[0]='The Zapthrottle Mote Extractor!',[1]='B0 K0600 FA L058 A:17634 T:17634'},
[9637]={[0]="Kalynna's Request",[1]='B0 K0700 L070 A:17636 T:17636 P:9631'},
[9638]={[0]='In Good Hands',[1]='B0 K0700 L070 A:16813 T:16814 P:9630'},
[9639]={[0]='Kamsis',[1]='B0 K0700 L070 A:16814 T:16815 P:9638'},
[9640]={[0]='The Shade of Aran',[1]='B0 K0700 L070 A:16815 T:16815 P:9639'},
[9641]={[0]='Irradiated Crystal Shards',[1]='B476 K0150 FA L013 A:17684 T:17684'},
[9642]={[0]='More Irradiated Crystal Shards',[1]='B0 K0150 FA ++ L013 A:17684 T:17684 P:9641'},
[9643]={[0]='Constrictor Vines',[1]='B476 K0150 FA L014 A:17642 T:17642'},
[9644]={[0]='Nightbane',[1]='B0 K0700 L070 A:17636 T:17613 P:9637'},
[9645]={[0]="The Master's Terrace",[1]='B0 K0700 L070 A:16815 T:17613 P:9640'},
[9646]={[0]='WANTED: Deathclaw',[1]='B476 K0170 FA L009 A:1181889 T:17423'},
[9647]={[0]='Culling the Flutterers',[1]='B476 K0160 FA L014 A:17642 T:17642 P:9580,9643'},
[9648]={[0]="Mac'Aree Mushroom Menagerie",[1]='B476 K0140 FA L010 A:17663 T:17663'},
[9649]={[0]="Ysera's Tears",[1]='B476 K0180 FA L015 A:17663 T:17663 P:9648'},
[9663]={[0]='The Kessel Run',[1]='B476 K0120 FA L010 A:17649 T:17649'},
[9666]={[0]='Declaration of Power',[1]='B476 K0130 FA L010 A:17649 T:17649 P:9663'},
[9667]={[0]='Saving Princess Stillpine',[1]='B476 K0130 FA L010 A:17682 T:18803 P:9559'},
[9668]={[0]='Report to Exarch Admetius',[1]='B476 K0130 FA L010 A:17649 T:17658 P:9666 I:9693'},
[9669]={[0]='The Missing Expedition',[1]='B476 K0190 FA L016 A:17676 T:17676'},
[9670]={[0]="They're Alive! Maybe...",[1]='B476 K0190 FA L016 A:17686 T:17686'},
[9671]={[0]='Urgent Delivery',[1]='B476 K0180 FA L015 A:17703 T:17703 P:9506'}, -- is there something up with this needing an SP?
[9672]={[0]='The Bloodcurse Legacy',[1]='B476 K0180 FA L015 A:100024132 T:17712 P:9671 I:9751 B476'},
[9674]={[0]='The Bloodcursed Naga',[1]='B476 K0180 FA L015 A:17712 T:17712 P:9672,9751'},
[9676]={[0]='Paladin Training',[1]='B0 K0030 FH RB CP L003 A:15278 T:15280 P:8325'},
[9680]={[0]='Digging Up the Past',[1]='B0 K0700 L070 A:17613 T:17613 P:9645'},
[9682]={[0]='The Hopeless Ones...',[1]='B476 K0180 FA L015 A:17712 T:17712 P:9674'},
[9683]={[0]='Ending the Bloodcurse',[1]='B476 K0190 FA L015 A:17712 T:17712 P:9682'},
[9687]={[0]='Restoring Sanctity',[1]='B476 K0180 FA L015 A:17674 T:17674'},
[9688]={[0]='Into the Dream',[1]='B476 K0190 FA L016 A:17674 T:17674 P:9687'},
[9689]={[0]='Razormaw',[1]='B476 K0210 FA L019 A:17674 T:17674 P:9688'},
[9693]={[0]='What Argus Means to Me',[1]='B476 K0150 FA L010 A:17658 T:17684 O:9668'},
[9694]={[0]='Blood Watch',[1]='B476 K0150 FA L010 A:17684 T:17684 P:9693'},
[9696]={[0]='Translations...',[1]='B476 K0160 FA L014 A:17684 T:17825 P:9779'},
[9697]={[0]="Watcher Leesa'oh",[1]='B467 K0630 L061 A:17834 T:17831'},
[9698]={[0]='Audience with the Prophet',[1]='B476 K0160 FA L014 A:17825 T:17468 P:9696'},
[9699]={[0]='Truth or Fiction',[1]='B476 K0160 FA L014 A:17468 T:17684 P:9698'},
[9700]={[0]='I Shoot Magic Into the Darkness',[1]='B476 K0160 FA L014 A:17684 T:17684 P:9699'},
[9701]={[0]='Observing the Sporelings',[1]='B467 K0630 L061 A:17831 T:17831 P:9697'},
[9702]={[0]='A Question of Gluttony',[1]='B467 K0640 L061 A:17831 T:17831 P:9701'},
[9703]={[0]='The Cryo-Core',[1]='B476 K0170 FA L015 A:17843 T:17843 P:9700'},
[9704]={[0]='Slain by the Wretched',[1]='B0 K0050 FH RB L004 A:15301 T:17849 O:8347'},
[9705]={[0]='Package Recovery',[1]='B0 K0050 FH L004 A:17849 T:15301 P:9704'},
[9706]={[0]="Galaen's Journal - The Fate of Vindicator Saruan",[1]='B476 K0180 FA L015 A:1182032 T:17843 P:9779'},
[9708]={[0]='Familiar Fungi',[1]='B467 K0630 L061 A:17831 T:17831 P:9702'},
[9709]={[0]='Stealing Back the Mushrooms',[1]='B467 K0640 L061 A:17831 T:17831 P:9708'},
[9711]={[0]='Matis the Cruel',[1]='B476 K0180 FA L015 A:17843 T:17843 P:9706'},
[9714]={[0]='Bring Me Another Shrubbery!',[1]='B0 K0650 ++ L063 A:17856 T:17856 P:9715'},
[9715]={[0]='Bring Me A Shrubbery!',[1]='B0 K0650 L063 A:17856 T:17856 V2944999'},
[9716]={[0]='Disturbance at Umbrafen Lake',[1]='B467 K0630 L061 A:17841 T:17841'},
[9717]={[0]="Oh, It's On!",[1]='B0 K0650 L063 A:17857 T:17857 V2941999'},
[9718]={[0]='As the Crow Flies',[1]='B467 K0630 L061 A:17841 T:17841 P:9716'},
[9719]={[0]='Stalk the Stalker',[1]='B0 K0650 L063 A:17866 T:17866 V2941999'},
[9720]={[0]='Balance Must Be Preserved',[1]='B467 K0640 L061 A:17841 T:17841 P:9718'},
[9724]={[0]='Warning the Cenarion Circle',[1]='B467 K0640 L061 A:17841 T:16885 P:9731'},
[9726]={[0]="Now That We're Friends...",[1]='B467 K0640 L062 A:17856 T:17856 V2944999'},
[9727]={[0]="Now That We're Still Friends...",[1]='B0 K0640 L062 A:17856 T:17856 P:9726'},
[9728]={[0]='A Warm Welcome',[1]='B467 K0640 L061 A:17858 T:17858 P:9778'},
[9729]={[0]='Fhwoor Smash!',[1]='B0 K0650 L063 A:17877 T:17856'},
[9730]={[0]='Leader of the Darkcrest',[1]='B467 K0640 L058 A:1182115 T:17858'},
[9731]={[0]='Drain Schematics',[1]='B467 K0630 L059 A:100024330 T:17841'},
[9732]={[0]='Return to the Marsh',[1]='B467 K0630 L060 A:16885 T:17841 P:9724 B467'},
[9738]={[0]='Lost in Action',[1]='B0 K0650 L062 A:17884 T:17884 P:9876'},
[9739]={[0]="The Sporelings' Plight",[1]='B467 K0630 L061 A:17923 T:17923'},
[9740]={[0]='The Sun Gate',[1]='B476 K0180 FA L016 A:17844 T:17844 P:9746'},
[9741]={[0]='Critters of the Void',[1]='B476 K0180 FA L016 A:17926 T:17844'},
[9742]={[0]='More Spore Sacs',[1]='B467 K0630 ++ L061 A:17923 T:17923'},
[9743]={[0]='Natural Enemies',[1]='B467 K0640 L061 A:17923 T:17923'},
[9744]={[0]='More Tendrils!',[1]='B467 K0640 ++ L061 A:17923 T:17923'},
[9746]={[0]='Limits of Physical Exhaustion',[1]='B476 K0180 FA L016 A:17844 T:17844 P:9748'},
[9747]={[0]='The Umbrafen Tribe',[1]='B467 K0620 L060 A:17956 T:17956'},
[9748]={[0]="Don't Drink the Water",[1]='B476 K0180 FA L016 A:17844 T:17844 P:9703'},
[9751]={[0]='The Bloodcurse Legacy',[1]='B476 K0180 FA L015 A:17240 T:17712 P:9671 I:9672'},
[9752]={[0]='Escape from Umbrafen',[1]='B467 K0630 L060 A:17969 T:17841'},
[9753]={[0]='What We Know...',[1]='B476 K0200 FA L018 A:17844 T:17658'}, -- was RD, but NE got it too
[9756]={[0]="What We Don't Know...",[1]='B476 K0200 FA L018 A:17658 T:17658 P:9753'}, -- was RD, but NE got it too
[9758]={[0]='Return to Arcanist Vandril',[1]='B463 K0100 FH L009 A:16252 T:16197 P:9327,9329'},
[9759]={[0]='Ending Their World',[1]='B476 K0200 FA L018 A:17982 T:17658'}, -- was RD, but NE got it too
[9760]={[0]="Vindicator's Rest",[1]='B476 K0200 FA L018 A:17658 T:17986 P:9756'}, -- was RD, but NE got it too
[9761]={[0]='Clearing the Way',[1]='B476 K0200 FA L018 A:17986 T:17986 P:9760'}, -- was RD, but NE got it too
[9762]={[0]='The Unwritten Prophecy',[1]='B476 K0200 FA L018 A:17468 T:17468 P:9759'},
[9763]={[0]="The Warlord's Hideout",[1]='B0 K0700 L067 A:17884 T:17884'},
[9764]={[0]='Orders from Lady Vashj',[1]='B0 K0700 L067 A:100024367 T:17841'},
[9765]={[0]='Preparing for War',[1]='B0 K0700 L067 A:17841 T:17841 P:9764'},
[9766]={[0]='Coilfang Armaments',[1]='B0 K0700 ++ L067 A:17841 T:17841 P:9765'},
[9769]={[0]="There's No Explanation for Fashion",[1]='B467 K0620 FH L060 A:18016 T:18016'},
[9770]={[0]='Menacing Marshfangs',[1]='B467 K0620 FH L060 A:18012 T:18012'},
[9771]={[0]='Searching for Scout Jyoba',[1]='B467 K0620 FH L059 A:18011 T:18035 P:9774'},
[9772]={[0]="Jyoba's Report",[1]='B467 K0620 FH L060 A:18035 T:18011 P:9771'},
[9773]={[0]='No More Mushrooms!',[1]='B467 K0610 FH ++ L058 A:18016 T:18016'},
[9774]={[0]='Thick Hydra Scales',[1]='B467 K0620 FH L059 A:18011 T:18011'},
[9775]={[0]='Report to Shadow Hunter Denjai',[1]='B467 K0620 FH L062 A:18011 T:18013'},
[9776]={[0]='The Orebor Harborage',[1]='B467 FA K0640 L062 A:18003 T:18008'},
[9777]={[0]='Fulgor Spores',[1]='B467 FA K0620 L060 A:18007 T:18007'},
[9778]={[0]='Warden Hamoot',[1]='B467 K0640 L061 A:17841 T:17858'},
[9779]={[0]='Intercepting the Message',[1]='B476 K0160 FA L014 A:17684 T:17684 P:9694'},
[9780]={[0]='Umbrafen Eel Filets',[1]='B467 FA K0620 L060 A:18006 T:18006 P:9791'},
[9781]={[0]='Too Many Mouths to Feed',[1]='B467 FA K0620 L060 A:18005 T:18005'},
[9782]={[0]='The Dead Mire',[1]='B467 FA K0620 L060 A:18004 T:18004'},
[9783]={[0]='An Unnatural Drought',[1]='B467 FA K0620 L060 A:18004 T:18004 P:9782'},
[9784]={[0]='Identify Plant Parts',[1]='B0 K0640 ++ SP L060 A:17909 T:17909'},
[9785]={[0]='Blessings of the Ancients',[1]='B467 K0640 L059 A:18070 T:18070'},
[9786]={[0]="The Boha'mu Ruins",[1]='B467 FA K0620 L060 A:18003 T:18003'},
[9787]={[0]='Idols of the Feralfen',[1]='B467 FA K0620 L060 A:18003 T:18003 P:9786'},
[9788]={[0]='A Damp, Dark Place',[1]='B467 K0620 L060 A:17956 T:17956 P:9747'},
[9789]={[0]='Clefthoof Mastery',[1]='B477 K0660 L064 A:18180 T:18180 O:10113'},
[9790]={[0]='Diaphanous Wings',[1]='B467 FA K0620 L060 A:18005 T:18005 P:9781'},
[9791]={[0]='Menacing Marshfangs',[1]='B467 FA K0620 L060 A:18006 T:18006'},
[9792]={[0]='A Message to Telaar',[1]='B467 FA K0640 L064 A:18008 T:18097 V2541999'},
[9793]={[0]='The Fate of Tuurem',[1]='B467 FA K0620 L062 A:18004 T:18252 B478'},
[9794]={[0]='No Time for Curiosity',[1]='B475 FA K0650 L064 A:18019 T:18098 B475'},
[9795]={[0]='The Ogre Threat',[1]='B475 K0650 FH L064 A:18013 T:18248 B475'},
[9796]={[0]='News from Zangarmarsh',[1]='B467 K0620 FH L062 A:18011 T:18249 B478'},
[9797]={[0]='Reinforcements for Garadar',[1]='B467 K0640 FH L064 A:18091 T:18090 B477'},
[9798]={[0]='Blood Elf Plans',[1]='B0 K0050 FA L002 A:100024414 T:16535 P:9309'},
[9799]={[0]='Botanical Legwork',[1]='B0 K0030 FA A:20233 T:20233 P:10302'},
[9800]={[0]='A Rare Bean',[1]='B477 K0650 L064 A:18073 T:18073'},
[9801]={[0]='Gathering the Reagents',[1]='B467 FA K0620 L060 A:18003 T:18003 P:9787'},
[9802]={[0]='Plants of Zangarmarsh',[1]='B467 K0630 ++ L060 A:17909 T:17909'},
[9803]={[0]='Messenger to the Feralfen',[1]='B467 FA K0620 L060 A:18003 T:18003 P:9801'},
[9804]={[0]='Agitated Spirits of Skysong',[1]='B477 K0650 L064 A:18073 T:18073 P:9800'},
[9805]={[0]='Blessing of Incineratus',[1]='B477 K0650 L064 A:18073 T:18073 P:9804'},
[9806]={[0]='Fertile Spores',[1]='B467 K0640 L062 A:17925 T:17925'},
[9807]={[0]='More Fertile Spores',[1]='B0 K0640 ++ L062 A:17925 T:17925 P:9806'},
[9808]={[0]='Glowcap Mushrooms',[1]='B467 K0640 L062 A:17924 T:17924 W2944999'},
[9809]={[0]='More Glowcaps',[1]='B467 K0640 ++ SP L062 A:17924 T:17924 W2944999'},
[9810]={[0]='The Spirit Polluted',[1]='B477 K0660 L064 A:18073 T:18073 P:9805'},
[9811]={[0]="Friend of the Sin'dorei",[1]='B463 K0210 FH SB L015 A:16239 T:16802 P:9167'},
[9812]={[0]='Envoy to the Horde',[1]='B0 K0210 FH SB L015 A:16802 T:10181 P:9811'},
[9813]={[0]='Meeting the Warchief',[1]='B0 K0210 FH SB L015 A:10181 T:39605 P:9812'},
[9814]={[0]='Burstcap Mushrooms, Mon!',[1]='B467 K0640 FH L062 A:18014 T:18014'},
[9815]={[0]='Muck Diving',[1]='B477 K0660 L064 A:18073 T:18073'},
[9816]={[0]='Have You Ever Seen One of These?',[1]='B467 K0640 FH L062 A:18014 T:18014 P:9814'},
[9817]={[0]='Leader of the Bloodscale',[1]='B467 K0630 L058 A:1182115 T:17858'},
[9818]={[0]='The Underneath',[1]='B477 K0650 L064 A:18071 T:18099'},
[9819]={[0]='The Tortured Earth',[1]='B477 K0650 L064 A:18099 T:18099 P:9818'},
[9820]={[0]="WANTED: Boss Grog'ak",[1]='B467 K0640 FH L058 A:1182165 T:18013'},
[9821]={[0]='Eating Damnation',[1]='B477 K0660 L064 A:18099 T:18099 P:9819'},
[9822]={[0]='Impending Attack',[1]='B467 K0640 FH L062 A:18013 T:18013 P:9820'},
[9823]={[0]='Us or Them',[1]='B467 K0640 FH L062 A:18013 T:18013 P:9822'},
[9824]={[0]='Arcane Disturbances',[1]='B0 K0700 L068 A:17613 T:17613'},
[9825]={[0]='Restless Activity',[1]='B0 K0700 L068 A:17613 T:17613 P:9824'},
[9826]={[0]='Contact from Dalaran',[1]='B0 K0700 L068 A:17613 T:18165 P:9824,9825'},
[9827]={[0]='Withered Basidium',[1]='B467 FA K0620 L060 A:100024483 T:18007'},
[9828]={[0]='Withered Basidium',[1]='B467 K0620 FH L060 A:100024484 T:18012'},
[9829]={[0]='Khadgar',[1]='B0 K0700 L068 A:18165 T:18166 P:9826'},
[9830]={[0]='Stinger Venom',[1]='B467 FA K0640 L062 A:18009 T:18009 V2541999'},
[9831]={[0]='Entry Into Karazhan',[1]='B0 K0700 L068 A:18166 T:18166 P:9829'},
[9832]={[0]='The Second and Third Fragments',[1]='B0 K07064 L068 A:18166 T:18166 P:9831'},
[9833]={[0]='Lines of Communication',[1]='B467 FA K0640 L062 A:18009 T:18009 V2541999'},
[9834]={[0]='Natural Armor',[1]='B467 FA K0640 L062 A:18010 T:18010 V2541999'},
[9835]={[0]="Ango'rosh Encroachment",[1]='B467 FA K0640 L062 A:18008 T:18008'},
[9836]={[0]="The Master's Touch",[1]='B0 K0700 L068 A:18166 T:15608 P:9832'},
[9837]={[0]='Return to Khadgar',[1]='B0 K0700 L068 A:15608 T:18166 P:9836'},
[9838]={[0]='The Violet Eye',[1]='B0 K0700 L068 A:18166 T:17613 P:9837'},
[9839]={[0]='Overlord Gorefist',[1]='B467 FA K0640 L062 A:18008 T:18008 P:9835'},
[9840]={[0]='Assessing the Situation',[1]='B0 K0700 L068 A:17613 T:16388 P:9838'},
[9841]={[0]='Stinging the Stingers',[1]='B467 K0640 FH L062 A:18015 T:18015'},
[9842]={[0]='The Sharpest Blades',[1]='B467 K0640 FH L062 A:18015 T:18015 P:9841'},
[9843]={[0]="Keanna's Log",[1]='B0 K0700 L068 A:16388 T:17613 P:9840'},
[9844]={[0]='A Demonic Presence',[1]='B0 K0700 L068 A:17613 T:17613 P:9843'},
[9845]={[0]='Angling to Beat the Competition',[1]='B467 K0640 FH L062 A:18018 T:18018'},
[9846]={[0]='Spirits of the Feralfen',[1]='B467 K0620 FH L060 A:18017 T:18017'},
[9847]={[0]='A Spirit Ally?',[1]='B467 K0640 FH L060 A:18017 T:18017 P:9846'},
[9848]={[0]='Secrets of the Daggerfen',[1]='B467 FA K0640 L062 A:18019 T:18019'},
[9849]={[0]='Shattering the Veil',[1]='B477 K0670 L064 A:18099 T:18099 P:9821'},
[9850]={[0]='Clefthoof Mastery',[1]='B477 K0670 L064 A:18180 T:18180 P:9789'},
[9851]={[0]='Clefthoof Mastery',[1]='B477 K0670 L064 A:18180 T:18180 P:9850'},
[9852]={[0]='The Ultimate Bloodsport',[1]='B477 K0680 L064 A:18180 T:18180 P:9856+9859+9851'},
[9853]={[0]='Gurok the Usurper',[1]='B477 K0670 L064 A:18099 T:18099 P:9849'},
[9854]={[0]='Windroc Mastery',[1]='B477 K0650 L064 A:18200 T:18200'},
[9855]={[0]='Windroc Mastery',[1]='B477 K0670 L064 A:18200 T:18200 P:9854'},
[9856]={[0]='Windroc Mastery',[1]='B477 K0670 L064 A:18200 T:18200 P:9855'},
[9857]={[0]='Talbuk Mastery',[1]='B477 K0650 L064 A:18218 T:18218'},
[9858]={[0]='Talbuk Mastery',[1]='B477 K0660 L064 A:18218 T:18218 P:9857'},
[9859]={[0]='Talbuk Mastery',[1]='B477 K0660 L064 A:18218 T:18218 P:9858'},
[9860]={[0]='The New Directive',[1]='B0 K0700 L068 A:17613 T:18165 P:9844'},
[9861]={[0]='The Howling Wind',[1]='B477 K0670 L064 A:100024504 T:18074'},
[9862]={[0]='Murkblood Corrupters',[1]='B477 K0670 L064 A:18074 T:18074 P:9861'},
[9863]={[0]='Vile Idolatry',[1]='B477 K0660 FH L064 A:18066 T:18066'},
[9864]={[0]='The Missing War Party',[1]='B477 K0670 FH L064 A:18067 T:18229'},
[9865]={[0]='Once Were Warriors',[1]='B477 K0670 FH L064 A:18229 T:18229 P:9864'},
[9866]={[0]='He Will Walk The Earth...',[1]='B477 K0670 FH L064 A:18229 T:18067 P:9865'},
[9867]={[0]='Murkblood Leaders...',[1]='B477 K0670 FH L064 A:18068 T:18068'},
[9868]={[0]="The Totem of Kar'dash",[1]='B477 K0670 FH L064 A:18210 T:18063'},
[9869]={[0]='The Throne of the Elements',[1]='B477 FA K0660 L064 A:18233 T:18072'},
[9870]={[0]='The Throne of the Elements',[1]='B477 K0660 FH L064 A:18234 T:18072'},
[9871]={[0]='Murkblood Invaders',[1]='B477 FA K0670 L064 A:100024559 T:18183'},
[9872]={[0]='Murkblood Invaders',[1]='B477 K0670 FH L064 A:100024558 T:18063'},
[9873]={[0]='Ortor My Old Friend...',[1]='B477 FA K0670 L064 A:18183 T:18183 P:9871'},
[9874]={[0]='Stopping the Spread',[1]='B477 FA K0670 L064 A:18222 T:18222'},
[9875]={[0]='Uncatalogued Species',[1]='B0 K0630 ++ L060 A:100024407 T:17909'},
[9876]={[0]='Failed Incursion',[1]='B0 K0650 L062 A:17841 T:17884 P:9732'},
[9877]={[0]='A Restorative Draught',[1]='B463 K0200 FH L017 A:16240 T:16198 P:9220'},
[9878]={[0]='Solving the Problem',[1]='B477 FA K0670 L064 A:18224 T:18224'},
[9879]={[0]="The Totem of Kar'dash",[1]='B477 FA K0670 L064 A:18209 T:18183'},
[9882]={[0]='Stealing from Thieves',[1]='B477 K0660 L064 A:18265 T:18265 O:9913'},
[9883]={[0]='More Crystal Fragments',[1]='B0 K0660 ++ L064 A:18265 T:18265'},
[9884]={[0]='Membership Benefits',[1]='B477 K0700 L063 A:18265 T:18265'},
[9885]={[0]='Membership Benefits',[1]='B0 K0700 L063 A:18265 T:18265'},
[9886]={[0]='Membership Benefits',[1]='B477 K0700 L063 A:18265 T:18265'},
[9887]={[0]='Membership Benefits',[1]='B0 K0700 L063 A:18265 T:18265'},
[9888]={[0]='The Impotent Leader',[1]='B478 K0650 FH L064 A:18106 T:18273 B478'},
[9889]={[0]="Don't Kill the Fat One",[1]='B478 FH L064 A:18273 T:18262 P:9888'},
[9890]={[0]='Success!',[1]='B478 K0650 FH L064 A:18262 T:18273 P:9889'},
[9891]={[0]='Because Kilrath is a Coward',[1]='B477 K0650 FH L064 A:18273 T:18106 P:9890 B477'},
[9892]={[0]='More Obsidian Warbeads',[1]='B0 K0670 ++ L064 A:18265 T:18265'},
[9893]={[0]='Obsidian Warbeads',[1]='B477 K0670 L064 A:18265 T:18265'},
[9894]={[0]='Safeguarding the Watchers',[1]='B467 K0620 L060 A:18070 T:18070'},
[9895]={[0]='The Dying Balance',[1]='B467 K0620 L060 A:17834 T:17834'},
[9896]={[0]="Blacksting's Bane",[1]='B467 FA K0620 L060 A:18295 T:18295 P:9901'},
[9897]={[0]="I'm Saved!",[1]='B477 K0650 L064 A:18294 T:18218'},
[9898]={[0]="Nothin' Says Lovin' Like a Big Stinger",[1]='B467 K0620 FH L060 A:18012 T:18012 P:9770'},
[9899]={[0]='A Job Undone',[1]='B467 K0620 FH L060 A:18016 T:18016'},
[9900]={[0]="Gava'xi",[1]='B477 K0670 L065 A:18276 T:18276'},
[9901]={[0]='Unfinished Business',[1]='B467 FA K0620 L060 A:18295 T:18295'},
[9902]={[0]='The Terror of Marshlight Lake',[1]='B467 FA K0640 L062 A:18009 T:18009 V2541999'},
[9903]={[0]='The Biggest of Them All',[1]='B467 K0640 FH L062 A:18018 T:18018 P:9845'},
[9904]={[0]='Pursuing Terrorclaw',[1]='B467 K0640 FH L062 A:18018 T:18018'},
[9905]={[0]="Maktu's Revenge",[1]='B467 FA K0640 L062 A:18010 T:18010 P:9834'},
[9906]={[0]='Message in a Battle',[1]='B477 K0650 FH L064 A:18106 T:18106 P:9891'},
[9907]={[0]='An Audacious Advance',[1]='B477 K0660 FH L064 A:18106 T:18106 P:9906'},
[9910]={[0]='Standards and Practices',[1]='B477 K0650 FH L064 A:18300 T:18300'},
[9911]={[0]='The Count of the Marshes',[1]='B467 K0640 L062 A:100025459 T:17831'},
[9912]={[0]='The Cenarion Expedition',[1]='B467 K0620 L061 A:16885 T:17841 B467'},
[9913]={[0]='The Consortium Needs You!',[1]='B477 K0660 L064 A:18335 T:18265'},
[9914]={[0]='A Head Full of Ivory',[1]='B477 K0660 L064 A:18333 T:18333'},
[9915]={[0]='More Heads Full of Ivory',[1]='B0 K0660 ++ L064 A:18333 T:18333'},
[9916]={[0]='Bleeding Hollow Supply Crates',[1]='B477 K0660 FH L064 A:18300 T:18300 P:9910'},
[9917]={[0]='Do My Eyes Deceive Me',[1]='B477 FA K0650 L064 A:18353 T:18353'},
[9918]={[0]='Not On My Watch!',[1]='B477 FA K0650 L064 A:18353 T:18353 P:9917'},
[9919]={[0]='Sporeggar',[1]='B467 K0640 L060 A:17923 T:17924 V2941999'},
[9920]={[0]="Mo'mor the Breaker",[1]='B477 FA K0650 L064 A:18353 T:18223 P:9918'},
[9921]={[0]='The Ruins of Burning Blade',[1]='B477 FA K0650 L064 A:18223 T:18223 P:9920'},
[9922]={[0]='The Twin Clefts of Nagrand',[1]='B477 FA K0660 L064 A:18223 T:18223 P:9921'},
[9923]={[0]='HELP!',[1]='B477 FA K0650 L064 A:18369 T:18183'},
[9924]={[0]="Corki's Gone Missing Again!",[1]='B477 FA K0660 L064 A:18183 T:18183 P:9923'},
[9925]={[0]='Matters of Security',[1]='B477 K0660 L064 A:18276 T:18276'},
[9927]={[0]='Ruthless Cunning',[1]='B477 K0660 L064 A:18261 T:18261 O:10108'},
[9928]={[0]='Armaments for Deception',[1]='B477 K0660 L064 A:18261 T:18261 O:10108'},
[9931]={[0]='Returning the Favor',[1]='B477 K0660 L064 A:18261 T:18261 P:9928+9927'},
[9932]={[0]='Body of Evidence',[1]='B477 K0660 L064 A:18261 T:18261 P:9928+9927'},
[9933]={[0]='Message to Telaar',[1]='B477 FA K0660 L064 A:18261 T:18183 P:9932+9931'},
[9934]={[0]='Message to Garadar',[1]='B477 K0660 FH L064 A:18261 T:18063'},
[9935]={[0]='Wanted: Giselda the Crone',[1]='B477 K0660 FH L064 A:1182392 T:18407'},
[9936]={[0]='Wanted: Giselda the Crone',[1]='B477 FA K0660 L064 A:1182393 T:18408'},
[9937]={[0]='Wanted: Durn the Hungerer',[1]='B477 K0670 FH L066 A:18407 T:18407'},
[9938]={[0]='Wanted: Durn the Hungerer',[1]='B477 FA K0670 L066 A:18408 T:18408 P:9936+9940'},
[9939]={[0]='Wanted: Zorbo the Advisor',[1]='B477 K0660 FH L064 A:1182392 T:18407'},
[9940]={[0]='Wanted: Zorbo the Advisor',[1]='B477 FA K0660 L064 A:1182393 T:18408'},
[9944]={[0]="Missing Mag'hari Procession",[1]='B477 K0670 FH L065 A:18302 T:18414'},
[9945]={[0]='War on the Warmaul',[1]='B477 K0670 FH L065 A:18414 T:18414 P:9944'},
[9946]={[0]="Cho'war the Pillager",[1]='B477 K0670 FH L065 A:18414 T:18414 P:9945'},
[9948]={[0]='Finding the Survivors',[1]='B477 K0670 FH L065 A:18415 T:18415'},
[9951]={[0]="It's Watching You!",[1]='B478 K0640 L062 A:18424 T:18424'},
[9954]={[0]="Corki's Ransom",[1]='B477 FA K0670 L065 A:18183 T:18445 P:9924'},
[9955]={[0]="Cho'war the Pillager",[1]='B477 FA K0670 L065 A:18445 T:18183 P:9954'},
[9956]={[0]='The Ravaged Caravan',[1]='B477 FA K0670 L065 A:18416 T:18416'},
[9957]={[0]="What's Wrong at Cenarion Thicket?",[1]='B478 K0630 L062 A:17834 T:18446 I:9960,9961 B478'},
[9960]={[0]="What's Wrong at Cenarion Thicket?",[1]='B478 K0630 FH L062 A:18447 T:18446 I:9957,9961 B478'},
[9961]={[0]="What's Wrong at Cenarion Thicket?",[1]='B478 FA K0630 L062 A:18459 T:18446 I:9957,9960 B478'},
[9962]={[0]='The Ring of Blood: Brokentoe',[1]='B477 K0670 L065 A:18471 T:22893'},
[9967]={[0]='The Ring of Blood: The Blue Brothers',[1]='B477 K0670 L065 A:18471 T:22893 P:9962'},
[9968]={[0]='Strange Energy',[1]='B478 K0630 L062 A:18446 T:18446 P:9957,9960,9961'},	-- ?? does this really require one of the other breadcrumb quests?
[9970]={[0]='The Ring of Blood: Rokdar the Sundered Lord',[1]='B477 K0670 L065 A:18471 T:22893 P:9967'},
[9971]={[0]='Clues in the Thicket',[1]='B478 K0630 L062 A:18446 T:18446'},
[9972]={[0]="The Ring of Blood: Skra'gath",[1]='B477 K0670 L065 A:18471 T:22893 P:9970'},
[9973]={[0]='The Ring of Blood: The Warmaul Champion',[1]='B477 K0670 L065 A:18471 T:22893 P:9972'},
[9977]={[0]='The Ring of Blood: The Final Challenge',[1]='B477 K0680 L065 A:18471 T:22893 P:9973'},
[9978]={[0]='By Any Means Necessary',[1]='B478 K0630 L062 A:18446 T:18482 P:9968'},
[9979]={[0]='Wind Trader Lathrai',[1]='B0 K0630 L062 A:18482 T:18484 P:9978'},
[9982]={[0]='He Called Himself Altruis...',[1]='B477 FA K0680 L066 A:18416 T:18417'},
[9983]={[0]='He Called Himself Altruis...',[1]='B477 K0680 FH L066 A:18301 T:18417'},
[9986]={[0]='Stymying the Arakkoa',[1]='B478 FA K0640 L062 A:18389 T:18389'},
[9987]={[0]='Stymying the Arakkoa',[1]='B478 K0640 FH L062 A:18386 T:18386'},
[9990]={[0]='Investigate Tuurem',[1]='B478 K0640 L062 A:18484 T:18446 P:10112 B478'},
[9991]={[0]='Survey the Land',[1]='B477 K0680 L066 A:18417 T:18417 P:9982,9983'},
[9992]={[0]='Olemba Seeds',[1]='B478 FA K0630 L062 A:18390 T:18390'},
[9993]={[0]='Olemba Seed Oil',[1]='B478 K0630 FH L062 A:18385 T:18385'},
[9994]={[0]='What Are These Things?',[1]='B478 FA K0640 L062 A:18446 T:18459 P:9990'},
[9995]={[0]='What Are These Things?',[1]='B478 K0640 FH L062 A:18446 T:18447'},
[9996]={[0]='Attack on Firewing Point',[1]='B478 FA K0640 L062 A:21006 T:21006 P:10444'},
[9997]={[0]='Attack on Firewing Point',[1]='B478 K0640 FH L062 A:21007 T:21007 P:10448'},
[9998]={[0]='Unruly Neighbors',[1]='B478 FA K0630 L062 A:18387 T:18565'},
[9999]={[0]='Buying Time',[1]='B477 K0680 L066 A:18417 T:18417 P:9991'},
[10000]={[0]='An Unwelcome Presence',[1]='B478 K0630 FH L062 A:18383 T:18566'},
[10001]={[0]='The Master Planner',[1]='B477 K0680 L066 A:18417 T:18417 P:9999'},
[10002]={[0]='The Firewing Liaison',[1]='B478 FA K0640 L062 A:18565 T:18565 P:9998'},
[10003]={[0]='The Firewing Liaison',[1]='B478 K0640 FH L062 A:18566 T:18566 P:10000'},
[10004]={[0]='Patience and Understanding',[1]='B477 K0680 L066 A:18417 T:18584 P:10001'},
[10005]={[0]='Letting Earthbinder Tavgren Know',[1]='B478 FA K0630 L062 A:18459 T:18446 P:10446'},
[10006]={[0]='Letting Earthbinder Tavgren Know',[1]='B478 K0630 FH L062 A:18447 T:18446 P:10447'},
[10007]={[0]='Thinning the Ranks',[1]='B478 FA K0640 L062 A:18565 T:18565 P:9998'},
[10008]={[0]='What Happens in Terokkar Stays in Terokkar',[1]='B478 K0640 FH L062 A:18566 T:18566'},
[10009]={[0]="Crackin' Some Skulls",[1]='B478 K0680 L066 A:18584 T:18584 P:10004'},
[10010]={[0]="It's Just That Easy?",[1]='B478 K0680 L066 A:18584 T:18417 P:10009'},
[10011]={[0]='Forge Camp: Annihilated',[1]='B477 K0680 L066 A:18417 T:18417 P:10010'},
[10012]={[0]='Fel Orc Plans',[1]='B478 FA K0640 L062 A:1182549 T:18387 P:9998'},
[10013]={[0]='An Unseen Hand',[1]='B478 K0640 FH L062 A:1182549 T:18386'},
[10016]={[0]='Timber Worg Tails',[1]='B478 FA K0640 L062 A:18387 T:18387'},
[10017]={[0]='Strained Supplies',[1]='B0 K0640 ++ L062 A:18597 T:18597'},
[10018]={[0]='Vestments of the Wolf Spirit',[1]='B478 K0640 FH L062 A:18384 T:18384'},
[10019]={[0]='More Venom Sacs',[1]='B0 K0640 ++ L062 A:18597 T:18597'},
[10020]={[0]='A Cure for Zahlia',[1]='B0 K064512 L062 V3544999 A:18597 T:18597'},
[10021]={[0]='Restoring the Light',[1]='B0 K0640 L062 V3544999 A:18538 T:18538'},
[10022]={[0]='The Elusive Ironjaw',[1]='B478 FA K0640 L062 A:18387 T:18387 P:10016'},
[10023]={[0]='Patriarch Ironjaw',[1]='B478 K0640 FH L062 A:18384 T:18384 P:10018'},
[10024]={[0]="Voren'thal's Visions",[1]='B0 K0650 ++ L062 A:18596 T:18596'},
[10025]={[0]='More Basilisk Eyes',[1]='B0 K0650 ++ L062 A:18596 T:18596'},
[10026]={[0]='Magical Disturbances',[1]='B478 FA K0640 L062 A:18252 T:18252'},
[10027]={[0]='Magical Disturbances',[1]='B478 K0640 FH L062 A:18383 T:18383'},
[10028]={[0]='Vessels of Power',[1]='B478 FA K0630 L062 A:18390 T:18390 P:9992'},
[10030]={[0]='Recover the Bones',[1]='B478 K0650 L063 A:18675 T:19417 P:10840+10842'},
[10031]={[0]='Helping the Lost Find Their Way',[1]='B478 K0650 L063 A:19417 T:18675 P:10030'},
[10033]={[0]='Wanted: Bonelashers Dead!',[1]='B478 FA K0650 L062 A:1182587 T:18704'},
[10034]={[0]='Wanted: Bonelashers Dead!',[1]='B478 K0650 FH L062 A:1182588 T:18705'},
[10035]={[0]='Torgos!',[1]='B478 FA K0650 L063 A:18704 T:18704 P:10033'},
[10036]={[0]='Torgos!',[1]='B478 K0650 FH L063 A:18705 T:18705 P:10034'},
[10037]={[0]="Rather Be Fishin'",[1]='B478 K0640 L062 A:18653 T:18653'},
[10038]={[0]='Speak with Private Weeks',[1]='B478 FA K0640 L062 A:18713 T:18715'},
[10039]={[0]='Speak with Scout Neftis',[1]='B478 K0640 FH L062 A:18712 T:18714'},
[10040]={[0]='Who Are They?',[1]='B478 FA K0650 L062 A:18715 T:18715 P:10038'},
[10041]={[0]='Who Are They?',[1]='B478 K0650 FH L062 A:18714 T:18714 P:10039'},
[10042]={[0]='Kill the Shadow Council!',[1]='B478 FA K0650 L062 A:18715 T:18713 P:10040'},
[10043]={[0]='Kill the Shadow Council!',[1]='B478 K0650 FH L062 A:18714 T:18712 P:10041'},
[10044]={[0]='A Visit With the Greatmother',[1]='B477 K0680 FH L066 A:18063 T:18141'},
[10045]={[0]='Material Components',[1]='B477 K0680 FH L066 A:18141 T:18141 P:10044'},
[10047]={[0]='The Path of Glory',[1]='B465 FA K0610 L058 A:16839 T:16839'},
[10050]={[0]='Unyielding Souls',[1]='B465 FA K0610 L058 A:16827 T:16827'},
[10051]={[0]='Escape from Firewing Point!',[1]='B478 FA K0640 L062 A:18760 T:18745'},
[10052]={[0]='Escape from Firewing Point!',[1]='B478 K0640 FH L062 A:18760 T:18712'},
[10055]={[0]='Waste Not, Want Not',[1]='B465 FA K0610 L058 A:21209 T:21209'},
[10057]={[0]='Looking to the Leadership',[1]='B465 FA K0610 L058 A:16827 T:16827 P:10050'},
[10058]={[0]='An Old Gift',[1]='B465 FA K0610 L058 A:16825 T:16825'},
[10063]={[0]="Explorers' League, Is That Something for Gnomes?",[1]='B476 K0170 FA L013 A:18804 T:17421 I:9549'},
[10064]={[0]='Talk to the Hand',[1]='B476 K0180 FA L016 A:17423 T:17927'},
[10065]={[0]='Cutting a Path',[1]='B476 K0170 FA L016 A:17927 T:17927'},
[10066]={[0]='Oh, the Tangled Webs They Weave',[1]='B476 K0180 FA L016 A:17986,18020,18024 T:17986'},
[10067]={[0]='Fouled Water Spirits',[1]='B476 K0190 FA L016 A:17986,18020,18024 T:17986'},
[10068]={[0]='Arcane Missiles',[1]='B0 K0030 FH RL RB CM L003 A:15279 T:15279 P:8328'},
[10069]={[0]='Ways of the Light',[1]='B0 K0030 FH RB CP L003 A:15280 T:15280 P:9676'},
[10070]={[0]='Steady Shot',[1]='B0 K0030 FH RB CH L003 A:15513 T:15513 P:9393'},
[10071]={[0]='Evisceration',[1]='B0 K0030 FH RB CR L003 A:15285 T:15285 P:9392'},
[10072]={[0]='Healing the Wounded',[1]='B0 K0030 FH RB CT L003 A:15284 T:15284 P:8564'},
[10073]={[0]='Immolation',[1]='B0 K0030 FH RB CL L003 A:15283 T:15283 P:8563'},
[10074]={[0]="Oshu'gun Crystal Powder",[1]='B477 K0670 FH L064 A:18816 T:18816'},
[10075]={[0]="Oshu'gun Crystal Powder",[1]='B0 K0670 FH ++ L064 A:18816 T:18816 P:10074'},
[10076]={[0]="Oshu'gun Crystal Powder",[1]='B477 FA K067256 L064 A:18817 T:18817'},
[10077]={[0]="Oshu'gun Crystal Powder",[1]='B0 K0670 FA ++ L064 A:18817 T:18817 P:10076'},
[10078]={[0]='Laying Waste to the Unwanted',[1]='B465 FA K0610 L058 A:21209 T:21209 P:10055'},
[10079]={[0]="When This Mine's a-Rockin'",[1]='B465 FA K0610 L058 A:16837 T:16837'},
[10081]={[0]='To Meet Mother Kashur',[1]='B477 K0680 FH L066 A:18141 T:18687 P:10045'},
[10082]={[0]='The Agitated Ancestors',[1]='B477 K0680 FH L066 A:18687 T:18687 P:10081'},
[10085]={[0]='A Visit With The Ancestors',[1]='B477 K0680 FH L066 A:18687 T:18687 P:10082'},
[10086]={[0]='I Work... For the Horde!',[1]='B465 K0610 FH L058 A:21283 T:21283'},
[10087]={[0]='Burn It Up... For the Horde!',[1]='B465 K0610 FH L058 A:21283 T:21283 P:10086'},
[10091]={[0]='The Soul Devices',[1]='B0 K0700 L068 A:18891 T:18893 P:10178'},
[10093]={[0]='The Temple of Telhamat',[1]='B465 FA K0630 L058 A:16839 T:16796 P:10047'},
[10094]={[0]='The Codex of Blood',[1]='B0 K0700 L068 A:19542 T:1182947 P:10177'},
[10095]={[0]='Into the Heart of the Labyrinth',[1]='B0 K0700 L068 A:1182947 T:18893 P:10094'},
[10096]={[0]='Saving the Sporeloks',[1]='B467 K0620 L060 A:17909 T:17909 P:9747'},
[10097]={[0]='Brother Against Brother',[1]='B0 K0690 L065 A:18933 T:18933'},
[10098]={[0]="Terokk's Legacy",[1]='B0 K0690 L065 A:18933 T:18933'},
[10099]={[0]='The Mastermind',[1]='B465 FA K0610 L058 A:16837 T:16837 P:10079'},
[10101]={[0]='When Spirits Speak',[1]='B477 K0680 FH L066 A:18687 T:17545 P:10085'},
[10102]={[0]='A Secret Revealed',[1]='B477 K0680 FH L066 A:17545 T:18481 P:10101'},
[10103]={[0]='Report to Zurai',[1]='B465 K0610 FH L061 A:16789 T:18011 B467'},
[10104]={[0]='Concerns About Tuurem',[1]='B467 FA K0620 L062 A:18008 T:18252 B478'},
[10105]={[0]='News for Rakoria',[1]='B467 K0620 FH L062 A:18013 T:18385 B478'},
[10106]={[0]='Hellfire Fortifications',[1]='B465 +D FA K060256 L055 A:18266 T:18266 P:13408,13410'},	-- TODO: Really verify the P: for this
[10107]={[0]='Diplomatic Measures',[1]='B477 K0660 FH L064 A:18106 T:18261 P:9907'},
[10108]={[0]='Diplomatic Measures',[1]='B477 FA K0660 L064 A:18223 T:18261 P:9922'},
[10109]={[0]='I Must Have Them!',[1]='B477 K0660 L064 A:19035 T:19035'},
[10110]={[0]='Hellfire Fortifications',[1]='B465 +D FH K060256 L055 A:18267 T:18267 P:13409,13411'},	-- TODO: Really verify the P: for this
[10111]={[0]='Bring Me The Egg!',[1]='B477 K0660 L064 A:19035 T:19035 P:10109'},
[10112]={[0]='A Personal Favor',[1]='B478 K0640 L062 A:18484 T:18484 P:9979'},
[10113]={[0]='The Nesingwary Safari',[1]='B477 FA K0650 L064 A:19137 T:18180'},
[10114]={[0]='The Nesingwary Safari',[1]='B477 K0650 FH L064 A:19133 T:18200'},
[10115]={[0]='Daggerfen Deviance',[1]='B467 FA K0640 L062 A:18008 T:18008'},
[10116]={[0]='Wanted: Chieftain Mummaki',[1]='B467 FA K0640 L058 A:1183284 T:18008'},
[10117]={[0]='Wanted: Chieftain Mummaki',[1]='B467 K0640 FH L058 A:1182165 T:18013'},
[10118]={[0]='Message to the Daggerfen',[1]='B467 K0640 FH L062 A:18013 T:18013'},
[10119]={[0]='Through the Dark Portal',[1]='B465 FA K0610 L058 A:16841 T:19229'},
[10120]={[0]='Arrival in Outland',[1]='B465 K0610 FH L058 A:19253 T:18930 P:9407,28705'},
[10121]={[0]='Eradicate the Burning Legion',[1]='B465 K0610 FH L058 A:3230 T:19256 P:10291'},
[10123]={[0]='Felspark Ravine',[1]='B465 K0610 FH L058 A:19256 T:19256 P:10121'},
[10124]={[0]="Forward Base: Reaver's Fall",[1]='B465 K0610 FH L058 A:19256 T:19273 P:10123'},
[10129]={[0]='Mission: Gateways Murketh and Shaadraz',[1]='B465 K0620 FH L058 A:19273 T:19273 P:10208'},
[10132]={[0]='Colossal Menace',[1]='B465 K0630 L061 A:19293 T:19293'},
[10134]={[0]='Crimson Crystal Clue',[1]='B465 K0630 L061 A:100029476 T:19293'},
[10136]={[0]="Cruel's Intentions",[1]='B465 K0630 FH L058 A:3230 T:3230'},
[10140]={[0]='Journey to Honor Hold',[1]='B465 FA K0610 L058 A:18931 T:19308 P:10288'},
[10141]={[0]='The Legion Reborn',[1]='B465 FA K0610 L058 A:16819 T:19309'},
[10142]={[0]='The Path of Anguish',[1]='B465 FA K0610 L058 A:19309 T:19309 P:10141'},
[10143]={[0]='Expedition Point',[1]='B465 FA K0610 L058 A:19309 T:19310 P:10142'},
[10144]={[0]='Disrupt Their Reinforcements',[1]='B465 FA K0620 L058 A:19310 T:19310 P:10143'},
[10146]={[0]='Mission: The Murketh and Shaadraz Gateways',[1]='B465 FA K0620 L058 A:19310 T:19310'},
[10159]={[0]='Keep Thornfang Hill Clear!',[1]='B465 K0630 L061 A:16888 T:16888'},
[10160]={[0]='Know your Enemy',[1]='B465 FA K0610 L058 A:16819 T:16820'},
[10161]={[0]='In Case of Emergency...',[1]='B465 K0610 L058 A:19367 T:19367'},
[10162]={[0]='Mission: The Abyssal Shelf',[1]='B465 K0620 FH L058 A:19273 T:19273 P:10129'},
[10163]={[0]='Mission: The Abyssal Shelf',[1]='B465 FA K0620 L058 A:20232 T:20232'},
[10164]={[0]='Everything Will Be Alright',[1]='B0 K0670 L064 A:19698 T:19698'},
[10165]={[0]='Undercutting the Competition',[1]='B0 K0660 L064 A:19674 T:19674'},
[10166]={[0]="Whitebark's Memory",[1]='B0 K0100 FH L007 A:15398 T:19456 P:8474'},
[10167]={[0]='Auchindoun...',[1]='B504956 K0680 FH L066 A:18481 T:19412 P:10102'},
[10168]={[0]='What the Soul Sees',[1]='B0 K0680 FH L066 A:19412 T:18687 P:10167'},
[10170]={[0]='Return to the Greatmother',[1]='B477 K0680 FH L066 A:18687 T:18141 P:10168'},
[10171]={[0]='The Inconsolable Chieftain',[1]='B477 K0680 FH L066 A:18141 T:18063 P:10170'},
[10172]={[0]='There Is No Hope',[1]='B477 K0680 FH L066 A:18063 T:18141 P:10171'},
[10173]={[0]="The Archmage's Staff",[1]='B479 K0680 L067 A:19217 T:19217'},
[10174]={[0]='Curse of the Violet Tower',[1]='B479 K0680 L067 A:19217 T:19644 P:10300'},
[10176]={[0]="Ar'kelos the Guardian",[1]='B479 K0680 L067 A:19644 T:19481 P:10209'},
[10177]={[0]='Trouble at Auchindoun',[1]='B504956 K0700 L068 A:18893 T:19542'},
[10178]={[0]="Find Spy To'gun",[1]='B0 K0700 L068 A:19496 T:18891'},
[10180]={[0]="Can't Stay Away",[1]='B478 K0690 L065 A:19045 T:18933 B478'},
[10182]={[0]='Battle-Mage Dathric',[1]='B479 K0680 L067 A:100029233 T:19488'},
[10183]={[0]='Off To Area 52',[1]='B479 K0680 L067 A:19569 T:19570 I:11036,11037,11040,11042'},
[10184]={[0]='Malevolent Remnants',[1]='B479 K0680 L067 A:19488 T:19488'},
[10185]={[0]='A Fate Worse Than Death',[1]='B479 K0680 L067 A:19488 T:19488'},
[10186]={[0]="You're Hired!",[1]='B479 K0680 L067 A:19570 T:19570 P:10183,11036,11037,11040,11042'},
[10188]={[0]='The Sigil of Krasus',[1]='B479 K0690 L067 A:19644 T:19644 P:10174'},
[10189]={[0]="Manaforge B'naar",[1]='B479 K0680 L067 A:19468 T:19468 P:11039'},
[10190]={[0]='Recharging the Batteries',[1]='B479 K0680 L067 A:19578 T:19578'},
[10191]={[0]='Mark V is Alive!',[1]='B479 K0680 L067 A:19589 T:19578'},
[10192]={[0]="Krasus's Compendium",[1]='B479 K0690 L067 A:19644 T:19644 P:10188'},
[10193]={[0]='High Value Targets',[1]='B479 K0680 L067 A:19468 T:19468 P:10189'},
[10194]={[0]='Stealth Flight',[1]='B479 K0680 L067 A:19468 T:20162 P:10329'},
[10197]={[0]='A Convincing Disguise',[1]='B479 K0680 L067 A:19840 T:19840 P:10652'},
[10198]={[0]='Information Gathering',[1]='B479 K0680 L067 A:19840 T:19840 P:10197'},
[10199]={[0]='That Little Extra Kick',[1]='B479 K0680 L067 A:19617 T:19617 P:10342'},
[10200]={[0]='Return to Thalodien',[1]='B479 K0680 L067 A:19840 T:19468 P:10330'},
[10201]={[0]='And Now, the Moment of Truth',[1]='B478 K0650 FH L062 A:18385 T:18385 P:9993'},
[10202]={[0]='A Defector',[1]='B479 K0700 L067 A:19469 T:20920 P:10341'},
[10203]={[0]='Invaluable Asset Zapping',[1]='B479 K0690 L067 A:19570 T:19634'},
[10204]={[0]='Bloodgem Crystals',[1]='B479 K0680 L067 A:19469 T:19469'},
[10205]={[0]='Warp-Raider Nesaad',[1]='B479 K0690 L067 A:19880 T:19880'},
[10206]={[0]='Pick Your Part',[1]='B479 K0680 L067 A:19645 T:19645'},
[10208]={[0]='Disrupt Their Reinforcements',[1]='B465 K0620 FH L058 A:19273 T:19273 P:10124'},
[10209]={[0]="Summoner Kanthin's Prize",[1]='B479 K0690 L067 A:19644 T:19644 P:10301'},
[10210]={[0]="A'dal",[1]='B478 K0650 L060 A:19684 T:18481'},
[10211]={[0]='City of Light',[1]='B0 K0650 L060 A:18166 T:18166 P:10210'},
[10213]={[0]='Investigate the Crash',[1]='B465 K0610 FH L058 A:16858 T:19367 P:9345'},
[10216]={[0]='Safety Is Job One',[1]='B504956 K0660 L064 A:19670 T:1183877'},
[10218]={[0]="Someone Else's Hard Work Pays Off",[1]='B0 K0660 L064 A:19671 T:19674'},
[10220]={[0]='Make Them Listen',[1]='B465 K0610 FH L058 A:19682 T:19682'},
[10221]={[0]='Dr. Boom!',[1]='B479 K0680 L067 A:19634 T:19634'},
[10222]={[0]='The Sunfury Garrison',[1]='B479 K0690 L067 A:19488 T:19488'},
[10223]={[0]='Down With Daellis',[1]='B479 K0690 L067 A:19488 T:19488 P:10222'},
[10224]={[0]='Essence for the Engines',[1]='B479 K0680 L067 A:19709 T:19709 P:10225'},
[10225]={[0]='Report to Engineering',[1]='B479 K0680 L067 A:19570 T:19709'},
[10226]={[0]='Elemental Power Extraction',[1]='B479 K0680 L067 A:19709 T:19709 P:10224'},
[10227]={[0]='I See Dead Draenei',[1]='B478 K0670 L064 A:19697 T:19417'},
[10228]={[0]='Ezekiel',[1]='B0 K0670 L064 A:19417 T:19715 P:10227'},
[10229]={[0]='Decipher the Tome',[1]='B465 K0610 FH L058 A:100028552 T:19736'},
[10230]={[0]='The Battle Horn',[1]='B465 K0610 FH L058 A:19736 T:19736 P:10229'},
[10231]={[0]="What Book? I Don't See Any Book.",[1]='B0 K0670 L064 A:19715 T:19720 P:10228'},
[10232]={[0]='In A Scrap With The Legion',[1]='B479 K0690 L067 A:19645 T:19645'},
[10233]={[0]='Torching Sunfury Hold',[1]='B479 K0690 L067 A:19489 T:19489'},
[10234]={[0]="One Demon's Trash...",[1]='B479 K0690 L067 A:19728 T:19728 P:10333'},
[10235]={[0]='Declawing Doomclaw',[1]='B479 K0690 L067 A:19728 T:19728 P:10234'},
[10236]={[0]='Outland Sucks!',[1]='B465 K0610 L058 A:16915 T:16915'},
[10237]={[0]='Warn Area 52!',[1]='B479 K0690 L067 A:19728 T:19570 P:10235'},
[10238]={[0]='How to Serve Goblins',[1]='B465 K0610 L058 A:16915 T:16915 P:10236'},
[10239]={[0]='Potential Energy Source',[1]='B479 K0690 L067 A:19489 T:19489 P:10343'},
[10240]={[0]='Building a Perimeter',[1]='B479 K0690 L067 A:19489 T:19489 P:10239'},
[10241]={[0]="Distraction at Manaforge B'naar",[1]='B479 K0680 L067 A:19466 T:19466 P:11038'},
[10242]={[0]='Spinebreaker Post',[1]='B465 K0600 FH L058 A:21257 T:21279'},
[10243]={[0]='Naaru Technology',[1]='B479 K0680 L067 A:19467 T:1183770'},
[10245]={[0]="B'naar Console Transcription",[1]='B479 K0680 L067 A:1183770 T:19467 P:10243'},
[10246]={[0]='Attack on Manaforge Coruu',[1]='B479 K0680 L067 A:19466 T:19466'},
[10247]={[0]='Doctor Vomisa, Ph.T.',[1]='B479 K0690 L067 A:19570 T:19832 P:10237'},
[10248]={[0]='You, Robot',[1]='B479 K0690 L067 A:19832 T:19832 P:10247'},
[10249]={[0]='Back to the Chief!',[1]='B479 K0690 L067 A:19832 T:19570 P:10248'},
[10250]={[0]='Bloody Vengeance',[1]='B465 K0610 FH L058 A:19736 T:19736 P:10230'},
[10251]={[0]="The Master's Grand Design?",[1]='B0 K0670 L064 A:19720 T:19844 P:10231 B477'},
[10252]={[0]='Vision of the Dead',[1]='B477 K0670 L064 A:19844 T:19844 P:10251'},
[10253]={[0]='Levixus the Soul Caller',[1]='B504956 K0670 L064 A:19844 T:19417 P:10252'},
[10254]={[0]='Force Commander Danath',[1]='B465 FA K0600 L055 A:19308 T:16819 P:10140'},
[10255]={[0]='Testing the Antidote',[1]='B465 K0630 L061 A:16991 T:16991 P:9372'},
[10256]={[0]='Finding the Keymaster',[1]='B479 K0690 L067 A:19481 T:19481'},
[10257]={[0]='Capturing the Keystone',[1]='B479 K07064 L067 A:19481 T:19481 P:10256'},
[10258]={[0]='Honor the Fallen',[1]='B465 K0610 FH L058 A:19736 T:19937 P:10250'},
[10261]={[0]='Wanted: Annihilator Servo!',[1]='B479 K0680 L067 A:1183811 T:19645'},
[10262]={[0]='A Heap of Ethereals',[1]='B479 K0680 L067 A:19880 T:19880 P:10265'},
[10263]={[0]='Assisting the Consortium',[1]='B479 K0680 L067 A:19467 T:19880'},
[10264]={[0]='Assisting the Consortium',[1]='B479 K0680 L067 A:19468 T:19880'},
[10265]={[0]='Consortium Crystal Collection',[1]='B479 K0690 L067 A:19880 T:19880 P:10263,10264'},
[10266]={[0]='Request for Assistance',[1]='B479 K0690 L067 A:19880 T:20066 P:10205'},
[10267]={[0]='Rightful Repossession',[1]='B479 K0690 L067 A:20066 T:20066 P:10266'},
[10268]={[0]='An Audience with the Prince',[1]='B479 K0690 L067 A:20066 T:20084 P:10267'},
[10269]={[0]='Triangulation Point One',[1]='B479 K0690 L067 A:20084 T:20092 P:10268'},
[10270]={[0]='A Not-So-Modest Proposal',[1]='B479 K0700 L068 A:20071 T:20518'},
[10271]={[0]='Getting Down to Business',[1]='B479 K0700 L068 A:20518 T:20154 P:10270'},
[10272]={[0]='A Promising Start',[1]='B479 K0700 L068 A:20110 T:20110 P:10281'},
[10273]={[0]='Troublesome Distractions',[1]='B479 K0700 L068 A:20110 T:20110 P:10272'},
[10274]={[0]='Securing the Celestial Ridge',[1]='B479 K0700 L068 A:20110 T:20110 P:10273'},
[10275]={[0]='Triangulation Point Two',[1]='B479 K0700 L067 A:20092 T:20112 P:10269'},
[10276]={[0]='Full Triangle',[1]='B479 K0700 L067 A:20112 T:20084 P:10275'},
[10277]={[0]='The Caverns of Time',[1]='B0 K0680 L066 A:20130 T:20130 O:10279'},
[10278]={[0]='The Warp Rifts',[1]='B465 K0610 FH L058 A:19683 T:19683'},
[10279]={[0]="To The Master's Lair",[1]='B0 K0660 L066 A:20142 T:20130 I:10277'},
[10280]={[0]='Special Delivery to Shattrath City',[1]='B0 K0700 L067 A:20084 T:18481 P:10276'},
[10281]={[0]='Formal Introductions',[1]='B479 K0700 L068 A:20154 T:20110 P:10271'},
[10282]={[0]='Old Hillsbrad',[1]='B0 K0680 L066 A:20130 T:18723 P:1'},
[10283]={[0]="Taretha's Diversion",[1]='B0 K0680 L066 A:18723 T:17876 P:10282'},
[10284]={[0]='Escape from Durnholde',[1]='B0 K0680 L066 A:17876 T:18723 P:10283'},
[10285]={[0]='Return to Andormu',[1]='B0 K0680 L066 A:18723 T:20130 P:10284'},
[10286]={[0]="Arelion's Secret",[1]='B465 K0620 FH L060 A:16793 T:20159 P:9374'},
[10287]={[0]='The Mistress Revealed',[1]='B465 K0620 FH L060 A:20159 T:16793 P:10286'},
[10288]={[0]='Arrival in Outland',[1]='B465 FA K0610 L058 A:19229 T:18931 P:10119,28708'},
[10289]={[0]='Journey to Thrallmar',[1]='B465 K0610 FH L058 A:18930 T:19255 P:10120'},
[10290]={[0]='In Search of Farahlite',[1]='B479 K0700 L068 A:20067 T:20067'},
[10291]={[0]='Report to Nazgrel',[1]='B465 K0610 FH L055 A:19255 T:3230 P:10289'},
[10293]={[0]='Hitting the Motherlode',[1]='B479 K0690 L067 A:20067 T:20067 P:10290'},
[10294]={[0]='Void Ridge',[1]='B465 K0610 FH L058 A:19683 T:19683 P:10278'},
[10295]={[0]='From the Abyss',[1]='B465 K0630 FH L058 A:19683 T:19683 P:10294'},
[10296]={[0]='The Black Morass',[1]='B0 K0700 L066 A:20130 T:20201 P:1'},
[10297]={[0]='The Opening of the Dark Portal',[1]='B0 K0700 L066 A:20201 T:20201 P:10296'},
[10298]={[0]='Hero of the Brood',[1]='B0 K0700 L066 A:20201 T:20130 P:10297'},
[10299]={[0]="Shutting Down Manaforge B'naar",[1]='B479 K0680 L067 A:19467 T:19467 P:10245'},
[10300]={[0]='Rebuilding the Staff',[1]='B479 K0690 L067 A:19217 T:19217 P:10173'},
[10301]={[0]='Unlocking the Compendium',[1]='B479 K0690 L067 A:19644 T:19644 P:10192'},
[10302]={[0]='Volatile Mutations',[1]='B0 K0020 FA A:16514 T:16514 O:9371'},
[10303]={[0]='The Blood Elves',[1]='B0 K0040 FA A:16521,16546 T:16546 P:9309'},
[10304]={[0]='Vindicator Aldar',[1]='B0 K0040 FA A:16514 T:16535 P:9294 I:9303'},
[10305]={[0]='Abjurist Belmara',[1]='B479 K0690 L067 A:100029234 T:19488'},
[10306]={[0]='Conjurer Luminrath',[1]='B479 K0690 L067 A:100029235 T:19488'},
[10307]={[0]='Cohlien Frostweaver',[1]='B479 K0690 L067 A:100029236 T:19488'},
[10308]={[0]='Another Heap of Ethereals',[1]='B0 K0680 ++ L067 A:19880 T:19880'},
[10309]={[0]="It's a Fel Reaver, But with Heart",[1]='B479 K0680 L067 A:19690 T:19690'},
[10310]={[0]='Sabotage the Warp-Gate!',[1]='B479 K0700 L068 A:20281 T:20066 P:10311'},
[10311]={[0]='Drijya Needs Your Help',[1]='B479 K0700 L068 A:20066 T:20281'},
[10312]={[0]="The Annals of Kirin'Var",[1]='B479 K0690 L067 A:19488 T:19488 P:10184'},
[10313]={[0]='Measuring Warp Energies',[1]='B479 K0680 L067 A:19466 T:19466 P:10241'},
[10314]={[0]='A Lingering Suspicion',[1]='B479 K0690 L067 A:1184300 T:19488 P:10316'},
[10315]={[0]='Neutralizing the Nethermancers',[1]='B479 K0700 L068 A:20341 T:20341'},
[10316]={[0]='Searching for Evidence',[1]='B479 K0690 L067 A:19488 T:1184300 P:10312'},
[10317]={[0]='Dealing with the Foreman',[1]='B479 K0700 L068 A:20112 T:20393'},
[10318]={[0]='Dealing with the Overmaster',[1]='B479 K0700 L068 A:20393 T:20112 P:10317'},
[10319]={[0]='Capturing the Phylactery',[1]='B479 K0690 L067 A:19488 T:19488 P:10314'},
[10320]={[0]='Destroy Naberius!',[1]='B479 K0690 L067 A:19488 T:19488 P:10319'},
[10321]={[0]='Shutting Down Manaforge Coruu',[1]='B479 K0690 L067 A:19467 T:19467 P:10299'},
[10322]={[0]='Shutting Down Manaforge Duro',[1]='B479 K0700 L067 A:19467 T:19467 P:10321'},
[10323]={[0]='Shutting Down Manaforge Ara',[1]='B479 K0700 L067 A:19467 T:19467 P:10322'},
[10324]={[0]='The Great Moongraze Hunt',[1]='B0 K0080 FA L004 A:17110 T:17110 P:9454'},
[10325]={[0]="Marks of Kil'jaeden",[1]='B0 K0650 L062 A:18537 T:18537'},
[10326]={[0]="More Marks of Kil'jaeden",[1]='B0 K0650 ++ L062 A:18537 T:18537 P:10325'},
[10327]={[0]="Single Mark of Kil'jaeden",[1]='B0 K0650 ++ L062 A:18537 T:18537 P:10325'},
[10328]={[0]='Sunfury Briefings',[1]='B479 K0700 L067 A:19466 T:19466'},
[10329]={[0]="Shutting Down Manaforge B'naar",[1]='B479 K0680 L067 A:19468 T:19468 P:10193'},
[10330]={[0]='Shutting Down Manaforge Coruu',[1]='B479 K0690 L067 A:19840 T:19840 P:10198'},
[10331]={[0]='Indispensable Tools',[1]='B479 K0690 L067 A:20463 T:20463'},
[10332]={[0]='Master Smith Rhonsus',[1]='B479 K0690 L067 A:20463 T:20463 P:10331'},
[10333]={[0]='Help Mama Wheeler',[1]='B479 K0690 L067 A:19645 T:19728'},
[10334]={[0]='Needs More Cowbell',[1]='B479 K0690 L067 A:20464 T:20415'},
[10335]={[0]='Surveying the Ruins',[1]='B479 K0700 L068 A:20470 T:20470'},
[10336]={[0]='The Minions of Culuthas',[1]='B479 K0700 L068 A:20471 T:20471'},
[10337]={[0]='When the Cows Come Home',[1]='B479 K0690 L067 A:20415 T:20464'},
[10338]={[0]='Shutting Down Manaforge Duro',[1]='B479 K0700 L067 A:19468 T:19468 P:10200'},
[10339]={[0]='The Ethereum',[1]='B479 K0700 L070 A:20448 T:20482'},
[10340]={[0]='Shatter Point',[1]='B465 FA K0600 L058 A:19310 T:20234 P:10146'},
[10341]={[0]="Kick Them While They're Down",[1]='B479 K0700 L067 A:19469 T:19469'},
[10342]={[0]='Securing the Shaleskin Shale',[1]='B479 K0680 L067 A:19617 T:19617'},
[10343]={[0]='The Unending Invasion',[1]='B479 K0690 L067 A:19489 T:19489'},
[10344]={[0]='Wing Commander Gryphongar',[1]='B465 FA K0600 L058 A:20234 T:20232 P:10340'},
[10345]={[0]='The Flesh Lies...',[1]='B479 K0700 L068 A:20551 T:20551'},
[10346]={[0]='Return to the Abyssal Shelf',[1]='B465 FA K0620 L058 A:20235 T:20235'},
[10347]={[0]='Return to the Abyssal Shelf',[1]='B465 K0620 FH ++ L058 A:19401 T:19401'},
[10348]={[0]='New Opportunities',[1]='B479 K0690 L067 A:20810 T:20810'},
[10349]={[0]='The Earthbinder',[1]='B465 K0630 L061 A:19293 T:19294 P:10134'},
[10350]={[0]='Behomat',[1]='B0 K0100 FA CW L010 A:17480 T:17120 P:9582'},
[10351]={[0]='Natural Remedies',[1]='B465 K0630 L061 A:19294 T:19294'},
[10353]={[0]='Arconus the Insatiable',[1]='B479 K0700 L068 A:20552 T:20448'},
[10355]={[0]='Withered Flesh',[1]='B467 FA K0620 L060 A:18007 T:18007 P:9827'},
[10365]={[0]='Shutting Down Manaforge Ara',[1]='B479 K0700 L067 A:19468 T:19468 P:10338'},
[10367]={[0]='A Traitor Among Us',[1]='B465 K0620 L060 A:19361 T:19361 P:10403'},
[10368]={[0]='The Dreghood Elders',[1]='B465 K0620 L060 A:19361 T:19361 P:10367'},
[10369]={[0]="Arzeth's Demise",[1]='B465 K0620 L060 A:19361 T:19361 P:10368'},
[10380]={[0]='A Dark Pact',[1]='B479 K0700 L067 A:20780 T:20780 P:10431'},
[10381]={[0]='Aldor No More',[1]='B479 K0700 L067 A:20780 T:19466 P:10380'},
[10382]={[0]='Go to the Front',[1]='B465 FA K0610 L058 A:20232 T:20793'},
[10384]={[0]='Ethereum Data',[1]='B479 K0700 L068 A:20482 T:20482 P:10339'},
[10385]={[0]='Potential for Brain Damage = High',[1]='B479 K0700 L068 A:20482 T:20482 P:10384'},
[10388]={[0]='Return to Thrallmar',[1]='B465 K0610 FH L058 A:16576,19273 T:3230'},
[10389]={[0]='The Agony and the Darkness',[1]='B465 K0610 FH L058 A:21175 T:21175'},
[10390]={[0]='Forge Camp: Mageddon',[1]='B465 K0610 FH L058 A:3230 T:3230 P:10388'},
[10391]={[0]='Cannons of Rage',[1]='B465 K0610 FH L058 A:3230 T:3230 P:10390'},
[10392]={[0]='Doorway to the Abyss',[1]='B465 K0610 FH L058 A:3230 T:3230 P:10391'},
[10393]={[0]='Vile Plans',[1]='B465 K0610 FH L058 A:100029590 T:21175'},
[10394]={[0]='Disruption - Forge Camp: Mageddon',[1]='B465 FA K0610 L058 A:20793 T:20793 P:10382'},
[10395]={[0]='The Dark Missive',[1]='B465 FA K0610 L058 A:100029588 T:16839'},
[10396]={[0]='Enemy of my Enemy...',[1]='B465 FA K0610 L058 A:20793 T:20793 P:10394'},
[10397]={[0]='Invasion Point: Annihilator',[1]='B465 FA K0610 L058 A:20793 T:20793 P:10396'},
[10399]={[0]='The Heart of Darkness',[1]='B465 FA K0610 L058 A:16839 T:16839 P:10395'},
[10400]={[0]='Overlord',[1]='B465 FA K0630 L058 A:16819 T:16819'},
[10403]={[0]='Naladu',[1]='B465 K0620 L060 A:20678,20679 AH:20677 T:19361'},
[10405]={[0]='S-A-B-O-T-A-G-E',[1]='B479 K0700 L068 A:20482 T:20482 P:10385'},
[10406]={[0]='Delivering the Message',[1]='B479 K0700 L068 A:20482 T:20482 P:10405'},
[10407]={[0]="Socrethar's Shadow",[1]='B479 K0700 L067 A:19467 T:19467'},
[10408]={[0]='Nexus-King Salhadaar',[1]='B479 K0700 L068 A:20482 T:20482 P:10406'},
[10409]={[0]='Deathblow to the Legion',[1]='B0 K0700 L067 A:18538 T:18538 P:10410'},
[10410]={[0]="Ishanah's Help",[1]='B479 K0700 L067 A:19467 T:18538 P:10407'},
[10411]={[0]='Electro-Shock Goodness!',[1]='B479 K0700 L068 A:20449 T:20449'},
[10412]={[0]='Firewing Signets',[1]='B0 K0650 L062 A:18531 T:18531'},
[10414]={[0]='Single Firewing Signet',[1]='B0 K0700 ++ L064 A:18531 T:18531 P:10415'},
[10415]={[0]='More Firewing Signets',[1]='B0 K0700 ++ L064 A:18531 T:18531 P:10412'},
[10416]={[0]='Synthesis of Power',[1]='B0 K0700 ++ L064 A:18530 T:18530'},
[10417]={[0]='Run a Diagnostic!',[1]='B479 K0680 L067 A:20810 T:20810'},
[10418]={[0]='Deal With the Saboteurs',[1]='B479 K0680 L067 A:20810 T:20810 P:10417'},
[10419]={[0]='Arcane Tomes',[1]='B0 K0700 ++ L064 A:18530 T:18530 P:10416'},
[10420]={[0]='A Cleansing Light',[1]='B0 K0700 ++ L064 A:18538 T:18538'},
[10421]={[0]='Fel Armaments',[1]='B0 K0700 ++ L064 A:18538 T:18538 P:10420'},
[10422]={[0]='Captain Tyralius',[1]='B479 K0700 L068 A:20450 T:20450'},
[10423]={[0]='To the Stormspire',[1]='B479 K0690 L067 A:20810 T:20811 P:10418'},
[10424]={[0]='Diagnosis: Critical',[1]='B479 K0690 L067 A:20811 T:20811 P:10423'},
[10425]={[0]='Escape from the Staging Grounds',[1]='B479 K0700 L068 A:20763 T:20448'},
[10426]={[0]='Flora of the Eco-Domes',[1]='B479 K0690 L067 A:20871 T:20871'},
[10427]={[0]='Creatures of the Eco-Domes',[1]='B479 K0690 L067 A:20871 T:20871 P:10426'},
[10428]={[0]='The Missing Fisherman',[1]='B0 K0100 FA L008 A:17488 T:17311'},
[10429]={[0]='When Nature Goes Too Far',[1]='B479 K0690 L067 A:20871 T:20871 P:10427'},
[10430]={[0]='Testing the Prototype',[1]='B479 K0690 L067 A:20811 T:20913 P:10424'},
[10431]={[0]='Outside Assistance',[1]='B479 K0700 L067 A:19466 T:20780 P:10328'},
[10432]={[0]='Damning Evidence',[1]='B479 K0700 L067 A:20920 T:19468 P:10202'},
[10433]={[0]='Keeping Up Appearances',[1]='B479 K0690 L067 A:20921 T:20921'},
[10434]={[0]='The Dynamic Duo',[1]='B479 K0690 L067 A:20921 T:20205 P:10433'},
[10435]={[0]='Retrieving the Goods',[1]='B479 K0690 L067 A:20205 T:20205 P:10434'},
[10436]={[0]='All Clear!',[1]='B479 K0690 L067 A:20913 T:20913 P:10430'},
[10437]={[0]='Recipe for Destruction',[1]='B479 K0700 L068 A:20907 T:20907'},
[10438]={[0]='On Nethery Wings',[1]='B479 K0700 L068 A:20907 T:20907 P:10437'},
[10439]={[0]='Dimensius the All-Devouring',[1]='B479 K0700 L068 A:20907 T:20907 P:10438'},
[10440]={[0]='Success!',[1]='B479 K0690 L067 A:20913 T:20811 P:10436'},
[10442]={[0]='Helping the Cenarion Post',[1]='B465 K0610 FH L061 A:16790 T:16991'},
[10443]={[0]='Helping the Cenarion Post',[1]='B465 FA K0610 L061 A:16796 T:16991 P:10442'},
[10444]={[0]='Report to the Allerian Post',[1]='B478 FA K0640 L062 A:18459 T:21006 P:9994'},
[10446]={[0]='The Final Code',[1]='B478 FA K0650 L062 A:21006 T:18459 P:9996'},
[10447]={[0]='The Final Code',[1]='B478 K0650 FH L062 A:21007 T:18447 P:9997'},
[10448]={[0]='Report to Stonebreaker Camp',[1]='B478 K0640 FH L062 A:18447 T:21007 P:9995'},
[10449]={[0]='Apothecary Zelana',[1]='B465 K0600 FH L058 A:21256 T:21257 P:10450'},
[10450]={[0]='Bonechewer Blood',[1]='B465 K0600 FH L058 A:21256 T:21256'},
[10451]={[0]='Escape from Coilskar Cistern',[1]='B473 K0700 L068 A:21027 T:21024'},
[10455]={[0]='The Encroaching Wilderness',[1]='B475 FA K0660 L065 A:21066 T:21066'},
[10456]={[0]='Marauding Wolves',[1]='B475 FA K0660 L065 A:21066 T:21066 P:10455'},
[10457]={[0]='Protecting Our Own',[1]='B475 FA K0660 L065 A:21066 T:21066 P:10456'},
[10458]={[0]='Enraged Spirits of Fire and Earth',[1]='B473 K0700 L068 A:21024 T:21024 P:10680,10681'},
[10460]={[0]="Defender's Pledge",[1]='B0 K0700 L070 A:19936 T:19935 TA:19936 P:1'},
[10461]={[0]="Restorer's Pledge",[1]='B0 K0700 SP L070 A:19935 T:19935 P:1'},
[10462]={[0]="Champion's Pledge",[1]='B0 K0700 L070 A:19935 T:19935 P:1'},
[10463]={[0]="Sage's Pledge",[1]='B0 K0700 L070 A:19936 T:19935 TA:19936 P:1'},
[10464]={[0]="Sage's Vow",[1]='B0 K0700 L070 A:19935,19936 T:19935 P:1'},
[10465]={[0]="Restorer's Vow",[1]='B0 K0700 L070 A:19935 T:19935 P:10461 P:1'},
[10466]={[0]="Champion's Vow",[1]='B0 K0700 L070 A:19935 AH:19936 T:19935 P:1'},
[10467]={[0]="Defender's Vow",[1]='B0 K0700 L070 A:19935 AA:19936 T:19935 P:1'},
[10468]={[0]="Sage's Oath",[1]='B0 K0700 L070 A:19935 AA:19936 T:19935 P:10464'},
[10469]={[0]="Restorer's Oath",[1]='B0 K0700 L070 A:19935 T:19935 P:10465'},
[10470]={[0]="Champion's Oath",[1]='B0 K0700 L070 A:19935 AH:19936 T:19935 P:10466'},
[10471]={[0]="Defender's Oath",[1]='B0 K0700 L070 A:19935 T:19935 P:10467'},
[10472]={[0]="Sage's Covenant",[1]='B0 K0700 L070 A:19935 AH:19936 T:19935 P:10468'},
[10473]={[0]="Restorer's Covenant",[1]='B0 K0700 L070 A:19935 T:19935 P:10469'},
[10474]={[0]="Champion's Covenant",[1]='B0 K0700 L070 A:19935 T:19935 P:10470'},
[10475]={[0]="Defender's Covenant",[1]='B0 K0700 L070 A:19935 T:19935 P:10471'},
[10476]={[0]='Fierce Enemies',[1]='B477 FA K0670 L065 A:18408 T:18408'},
[10477]={[0]='More Warbeads',[1]='B0 K0680 FA ++ L065 A:18408 T:18408'},
[10478]={[0]='More Warbeads!',[1]='B0 K0680 FH ++ L065 A:18407 T:18407'},
[10479]={[0]='Proving Your Strength',[1]='B477 K0670 FH L065 A:18407 T:18407'},
[10480]={[0]='Enraged Spirits of Water',[1]='B473 K0700 L068 A:21024 T:21024 P:10458'},
[10481]={[0]='Enraged Spirits of Air',[1]='B473 K0700 L068 A:21024 T:21024 P:10480'},
[10482]={[0]='Fel Orc Scavengers',[1]='B465 FA K0580 L058 A:16820 T:16820 P:10160'},
[10483]={[0]='Ill Omens',[1]='B465 FA K0580 L058 A:16820 T:21133 P:10482'},
[10484]={[0]='Cursed Talismans',[1]='B465 FA K0580 L058 A:21133 T:21133'},
[10485]={[0]='Warlord of the Bleeding Hollow',[1]='B465 FA K0600 L058 A:21133 T:21133 P:10484'},
[10486]={[0]='The Encroaching Wilderness',[1]='B475 K0660 FH L065 A:21117 T:21117'},
[10487]={[0]='Dust from the Drakes',[1]='B475 K0660 FH L065 A:21117 T:21117 P:10486'},
[10488]={[0]='Protecting Our Own',[1]='B475 K0660 FH L065 A:21117 T:21117 P:10487'},
[10489]={[0]='Felling an Ancient Tree',[1]='B475 K0660 FH L065 A:1184660 T:21147'},
[10502]={[0]='The Bloodmaul Ogres',[1]='B475 FA K0660 L065 A:21158 T:21158'},
[10503]={[0]='The Bladespire Threat',[1]='B475 K0660 FH L065 A:21147 T:21147'},
[10504]={[0]='The Bladespire Ogres',[1]='B475 FA K0660 L065 A:21158 T:21158 P:10502'},
[10505]={[0]='The Bloodmaul Ogres',[1]='B475 K0660 FH L065 A:21147 T:21147 P:10503'},
[10506]={[0]='A Dire Situation',[1]='B475 FA K0660 L065 A:21066 T:21066 P:10457'},
[10507]={[0]='Turning Point',[1]='B0 K0700 L067 A:18530 T:18530 P:10509'},
[10508]={[0]="A Gift for Voren'thal",[1]='B479 K0700 L067 A:19468 T:19468 P:10432'},
[10509]={[0]='Bound for Glory',[1]='B0 K0700 L067 A:19468 T:18530 P:10508'},
[10510]={[0]='Into the Draenethyst Mine',[1]='B475 FA K0660 L065 A:21197 T:21197'},
[10511]={[0]='Strange Brew',[1]='B475 FA K0660 L065 A:21151 T:21151'},
[10512]={[0]='Getting the Bladespire Tanked',[1]='B475 FA K0660 L065 A:21151 T:21151'},
[10513]={[0]='Oronok Torn-heart',[1]='B473 K0700 L068 A:21024 T:21183 P:10481'},
[10514]={[0]='I Was A Lot Of Things...',[1]='B473 K0700 L068 A:21183 T:21183 P:10513'},
[10515]={[0]='A Lesson Learned',[1]='B473 K0700 L068 A:21183 T:21183 P:10514'},
[10516]={[0]='The Trappings of a Vindicator',[1]='B475 FA K0660 L065 A:21277 T:21277'},
[10517]={[0]="Gorr'Dim, Your Time Has Come...",[1]='B475 FA K0670 L065 A:21277 T:21277 P:10516'},
[10518]={[0]='Planting the Banner',[1]='B475 FA K0670 L065 A:21277 T:21158 P:10517'},
[10519]={[0]='The Cipher of Damnation - Truth and History',[1]='B473 K0700 L068 A:21183 T:21183 P:10515'},
[10521]={[0]="Grom'tor, Son of Oronok",[1]='B473 K0700 L068 A:21183 T:21291'},
[10522]={[0]="The Cipher of Damnation - Grom'tor's Charge",[1]='B473 K0700 L068 A:21291 T:21291 P:10521'},
[10523]={[0]='The Cipher of Damnation - The First Fragment Recovered',[1]='B473 K0700 L068 A:21291 T:21183 P:10522'},
[10524]={[0]='Thunderlord Clan Artifacts',[1]='B475 K0660 FH L065 A:100030431 T:21311'},
[10525]={[0]='Vision Guide',[1]='B475 K0660 FH L065 A:21311 T:21311 P:10524'},
[10526]={[0]='The Thunderspike',[1]='B475 K0670 FH L065 A:21311 T:21311 P:10525'},
[10527]={[0]="Ar'tor, Son of Oronok",[1]='B473 K0700 L068 A:21183 T:21292'},
[10528]={[0]='Demonic Crystal Prisons',[1]='B473 K0700 L068 A:21292 T:21292 P:10527'},
[10537]={[0]="Lohn'goron, Bow of the Torn-heart",[1]='B473 K0700 L068 A:21318 T:21318'},
[10538]={[0]='Boiling Blood',[1]='B465 K0600 FH L058 A:21279 T:21279'},
[10540]={[0]="The Cipher of Damnation - Ar'tor's Charge",[1]='B473 K0700 L068 A:21318 T:21318 P:10537'},
[10541]={[0]='The Cipher of Damnation - The Second Fragment Recovered',[1]='B473 K0700 L068 A:21318 T:21183 P:10540'},
[10542]={[0]='They Stole Me Hookah and Me Brews!',[1]='B475 K0660 FH L065 A:21349 T:21349'},
[10543]={[0]='Grimnok and Korgaah, I Am For You!',[1]='B475 K0670 FH L065 A:21349 T:21349 P:10545'},
[10544]={[0]='A Curse Upon Both of Your Clans!',[1]='B475 K0660 FH L065 A:21349 T:21349 P:10543'},
[10545]={[0]='Bladespire Kegger',[1]='B475 K0660 FH L065 A:21349 T:21349 P:10542'},
[10546]={[0]='Borak, Son of Oronok',[1]='B473 K0700 L068 A:21183 T:21293'},
[10547]={[0]='Of Thistleheads and Eggs...',[1]='B473 K0700 L068 A:21293 T:21411 P:10546'},
[10550]={[0]='The Bundle of Bloodthistle',[1]='B473 K0700 L068 A:21411 T:21293 P:10547 B473'},
[10551]={[0]='Allegiance to the Aldor',[1]='B0 SP K0650 L060 A:18166 T:18166 P:10211'},
[10552]={[0]='Allegiance to the Scryers',[1]='B0 SP K0650 L060 A:18166 T:18166 P:10211'},
[10553]={[0]="Voren'thal the Seer",[1]='B0 K0650 L060 A:18166 T:18530'},
[10554]={[0]='Ishanah',[1]='B0 K0650 L060 V3544999 A:18166 T:18538 P:10551'},
[10555]={[0]='Malaise',[1]='B475 FA K0660 L065 A:21469 T:1184825'},
[10556]={[0]='Scratches',[1]='B475 FA K0660 L065 A:1184825 T:21469 P:10555'},
[10557]={[0]='Test Flight: The Zephyrium Capacitorium',[1]='B475 FA K0640 L062 A:21460 T:21460'},
[10562]={[0]='Besieged!',[1]='B473 FA K0690 L067 A:21357 T:21357 P:11044'},
[10563]={[0]='To Legion Hold',[1]='B473 FA K0690 L067 A:21357 T:21357 P:10562'},
[10564]={[0]='Blast the Infernals!',[1]='B473 FA K0690 L067 A:21357 T:21357 P:10572'},
[10565]={[0]="The Stones of Vekh'nir",[1]='B475 K0660 FH L061 A:21496 T:21496'},
[10566]={[0]='Trial and Error',[1]='B475 K0660 FH L061 A:21496 T:21496'},
[10567]={[0]='Creating the Pendant',[1]='B475 K0660 L066 A:21782 T:21782'},
[10568]={[0]="Tablets of Baa'ri",[1]='B473 K0700 L068 A:21402 T:21402'},
[10569]={[0]="The Sketh'lon Wreckage",[1]='B473 FA K0690 L067 A:22042 T:22042'},
[10570]={[0]='To Catch A Thistlehead',[1]='B473 K0700 L068 A:21293 T:21293 P:10550'},
[10571]={[0]='Oronu the Elder',[1]='B473 K0700 L068 A:21402 T:21402 P:10568,10683'},
[10572]={[0]='Setting Up the Bomb',[1]='B473 FA K0690 L067 A:21357 T:21357 P:10563'},
[10573]={[0]='The Deathforge',[1]='B473 FA K0690 L067 A:21357 T:21471 P:10564'},
[10574]={[0]='The Ashtongue Corruptors',[1]='B473 K0700 L068 A:21402 T:21402 P:10571,10684'},
[10575]={[0]="The Warden's Cage",[1]='B473 K0700 L068 A:21402 T:21826 P:10574,10685'},
[10576]={[0]='The Shadowmoon Shuffle',[1]='B473 K0700 L068 A:21293 T:21293 P:10570'},
[10577]={[0]='What Illidan Wants, Illidan Gets...',[1]='B473 K0700 L068 A:21293 T:21293 P:10576'},
[10578]={[0]="The Cipher of Damnation - Borak's Charge",[1]='B473 K0700 L068 A:21293 T:21293 P:10577'},
[10579]={[0]='The Cipher of Damnation - The Third Fragment Recovered',[1]='B473 K0700 L068 A:21293 T:21183 P:10578'},
[10580]={[0]='Where Did Those Darn Gnomes Go?',[1]='B475 FA K0670 L065 A:21158 T:21690'},
[10581]={[0]='Follow the Breadcrumbs',[1]='B475 FA K0670 L065 A:21690 T:21691 P:10580'},
[10582]={[0]='Minions of the Shadow Council',[1]='B473 FA K0690 L067 A:21471 T:21471 P:10573'},
[10583]={[0]='The Fate of Flanis',[1]='B473 FA K0690 L067 A:21471 T:21471'},
[10584]={[0]='Picking Up Some Power Converters',[1]='B475 FA K0670 L065 A:21691 T:21691'},
[10585]={[0]='The Summoning Chamber',[1]='B473 FA K0690 L067 A:21471 T:21471'},
[10586]={[0]='Bring Down the Warbringer!',[1]='B473 FA K0690 L067 A:21471 T:21357'},
[10587]={[0]='Karabor Training Grounds',[1]='B473 K0700 L068 A:21860 T:21860'},
[10588]={[0]='The Cipher of Damnation',[1]='B473 K0700 L068 A:21183 T:21024'},
[10589]={[0]='Gaining Access',[1]='B473 FA K0690 L067 A:21357 T:21357 P:10586'},
[10594]={[0]='Gauging the Resonant Frequency',[1]='B475 FA K0670 L065 A:21755 T:21755 P:10608'},
[10595]={[0]='Besieged!',[1]='B473 K0690 FH L067 A:21359 T:21359 P:11048'},
[10596]={[0]='To Legion Hold',[1]='B473 K0690 FH L067 A:21359 T:21359 P:10595'},
[10597]={[0]='Setting Up the Bomb',[1]='B473 K0690 FH L067 A:21359 T:21359 P:10596'},
[10598]={[0]='Blast the Infernals!',[1]='B473 K0690 FH L067 A:21359 T:21359 P:10597'},
[10599]={[0]='The Deathforge',[1]='B473 K0690 FH L067 A:21359 T:21475 P:10598'},
[10600]={[0]='Minions of the Shadow Council',[1]='B473 K0690 FH L067 A:21475 T:21475 P:10599'},
[10601]={[0]='The Fate of Kagrosh',[1]='B473 K0690 FH L067 A:21475 T:21475'},
[10602]={[0]='The Summoning Chamber',[1]='B473 K0690 FH L067 A:21475 T:21475'},
[10603]={[0]='Bring Down the Warbringer!',[1]='B473 K0690 FH L067 A:21475 T:21359'},
[10604]={[0]='Gaining Access',[1]='B473 K0690 FH L067 A:21359 T:21359 P:10603'},
[10606]={[0]='The Art of Fel Reaver Maintenance',[1]='B473 FA K0690 L067 A:21790 T:21790 P:10766'},
[10607]={[0]='Whispers of the Raven God',[1]='B475 K0680 L066 A:21782 T:21782 P:10567'},
[10608]={[0]='Crystal Clear',[1]='B475 FA K0670 L065 A:21755 T:21755'},
[10609]={[0]='What Came First, the Drake or the Egg?',[1]='B475 FA K0670 L065 A:21110 T:21110'},
[10611]={[0]='The Art of Fel Reaver Maintenance',[1]='B473 K0690 FH L067 A:21789 T:21789 P:10767'},
[10612]={[0]='The Fel and the Furious',[1]='B473 FA K0690 L067 A:21790 T:21790 P:10606'},
[10613]={[0]='The Fel and the Furious',[1]='B473 K0690 FH L067 A:21789 T:21789 P:10611'},
[10614]={[0]='Whispers on the Wind',[1]='B475 K0660 FH L065 A:21984 T:22004 P:10718'},
[10615]={[0]='Ruuan Weald',[1]='B475 K0640 FH L061 A:21496 T:21782 P:10566'},
[10617]={[0]='Silkwing Cocoons',[1]='B475 K0660 FH L061 A:21895 T:21895'},
[10618]={[0]='The Softest Wings',[1]='B475 K0650 FH L061 A:21896 T:21896'},
[10619]={[0]='The Ashtongue Tribe',[1]='B473 K0700 L068 A:21822 T:21822'},
[10620]={[0]='Ridgespine Menace',[1]='B475 FA K0670 L065 A:21824 T:21824'},
[10621]={[0]='Illidari-Bane Shard',[1]='B473 FA K0690 L067 A:100030756 T:19370'},
[10622]={[0]='Proof of Allegiance',[1]='B473 K0700 L068 A:21826 T:21826 P:10575,10686'},
[10623]={[0]='Illidari-Bane Shard',[1]='B473 K0690 FH L067 A:100030579 T:19333'},
[10624]={[0]='A Haunted History',[1]='B473 K0690 FH L067 A:21772 T:21772 P:11046'},
[10625]={[0]='Spectrecles',[1]='B473 K0690 FH L067 A:21772 T:21772 P:10624'},
[10626]={[0]='Capture the Weapons',[1]='B473 FA K0690 L067 A:19370 T:19370 P:10621'},
[10627]={[0]='Capture the Weapons',[1]='B473 K0690 FH L067 A:19333 T:19333 P:10623'},
[10628]={[0]='Akama',[1]='B473 K0700 L068 A:21826 T:21700 P:10622'},
[10629]={[0]='Shizz Work',[1]='B465 K0610 L058 A:16915 T:16915 P:10238'},
[10630]={[0]='Beneath Thrallmar',[1]='B465 K0610 L058 A:16915 T:16915 P:10629'},
[10632]={[0]='Cutting Your Teeth',[1]='B475 FA K0670 L065 A:21118 T:21118'},
[10633]={[0]='Teron Gorefiend - Lore and Legend',[1]='B473 K0700 FH L067 A:21772 T:21797 P:10625'},
[10634]={[0]="Divination: Gorefiend's Armor",[1]='B473 K0700 L067 A:21797 T:21797'},
[10635]={[0]="Divination: Gorefiend's Cloak",[1]='B473 K0700 L067 A:21797 T:21797'},
[10636]={[0]="Divination: Gorefiend's Truncheon",[1]='B473 K0700 L067 A:21797 T:21797'},
[10637]={[0]='A Necessary Distraction',[1]='B473 K0700 L068 A:21860 T:21860 P:10587'},
[10639]={[0]='Teron Gorefiend, I am...',[1]='B473 K0700 FH L067 A:21797 T:21772'},
[10640]={[0]='Altruis',[1]='B477 K0700 L068 A:21860 T:18417 P:10637 B477'},
[10641]={[0]='Against the Legion',[1]='B477 K0700 L068 A:18417 T:18417'},
[10642]={[0]='A Ghost in the Machine',[1]='B473 FA K0690 L067 A:21774 T:21774 P:11045'},
[10643]={[0]='Harbingers of Shadowmoon',[1]='B473 FA K0690 L067 A:21774 T:21774 P:10642'},
[10644]={[0]='Teron Gorefiend - Lore and Legend',[1]='B473 FA K0700 L067 A:21774 T:21797 P:10643'},
[10645]={[0]='Teron Gorefiend, I am...',[1]='B473 FA K0700 L067 A:21797 T:21774'},
[10646]={[0]="Illidan's Pupil",[1]='B477 K0700 L068 A:18417 T:18417'},
[10647]={[0]='Wanted: Uvuros, Scourge of Shadowmoon',[1]='B473 K0700 FH L067 A:1184945 T:21771'},
[10648]={[0]='Wanted: Uvuros, Scourge of Shadowmoon',[1]='B473 FA K0700 L067 A:1184946 T:21775'},
[10649]={[0]='The Book of Fel Names',[1]='B0 K0700 L068 A:18417 T:18417 P:10646'},
[10650]={[0]='Return to the Aldor',[1]='B0 K0700 L068 A:18417 T:21860 B473'},
[10651]={[0]='Varedis Must Be Stopped',[1]='B0 K0700 L068 A:21860 T:21860 P:10650'},
[10652]={[0]='Behind Enemy Lines',[1]='B479 K0690 L067 A:20162 T:19840 P:10194'},
[10653]={[0]='Marks of Sargeras',[1]='B0 K0700 L068 A:18537 T:18537'},
[10654]={[0]='More Marks of Sargeras',[1]='B0 K0700 ++ L068 A:18537 T:18537 P:10653'},
[10655]={[0]='Single Mark of Sargeras',[1]='B0 K0700 ++ L068 A:18537 T:18537 P:10654'},
[10656]={[0]='Sunfury Signets',[1]='B0 K0700 L068 A:18531 T:18531'},
[10657]={[0]='Ride the Lightning',[1]='B475 FA K0670 L065 A:21691 T:21691 P:10584'},
[10658]={[0]='More Sunfury Signets',[1]='B0 K0700 ++ L068 A:18531 T:18531 P:10656'},
[10659]={[0]='Single Sunfury Signet',[1]='B0 K0700 ++ L068 A:18531 T:18531 P:10658'},
[10660]={[0]='What Strange Creatures...',[1]='B473 K0690 FH L067 A:21770 T:21770'},
[10661]={[0]='Spleendid!',[1]='B473 FA K0690 L067 A:21777 T:21777'},
[10662]={[0]='The Hermit Smith',[1]='B473 FA K0690 L067 A:19370 T:21465 P:10626 B478'},
[10663]={[0]='The Hermit Smith',[1]='B473 K0690 FH L067 A:19333 T:21465 P:10662 B478'},
[10664]={[0]='Additional Materials',[1]='B473 K0690 L067 A:21465 T:21465 P:10662,10663'},
[10665]={[0]='Fresh from the Mechanar',[1]='B0 K06964 L067 A:21465 T:21465'},
[10666]={[0]='The Lexicon Demonica',[1]='B0 K06964 L067 A:21465 T:21465'},
[10667]={[0]='Underworld Loam',[1]='B0 K07064 L067 A:21465 T:21465'},
[10668]={[0]='Against the Illidari',[1]='B477 K0700 L068 A:18417 T:18417'},
[10669]={[0]='Against All Odds',[1]='B477 K0700 L068 A:18417 T:18417'},
[10670]={[0]='Tear of the Earthmother',[1]='B0 K07064 L067 A:21465 T:21465'},
[10671]={[0]='More than a Pound of Flesh',[1]='B475 FA K0670 L065 A:21824 T:21824'},
[10672]={[0]='Frankly, It Makes No Sense...',[1]='B473 K0690 FH L067 A:21770 T:21770 P:10660'},
[10673]={[0]='Felspine the Greater',[1]='B473 K0700 FH L067 A:21770 T:21770 P:10672'},
[10674]={[0]='Trapping the Light Fantastic',[1]='B475 FA K0670 L065 A:21691 T:21691 P:10657'},
[10675]={[0]='Show Them Gnome Mercy!',[1]='B475 FA K0680 L065 A:21691 T:21691 P:10674'},
[10676]={[0]='Bane of the Illidari',[1]='B0 K0700 L067 A:21465 T:21465'},
[10677]={[0]='The Second Course...',[1]='B473 FA K0690 L067 A:21777 T:21777 P:10661'},
[10678]={[0]='The Main Course!',[1]='B473 FA K0700 L067 A:21777 T:21777 P:10677'},
[10679]={[0]='Quenching the Blade',[1]='B0 K0700 L067 A:21465 T:21465 P:10676'},
[10680]={[0]="The Hand of Gul'dan",[1]='B473 FA K0700 L068 A:21937 T:21024'},
[10681]={[0]="The Hand of Gul'dan",[1]='B473 K0700 FH L068 A:21938 T:21024 P:10680'},
[10682]={[0]='A Time for Negotiation...',[1]='B475 K0670 L065 A:22007 T:22007'},
[10683]={[0]="Tablets of Baa'ri",[1]='B473 K0700 L068 A:21955 T:21955 P:10568'},
[10684]={[0]='Oronu the Elder',[1]='B473 K0700 L068 A:21955 T:21955 P:10571'},
[10685]={[0]='The Ashtongue Corruptors',[1]='B473 K0700 L068 A:21955 T:21955 P:10574'},
[10686]={[0]="The Warden's Cage",[1]='B473 K0700 L068 A:21955 T:21826 P:10575'},
[10687]={[0]='Karabor Training Grounds',[1]='B473 K0700 L068 A:21954 T:21954'},
[10688]={[0]='A Necessary Distraction',[1]='B473 K0700 L068 A:21954 T:21954 P:10687'},
[10689]={[0]='Altruis',[1]='B477 K0700 L068 A:21954 T:18417 P:10688 B477'},
[10690]={[0]='The Den Mother',[1]='B475 FA K0660 L065 A:1185035 T:21158'},
[10691]={[0]='Return to the Scryers',[1]='B0 K0700 L068 A:18417 T:21954'},
[10692]={[0]='Varedis Must Be Stopped',[1]='B473 K0700 L068 A:21954 T:21954 P:10691'},
[10701]={[0]='Breaking Down Netherock',[1]='B479 K0680 L067 A:1183811 T:19570'},
[10702]={[0]="A Grunt's Work...",[1]='B473 K0690 FH L067 A:21769 T:21769'},
[10703]={[0]='Put On Yer Kneepads...',[1]='B473 FA K0690 L067 A:21773 T:21773'},
[10704]={[0]='How to Break Into the Arcatraz',[1]='B0 K0700 L067 A:18481 T:18481 P:10280'},
[10705]={[0]='Seer Udalo',[1]='B504956 K0700 L068 A:21700 T:21962 P:10628'},
[10706]={[0]='A Mysterious Portent',[1]='B0 K0700 L068 A:21962 T:21700 P:10705'},
[10707]={[0]="The Ata'mal Terrace",[1]='B0 K0700 L068 A:21700 T:21700 P:10706'},
[10709]={[0]='Reunion',[1]='B475 K0670 FH L065 A:22004 T:21984 P:10614'},
[10710]={[0]='Test Flight: The Singing Ridge',[1]='B475 FA K0640 L062 A:21460 T:21460 P:10557'},
[10711]={[0]="Test Flight: Razaan's Landing",[1]='B475 FA K00640 L062 A:21460 T:21460'},
[10712]={[0]='Test Flight: Ruuan Weald',[1]='B475 FA K0640 L062 A:21460 T:22020'},
[10713]={[0]='...and a Time for Action',[1]='B475 K0670 L065 A:22007 T:22007 P:10682'},
[10714]={[0]="On Spirit's Wings",[1]='B475 K0670 FH L065 A:21984 T:21984 P:10709'},
[10715]={[0]='Into the Churning Gulch',[1]='B475 K0670 FH L065 A:22103 T:22103 P:10783'},
[10717]={[0]='Poaching from Poachers',[1]='B475 K0670 L065 A:21983 T:21983'},
[10718]={[0]='The Spirits Have Voices',[1]='B475 K0670 FH L065 A:21950 T:21984'},
[10719]={[0]='Did You Get The Note?',[1]='B475 K0670 L065 A:100031120 T:22007'},
[10720]={[0]='The Smallest Creatures',[1]='B475 K0670 FH L065 A:21984 T:21984 P:10749'},
[10721]={[0]='A Boaring Time for Grulloc',[1]='B475 K0670 FH L065 A:21984 T:22103 P:10720'},
[10722]={[0]='Meeting at the Blackwing Coven',[1]='B475 K0680 L065 A:22386 T:22007 P:10893'},
[10723]={[0]='Gorgrom the Dragon-Eater',[1]='B475 K0680 FH L065 A:21984 T:21984 P:10785'},
[10724]={[0]='Prisoner of the Bladespire',[1]='B475 K0670 FH L065 A:21984 T:21984 P:10723'},
[10725]={[0]='Eminence Among the Violet Eye',[1]='B0 K0700 L070 A:18253 T:18253 P:10738'},
[10726]={[0]='Eminence Among the Violet Eye',[1]='B0 K0700 L070 A:18253 T:18253 P:10739'},
[10727]={[0]='Eminence Among the Violet Eye',[1]='B0 K0700 L070 A:18253 T:18253 P:10740'},
[10728]={[0]='Eminence Among the Violet Eye',[1]='B0 K0700 L070 A:18253 T:18253 P:10741'},
[10729]={[0]='Path of the Violet Mage',[1]='B0 K0700 L070 A:18253 T:18253'},
[10730]={[0]='Path of the Violet Restorer',[1]='B0 K0700 L070 A:18253 T:18253'},
[10731]={[0]='Path of the Violet Assassin',[1]='B0 K0700 L070 A:18253 T:18253'},
[10732]={[0]='Path of the Violet Protector',[1]='B0 K0700 L070 A:18253 T:18253'},
[10733]={[0]='Down the Violet Path',[1]='B0 K0700 L070 A:18253 T:18253 P:10729'},
[10734]={[0]='Down the Violet Path',[1]='B0 K0700 L070 A:18253 T:18253 P:10730'},
[10735]={[0]='Down the Violet Path',[1]='B0 K0700 L070 A:18253 T:18253 P:10731'},
[10736]={[0]='Down the Violet Path',[1]='B0 K0700 L070 A:18253 T:18253 P:10732'},
[10738]={[0]='Distinguished Service',[1]='B0 K0700 L070 A:18253 T:18253 P:10733'},
[10739]={[0]='Distinguished Service',[1]='B0 K0700 L070 A:18253 T:18253 P:10734'},
[10740]={[0]='Distinguished Service',[1]='B0 K0700 L070 A:18253 T:18253 P:10735'},
[10741]={[0]='Distinguished Service',[1]='B0 K0700 L070 A:18253 T:18253 P:10736'},
[10742]={[0]='Showdown',[1]='B475 K0700 FH L065 A:21984 T:21984 P:10724'},
[10744]={[0]='News of Victory',[1]='B473 FA K0700 L067 A:21790 T:21330 P:10612'},
[10745]={[0]='News of Victory',[1]='B473 K0700 FH L067 A:21789 T:21769 P:10613'},
[10747]={[0]='Whelps of the Wyrmcult',[1]='B475 K0680 L065 A:21983 T:21983 P:10717'},
[10748]={[0]='Maxnar Must Die!',[1]='B475 K0680 L065 A:22007 T:22007 P:10722'},
[10749]={[0]="Baron Sablemane's Poison",[1]='B475 K0670 FH L065 A:22103 T:21984'},
[10750]={[0]='The Path of Conquest',[1]='B473 K0700 FH L068 A:21769 T:21998'},
[10751]={[0]='Breaching the Path',[1]='B473 K0700 FH L068 A:21998 T:21998 P:10750'},
[10753]={[0]='Culling the Wild',[1]='B475 K0670 L065 A:22133 T:22133'},
[10754]={[0]='Entry Into the Citadel',[1]='B465 FA K0700 L068 A:100031239 T:16819 B465'},
[10755]={[0]='Entry Into the Citadel',[1]='B465 K0700 FH L068 A:100031241 T:3230 B465'},
[10756]={[0]='Grand Master Rohok',[1]='B465 K0700 FH L068 A:3230 T:16583 P:10755'},
[10757]={[0]="Rohok's Request",[1]='B465 K0700 FH L068 A:16583 T:16583 P:10756'},
[10758]={[0]='Hotter than Hell',[1]='B465 K0700 FH L068 A:16583 T:16583 P:10757'},
[10759]={[0]='Find the Deserter',[1]='B473 FA K0690 L067 A:22042 T:22024 P:10569,10760'},
[10760]={[0]="The Sketh'lon Wreckage",[1]='B473 K0690 FH L067 A:22043 T:22043 P:10569'},
[10761]={[0]='Find the Deserter',[1]='B473 K0690 FH L067 A:22043 T:22024 P:10759'},
[10762]={[0]='Grand Master Dumphry',[1]='B0 FA K0700 L068 A:16819 T:21209 P:10754'},
[10763]={[0]="Dumphry's Request",[1]='B465 FA K0700 L068 A:21209 T:21209 P:10762'},
[10764]={[0]='Hotter than Hell',[1]='B0 FA K0700 L068 A:21209 T:21209 P:10763'},
[10765]={[0]='When Worlds Collide...',[1]='B473 K0700 FH L068 A:21998 T:21998 P:10751'},
[10766]={[0]='Invasion Point: Cataclysm',[1]='B473 FA K0690 L067 A:21357 T:21790 P:10589'},
[10767]={[0]='Invasion Point: Cataclysm',[1]='B473 K0690 FH L067 A:21359 T:21789 P:10604'},
[10768]={[0]='Tabards of the Illidari',[1]='B473 K0700 FH L068 A:21998 T:21998 P:10765'},
[10769]={[0]='Dissension Amongst the Ranks...',[1]='B473 K0700 FH L068 A:21998 T:21769 P:10768'},
[10770]={[0]='Little Embers',[1]='B475 K0670 L065 A:22053 T:22053'},
[10771]={[0]='From the Ashes',[1]='B475 K0670 L065 A:22053 T:22053'},
[10772]={[0]='The Path of Conquest',[1]='B473 FA K0700 L068 A:21773 T:22059'},
[10773]={[0]='Breaching the Path',[1]='B473 FA K0700 L068 A:22059 T:22059 P:10772'},
[10774]={[0]='Blood Elf + Giant = ???',[1]='B473 FA K0700 L068 A:22059 T:22059 P:10773'},
[10775]={[0]='Tabards of the Illidari',[1]='B473 FA K0700 L068 A:22059 T:22059 P:10774'},
[10776]={[0]='Dissension Amongst the Ranks...',[1]='B473 FA K0700 L068 A:22059 T:21773 P:10775'},
[10777]={[0]="Asghar's Totem",[1]='B473 K0690 L067 A:22024 T:22024 P:10759,10761'},
[10778]={[0]='The Rod of Lianthe',[1]='B473 K0690 L067 A:22024 T:22024 P:10777'},
[10780]={[0]="Sketh'lon Feathers",[1]='B473 K0690 L067 A:22024 T:22024 P:10778'},
[10781]={[0]='Battle of the Crimson Watch',[1]='B473 K0700 L068 A:1185126 T:18481 P:10793'},
[10782]={[0]='Imbuing the Headpiece',[1]='B473 K0690 L067 A:22024 T:22024 P:10780'},
[10783]={[0]='Baron Sablemane',[1]='B475 K0670 FH L062 A:21984 T:22103 P:10714'},
[10784]={[0]='Crush the Bloodmaul Camp',[1]='B475 K0670 FH L065 A:21147 T:21147'},
[10785]={[0]="It's a Trap!",[1]='B475 K0670 FH L065 A:22103 T:21984 P:10721'},
[10786]={[0]="Slaughter at Boulder'mok",[1]='B475 K0680 FH L065 A:21147 T:21147'},
--[10788]={[0]='Return to Talionia',[1]='B0 K010 L010 FH CL A:5675 T:16647'},
[10791]={[0]='Welcoming the Wolf Spirit',[1]='B478 K0640 FH L062 A:18384 T:18384 P:10023'},
[10792]={[0]="Zeth'Gor Must Burn!",[1]='B465 K0610 FH L058 A:22107 T:22107'},
[10793]={[0]="The Journal of Val'zareq: Portends of War",[1]='B473 K0700 L068 A:100031345 T:1185126'},
[10795]={[0]='A Date with Dorgok',[1]='B475 FA K0670 L065 A:22149 T:22149'},
[10796]={[0]='Crush the Bloodmaul Camp!',[1]='B475 FA K0670 L065 A:22150 T:22150'},
[10797]={[0]='Favor of the Gronn',[1]='B475 FA K0670 L065 A:100031363 T:22149'},
[10798]={[0]='Pay the Baron a Visit',[1]='B475 FA K0670 L065 A:22149 T:22103 P:10797'},
[10799]={[0]='Into the Churning Gulch',[1]='B475 FA K0670 L065 A:22103 T:22103 P:10798'},
[10800]={[0]='Goodnight, Gronn',[1]='B475 FA K0670 L065 A:22103 T:22103 P:10799'},
[10801]={[0]="It's a Trap!",[1]='B475 FA K0670 L065 A:22103 T:22149 P:10800'},
[10802]={[0]='Gorgrom the Dragon-Eater',[1]='B475 FA K0680 L065 A:22149 T:22149 P:10801'},
[10803]={[0]="Slaughter at Boulder'mok",[1]='B475 FA K0680 L065 A:22150 T:22150'},
[10804]={[0]='Kindness',[1]='B473 K0700 L070 A:22113 T:22113'},
[10805]={[0]="Massacre at Gruul's Lair",[1]='B475 FA K0670 L065 A:22103 T:22103 P:10818'},
[10806]={[0]='Showdown',[1]='B475 FA K0700 L065 A:22103 T:22103 P:10805'},
[10807]={[0]='The Ashtongue Broken',[1]='B473 K0700 L068 A:21953 T:21953'},
[10808]={[0]='Thwart the Dark Conclave',[1]='B473 K0690 L067 A:22024 T:22024 P:10782'},
[10809]={[0]='Wanted: Worg Master Kruush',[1]='B465 K0600 FH L058 A:1185166 T:22107'},
[10810]={[0]='Damaged Mask',[1]='B475 K0680 L065 A:100031384 T:22020'},
[10811]={[0]='Seek Out Neltharaku',[1]='B473 K0700 L070 A:22113 T:21657 P:10804'},
[10812]={[0]='Mystery Mask',[1]='B475 K0680 L065 A:22020 T:22127 P:10810'},
[10813]={[0]='The Eyes of Grillok',[1]='B465 K0620 FH L058 A:22231 T:22231'},
[10814]={[0]="Neltharaku's Tale",[1]='B473 K0700 L070 A:21657 T:21657 P:10811'},
[10816]={[0]='Reclaiming Holy Grounds',[1]='B473 K0700 L068 A:21822 T:21822 P:10619'},
[10817]={[0]='The Great Retribution',[1]='B473 K0700 L068 A:21953 T:21953 P:10807'},
[10818]={[0]='Baron Sablemane Has Requested Your Presence',[1]='B475 FA K0670 L065 A:22149 T:22103 P:10802'},
[10819]={[0]='Felsworn Gas Mask',[1]='B475 K0680 L065 A:22127 T:1185165 P:10812'},
[10820]={[0]='Deceive thy Enemy',[1]='B475 K0680 L065 A:1185165 T:1185165 P:10819'},
[10821]={[0]="You're Fired!",[1]='B475 K0680 L065 A:1185165 T:22127 P:10820'},
[10822]={[0]='Single Sunfury Signet',[1]='B0 K0700 ++ L068 A:22211 T:22211 P:10823'},
[10823]={[0]='More Sunfury Signets',[1]='B0 K0700 ++ L068 A:22211 T:22211 P:10824'},
[10824]={[0]='Sunfury Signets',[1]='B473 K0700 L068 A:22211 T:22211'},
[10825]={[0]='The Truth Unorbed',[1]='B475 K0680 L065 A:100031489 T:22007'},
[10826]={[0]='Marks of Sargeras',[1]='B473 K0700 L068 A:22214 T:22214'},
[10827]={[0]='More Marks of Sargeras',[1]='B0 K0700 ++ L068 A:22214 T:22214 P:10826'},
[10828]={[0]='Single Mark of Sargeras',[1]='B0 K0700 ++ L068 A:22214 T:22214 P:10827'},
[10829]={[0]='Treebole Must Know',[1]='B475 K0680 L065 A:22007 T:22215'},
[10830]={[0]='Exorcising the Trees',[1]='B475 K0680 L065 A:22215 T:22215 P:10829'},
[10834]={[0]='Grillok "Darkeye"',[1]='B465 K0620 FH L058 A:22231 T:22231 P:10813'},
[10835]={[0]='Apothecary Antonivich',[1]='B465 K0610 FH L058 A:21279 T:16588 P:10538'},
[10836]={[0]='Infiltrating Dragonmaw Fortress',[1]='B473 K0700 L070 A:21657 T:21657 P:10814'},
[10837]={[0]='To Netherwing Ledge!',[1]='B473 K0700 L070 A:21657 T:21657 P:10836'},
[10838]={[0]='The Demoniac Scryer',[1]='B465 K0610 FH L058 A:16588 T:16588 P:10864'},
[10839]={[0]='Veil Skith: Darkstone of Terokk',[1]='B478 K0640 L062 A:22272 T:22272 P:10849'},
[10840]={[0]='The Tomb of Lights',[1]='B478 K0650 L063 A:22278 T:22278'},
[10842]={[0]='Vengeful Souls',[1]='B478 K0650 L063 A:22278 T:22278'},
[10843]={[0]='Since Time Forgotten...',[1]='B475 K0680 FH L065 A:22004 T:22004 P:10846'},
[10845]={[0]='Slay the Brood Mother',[1]='B475 K0680 FH L065 A:22004 T:22004 P:10843'},
[10846]={[0]="Understanding the Mok'Nathal",[1]='B475 K0670 FH L065 A:22004 T:22004'},
[10847]={[0]='The Eyes of Skettis',[1]='B478 K0620 L062 A:22292 T:22292 O:10908'}, -- not available if one has 10908 until 10908 turned in
[10848]={[0]='Veil Rhaze: Unliving Evil',[1]='B478 K0640 L062 A:22272 T:22272 P:10839'},
[10849]={[0]='Seek Out Kirrik',[1]='B478 K0630 L062 A:22292 T:22272 P:10847 B478'},
[10850]={[0]='Nether Gas In a Fel Fire Engine',[1]='B479 K0700 ++ L067 A:22293 T:22293'},
[10851]={[0]='The Totems of My Enemy',[1]='B475 K0670 FH L065 A:22312 T:22312'},
[10852]={[0]='Missing Friends',[1]='B478 K0640 L062 A:22365 T:22365'},
[10853]={[0]='Spirit Calling',[1]='B475 K0670 FH L065 A:22312 T:22312 P:10851'},
[10854]={[0]='The Force of Neltharaku',[1]='B473 K0700 L070 A:21657 T:21657 P:10837'},
[10855]={[0]='Fel Reavers, No Thanks!',[1]='B479 K0690 L067 A:20471 T:20471'},
[10856]={[0]='The Best Defense',[1]='B479 K0690 L067 A:20471 T:20471 P:10855'},
[10857]={[0]='Teleport This!',[1]='B479 K0690 L067 A:20471 T:20471 P:10856'},
[10858]={[0]='Karynaku',[1]='B473 K070512 L070 A:21657 T:22112 P:10854'},
[10859]={[0]='Gather the Orbs',[1]='B475 K0670 FH L065 A:22312 T:22312 P:10853'},
[10860]={[0]="Mok'Nathal Treats",[1]='B475 K0670 FH L065 A:21088 T:21088'},
[10861]={[0]='Veil Lithic: Preemptive Strike',[1]='B478 K0640 L062 A:22272 T:22272 P:10848'},
[10862]={[0]='Surrender to the Horde',[1]='B478 K0630 FH L062 A:18386 T:22292'},
[10863]={[0]='Secrets of the Arakkoa',[1]='B478 FA K0630 L062 A:15991 T:22292 P:10862,10908'},
[10864]={[0]='A Burden of Souls',[1]='B465 K0610 FH L058 A:16588 T:16588 P:10835'},
[10865]={[0]='Inform Leoroxx!',[1]='B475 K0680 FH L065 A:22312 T:22004 P:10859'},
[10866]={[0]='Zuluhed the Whacked',[1]='B473 K070512 L070 A:22112 T:22112 P:10858'},
[10867]={[0]='There Can Be Only One Response',[1]='B475 K0680 FH L065 A:22004 T:22312'},
[10868]={[0]='Arakkoa War Path',[1]='B478 K0620 FH L060 A:18712 T:18712'},
[10869]={[0]='Thin the Flock',[1]='B478 FA K0620 L060 A:18713 T:18713'},
[10870]={[0]='Ally of the Netherwing',[1]='B473 K0700 L070 A:22112 T:22113 P:10866'},
[10871]={[0]='Ally of the Netherwing',[1]='B473 K0700 FA L070 A:22112 T:22113'},
[10872]={[0]='Zuluhed the Whacked',[1]='B473 K0700 FA L070 A:22112 T:22112'},
[10873]={[0]='Taken in the Night',[1]='B478 K0650 L063 A:22364 T:22364'},
[10874]={[0]='Veil Shalas: Signal Fires',[1]='B478 K0650 L062 A:22272 T:22272 P:10861'},
[10875]={[0]='Report to Nazgrel',[1]='B465 K0610 FH L058 A:16588 T:3230 P:10838'},
[10876]={[0]='The Foot of the Citadel',[1]='B465 K0630 FH L058 A:3230 T:3230 P:10875'},
[10877]={[0]='The Dread Relic',[1]='B478 K0660 L063 A:22456 T:22456'},
[10878]={[0]='Before Darkness Falls',[1]='B478 K0630 L062 A:22370 T:22370'},
[10879]={[0]='The Skettis Offensive',[1]='B478 K0650 L062 A:22373 T:22292'},
[10880]={[0]='Cabal Orders',[1]='B478 K0640 L062 A:100031707 T:22370'},
[10881]={[0]='The Shadow Tomb',[1]='B478 K0640 L062 A:22370 T:22370 P:10880'},
[10882]={[0]='Harbinger of Doom',[1]='B0 K0700 L067 A:18481 T:18481 P:10704'},
[10883]={[0]='The Tempest Key',[1]='B0 K0700 L070 A:18166 T:18481'},
[10884]={[0]='Trial of the Naaru: Mercy',[1]='B0 K07064 L070 A:18481 T:18481'},
[10885]={[0]='Trial of the Naaru: Strength',[1]='B0 K07064 L070 A:18481 T:18481'},
[10886]={[0]='Trial of the Naaru: Tenacity',[1]='B0 K07064 L070 A:18481 T:18481'},
[10887]={[0]='Escaping the Tomb',[1]='B478 K0640 L062 A:22377 T:22370'},
[10889]={[0]='Return to Shattrath',[1]='B478 K0650 L062 A:22272 T:22292 P:10874'},
[10893]={[0]='Longtail is the Lynchpin',[1]='B475 K0670 L065 A:22386 T:22386 P:10894'},
[10894]={[0]='Wyrmskull Watcher',[1]='B475 K0670 L065 A:22007 T:22386'},
[10895]={[0]="Zeth'Gor Must Burn!",[1]='B465 FA K0600 L058 A:19409 T:19409'},
[10896]={[0]='The Infested Protectors',[1]='B478 K0650 L062 A:22420 T:22420'},
[10897]={[0]='Master of Potions',[1]='B0 K0700 L068 A:17909 T:17909 P:10905'},
[10898]={[0]='Skywing',[1]='B478 K0650 L063 A:22424 T:22292'},
[10899]={[0]='Master of Transmutation',[1]='B0 K0700 L068 A:22427 T:22427 P:10907'},
[10900]={[0]='The Mark of Vashj',[1]='B504956 K0700 FH L070 A:22421 T:22421'},
[10902]={[0]='Master of Elixirs',[1]='B0 K0700 L068 A:19052 T:19052 P:10906'},
[10903]={[0]='Return to Honor Hold',[1]='B465 FA K0610 L058 A:21133 T:22430 P:10485'},
[10904]={[0]='Harvesting the Fel Ammunition',[1]='B475 K0680 L065 A:22423 T:22423 P:10910'},
[10905]={[0]='Master of Potions',[1]='B0 K0700 L068 AA:18802 AH:16588 T:17909'},
[10906]={[0]='Master of Elixirs',[1]='B0 K0700 L068 AA:18802 AH:16588 T:19052'},
[10907]={[0]='Master of Transmutation',[1]='B0 K0700 L068 AA:18802 AH:16588 T:22427'},
[10908]={[0]='Speak with Rilak the Redeemed',[1]='B478 K0630 L062 A:22272 T:22292 I:10847'},
[10909]={[0]='Fel Spirits',[1]='B465 FA K0610 L058 A:22430 T:22430'},
[10910]={[0]="Death's Door",[1]='B475 K0680 L065 A:22127 T:22423 P:10821'},
[10911]={[0]='Fire At Will!',[1]='B475 K0680 L065 A:22423 T:22423 P:10904'},
[10912]={[0]='The Hound-Master',[1]='B475 K0680 L065 A:22423 T:22127 P:10911'},
[10913]={[0]='An Improper Burial',[1]='B478 K0650 L063 A:22446 T:22446'},
[10914]={[0]='A Hero Is Needed',[1]='B478 K0650 L063 A:22446 T:22446 P:10913'},
[10915]={[0]='The Fallen Exarch',[1]='B478 K0650 L063 A:22446 T:22446 P:10914'},
[10916]={[0]='Digging for Prayer Beads',[1]='B465 FA K0610 L058 A:22430 T:22430'},
[10917]={[0]="The Outcast's Plight",[1]='B478 K0650 L062 A:22429 T:22429'},
[10918]={[0]='More Feathers',[1]='B0 K0650 ++ L062 A:22429 T:22429 P:10917'},
[10919]={[0]="Fei Fei's Treat",[1]='B465 K0610 FA ++ A:20206 T:20206'},
[10920]={[0]='For the Fallen',[1]='B478 K0650 L063 A:22462 T:22462'},
[10921]={[0]='Terokkarantula',[1]='B478 K0650 L063 A:22462 T:22462 P:10920'},
[10922]={[0]='Digging Through Bones',[1]='B478 K0650 L063 A:22458 T:22481'},
[10923]={[0]='Evil Draws Near',[1]='B478 K0650 L063 A:22456 T:22456 P:10877'},
[10924]={[0]='Bloody Imp-ossible!',[1]='B479 K0690 L067 A:22479 T:22479'},
[10926]={[0]="Return to Sha'tari Base Camp",[1]='B478 K0650 L063 A:22462 T:22364 P:10921'},
[10927]={[0]='Killing the Crawlers',[1]='B475 FA K0650  L065 A:22488 T:21158'},
[10928]={[0]='Killing the Crawlers',[1]='B475 K0650 FH L065 A:22489 T:21147'},
[10929]={[0]='Fumping',[1]='B478 K0650 L063 A:22481 T:22481 P:10922'},
[10930]={[0]='The Big Bone Worm',[1]='B478 K0650 L063 A:22481 T:22481 P:10929'},
[10935]={[0]='The Exorcism of Colonel Jules',[1]='B465 FA K0610 L058 A:22430 T:22430'},
[10936]={[0]='Trollbane is Looking for You',[1]='B465 FA K0610 L058 A:22430 T:16819 P:10935'},
[10937]={[0]='Drill the Drillmaster',[1]='B465 FA K0620 L058 A:16819 T:16819 P:10936'},
[10938]={[0]='Darkmoon Blessings Deck',[1]='B0 K0700 A:100031890 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[10939]={[0]='Darkmoon Storms Deck',[1]='B0 K0700 A:100031891 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[10940]={[0]='Darkmoon Furies Deck',[1]='B0 K0700 A:100031907 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[10941]={[0]='Darkmoon Lunacy Deck',[1]='B0 K0700 A:100031914 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[10942]={[0]="Children's Week",[1]='B0 HC FH L060 A:22819 T:22914'},
[10943]={[0]="Children's Week",[1]='B0 HC FA L060 A:22819 T:22818'},
[10944]={[0]='The Secret Compromised',[1]='B0 K0700 L070 A:22820 T:21700'},
[10945]={[0]="Hch'uu and the Mushroom People",[1]='B0 HC FH L060 A:22914 T:22823 P:10942'},
[10946]={[0]='Ruse of the Ashtongue',[1]='B0 K0700 L070 A:21700 T:21700 P:10944'},
[10947]={[0]='An Artifact From the Past',[1]='B0 K0700 L070 A:21700 T:21700 P:10946'},
[10948]={[0]='The Hostage Soul',[1]='B0 K0700 L070 A:21700 T:18481 P:10947'},
[10949]={[0]='Entry Into the Black Temple',[1]='B0 K0700 L070 A:18481 T:18528 P:10948'},
[10950]={[0]='Auchindoun and the Ring of Observance',[1]='B0 HC FA L060 A:22818 T:22818 P:10943'},
[10951]={[0]='A Trip to the Dark Portal',[1]='B0 HC FH L060 A:22914 T:22914 P:10942'},
[10952]={[0]='A Trip to the Dark Portal',[1]='B0 HC FA L060 A:22818 T:500013 P:10943'},
[10953]={[0]='Visit the Throne of the Elements',[1]='B0 HC FH L060 A:22914 T:18072 P:10942'},
[10954]={[0]='Jheel is at Aeris Landing!',[1]='B0 HC FA L060 A:22818 T:22836 P:10943'},
[10956]={[0]='The Seat of the Naaru',[1]='B0 HC FA L060 A:22818 T:17538 P:10950+10952+10954'},
[10957]={[0]='Redemption of the Ashtongue',[1]='B0 K0700 L070 A:23158 T:23158 P:10958'},
[10958]={[0]='Seek Out the Ashtongue',[1]='B0 K0700 L070 A:18528 T:23158 P:10985,13429'},
[10959]={[0]='The Fall of the Betrayer',[1]='B0 K0700 L070 A:23158 T:23158 P:10957'},
[10962]={[0]='Time to Visit the Caverns',[1]='B0 HC FA L060 A:22818 T:500014 P:10950+10952+10954'},
[10963]={[0]='Time to Visit the Caverns',[1]='B0 HC FH L060 A:22914 T:22914 P:10945+10953+10951'},
[10966]={[0]='Back to the Orphanage',[1]='B0 HC FA L060 A:22818 T:22819 P:10968+10962'},
[10967]={[0]='Back to the Orphanage',[1]='B0 HC FH L060 A:22914 T:22819 P:10963+11975'},
[10968]={[0]='Call on the Farseer',[1]='B0 HC FA L060 A:17538 T:17204 P:10956'},
[10969]={[0]='Seek Out Ameer',[1]='B479 K0700 L070 A:22899 T:20448'},
[10970]={[0]='A Mission of Mercy',[1]='B479 K0700 L070 A:20448 T:20448 P:10969'},
[10971]={[0]='Ethereum Secrets',[1]='B479 K0700 L070 A:20448 T:20448'},
[10973]={[0]='A Thousand Worlds',[1]='B0 K0700 L070 A:20448 T:20448'},
[10974]={[0]="Stasis Chambers of Bash'ir",[1]='B0 K0700 L070 A:20448 T:22919 P:10973'},
[10975]={[0]="Purging the Chambers of Bash'ir",[1]='B0 K0700 ++ L070 A:22919 T:22919'},
[10976]={[0]='The Mark of the Nexus-King',[1]='B0 K0700 L070 A:22919 T:22919'},
[10977]={[0]='Stasis Chambers of the Mana-Tombs',[1]='B0 K0700 L070 A:22919 T:22919 P:10976'},
[10981]={[0]="Nexus-Prince Shaffar's Personal Chamber",[1]='B0 K0700 ++ L070 A:22919 T:22919'},
[10982]={[0]='The Eye of Haramad',[1]='B0 K0700 L070 A:22919 T:22919'},
[10983]={[0]="Mog'dorg the Wizened",[1]='B475 K0700 L070 A:22940 T:22941 P:10984'},
[10984]={[0]='Speak with the Ogre',[1]='B0 K0700 L070 A:22497 T:22940'},
[10985]={[0]='A Distraction for Akama',[1]='B0 K0700 L070 A:18528 T:18528 P:10949'},
[10989]={[0]="Mog'dorg the Wizened",[1]='B475 K0700 L070 A:22995 T:22941'},
[10995]={[0]='Grulloc Has Two Skulls',[1]='B475 K0700 L070 A:22941 T:22941'},
[10996]={[0]="Maggoc's Treasure Chest",[1]='B475 K0700 L070 A:22941 T:22941'},
[10997]={[0]='Even Gronn Have Standards',[1]='B475 K0700 L070 A:22941 T:22941'},
[10998]={[0]='Grim(oire) Business',[1]='B0 K0700 L070 A:22941 T:22941'},
[11000]={[0]='Into the Soulgrinder',[1]='B475 K0700 L070 A:22941 T:22941 P:10998'},
[11002]={[0]='The Fall of Magtheridon',[1]='B465 K0700 FA L070 A:100032385 T:16819'},
[11003]={[0]='The Fall of Magtheridon',[1]='B465 K0700 FH L070 A:100032386 T:3230'},
[11004]={[0]='World of Shadows',[1]='B0 K0700 L070 A:23042 T:23042'},
[11005]={[0]='Secrets of the Talonpriests',[1]='B0 K0700 L070 A:23038 T:23038'},
[11006]={[0]='More Shadow Dust',[1]='B0 K0700 ++ L070 A:23042 T:23042'},
[11007]={[0]="Kael'thas and the Verdant Sphere",[1]='B0 K0700 L070 A:100032405 T:18481'},
[11008]={[0]='Fires Over Skettis',[1]='B0 +D K0700 L070 A:23048 T:23048'},
[11009]={[0]='Ogre Heaven',[1]='B475 K0700 L070 A:22941 T:23233 P:11022'},
[11010]={[0]='Bombing Run',[1]='B475 K0700 L070 A:23120 T:23120'},
[11012]={[0]='Blood Oath of the Netherwing',[1]='B473 K0700 L070 V2841999 PR300 A:22113 T:22113'},
[11013]={[0]='In Service of the Illidari',[1]='B473 K0700 L070 A:22113 T:23139 P:11012'},
[11014]={[0]='Enter the Taskmaster',[1]='B473 K0700 L070 A:23139 T:23140 P:11013'},
[11015]={[0]='Netherwing Crystals',[1]='B0 +D K0700 L070 V2841999 A:23140 T:23140'},
[11016]={[0]='Nethermine Flayer Hide',[1]='B0 +D K0700 L070 V2841999 PS350 A:23140 T:23140 I:11017,11018'},
[11017]={[0]='Netherdust Pollen',[1]='B0 +D K0700 L070 V2841999 PH350 A:23140 T:23140 I:11016,11018'},
[11018]={[0]='Nethercite Ore',[1]='B0 +D K0700 L070 V2841999 PM350 A:23140 T:23140 I:11016,11017'},
[11019]={[0]='Your Friend On The Inside',[1]='B473 K0700 L070 A:23141 T:23141'},
[11020]={[0]='A Slow Death',[1]='B0 +D K0700 L070 V2841999 A:23141 T:23141 P:11019'},
[11021]={[0]="Ishaal's Almanac",[1]='B0 K0700 L070 A:100032523 T:23038'},
[11022]={[0]="Speak with Mog'dorg",[1]='B475 FA K070 L070 A:23053 T:22941'},
[11023]={[0]='Bomb Them Again!',[1]='B0 +D K0700 L070 A:23120 T:23120 P:11010,11102'},
[11024]={[0]='An Ally in Lower City',[1]='B0 K0700 L070 A:23038 T:22292 P:11021'},
[11025]={[0]='The Crystals',[1]='B475 K0700 L070 A:23233 T:23233'},
[11026]={[0]='Banish the Demons',[1]='B0 K0700 L070 A:23253 T:23253 V2750999'},
[11028]={[0]='Countdown to Doom',[1]='B0 K0700 L070 A:22292 T:23038 P:11024'},
[11029]={[0]='A Shabby Disguise',[1]='B0 K0700 L070 A:23306 T:23306 P:11056'},
[11030]={[0]='Our Boy Wants To Be A Skyguard Ranger',[1]='B475 K0700 L070 A:23316 T:23316'},
[11031]={[0]='Archmage No More',[1]='B0 K0700 ++ L070 A:18253 T:18253'},
[11035]={[0]='The Not-So-Friendly Skies...',[1]='B0 +D K0700 L070 V2841999 A:23141 T:23141 P:11019'},
[11036]={[0]='Out of This World Produce!',[1]='B475 K0670 FH L067 A:19471 T:19570 I:10183,11037,11040,11042 B479'},
[11037]={[0]='A Strange Vision',[1]='B477 K0670 FH L067 A:23265 T:19570 I:10183,11036,11040,11042 B479'},
[11038]={[0]='Assist Exarch Orelis',[1]='B0 K0670 L067 A:23270,23271 T:19466'},
[11039]={[0]='Report to Spymaster Thalodien',[1]='B0 K0670 L067 A:23272,23273 T:19468'},
[11040]={[0]='Parts for the Rocket-Chief',[1]='B475 FA K0670 L067 A:21112 T:19570 I:10183,11036,11037,11042 B479'},
[11041]={[0]='A Job Unfinished...',[1]='B0 K070512 L070 V2841999 A:100032621 T:23139 P:11014'},
[11042]={[0]='A Mystifying Vision',[1]='B477 FA K0670 L067 A:23268 T:19570 I:10183,11036,11037,11040 B479'},
[11043]={[0]='Building a Better Gryphon',[1]='B475 FA K0670 L067 A:21107 T:20510 B473'},
[11044]={[0]='Visions of Destruction',[1]='B477 FA K0670 L067 A:23268 T:21357 B473'},
[11045]={[0]='Zorus the Judicator',[1]='B0 FA K0670 L067 A:19678 T:21774'},
[11046]={[0]='Chief Apothecary Hildagard',[1]='B0 K0670 FH L067 A:19678 T:21772'},
[11047]={[0]="The Apprentice's Request",[1]='B475 K0670 FH L067 A:23280 T:20494 B473'},
[11048]={[0]="Kroghan's Report",[1]='B477 K0670 FH L067 A:18090 T:21359 B473'},
[11049]={[0]='The Great Netherwing Egg Hunt',[1]='B0 K0700 L070 V2841999 A:23141 T:23141 P:11019'},
[11050]={[0]='Accepting All Eggs',[1]='B0 ++ K0700 L070 V2841999 A:23141 T:23141 P:11049'},
[11051]={[0]='Banish More Demons',[1]='B0 +D K0700 L070 A:23253 T:23253'},
[11052]={[0]="Akama's Promise",[1]='B0 K0700 L068 A:21700 T:18481'},
[11053]={[0]='Rise, Overseer!',[1]='B0 K0700 L070 V2844999 A:23140 T:23139'},
[11054]={[0]='Overseeing and You: Making the Right Choices',[1]='B0 K0700 L070 V2844999 A:23291 T:23291 P:11053'},
[11055]={[0]='The Booterang: A Cure For The Common Worthless Peon',[1]='B0 +D K0700 L070 V2844999 A:23291 T:23291 P:11054'},
[11056]={[0]="Hazzik's Bargain",[1]='B0 K0700 L070 A:23306 T:23306 P:11028'},
[11057]={[0]='The Trouble Below',[1]='B475 K0700 L070 A:23233 T:22941'},
[11058]={[0]='An Apexis Relic',[1]='B475 K0700 L070 A:23233 T:23233 P:11025'},
[11059]={[0]='Guardian of the Monument',[1]='B475 K0700 L070 A:23233 T:23233'},
[11060]={[0]='A Crystalforged Darkrune',[1]='B0 K0700 ++ L070 A:23300 T:23300'},
[11061]={[0]="A Father's Duty",[1]='B475 K0700 L070 A:23316 T:23316 P:11030'},
[11062]={[0]='The Skyguard Outpost',[1]='B475 K0700 L070 A:23233 T:23334'},
[11063]={[0]='Earning Your Wings...',[1]='B473 K0700 L070 V2850999 A:22433 T:22433'},
[11064]={[0]='Dragonmaw Race: The Ballad of Oldie McOld',[1]='B473 K0700 L070 V2850999 A:23340 T:22433 P:11063'},
[11065]={[0]='Wrangle Some Aether Rays!',[1]='B475 K0700 L070 A:23335 T:23335'},
[11066]={[0]='Wrangle More Aether Rays!',[1]='B0 +D K0700 L070 A:23335 T:23335 P:11065'},
[11067]={[0]='Dragonmaw Race: Trope the Filth-Belcher',[1]='B473 K070 L070 V2850999 A:23342 T:22433 P:11064'},
[11068]={[0]='Dragonmaw Race: Corlok the Vet',[1]='B473 K070 L070 V2850999 A:23344 T:22433 P:11067'},
[11069]={[0]='Dragonmaw Race: Wing Commander Ichman',[1]='B473 K070 L070 V2850999 A:23345 T:22433 P:11068'},
[11070]={[0]='Dragonmaw Race: Wing Commander Mulverick',[1]='B473 K070 L070 V2850999 A:23346 T:22433 P:11069'},
[11071]={[0]='Dragonmaw Race: Captain Skyshatter',[1]='B0 K0700 L070 V2850999 A:23348 T:22433 P:11070'},
[11073]={[0]="Terokk's Downfall",[1]='B0 K0700 L070 A:23038 T:23038'},
[11075]={[0]='The Netherwing Mines',[1]='B473 K0700 L070 V2844999 A:23140 T:23149 P:11053'},
[11076]={[0]='Picking Up The Pieces...',[1]='B0 +D FA K0700 L070 V2844999 A:23149 T:23149 P:11075'},
[11077]={[0]='Dragons are the Least of Our Problems',[1]='B0 +D K07000 L070 V2844999 A:23376 T:23376 P:11075'},
[11078]={[0]='To Rule The Skies',[1]='B0 K0700 L070 A:23334 T:23334'},
[11079]={[0]='A Fel Whip For Gahk',[1]='B475 K0700 L070 A:23300 T:23300'},
[11080]={[0]="The Relic's Emanation",[1]='B0 +D K0700 L070 A:23233 T:23233 P:11058'},
[11081]={[0]='The Great Murkblood Revolt',[1]='B0 K0700 L070 V2844999 A:100032726 T:23149 P:11075'},
[11082]={[0]='Seeker of Truth',[1]='B0 K0700 L070 V2844999 A:23149 T:23149 P:11081'},
[11083]={[0]='Crazed and Confused',[1]='B473 K0700 L070 V2844999 A:23166 T:23166 P:11075'},
[11084]={[0]='Stand Tall, Captain!',[1]='B0 K0700 L070 V2850999 A:23140 T:23139'},
[11085]={[0]='Escape from Skettis',[1]='B0 +D K0700 L070 A:23383 T:23048'},
[11086]={[0]='Disrupting the Twilight Portal',[1]='B0 +D K0700 L070 V2850999 A:23139 T:23139 P:11084'},
[11089]={[0]="The Soul Cannon of Reth'hedron",[1]='B0 K0700 L070 V2850999 A:23427 T:23427'},
[11090]={[0]='Subdue the Subduer',[1]='B0 K0700 L070 V2850999 A:23427 T:23427 P:11089'},
[11091]={[0]='A Special Thank You',[1]='B475 K0700 L070 A:23233 T:23428 V2744999'},
[11092]={[0]='Hail, Commander!',[1]='B0 K0700 L070 V2862999 A:23140 T:23139'},
[11093]={[0]='Hungry Nether Rays',[1]='B0 K0700 L070 A:23415 T:23415'},
[11094]={[0]='Kill Them All!',[1]='B0 K0700 L070 V2862999 V3644999 A:23139 T:21955 P:11092'},
[11095]={[0]='Commander Hobb',[1]='B473 K070 L070 V2862999 V3644999 A:21955 T:23434 P:11094'},
[11096]={[0]='Threat from Above',[1]='B0 K0700 L070 A:23449 T:23449'},
[11097]={[0]='The Deadliest Trap Ever Laid',[1]='B0 +D K070512 L070 V2862999 V3644999 A:23434 T:23139 P:11095'},
[11098]={[0]='To Skettis!',[1]='B0 K0700 L070 A:23449 T:23048 P:11096'},
[11099]={[0]='Kill Them All!',[1]='B0 K0700 L070 V2862999 V3544999 A:23139 T:21402 P:11092'},
[11100]={[0]='Commander Arcus',[1]='B0 K0700 L070 V2862999 V3544999 A:21402 T:23452 P:11099'},
[11101]={[0]='The Deadliest Trap Ever Laid',[1]='B0 +D K070512 L070 V2862999 V3544999 A:23452 T:23139 P:11100'},
[11102]={[0]='Bombing Run',[1]='B475 CD K0700 L070 A:23120 T:23120 P:11010'},
[11103]={[0]='Sage No More',[1]='B0 K0700 ++ L070 A:19935 T:19935'},
[11104]={[0]='Restorer No More',[1]='B0 K0700 ++ L070 A:19935 T:19935 P:10473'},
[11105]={[0]='Champion No More',[1]='B0 K0700 ++ L070 A:19935 T:19935'},
[11106]={[0]='Defender No More',[1]='B0 K0700 ++ L070 A:19935 T:19935'},
[11107]={[0]='Bow to the Highlord',[1]='B0 K0700 L070 V2883999 A:23140 T:23139'},
[11108]={[0]='Lord Illidan Stormrage',[1]='B473 K0700 L070 V2883999 A:23139 T:23433 P:11107'},
[11109]={[0]='Jorus the Cobalt Netherwing Drake',[1]='B0 K0700 L070 V2883999 A:23462 T:23462 P:11108 I:11110,11111,11112,11113,11114'},
[11110]={[0]='Malfas the Purple Netherwing Drake',[1]='B0 K0700 L070 V2883999 A:23464 T:23464 P:11108 I:11109,11111,11112,11113,11114'},
[11111]={[0]='Onyxien the Onyx Netherwing Drake',[1]='B0 K0700 L070 V2883999 A:23463 T:23463 P:11108 I:11109,11110,11112,11113,11114'},
[11112]={[0]='Suraku the Azure Netherwing Drake',[1]='B0 K0700 L070 V2883999 A:23461 T:23461 P:11108 I:11109,11110,11111,11113,11114'},
[11113]={[0]='Voranaku the Violet Netherwing Drake',[1]='B0 K0700 L070 V2883999 A:23466 T:23466 P:11108 I:11109,11110,11111,11112,11114'},
[11114]={[0]='Zoya the Veridian Netherwing Drake',[1]='B0 K0700 L070 V2883999 A:23465 T:23465 P:11108 I:11109,11110,11111,11112,11113'},
[11117]={[0]='Catch the Wild Wolpertinger!',[1]='B0 FA HB +Y K0000 A:23486 T:23486 I:11431'},
[11118]={[0]='Pink Elekks On Parade',[1]='B0 FA HB +Y K0000 A:23486 T:23486'}, -- note that this is not I: with 11120 for some reason
[11119]={[0]="Assault on Bash'ir Landing!",[1]='B475 K0700 L070 A:23334 T:23473'},
[11120]={[0]='Pink Elekks On Parade',[1]='B0 FH HB +Y K0000 A:24657 T:24657'},
[11122]={[0]='There and Back Again',[1]='B0 FA HB +D A:23558 T:23558 P:11318 P:11318'},
[11129]={[0]="Kyle's Gone Missing!",[1]='B0 K0070 FH L005 A:23618 T:23618'},
[11130]={[0]='Oooh, Shinies!',[1]='B0 K0700 L070 A:19227 T:23559'},
[11131]={[0]='Stop the Fires!',[1]='B0 HW +D FA A:24519 T:24519 I:12135'},
[11132]={[0]='Promises, Promises...',[1]='B504956 K0700 L070 A:23559 T:23559 P:11130'},
[11135]={[0]='The Headless Horseman',[1]='B0 K0800 HW L075'},
[11153]={[0]='Break the Blockade',[1]='B491 +D FA K0710 L068 A:23895 T:23895'},
[11154]={[0]='Scare the Guano Out of Them!',[1]='B491 FA K0710 L069 A:24227 T:24227'},
[11155]={[0]='Shoveltusk Soup Again?',[1]='B491 FA K0710 L068 A:23773 T:23773'},
[11157]={[0]='The Clutches of Evil',[1]='B491 FA K0710 L068 A:23749 T:23749'},
[11163]={[0]='Undercover Sister',[1]='B0 K0700 L070 A:23858 T:23858 P:11178'},
[11164]={[0]="Tuskin' Raiders",[1]='B0 K0700 L070 A:23761 T:23761'},
[11165]={[0]='A Troll Among Trolls',[1]='B0 K0700 L070 A:23761 T:23897 P:11164'},
[11166]={[0]='X Marks... Your Doom!',[1]='B0 K0700 L070 A:23559 T:23559 P:11132'},
[11167]={[0]='The New Plague',[1]='B491 K0710 FH L068 A:24126 T:24126'},
[11168]={[0]='Spiking the Mix',[1]='B491 K0710 FH L068 A:24126 T:24126 P:11167'},
[11170]={[0]='Test at Sea',[1]='B491 K0710 FH L068 A:24126 T:24126 P:11168'},
[11171]={[0]='Hex Lord? Hah!',[1]='B0 K0700 L070 A:23559 T:23559 P:11166'},
[11175]={[0]='My Daughter',[1]='B491 FA K0710 L069 A:23831 T:23891'}, -- TODO: Determine breadcrumb status as QuestHubberGrail says one can get this, even though Steel Gate quests are done.
[11176]={[0]='See to the Operations',[1]='B491 FA K0710 L069 A:23891 T:24399'},
[11178]={[0]='Blood of the Warlord',[1]='B504956 K0700 L070 A:100033102 T:23559'},
[11182]={[0]='Root Causes',[1]='B491 K0710 L068 A:23870 T:23870'},
[11187]={[0]='Mage-Lieutenant Malister',[1]='B491 FA K0710 L068 A:23749 T:23888 P:11157'},
[11188]={[0]='Two Wrongs...',[1]='B491 FA K0710 L068 A:23888 T:23888 P:11187'},
[11190]={[0]='One Size Does Not Fit All',[1]='B491 FA K0710 L068 A:23770 T:23770'},
[11195]={[0]="Playin' With Dolls",[1]='B0 K0700 L070 A:23897 T:19227 P:11165'},
[11199]={[0]='Report to Scout Knowles',[1]='B491 FA K0710 L068 A:23749 T:23906 P:11188'},
[11202]={[0]='Mission: Eternal Flame',[1]='B491 FA K0710 L068 A:23906 T:23906 P:11199'},
[11208]={[0]='Delivery for Drazzit',[1]='B141 K0390 L035 A:23797 T:23572 P:27348'},
[11211]={[0]='Help for Mudsprocket',[1]='B141 K0390 L038 A:6546 T:23572'},
[11212]={[0]="Tabetha's Farm",[1]='B141 K0370 FA L037 A:4921 T:6546'},
[11213]={[0]='Check Up on Tabetha',[1]='B141 K0370 FH L037 A:4791 T:6546'},
[11215]={[0]='Help Mudsprocket',[1]='B141 K0390 FH L039 A:4791 T:23572'},
[11216]={[0]='Archmage Alturus',[1]='B0 K0700 L068 A:23948 T:17613'},
[11218]={[0]='Danger! Explosives!',[1]='B491 FA K0710 L068 A:23976 T:23976 P:11188'},
[11219]={[0]='Stop the Fires!',[1]='B0 HW +D FH A:23973 T:23973'},
[11220]={[0]='The Headless Horseman',[1]='B0 K0800 HW L075'},
[11221]={[0]='Reports from the Field',[1]='B491 K0710 FH L068 A:23780 T:23780 P:11270'},
[11224]={[0]='Send Them Packing',[1]='B491 FA K0710 L068 A:23978 T:23978 P:11188'},
[11227]={[0]='Let Them Eat Crow',[1]='B491 K0710 FH L068 A:23938 T:23938'},
[11228]={[0]='Hell Has Frozen Over...',[1]='B491 FA K0700 L068 A:23547 T:23546'},
[11229]={[0]='The Windrunner Fleet',[1]='B491 K0710 FH L068 A:23780 T:24037 P:11221'},
[11230]={[0]='Ambushed!',[1]='B491 K0710 FH L068 A:24037 T:24037 P:11229'},
[11231]={[0]='Of Keys and Cages',[1]='B491 FA K0710 L068 A:24038 T:24038 P:11250'}, -- TODO: is also 11249 needed?
[11232]={[0]='Guide Our Sights',[1]='B491 K0710 FH L068 A:24037 T:23778 P:11230'},
[11233]={[0]='Landing the Killing Blow',[1]='B491 K0710 FH L068 A:23778 T:23778 P:11232'},
[11234]={[0]='Report to Anselm',[1]='B491 K0710 FH L068 A:23778 T:23780 P:11233'},
[11235]={[0]='Dealing With Gjalerbron',[1]='B491 FA K0710 L068 A:23749 T:23749 P:11250'},
[11236]={[0]='Necro Overlord Mezhen',[1]='B491 FA K0720 L068 A:23749 T:23749 P:11235'},
[11237]={[0]='Gjalerbron Attack Plans',[1]='B491 FA K0720 L068 A:100033289 T:23888'},
[11238]={[0]='The Frost Wyrm and its Master',[1]='B491 FA K0720 L068 A:23888 T:23888 P:11237'},
[11239]={[0]='In Service to the Light',[1]='B491 FA K0710 L068 A:24038 T:24038 P:11231'},
[11240]={[0]='Leader of the Deranged',[1]='B491 FA K0710 L068 A:23976 T:23976 P:11218'},
[11241]={[0]='Trail of Fire',[1]='B491 K0710 FH L068 A:23784 T:24126'},
[11242]={[0]='Free at Last!',[1]='B0 HW FA L060 A:23904 T:24519'},
[11243]={[0]='If Valgarde Falls...',[1]='B491 FA K0700 L068 A:23546 T:23546 P:11228'},
[11244]={[0]='Rescuing the Rescuers',[1]='B491 FA K0700 L068 A:23546 T:23546 P:11243'},
[11245]={[0]='Towers of Certain Doom',[1]='B491 K0710 FA L068 A:24060 T:24060 P:11248'},
[11246]={[0]='Gruesome, But Necessary',[1]='B491 K0710 FA L068 A:24060 T:24060 P:11248'},
[11247]={[0]='Burn Skorn, Burn!',[1]='B491 K0710 FA L068 A:24060 T:24060 P:11248'},
[11248]={[0]='Operation: Skornful Wrath',[1]='B491 FA K0710 L068 A:23749 T:24060 P:11332'},
[11249]={[0]='Stop the Ascension!',[1]='B491 FA K0720 L068 A:100033314 T:24038'},
[11250]={[0]='All Hail the Conqueror of Skorn!',[1]='B491 K0720 FA L068 A:24060 T:23749 P:11245+11246+11247'},
[11251]={[0]='Fresh Legs',[1]='B491 FA K0710 L068 A:24106 T:24111'},
[11252]={[0]='Into Utgarde!',[1]='B504956 K0710 FA L068 A:24111 T:23546 P:11251'},
[11253]={[0]='Sniff Out the Enemy',[1]='B491 K0710 FH L068 A:23938 T:1186585 P:11227'},
[11254]={[0]='The Dragonskin Map',[1]='B491 K0710 FH L068 A:1186585 T:23780 P:11253'},
[11255]={[0]='Prisoners of Wyrmskull',[1]='B491 FA K0700 L068 A:23546 T:23546 P:11244'},
[11256]={[0]='Skorn Must Fall!',[1]='B491 K0710 FH L068 A:24129 T:24130'},
[11257]={[0]='Gruesome, But Necessary',[1]='B491 K0710 FH L068 A:24130 T:24130'},
[11258]={[0]='Burn Skorn, Burn!',[1]='B491 K0710 FH L068 A:24130 T:24130'},
[11259]={[0]='Towers of Certain Doom',[1]='B491 K0710 FH L068 A:24130 T:24130'},
[11260]={[0]='Stop the Ascension!',[1]='B491 K0720 FH L068 A:100033345 T:24135'},
[11261]={[0]='The Conqueror of Skorn!',[1]='B491 K0720 FH L068 A:24130 T:24129'},
[11262]={[0]='Ingvar Must Die!',[1]='B0 K0710 FH L068 A:24137 T:23780'},
[11263]={[0]='Dealing With Gjalerbron',[1]='B491 K0710 FH L068 A:24129 T:24129 P:11261'},
[11264]={[0]='Necro Overlord Mezhen',[1]='B491 K0720 FH L068 A:24129 T:24129 P:11263'},
[11265]={[0]='Of Keys and Cages',[1]='B491 K0710 FH L068 A:24135 T:24135'},
[11266]={[0]='Gjalerbron Attack Plans',[1]='B491 K0720 FH L068 A:100033347 T:24032'},
[11267]={[0]='The Frost Wyrm and its Master',[1]='B491 K0720 FH L068 A:24032 T:24032 P:11266'},
[11268]={[0]='The Walking Dead',[1]='B491 K0710 FH L068 A:24135 T:24135 P:11265'},
[11269]={[0]='Down to the Wire',[1]='B491 FA K0710 L069 A:24139 T:24139'},
[11270]={[0]='War is Hell',[1]='B491 K0710 FH L068 A:23780 T:23780'},
[11271]={[0]='Hasty Preparations',[1]='B491 K0710 FH L069 A:24127 T:24127'},
[11272]={[0]='A Score to Settle',[1]='B504956 K0710 FH L068 A:23780 T:23780'},
[11273]={[0]='The Human League',[1]='B491 FA K0700 L068 A:23548 T:24122 P:11244'},
[11274]={[0]="Zedd's Probably Dead",[1]='B491 FA K0700 L068 A:24122 T:24145 P:11273'},
[11275]={[0]='Making the Horn',[1]='B491 K0710 FH L069 A:24123 T:24123'},
[11276]={[0]='And Then There Were Two...',[1]='B491 FA K0700 L068 A:24145 T:24150 P:11274'},
[11277]={[0]='The Depths of Depravity',[1]='B491 FA K0710 L068 A:24150 T:24150 P:11276'},
[11278]={[0]='Return to Valgarde',[1]='B491 FA K0710 L068 A:24150 T:23548 P:11300'},
[11279]={[0]='Green Eggs and Whelps',[1]='B491 K0710 FH L068 A:24157 T:24157'},
[11280]={[0]='Draconis Gastritis',[1]='B491 K0710 FH L068 A:24157 T:24157 P:11279'},
[11281]={[0]="Mimicking Nature's Call",[1]='B491 K0710 FH L069 A:24123 T:24123 P:11275'},
[11282]={[0]='A Lesson in Fear',[1]='B491 K0710 FH L068 A:24027 T:24027 P:11295'},
[11283]={[0]='Baleheim Bodycount',[1]='B491 K0710 FH L068 A:24027 T:24027'},
[11284]={[0]='The Yeti Next Door',[1]='B491 FA K0710 L068 A:24176 T:24176'},
[11285]={[0]='Baleheim Must Burn!',[1]='B491 K0710 FH L068 A:24027 T:24027'},
[11286]={[0]='The Artifacts of Steel Gate',[1]='B491 K0710 FH L069 A:24186 T:24186 P:11287'},
[11287]={[0]='Find Sage Mistwalker',[1]='B491 K0710 FH L069 A:24135 T:24186'},
[11288]={[0]='The Shining Light',[1]='B491 FA K0710 L068 A:24189 T:24189'},
[11289]={[0]='Guided by Honor',[1]='B491 FA K0710 L068 A:24189 T:24191 P:11288'},
[11290]={[0]='Dragonflayer Battle Plans',[1]='B491 FA K0700 L068 A:23546 T:23546 P:11255'},
[11291]={[0]='To Westguard Keep!',[1]='B491 FA K0700 L068 A:23546 T:23749 P:11290'},
[11292]={[0]='Preying Upon the Weak',[1]='B491 FA K0700 L069 A:24131 T:24131'},
[11293]={[0]='Bark for the Barleybrews!',[1]='B0 FA +D HB A:23627 T:23627 P:11318 I:11294'},
[11294]={[0]='Bark for the Thunderbrews!',[1]='B0 FA +D HB A:23628 T:23628 P:11318 I:11293'},
[11295]={[0]='The Offensive Begins',[1]='B491 K0710 FH L068 A:23780 T:24027 P:11254'},
[11296]={[0]='Rivenwood Captives',[1]='B491 K0720 FH L070 A:24209 T:24209'},
[11297]={[0]='Keeping Watch on the Interlopers',[1]='B491 K0710 FH L069 A:24234 T:24152'},
[11298]={[0]="What's in That Brew?",[1]='B491 K0710 FH L069 A:24152 T:24152 P:11297'},
[11299]={[0]='The Ring of Judgement',[1]='B491 FA K0710 L068 A:24150 T:24151 P:11277'},
[11300]={[0]='Stunning Defeat at the Ring',[1]='B491 FA K0710 L068 A:24151 T:24150 P:11299'},
[11301]={[0]='Brains! Brains! Brains!',[1]='B491 K0710 FH L069 A:24218 T:24218'},
[11302]={[0]='The Enigmatic Frost Nymphs',[1]='B491 FA K0700 L068 A:24282 T:24117 P:11329'},
[11303]={[0]='The Ambush',[1]='B491 K0710 FH L068 A:24027 T:24458'},
[11304]={[0]='New Agamand',[1]='B491 K0710 FH L068 A:24126 T:24251'},
[11305]={[0]='A Tailor-Made Formula',[1]='B491 K0710 FH L068 A:24251 T:24251 P:11304'},
[11306]={[0]='Apply Heat and Stir',[1]='B491 K0710 FH L068 A:24251 T:24251 P:11305'},
[11307]={[0]='Field Test',[1]='B491 K0710 FH L068 A:24251 T:24251 P:11306'},
[11308]={[0]='Time for Cleanup',[1]='B491 K0710 FH L068 A:24251 T:24252 P:11307'},
[11309]={[0]='Parts for the Job',[1]='B491 K0710 FH L068 A:24252 T:24252 P:11308'},
[11310]={[0]='Warning: Some Assembly Required',[1]='B491 K0710 FH L068 A:24252 T:24252 P:11309'},
[11311]={[0]='Suppressing the Elements',[1]='B491 K0710 FH L069 A:24256 T:24256'},
[11312]={[0]='The Frozen Glade',[1]='B491 K0710 FH L069 A:24123 T:24117 P:11302'},
[11313]={[0]='Spirits of the Ice',[1]='B491 K0710 L069 A:24117 T:24117 P:11302,11312'},
[11314]={[0]='The Fallen Sisters',[1]='B491 K0710 L069 A:24117 T:24117 P:11313'},
[11315]={[0]='Wild Vines',[1]='B491 K0710 L069 A:24117 T:24117 P:11313'},
[11316]={[0]='Spawn of the Twisted Glade',[1]='B491 K0710 L069 A:24117 T:24117 P:11314+11315'},
[11317]={[0]='The Cleansing',[1]='B491 K0710 FH L069 A:24186 T:24186 P:11286'},
[11318]={[0]='Now This is Ram Racing... Almost.',[1]='B0 FA HB +Y A:23558 T:23558'},
[11319]={[0]='Seeds of the Blacksouled Keepers',[1]='B491 K0710 L069 A:24117 T:24117 P:11314+11315'},
--[11321]={[0]='Did Someone Say "Souvenir?"',[1]='FA HB A:24468 T:23710 P:11318'},
[11322]={[0]='The Cleansing',[1]='B491 FA K0710 L069 A:24273 T:24273'},
[11323]={[0]="In Worg's Clothing",[1]='B491 K0710 FH L069 A:24186 T:24261 P:11317'},
[11324]={[0]='Alpha Worg',[1]='B491 K0710 FH L069 A:24261 T:24186 P:11417'},
[11325]={[0]="In Worg's Clothing",[1]='B491 FA K0710 L069 A:24273 T:24261 P:11322'},
[11326]={[0]='Alpha Worg',[1]='B491 FA K0710 L069 A:24261 T:24273 P:11416'},
[11327]={[0]='Mission: Package Retrieval',[1]='B491 FA K0710 L068 A:23906 T:23906 P:11202'},
[11328]={[0]='Mission: Forsaken Intel',[1]='B491 FA K0710 L068 A:23906 T:24283 P:11327'},
[11329]={[0]="I'll Try Anything!",[1]='B491 FA K0700 L069 A:24056 T:24056'},
[11330]={[0]='Absholutely... Thish Will Work!',[1]='B491 FA K0710 L068 A:24283 T:24283 P:11328'},
[11331]={[0]='You Tell Him ...Hic!',[1]='B491 FA K0710 L068 A:24283 T:23749 P:11330'},
[11332]={[0]='Mission: Plague This!',[1]='B491 FA K0710 L068 A:23749 T:23749 P:11331'},
[11333]={[0]='Into the World of Spirits',[1]='B491 FA K0710 L068 A:23975 T:23975 P:11244'},
--[11335]={[0]='Call to Arms: Arathi Basin',[1]='+D FA L071 A:15351 T:15351'},
--[11339]={[0]='Call to Arms: Arathi Basin',[1]='+D FH L071 A:15350 T:15350'},
[11343]={[0]='The Echo of Ymiron',[1]='B491 FA K0710 L068 A:23975 T:23975 P:11333'},
[11344]={[0]='Anguish of Nifflevar',[1]='B491 FA K0710 L068 A:23975 T:23975 P:11343'},
[11346]={[0]='The Book of Runes',[1]='B491 FA K0710 L069 A:24328 T:24328 P:11329'},
[11348]={[0]='The Rune of Command',[1]='B491 FA K0710 L069 A:24328 T:24328 P:11349'},
[11349]={[0]='Mastering the Runes',[1]='B491 FA K0710 L069 A:24328 T:24328 P:11346'},
[11350]={[0]='The Book of Runes',[1]='B491 K0710 FH L069 A:24362 T:24362'},
[11351]={[0]='Mastering the Runes',[1]='B491 K0710 FH L069 A:24362 T:24362 P:11350'},
[11352]={[0]='The Rune of Command',[1]='B491 K0710 FH L069 A:24362 T:24362 P:11351'},
[11354]={[0]="Wanted: Nazan's Riding Crop",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11355]={[0]='March of the Giants',[1]='B491 FA K0720 L069 A:24376 T:24376 P:11329'},
[11356]={[0]='Costumed Orphan Matron',[1]='B0 HW FA A:18927,19148,19171,19173,20102 T:24519 I:11356,11439,11440'},
[11357]={[0]='Masked Orphan Matron',[1]='B0 HW FH'},
[11358]={[0]='The Lodestone',[1]='B491 FA K0720 L069 A:24376 T:24376 P:11355'},
[11359]={[0]='Demolishing Megalith',[1]='B491 FA K0720 L069 A:24376 T:24376 P:11358'},
[11360]={[0]='Fire Brigade Practice',[1]='B0 HW FA A:24519 T:24519 I:11439,11440 O:11356'},
[11361]={[0]='Fire Training',[1]='B0 HW FH I:11449,11450'},
[11362]={[0]="Wanted: Keli'dan's Feathered Stave",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11363]={[0]="Wanted: Bladefist's Seal",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11364]={[0]='Wanted: Shattered Hand Centurions',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11365]={[0]='March of the Giants',[1]='B491 K0720 FH L069 A:24390 T:24390'},
[11366]={[0]='The Lodestone',[1]='B491 K0720 FH L069 A:24390 T:24390 P:11365'},
[11367]={[0]='Demolishing Megalith',[1]='B491 K0720 FH L069 A:24390 T:24390 P:11366'},
[11368]={[0]='Wanted: The Heart of Quagmirran',[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11369]={[0]='Wanted: A Black Stalker Egg',[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11370]={[0]="Wanted: The Warlord's Treatise",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11371]={[0]='Wanted: Coilfang Myrmidons',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11372]={[0]='Wanted: The Headfeathers of Ikiss',[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11373]={[0]="Wanted: Shaffar's Wondrous Pendant",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11374]={[0]="Wanted: The Exarch's Soul Gem",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11375]={[0]="Wanted: Murmur's Whisper",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11376]={[0]='Wanted: Malicious Instructors',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11377]={[0]='Revenge is Tasty',[1]='B0 +D K0700 L070 A:24393 T:24393'},
[11378]={[0]="Wanted: The Epoch Hunter's Head",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11379]={[0]='Super Hot Stew',[1]='B0 +D K0700 L070 A:24393 T:24393'},
[11380]={[0]='Manalicious',[1]='B0 +D K0700 L070 A:24393 T:24393'},
[11381]={[0]='Soup for the Soul',[1]='B0 +D K0700 L070 A:24393 T:24393'},
[11382]={[0]="Wanted: Aeonus's Hourglass",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11383]={[0]='Wanted: Rift Lords',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11384]={[0]='Wanted: A Warp Splinter Clipping',[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11385]={[0]='Wanted: Sunseeker Channelers',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11386]={[0]="Wanted: Pathaleon's Projector",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11387]={[0]='Wanted: Tempest-Forge Destroyers',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11388]={[0]='Wanted: The Scroll of Skyriss',[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11389]={[0]='Wanted: Arcatraz Sentinels',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11390]={[0]="I've Got a Flying Machine!",[1]='B491 FA K0710 L069 A:24399 T:24399 P:11176'},
[11391]={[0]='Steel Gate Patrol',[1]='B491 +D FA K0710 L069 A:24399 T:24399 P:11390'},
[11392]={[0]='Call the Headless Horseman',[1]='B0 K0800 HW L075'},
[11393]={[0]='Where is Explorer Jaren?',[1]='B491 FA K0710 L069 A:23891 T:23833'},
[11394]={[0]='And You Thought Murlocs Smelled Bad!',[1]='B491 FA K0710 L069 A:23833 T:23833 P:11393'},
[11395]={[0]="It's a Scourge Device",[1]='B491 FA K0710 L069 A:100033961 T:23833'},
[11396]={[0]='Bring Down Those Shields',[1]='B491 FA K0710 L069 A:23833 T:23833 P:11395'},
[11397]={[0]='And You Thought Murlocs Smelled Bad!',[1]='B491 K0710 FH L069 A:24359 T:24359'},
[11398]={[0]="It's a Scourge Device",[1]='B491 K0710 FH L069 A:100033962 T:24359'},
[11399]={[0]='Bring Down Those Shields',[1]='B491 K0710 FH L069 A:24359 T:24359 P:11398'},
[11401]={[0]='Call the Headless Horseman',[1]='B0 HW L075'},
[11403]={[0]='Free at Last!',[1]='B0 HW FH L060 A:23904 T:23973'},
[11404]={[0]='Call the Headless Horseman',[1]='B0 HW L075'},
[11405]={[0]='Call the Headless Horseman',[1]='B0 HW L075'},
[11406]={[0]='Everything Must Be Ready',[1]='B491 FA K0700 L068 A:24494 T:24139 P:11332'},
[11407]={[0]="Bark for Drohn's Distillery!",[1]='B0 FH +D HB A:24498 T:24498 P:11409 I:11408'},
[11408]={[0]="Bark for T'chali's Voodoo Brewery!",[1]='B0 FH +D HB A:24499 T:24499 P:11409 I:11407'},
[11409]={[0]='Now This is Ram Racing... Almost.',[1]='B0 FH HB +Y A:24497 T:24497'},
[11410]={[0]='The One That Got Away',[1]='B491 FA K0710 L068 A:24056 T:24056 P:11329'},
[11411]={[0]='Camp Winterhoof',[1]='B491 K0700 FH L068 A:24125 T:24129'},
[11412]={[0]='There and Back Again',[1]='B0 FH HB +D A:24497 T:24497 P:11409'},
--[11413]={[0]='Did Someone Say "Souvenir?"',[1]='FH HB T:24495'},
[11414]={[0]='Brother Betrayers',[1]='B491 FA K0710 L069 A:24261 T:24261 P:11325'},
[11415]={[0]='Brother Betrayers',[1]='B491 K0710 FH L069 A:24261 T:24261 P:11323'},
[11416]={[0]='Eyes of the Eagle',[1]='B491 FA K0710 L069 A:24261 T:24261 P:11414'},
[11417]={[0]='Eyes of the Eagle',[1]='B491 K0710 FH L069 A:24261 T:24261 P:11415'},
[11418]={[0]='We Call Him Steelfeather',[1]='B491 FA K0700 L068 A:24139 T:24139 P:11269'},
[11420]={[0]='The Path to Payback',[1]='B491 FA K0710 L068 A:23728 T:23728 P:11244'},
[11421]={[0]='It Goes to 11...',[1]='B491 FA K0710 L068 A:24634 T:24634 P:11430'},
[11422]={[0]='Trident of the Son',[1]='B491 K0710 L069 A:24544 T:24544'},
[11423]={[0]="The Enemy's Legacy",[1]='B491 K0710 FH L070 A:24548 T:24548'},
[11424]={[0]='Shield Hill',[1]='B491 K0710 FH L068 A:24252 T:24252'},
[11426]={[0]='Locating the Mechanism',[1]='B491 FA K0710 L068 A:23728 T:23728 P:11420'},
[11427]={[0]='Meet Lieutenant Icehammer...',[1]='B491 FA K0710 L068 A:23728 T:24634 P:11426'},
[11428]={[0]='Keeper Witherleaf',[1]='B491 K0710 L069 A:24117 T:24117 P:11316'},
[11429]={[0]='Drop It then Rock It!',[1]='B491 FA K0710 L068 A:24634 T:24634 P:11427'},
[11430]={[0]='Harpoon Master Yavus',[1]='B491 FA K0710 L068 A:24634 T:24634 P:11429'},
[11431]={[0]='Catch the Wild Wolpertinger!',[1]='B0 FH HB +Y K0000 A:24657 T:24657 I:11117'},
[11432]={[0]='Sleeping Giants',[1]='B491 FA K0710 L068 A:23888 T:23888 P:11231'},
[11433]={[0]='Sleeping Giants',[1]='B491 K0710 FH L068 A:24127 T:24127 P:11268'},
[11434]={[0]='Forgotten Treasure',[1]='B491 K0710 L069 A:24537 T:24537 P:11509'},
[11436]={[0]="Let's Go Surfing Now",[1]='B491 FA K0710 L068 A:24634 T:23728 P:11421'},
[11439]={[0]='Fire Brigade Practice',[1]='B0 HW FA A:24519 T:24519 I:11360,11440 O:11356'},
[11440]={[0]='Fire Brigade Practice',[1]='B0 HW FAA:24519 T:24519 I:11360,11439 O:11356'},
[11441]={[0]='Brewfest!',[1]='B0 FA HB +Y K0000 A:18927,19148,19171,19172,19173 T:24710 I:11442,11446,11447'},
[11442]={[0]='Welcome to Brewfest!',[1]='B0 SP FA HB +Y K0000 A:24710 T:24710 I:11441,11446,11447'},
[11443]={[0]="Daggercap Divin'",[1]='B491 FA K0710 L068 A:23730 T:23730'},
[11446]={[0]='Brewfest!',[1]='B0 FH HB +Y K0000 A:19169,19175,19176,19177,19178,20102 T:24711 I:11441,11442,11447'},
[11447]={[0]='Welcome to Brewfest!',[1]='B0 SP FH HB +Y K0000 A:24711 T:24711 I:11441,11442,11446'},
[11448]={[0]="The Explorers' League Outpost",[1]='B491 FA K0710 L068 A:23548 T:24717 P:11278'},
[11449]={[0]='Fire Training',[1]='B0 HW FH I:11361,11450'},
[11450]={[0]='Fire Training',[1]='B0 HW FH A:23973 T:23973 I:11361,11449'},
[11451]={[0]="Alicia's Poem",[1]='B0 FA K0700 L060 A:24729 T:24727'},
[11452]={[0]='The Slumbering King',[1]='B491 K0720 FA L068 A:100034090 T:23749'},
[11453]={[0]='The Slumbering King',[1]='B491 K0720 FH L068 A:100034091 T:24129'},
[11455]={[0]='The Fragrance of Money',[1]='B491 K0710 L069 A:24537 T:24537 P:11434'},
[11456]={[0]='Feeding the Survivors',[1]='B491 K0710 L069 A:24755 T:24755'},
[11457]={[0]='Arming Kamagua',[1]='B491 K0710 L069 A:24755 T:24755 P:11456'},
[11458]={[0]='Avenge Iskaal',[1]='B491 K0710 L069 A:24755 T:24755 P:11457'},
[11459]={[0]="Zeh'gehn Sez",[1]='B491 K0710 L069 A:24525 T:24537 P:11473'},
[11460]={[0]='Trust is Earned',[1]='B491 FA K0710 L068 A:24750 T:24750'},
[11464]={[0]='Gambling Debt',[1]='B491 K0710 L069 A:24541 T:24541 P:11434'},
[11465]={[0]='The Ransacked Caravan',[1]='B491 FA K0710 L068 A:24750 T:24750 P:11460'},
[11466]={[0]='Jack Likes His Drink',[1]='B491 K0710 L069 A:24541 T:24541 P:11464'},
[11467]={[0]="Dead Man's Debt",[1]='B491 K0710 L069 A:24541 T:24541 P:11466'},
[11468]={[0]='Falcon Versus Hawk',[1]='B491 FA K0710 L068 A:24750 T:24750 P:11465'},
[11469]={[0]="Swabbin' Soap",[1]='B491 K0710 L069 A:24784 T:24784'},	-- TODO: need to verify if 11509 needs to be done first
[11470]={[0]='There Exists No Honor Among Birds',[1]='B491 FA K0710 L068 A:24750 T:24750 P:11468'},
[11471]={[0]='The Jig is Up',[1]='B491 K0710 L069 A:24741 T:24741 P:11480'},
[11472]={[0]='The Way to His Heart...',[1]='B0 +D L069 A:24810 T:24810 P:11469'},
[11473]={[0]='A Traitor Among Us',[1]='B491 K0710 L069 A:24537 T:24525 P:11455'},
[11474]={[0]='Problems on the High Bluff',[1]='B491 FA K0710 L068 A:24717 T:24807 P:11448'},
[11475]={[0]='Tools to Get the Job Done',[1]='B491 FA K0710 L068 A:24807 T:24807'}, -- if one has 11474, this will not be available until that turned in
[11476]={[0]='A Carver and a Croaker',[1]='B491 K0710 L069 A:24537 T:24525 P:11459'},
[11477]={[0]='Out of My Element?',[1]='B491 FA K0700 L068 A:24811 T:24811'},
[11478]={[0]='Outpost Over Yonder...',[1]='B491 FA K0710 L068 A:24811 T:24717'},
[11479]={[0]='"Crowleg" Dan',[1]='B491 K0710 L069 A:24525 T:24537 P:11476'},
[11480]={[0]='Meet Number Two',[1]='B491 K0710 L069 A:24537 T:24741 P:11479'},
[11481]={[0]='Crisis at the Sunwell',[1]='B0 K0700 L070 A:18537 T:24813'},
[11482]={[0]='Duty Calls',[1]='B0 K0700 L070 A:18594 T:24813 P:11481'},
[11483]={[0]='We Can Rebuild It',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11475'},
[11484]={[0]='We Have the Technology',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11475'},
[11485]={[0]='Iron Rune Constructs and You: Rocket Jumping',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11484'}, -- TODO: does this also require 11483?
[11488]={[0]="Magisters' Terrace",[1]='B0 K0700 L070 A:24813 T:24822 P:11481,11482'},
[11489]={[0]='Iron Rune Constructs and You: Collecting Data',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11485'},
[11490]={[0]="The Scryer's Scryer",[1]='B0 K0700 L070 A:24822 T:24848 P:11488'},
[11491]={[0]='Iron Rune Constructs and You: The Bluff',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11489'},
[11492]={[0]='Hard to Kill',[1]='B0 K0700 L070 A:24848 T:24813 P:11490'},
[11494]={[0]='Lightning Infused Relics',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11491'},
[11495]={[0]='The Delicate Sound of Thunder',[1]='B491 FA K0710 L068 A:24807 T:24807 P:11491'},
[11499]={[0]="Wanted: The Signet Ring of Prince Kael'thas",[1]='B0 +D K07064 L070 A:24369 T:24369'},
[11500]={[0]='Wanted: Sisters of Torment',[1]='B0 +D K07064 L070 A:24370 T:24370'},
[11501]={[0]='News From the East',[1]='B491 FA K0710 L068 A:24807 T:23749 P:11495'},	-- TODO: does this also require 11494?
[11502]={[0]='In Defense of Halaa',[1]='B477 +D FA K070256 L064 A:24866 T:24866'},
[11503]={[0]='Enemies, Old and New',[1]='B0 +D FH K070256 L064 A:24881 T:24881'},
[11504]={[0]='The Dead Rise!',[1]='B491 K0710 L068 A:23804 T:23804 O:11573'},
[11505]={[0]='Spirits of Auchindoun',[1]='B478 +D FA K070256 L062 A:24885 T:24885'},
[11506]={[0]='Spirits of Auchindoun',[1]='B478 +D FH K070256 L062 A:24886 T:24886'},
[11507]={[0]='Elder Atuik and Kamagua',[1]='B491 K0710 L068 A:23804 T:24755 P:11504'},
[11508]={[0]='Grezzix Spindlesnap',[1]='B491 K0710 L068 A:24755 T:24643 P:11507'},
[11509]={[0]='Street "Cred"',[1]='B491 K0710 L068 A:24643 T:24539 P:11508'},
[11510]={[0]='"Scoodles"',[1]='B491 K0710 L068 A:24539 T:24539 P:11509'},
[11511]={[0]="The Staff of Storm's Fury",[1]='B491 K0710 L068 A:24539 T:23804 P:11510'},
[11512]={[0]='The Frozen Heart of Isuldof',[1]='B491 K0710 L068 A:24539 T:23804 P:11510'},
[11514]={[0]='Maintaining the Sunwell Portal',[1]='B0 +D K0700 L070 A:24932 T:24932'},
[11515]={[0]='Blood for Blood',[1]='B0 +D K0700 L070 A:24937 T:24937'},
[11516]={[0]='Blast the Gateway',[1]='B0 +D K0700 L070 A:24937 T:24937'},
[11519]={[0]='The Lost Shield of the Aesirites',[1]='B491 K0710 L068 A:24539 T:24910 P:11510'},
[11521]={[0]='Rediscovering Your Roots',[1]='B0 +D K0700 L070 A:24975 T:24975'},
[11523]={[0]='Arm the Wards!',[1]='B0 +D K0700 L070 A:24967 T:24967'},
[11525]={[0]='Further Conversions',[1]='B0 +D K0700 L070 A:24965 T:24965'},
[11526]={[0]='The Missing Magistrix',[1]='B0 K0700 L070 A:24967 T:24937'},
[11527]={[0]='Mutiny on the Mercy',[1]='B491 K0710 L068 A:24910 T:24910 P:11519'},
[11528]={[0]='A Winter Veil Gift',[1]='B0 HV L010'},
[11529]={[0]="Sorlof's Booty",[1]='B491 K0710 L068 A:24910 T:24910 P:11527'},
[11530]={[0]='The Shield of the Aesirites',[1]='B491 K0710 L068 A:24910 T:23804 P:11529'},
[11531]={[0]='Strange Engine Part',[1]='B0 K0700 FA L055 A:100034469 T:17634'},
[11533]={[0]='The Air Strikes Must Continue',[1]='B0 +D K0700 L070 A:25057 T:25057'},
[11534]={[0]='Report to Nasuun',[1]='B0 K0700 L070 A:25034 T:24932'},
[11536]={[0]="Don't Stop Now....",[1]='B0 +D K0700 L070 A:25046 T:25046'},
[11537]={[0]='The Battle Must Go On',[1]='B0 +D K0700 L070 A:25061 T:25061'},
[11540]={[0]='Crush the Dawnblade',[1]='B0 +D K0700 L070 A:25069 T:25069'},
[11541]={[0]='Disrupt the Greengill Coast',[1]='B0 +D K0700 L070 A:25088 T:25088'},
[11543]={[0]='Keeping the Enemy at Bay',[1]='B0 +D K0700 L070 A:25108 T:25108'},
[11544]={[0]="Ata'mal Armaments",[1]='B0 +D K0700 L070 A:25046 T:25046'},
[11546]={[0]='Open for Business',[1]='B0 +D K0700 L070 A:24975 T:24975'},
[11547]={[0]='Know Your Ley Lines',[1]='B0 +D K0700 L070 A:25133 T:25133'},
[11548]={[0]='Your Continued Support',[1]='B0 +D K0700 L070 A:25112 T:25112'},
[11549]={[0]='A Magnanimous Benefactor',[1]='B0 K0700 L070 A:25163 T:25163'},
[11554]={[0]='A Friend in the Frontlines',[1]='B0 K0700 L070 A:25032 T:25032'},
[11555]={[0]='Honored by Your Allies',[1]='B0 K0700 L070 A:25032 T:25032'},
[11556]={[0]='Revered in the Field of Battle',[1]='B0 K0700 L070 A:25032 T:25032'},
[11557]={[0]='Exalted Among All Combatants',[1]='B0 K0700 L070 A:25032 T:25032'},
[11559]={[0]='Winterfin Commerce',[1]='B486 K0710 L069 A:25197 T:25206 P:11571'},
[11560]={[0]='Oh Noes, the Tadpoles!',[1]='B486 K0710 L069 A:25197 T:25197 P:11559'},
[11561]={[0]='Them!',[1]='B486 K0710 L069 A:25199 T:25199 P:11559'},
[11562]={[0]="I'm Being Blackmailed By My Cleaner",[1]='B486 K0710 L069 A:25197 T:25205 P:11560'},
[11563]={[0]='Grmmurggll Mrllggrl Glrggl!!!',[1]='B486 K0710 L069 A:25205 T:25205 P:11562'},
[11564]={[0]='Succulent Orca Stew',[1]='B486 K0710 L069 A:25211 T:25211 P:11562'},
[11565]={[0]='The Spare Suit',[1]='B486 K0710 L069 A:25205 T:25197 P:11563'},
[11566]={[0]='Surrender... Not!',[1]='B486 K0720 L069 A:25197 T:25197 P:11565'},
[11567]={[0]='The Ancient Armor of the Kvaldir',[1]='B491 K0710 L068 A:24539 T:23804 P:11510'},
[11568]={[0]='A Return to Resting',[1]='B491 K0710 L068 A:23804 T:23804 P:11530+11567+11512+11511'},
[11569]={[0]='Keymaster Urmgrgl',[1]='B486 K0710 L069 A:28375 T:28375'},
[11570]={[0]='Escape from the Winterfin Caverns',[1]='B486 K0710 L069 A:25208 T:25197'},
[11571]={[0]='Learning to Communicate',[1]='B486 K0710 L069 A:25197 T:25197 P:11702,11704'},
[11572]={[0]='Return to Atuik',[1]='B491 K0710 L068 A:23804 T:24755 P:11568'},
[11573]={[0]='Orfus of Kamagua',[1]='B491 FA K0710 L068 A:25233 T:23804 I:11504'},
[11574]={[0]='Too Close For Comfort',[1]='B486 K0710 FH L069 A:25247 T:25262'},
[11575]={[0]='Nick of Time',[1]='B486 FA K0710 L069 A:25249 T:25262 P:11574'},
[11576]={[0]='Monitoring the Rift: Cleftcliff Anomaly',[1]='B486 K0710 L069 A:25291 T:25291'},
[11580]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056487'},
[11581]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056492'},
[11582]={[0]='Monitoring the Rift: Sundered Chasm',[1]='B486 K0710 L069 A:25291 T:25291 P:11576'},
[11583]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25910'},
[11584]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25939'},
[11585]={[0]="Hellscream's Vigil",[1]='B486 K0710 FH L068 A:25273 T:25237 P:28711'},
[11586]={[0]="Hellscream's Vigil",[1]='B486 K0710 FH L068 A:25273 T:25237'},
[11587]={[0]='Prison Break',[1]='B486 K0710 L069 A:25262 T:25262 P:11574,11575'},
[11590]={[0]='Abduction',[1]='B486 K0710 L069 A:25262 T:25262 P:11587'},
[11591]={[0]="Report to Steeljaw's Caravan",[1]='B486 K0710 FH L068 A:25326 T:25336'},
[11592]={[0]='We Strike!',[1]='B486 K0720 FH L068 A:25335 T:25326'},
[11593]={[0]='The Honored Dead',[1]='B486 K0710 FH L068 A:25336 T:25336'},
[11594]={[0]='Put Them to Rest',[1]='B486 K0710 FH L068 A:25336 T:25336'},
[11595]={[0]='The Defense of Warsong Hold',[1]='B486 K0710 FH L068 A:25256 T:25279 I:11596,11597'},
[11596]={[0]='The Defense of Warsong Hold',[1]='B486 K0710 FH L068 A:25256 T:25279 I:11595,11597'},
[11597]={[0]='The Defense of Warsong Hold',[1]='B0 K0710 FH L068 A:25256 T:25279 I:11595,11596'},
[11598]={[0]='Taking Back Mightstone Quarry',[1]='B486 K0710 FH L068 A:25279 T:25279 P:11595,11596,11597'},
[11599]={[0]='Thassarian, My Brother',[1]='B486 FA K0710 L068 A:25251 T:25385 P:11927'},
[11600]={[0]='The Late William Allerton',[1]='B486 FA K0710 L068 A:25385 T:25251 P:11599'},
[11601]={[0]='Lost and Found',[1]='B486 FA K0710 L068 A:25251 T:25245 P:11600'},
[11602]={[0]='Cutting Off the Source',[1]='B486 K0710 FH L068 A:25279 T:25279 P:11598'},
[11603]={[0]='In Wine, Truth',[1]='B486 FA K0710 L068 A:25245 T:25302 P:11601'},
[11604]={[0]='A Deserter',[1]='B486 FA K0710 L068 A:25302 T:25395 P:11603'},
[11605]={[0]='The Honored Ancestors',[1]='B486 K0720 L068 A:1187565 T:1187565'},
[11606]={[0]="Patience is a Virtue that We Don't Need",[1]='B486 K0710 FH L068 A:25327 T:25327'},
[11607]={[0]='The Lost Spirits',[1]='B486 K0720 L068 A:1187565 T:1187565 P:11605'},
[11608]={[0]='Bury Those Cockroaches!',[1]='B486 K0710 FH L068 A:25327 T:25327 P:11606'},
[11609]={[0]='Picking Up the Pieces',[1]='B486 K0720 L068 A:1187565 T:1187565 P:11607'},
[11610]={[0]='Leading the Ancestors Home',[1]='B486 K0720 L068 A:1187565 T:1187565 P:11609'},
[11611]={[0]='Taken by the Scourge',[1]='B486 K0710 FH L068 A:25280 T:25280'},
[11612]={[0]='Reclaiming the Quarry',[1]='B486 K0720 L068 A:25292 T:25292'},
[11613]={[0]="Karuk's Oath",[1]='B486 K0710 L068 A:25435 T:25435 P:12141'},
[11614]={[0]='Untold Truths',[1]='B486 K0710 FH L068 A:25394 T:25328'},
[11615]={[0]="Nerub'ar Secrets",[1]='B486 K0710 FH L068 A:25328 T:25394 P:11614'},
[11616]={[0]='Message to Hellscream',[1]='B486 K0710 FH L068 A:25394 T:25237 P:11615'},
[11617]={[0]='Hampering Their Escape',[1]='B486 K0720 L068 A:25292 T:25292 P:11612'},
[11618]={[0]='Reinforcements Incoming...',[1]='B486 K0710 FH L068 A:25237 T:25437 P:11616'},
[11619]={[0]='Gamel the Cruel',[1]='B486 K0710 L068 A:25435 T:25435 P:11613'},
[11620]={[0]="A Father's Words",[1]='B486 K0710 L068 A:25435 T:25450 P:11619'},
[11623]={[0]='A Visit to the Curator',[1]='B486 K0720 L068 A:25292 T:25292 P:11617'},
[11624]={[0]='The Sky Will Know',[1]='B486 K0710 FH L069 A:25339 T:25376 P:12486'},
[11625]={[0]="The Trident of Naz'jan",[1]='B486 K0710 L068 A:25450 T:25450 P:11620'},
[11626]={[0]='The Emissary',[1]='B486 K0710 L068 A:25450 T:25435 P:11625'},
[11627]={[0]='Boiling Point',[1]='B486 K0720 FH L069 A:25376 T:25376 P:11624'},
[11628]={[0]='Shrouds of the Scourge',[1]='B486 K0720 FH L068 A:24703 T:24703'},
[11629]={[0]='Return to the Spirit Talker',[1]='B486 K0710 FH L069 A:25376 T:25339 P:11649'},
[11630]={[0]='The Bad Earth',[1]='B486 K0720 FH L068 A:24703 T:24703 P:11628'},
[11631]={[0]='Vision of Air',[1]='B486 K0710 FH L069 A:25339 T:25339 P:11629'},
[11632]={[0]='What the Cold Wind Brings...',[1]='B486 K0710 FH L068 A:100034777 T:25256'},
[11633]={[0]='Blending In',[1]='B486 K0720 FH L068 A:24703 T:24703 P:11630'},
[11634]={[0]="Wind Master To'bor",[1]='B486 K0710 FH L068 A:25279 T:25289 P:11602'},
[11635]={[0]="Farseer Grimwalker's Spirit",[1]='B486 K0710 FH L069 A:25339 T:25425'},
[11636]={[0]='Magic Carpet Ride',[1]='B486 K0710 FH L068 A:25289 T:25329 P:11634'},
[11637]={[0]='Kaganishu',[1]='B486 K0720 FH L069 A:25425 T:25425 P:11635'},
[11638]={[0]='Return My Remains',[1]='B486 K0710 FH L069 A:25425 T:25339 P:11637'},
[11639]={[0]='Revenge Upon Magmoth',[1]='B486 K0710 FH L069 A:25374 T:25374'},
[11640]={[0]='Words of Power',[1]='B486 K0720 FH L068 A:24703 T:24703 P:11633'},
[11641]={[0]='A Courageous Strike',[1]='B486 K0720 FH L068 A:24706 T:24706'},
[11642]={[0]="Tank Ain't Gonna Fix Itself",[1]='B486 K0710 FH L068 A:25329 T:25475 P:11636'},
[11643]={[0]="Mobu's Pneumatic Tank Transjigamarig",[1]='B486 K0710 FH L068 A:25475 T:25475'},
[11644]={[0]='Super Strong Metal Plates!',[1]='B486 K0710 FH L068 A:25475 T:25475'},
[11645]={[0]="Dirty, Stinkin' Snobolds!",[1]='B486 FA K0710 L069 A:25477 T:25477'},
[11646]={[0]='The Borean Inquisition',[1]='B486 K0710 L069 A:25262 T:25480 P:11590'},
[11647]={[0]='Neutralizing the Cauldrons',[1]='B486 K0720 FH L068 A:24709 T:24709'},
[11648]={[0]='The Art of Persuasion',[1]='B486 K0710 L069 A:25480 T:25480 P:11646'},
[11649]={[0]='Motes of the Enraged',[1]='B486 K0710 FH L069 A:25376 T:25376 P:11627'},
[11650]={[0]='Just a Few More Things...',[1]='B486 FA K0710 L069 A:25477 T:25477 P:11645'},
[11651]={[0]='Tanks a lot...',[1]='B486 K0710 FH L068 A:25475 T:25329'},
[11652]={[0]='The Plains of Nasam',[1]='B486 K0710 FH L068 A:25329 T:25237 P:11651'},
[11653]={[0]="Hah... You're Not So Big Now!",[1]='B486 FA K0710 L069 A:25477 T:25477 P:11650'},
[11654]={[0]='The Spire of Blood',[1]='B486 K0720 FH L068 A:100034815 T:25516'},
[11655]={[0]='Into the Mist',[1]='B486 K0710 FH L068 A:25476 T:25476'},
[11656]={[0]='Burn in Effigy',[1]='B486 K0710 FH L068 A:25476 T:25476 P:11655'},
[11657]={[0]='Torch Catching',[1]='B0 HM FA K0850 A:25975 T:25975 P:11731 I:11923'},
[11658]={[0]='Plan B',[1]='B486 FA K0710 L069 A:25477 T:25477 P:11653'},
[11659]={[0]='Shatter the Orbs!',[1]='B486 K0720 FH L068 A:25516 T:24733 P:11654'},
[11660]={[0]='Horn of the Ancient Mariner',[1]='B486 K0710 FH L068 A:25476 T:25476'},
[11661]={[0]='Orabus the Helmsman',[1]='B486 K0710 FH L068 A:25476 T:25476 P:11660'},
[11662]={[0]='Seek Out Karuk!',[1]='B486 K0710 FH L068 A:25476 T:25435'},
[11663]={[0]='Sharing Intelligence',[1]='B486 K0710 L069 A:25480 T:25262 P:11648'},
[11664]={[0]='Escaping the Mist',[1]='B486 K0710 FH L068 A:25504 T:25503'},
[11665]={[0]='Crocolisks in the City',[1]='B0 +D K0700 L070 A:25580 T:25580 I:11666,11667,11668,11669'},
[11666]={[0]='Bait Bandits',[1]='B0 +D K0700 L070 A:25580 T:25580 I:11665,11667,11668,11669'},
[11667]={[0]='The One That Got Away',[1]='B0 +D K0700 L070 A:25580 T:25580 I:11665,11666,11668,11669'},
[11668]={[0]="Shrimpin' Ain't Easy",[1]='B0 +D K0700 L070 A:25580 T:25580 I:11665,11666,11667,11669'},
[11669]={[0]='Felblood Fillet',[1]='B0 +D K0700 L070 A:25580 T:25580 I:11665,11666,11667,11668'},
[11670]={[0]='It Was The Orcs, Honest!',[1]='B486 FA K0720 L069 A:25477 T:25477 P:11658'},
[11671]={[0]='A Race Against Time',[1]='B486 K0710 L069 A:25262 T:25262 P:11663'},
[11672]={[0]='Enlistment Day',[1]='B486 FA K0710 L068 A:25307 T:25250 O:28709'},
[11673]={[0]='Get Me Outa Here!',[1]='B486 FA K0720 L069 A:25589 T:25590'},
[11674]={[0]='Sage Highmesa is Missing',[1]='B486 K0710 FH L068 A:25602 T:25604'},
[11675]={[0]='A Proper Death',[1]='B486 K0710 FH L068 A:25604 T:25604 P:11674'},
[11676]={[0]='Merciful Freedom',[1]='B486 K0710 FH L068 A:25438 T:25438'},
[11677]={[0]='Stop the Plague',[1]='B486 K0710 FH L068 A:25604 T:25604 P:11675'},
[11678]={[0]='Find Bristlehorn',[1]='B486 K0710 FH L068 A:25604 T:25658'},
[11679]={[0]='Reforging the Key',[1]='B486 K0710 L069 A:25262 T:24795 P:11671'},
[11680]={[0]='Taking Wing',[1]='B486 K0710 L069 A:24795 T:25356 P:11679'},
[11681]={[0]='Rescuing Evanor',[1]='B486 K0710 L069 A:25356 T:25785 P:11680'},
[11682]={[0]='Dragonspeak',[1]='B486 K0710 L069 A:25785 T:24795 P:11681'},
[11683]={[0]='Fallen Necropolis',[1]='B486 K0710 FH L068 A:25604 T:25604'},
[11684]={[0]='Scouting the Sinkholes',[1]='B486 K0710 FH L068 A:24702 T:24702'},
[11685]={[0]='The Heart of the Elements',[1]='B486 K0710 FH L068 A:24702 T:24730 P:11684'},
[11686]={[0]='The Warsong Farms',[1]='B486 K0710 FH L068 A:25437 T:25437 P:11618'},
[11687]={[0]='The Doctor and the Lich-Lord',[1]='B486 K0720 FH L068 A:25658 T:25604 P:11678'},
[11688]={[0]='Damned Filthy Swine',[1]='B486 K0710 FH L068 A:25607 T:25607'},
[11689]={[0]='Return with the Bad News',[1]='B486 K0710 FH L068 A:25604 T:25602 P:11687'},
[11690]={[0]="Bring 'Em Back Alive",[1]='B486 K0710 FH L068 A:25607 T:25607 P:11688'},
[11691]={[0]='Summon Ahune',[1]='B0 K0700 HM L065 P:11696'},
[11692]={[0]='Check in With Bixie',[1]='B486 FA K0710 L068 A:25702 T:25705 P:11710'},
[11693]={[0]='Oh Great... Plagued Magnataur!',[1]='B486 FA K0710 L068 A:25705 T:25705 P:11692'},
[11694]={[0]="There's Something Going On In Those Caves",[1]='B486 FA K0710 L068 A:25705 T:25705 P:11693'},
[11695]={[0]='The Horn of Elemental Fury',[1]='B486 K0710 FH L068 A:24730 T:24730 P:11685'},
[11696]={[0]='Ahune is Here!',[1]='B0 K0700 HM L065'},
[11697]={[0]='Rats, Tinky Went into the Necropolis!',[1]='B486 FA K0710 L068 A:25705 T:25714 P:11694'},
[11698]={[0]='Might As Well Wipe Out the Scourge',[1]='B486 FA K0710 L068 A:25705 T:25705 P:11694'},
[11699]={[0]="I'm Stuck in this Damned Cage... But Not For Long!",[1]='B486 FA K0710 L068 A:25714 T:25714 P:11697'},
[11700]={[0]='Let Bixie Know',[1]='B486 FA K0710 L068 A:25714 T:25705 P:11699'},
[11701]={[0]='Back to the Airstrip',[1]='B486 FA K0710 L068 A:25705 T:25590 P:11700'},
[11702]={[0]='King Mrgl-Mrgl',[1]='B486 K0710 FH L069 A:25736 T:25197'},
[11703]={[0]='Get to Getry',[1]='B486 K0710 FH L068 A:25437 T:25729 P:11686'},
[11704]={[0]='King Mrgl-Mrgl',[1]='B486 FA K0710 L069 A:25702 T:25197 P:11708'},
[11705]={[0]='Foolish Endeavors',[1]='B486 K0710 FH L068 A:25729 T:25237'},
[11706]={[0]='The Collapse',[1]='B486 K0710 FH L068 A:24730 T:24730 P:11695'},
[11707]={[0]='Distress Call',[1]='B486 FA K0710 L068 A:25737 T:25590'},
[11708]={[0]='The Mechagnomes',[1]='B486 FA K0710 L068 A:25590 T:25747 P:11707'},
[11709]={[0]="Nork Bloodfrenzy's Charge",[1]='B486 K0710 FH L068 A:25237 T:25379 P:11705'},
[11710]={[0]="What's the Matter with the Transmatter?",[1]='B486 FA K0710 L068 A:25702 T:25702 P:11708'},
[11711]={[0]="Coward Delivery... Under 30 Minutes or it's Free",[1]='B486 K0710 FH L068 A:25379 T:25440 P:11709'},
[11712]={[0]='Re-Cursive',[1]='B486 FA K0710 L068 A:25747 T:25747 P:11708'},
[11713]={[0]='Scouting the Sinkholes',[1]='B486 FA K0710 L068 A:25780 T:25780'},
[11714]={[0]='Vermin Extermination',[1]='B486 K0710 FH L068 A:25440 T:25440 P:11711'},
[11715]={[0]='Fueling the Project',[1]='B486 FA K0710 L068 A:25780 T:25780 P:11713'},
[11716]={[0]='The Wondrous Bloodspore',[1]='B486 K0710 FH L068 A:25381 T:25381'},
[11717]={[0]='Pollen from the Source',[1]='B486 K0710 FH L068 A:25381 T:25381 P:11716'},
[11718]={[0]="A Bot in Mammoth's Clothing",[1]='B486 FA K0710 L068 A:25780 T:25780 P:11715'},
[11719]={[0]='A Suitable Test Subject',[1]='B486 K0710 FH L068 A:25381 T:25381 P:11717'},
[11720]={[0]='The Invasion of Gammoth',[1]='B486 K0710 FH L068 A:25381 T:25380 P:11719'},
[11721]={[0]='Gammothra the Tormentor',[1]='B486 K0710 FH L068 A:25380 T:25380 P:11720'},
[11722]={[0]='Trophies of Gammoth',[1]='B486 K0710 FH L068 A:25380 T:25237 P:11721'},
[11723]={[0]='Deploy the Shake-n-Quake!',[1]='B486 FA K0710 L068 A:25780 T:25780 P:11718'},
[11724]={[0]='Massive Moth Omelet?',[1]='B486 K0710 FH L068 A:1187905 T:25381'},
[11725]={[0]='Finding Pilot Tailspin',[1]='B486 FA K0710 L068 A:25590 T:25807 P:11712'},
[11726]={[0]='A Little Bit of Spice',[1]='B486 FA K0710 L068 A:25807 T:25807 P:11725'}, -- should the P: be O: ?
[11727]={[0]='A Time for Heroes',[1]='B486 FA K0710 L068 A:25250 T:25816 P:11672'},
[11728]={[0]='Lupus Pupus',[1]='B486 FA K0710 L068 A:25807 T:25807 P:11726'},
[11729]={[0]='The Ultrasonic Screwdriver',[1]='B486 FA K0710 L068 A:100034984 T:25477'},
[11730]={[0]='Master and Servant',[1]='B486 FA K0710 L068 A:25477 T:25477 P:11729'},
[11731]={[0]='Torch Tossing',[1]='B0 HM FA K0850 A:25975 T:25975 I:11922'},
[11732]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056842'},
[11733]={[0]='Traversing the Rift',[1]='B486 K0710 L069 A:24795 T:25314 P:11682'},
[11734]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056844'},
[11735]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056845'},
[11736]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056847'},
[11737]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056848'},
[11738]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056849'},
[11739]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056850'},
[11740]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056851'},
[11741]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056852'},
[11742]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056853'},
[11743]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056854'},
[11744]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056855'},
[11745]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056856'},
[11746]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056857'},
[11747]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056858'},
[11749]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056860'},
[11750]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056861'},
[11751]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056862'},
[11752]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056863'},
[11753]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056864'},
[11754]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056865'},
[11755]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056866'},
[11756]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056867'},
[11757]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056868'},
[11758]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056869'},
[11759]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056870'},
[11760]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056871'},
[11761]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056872'},
[11762]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056873'},
[11763]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1056874'},
[11764]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056875'},
[11765]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056876'},
[11766]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056882'},
[11767]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056883'},
[11768]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056884'},
[11769]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056885'},
[11770]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056886'},
[11771]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056887'},
[11772]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056888'},
[11773]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056889'},
[11774]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056890'},
[11775]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056891'},
[11776]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056892'},
[11777]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056893'},
[11778]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056894'},
[11779]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056895'},
[11780]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056896'},
[11781]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056897'},
[11782]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056898'},
[11783]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056899'},
[11784]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056900'},
--[11785]={[0]='Desecrate this Fire!',[1]='HM FA'}, -- probably no longer
[11786]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056902'},
[11787]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056903'},
[11788]={[0]='Lefty Loosey, Righty Tighty',[1]='B486 FA K0710 L068 A:25747 T:25747 P:11712'},
[11789]={[0]='A Soldier in Need',[1]='B486 FA K0710 L068 A:25825 T:25825'},
[11790]={[0]='Cultists Among Us',[1]='B486 FA K0710 L068 A:1187851 T:25298'},
[11791]={[0]='Notify Arlos',[1]='B486 FA K0710 L068 A:25299 T:25250 P:11920'},
[11792]={[0]='Enemies of the Light',[1]='B486 FA K0710 L068 A:25285 T:25285 P:11791'},
[11793]={[0]='Further Investigation',[1]='B486 FA K0710 L068 A:25285 T:25826 P:11792'},
[11794]={[0]='The Hunt is On',[1]='B486 FA K0710 L068 A:25826 T:25826 P:11793'},
[11795]={[0]='Emergency Protocol: Section 8.2, Paragraph C',[1]='B486 FA K0710 L068 A:25807 T:25807 P:11728'},
[11796]={[0]='Emergency Protocol: Section 8.2, Paragraph D',[1]='B486 FA K0710 L068 A:25807 T:25807 P:11795'},
[11797]={[0]='The Siege',[1]='B486 FA K0710 L068 A:25816 T:25816 P:11727'},
[11798]={[0]='The Gearmaster',[1]='B486 FA K0720 L068 A:25747 T:25590 P:11788'},
[11799]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056877'},
[11800]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056878'},
[11801]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056879'},
[11802]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056880'},
[11803]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1056881'},
[11804]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25887'},
[11805]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25883'},
[11806]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25888'},
[11807]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25889'},
[11808]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25890'},
[11809]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25891'},
[11810]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25892'},
[11811]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25893'},
[11812]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25894'},
[11813]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25895'},
[11814]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25896'},
[11815]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25897'},
[11816]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25898'},
[11817]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25899'},
[11818]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25900'},
--[11819]={[0]='Honor the Flame',[1]='HM FA SP A:25901'}, -- seems we lost the Hillsbrad quest
[11820]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25902'},
[11821]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25903'},
[11822]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25904'},
[11823]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25905'},
[11824]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25906'},
[11825]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25907'},
[11826]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25908'},
[11827]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25909'},
[11828]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25911'},
[11829]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25912'},
[11830]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25913'},
[11831]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25914'},
[11832]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25915'},
[11833]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25916'},
[11834]={[0]='Honor the Flame',[1]='B0 HM FA SP A:25917 I:28761'},
[11835]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25918'},
[11836]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25919'},
[11837]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25920'},
[11838]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25921'},
[11839]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25922'},
[11840]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25923'},
[11841]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25884'},
[11842]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25925'},
[11843]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25926'},
[11844]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25927'},
[11845]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25928'},
[11846]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25929'},
[11847]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25930'},
[11848]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25931'},
[11849]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25932'},
[11850]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25933'},
[11851]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25934'},
[11852]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25936'},
[11853]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25935'},
[11854]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25937'},
[11855]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25938'},
[11856]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25940'},
[11857]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25941'},
[11858]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25942'},
[11859]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25943'},
[11860]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25944'},
--[11861]={[0]='Honor the Flame',[1]='HM FH SP A:25945'}, -- seems we lost the Thousand Needles quest
[11862]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25946'},
[11863]={[0]='Honor the Flame',[1]='B0 HM FH SP A:25947'},
[11864]={[0]='A Mission Statement',[1]='B486 SP K0720 L070 A:25809 T:25809'},
[11865]={[0]='Unfit for Death',[1]='B486 K0720 L070 A:25811 T:25811 P:11864'},
[11866]={[0]='Ears of Our Enemies',[1]='B486 K0720 L070 A:25809 T:25809 P:11864'},
[11867]={[0]="Can't Get Ear-nough...",[1]='B0 K0720 ++ SP L070 A:25809 T:25809 P:11866'},
[11868]={[0]='The Culler Cometh',[1]='B486 K0720 L070 A:25811 T:25811 P:11865'},
[11869]={[0]='Happy as a Clam',[1]='B486 K0720 L070 A:25810 T:25810 P:11864'},
[11870]={[0]='The Abandoned Reach',[1]='B486 K0720 L070 A:25810 T:25838 P:11869'},
[11871]={[0]='Not On Our Watch',[1]='B486 K0720 L070 A:25838 T:25838 P:11870'},
[11872]={[0]='The Nefarious Clam Master...',[1]='B486 K0720 L070 A:25838 T:25810 P:11871'},
[11873]={[0]='Give Fizzcrank the News',[1]='B486 FA K0710 L068 A:25807 T:25590 P:11796'},
[11875]={[0]='Gaining the Advantage',[1]='B0 +D K0700 L070 A:19202 T:19202'},
[11876]={[0]='Help Those That Cannot Help Themselves',[1]='B486 K0720 L070 A:25809 T:25809 P:11864'},
[11877]={[0]='Sunfury Attack Plans',[1]='B0 +D K0700 L070 A:25140 T:25140'},
[11878]={[0]="Khu'nok Will Know",[1]='B486 K0720 L070 A:25809 T:25862 P:11876'},
[11879]={[0]='Kaw the Mammoth Destroyer',[1]='B486 K0720 L070 A:25862 T:25809 P:11878'},
[11880]={[0]='The Multiphase Survey',[1]='B0 +D K0700 L070 A:19475 T:19475'},
[11881]={[0]="Load'er Up!",[1]='B486 K0710 FH L068 A:25849 T:25849'},
[11882]={[0]='Playing with Fire',[1]='B0 HM FA K0850 L005 A:25962 T:25975'},
[11884]={[0]='Nedar, Lord of Rhinos...',[1]='B486 K0720 L070 A:25812 T:25812 P:11864'},
[11885]={[0]='Adversarial Blood',[1]='B0 K0700 L070 A:23306 T:23306 P:11029'},
[11886]={[0]='Unusual Activity',[1]='B0 HM K0850 L016 A:26221 T:25324'},
[11887]={[0]='Emergency Supplies',[1]='B486 K0710 FH L068 A:25984 T:25849'},
[11888]={[0]="Ride to Taunka'le Village",[1]='B486 K0710 FH L068 A:25978 T:25982'},
[11889]={[0]='Death From Above',[1]='B486 FA K0710 L068 A:25816 T:25816 P:11797'},
[11890]={[0]='What Are They Up To?',[1]='B486 K0710 FH L068 A:25982 T:25982 P:11888'},
[11891]={[0]='An Innocent Disguise',[1]='B0 HM L016 A:25324 T:25324 P:11886'},
[11892]={[0]='The Assassination of Harold Lane',[1]='B486 K0720 L070 A:25809 T:25809 P:11879'},
[11893]={[0]='The Power of the Elements',[1]='B486 K0710 FH L068 A:25983 T:25983'},
[11894]={[0]='Patching Up',[1]='B486 K0710 FH L068 A:25849 T:25849'},
[11895]={[0]='Master the Storm',[1]='B486 K0710 FH L068 A:25982 T:25982 P:11890'},
[11896]={[0]='Weakness to Lightning',[1]='B486 K0710 FH L068 A:25982 T:25982 P:11895'},
[11897]={[0]='Plug the Sinkholes',[1]='B486 FA K0710 L068 A:25816 T:25816 P:11889'},
[11898]={[0]='Breaking Through',[1]='B486 K0710 FH L068 A:24703 T:24703'},
[11899]={[0]='Souls of the Decursed',[1]='B486 K0710 FH L068 A:25602 T:25602'},
[11900]={[0]='Reading the Meters',[1]='B486 K0710 L069 A:25314 T:25314'},
[11901]={[0]='Military?  What Military?',[1]='B486 FA K0710 L068 A:26083 T:1188085 P:11928'},
[11902]={[0]='Pernicious Evidence',[1]='B486 FA K0710 L068 A:1188085 T:26083 P:11901'},
[11903]={[0]="It's Time for Action",[1]='B486 FA K0710 L068 A:26083 T:26083 P:11902'},
[11904]={[0]='Fruits of Our Labor',[1]='B486 FA K0710 L068 A:26083 T:26083 P:11903'},
[11905]={[0]='Postponing the Inevitable',[1]='B0 K0710 L069 A:25314 T:25314 P:11900'},
[11906]={[0]='Cleaning Up the Pools',[1]='B486 K0710 FH L068 A:26104 T:26104'},
[11907]={[0]='The Sub-Chieftains',[1]='B486 K0710 FH L068 A:25982 T:25982 P:11896'},
[11908]={[0]='Reference Material',[1]='B486 FA K0710 L068 A:26084 T:26084 P:11902'},
[11909]={[0]='Defeat the Gearmaster',[1]='B486 K0720 FH L068 A:25602 T:25602'},
[11910]={[0]='Secrets of the Ancients',[1]='B486 K0710 L069 A:25314 T:25314'},
[11911]={[0]='Quickening',[1]='B0 K0710 L069 A:25314 T:25314 P:11910'},
[11912]={[0]='Nuts for Berries',[1]='B486 K0710 L069 A:26110 T:26110'},
[11913]={[0]='Take No Chances',[1]='B486 FA K0710 L068 A:26085 T:26085 P:11902'},
[11914]={[0]='Keep the Secret Safe',[1]='B486 K0710 L069 A:26110 T:26110 P:11912'},
[11915]={[0]='Playing with Fire',[1]='B0 HM FH A:25994 T:26113'},
[11916]={[0]="Hellscream's Champion",[1]='B486 K0710 FH L068 A:25237 T:24703'},
[11917]={[0]='Striking Back',[1]='B0 K0220 HM +D L016 M028'},
[11918]={[0]='Basic Training',[1]='B486 K0710 L069 A:26117 T:26117'},
[11919]={[0]='Drake Hunt',[1]='B486 K0710 L069 A:26117 T:26117 P:11936'},
[11920]={[0]='Cultists Among Us',[1]='B486 FA K0710 L068 A:1187851 T:25298'},
[11921]={[0]='More Torch Tossing',[1]='B0 HM FA +D K0850 A:25975 T:25975 P:11657 I:11926'},
[11922]={[0]='Torch Tossing',[1]='B0 HM FH K0010 A:26113 T:26113 I:11731'},
[11923]={[0]='Torch Catching',[1]='B0 HM FH K0850 A:26113 T:26113 P:11922 I:11657'},
[11924]={[0]='More Torch Catching',[1]='B0 HM FA +D K0850 A:25975 T:25975 P:11657 I:11925'},
[11925]={[0]='More Torch Catching',[1]='B0 HM FH +D K0850 A:26113 T:26113 P:11923 I:11924'},
[11926]={[0]='More Torch Tossing',[1]='B0 HM FH +D K0850 A:26113 T:26113 P:11922 I:11921'},
[11927]={[0]='Word on the Street',[1]='B486 FA K0710 L068 A:26155 T:25251 P:11897'},
[11928]={[0]='Farshire',[1]='B486 FA K0710 L068 A:25816 T:26083 P:11897'},
[11929]={[0]="The Fall of Taunka'le Village",[1]='B486 K0720 FH L071 A:24703 T:26158'},
[11930]={[0]='Across Transborea',[1]='B486 K0720 FH L071 A:26158 T:26156 P:11929 B488'},
[11931]={[0]='Cracking the Code',[1]='B486 K0710 L069 A:26117 T:26117 P:11919'},
[11932]={[0]='Cowards and Fools',[1]='B486 FA K0710 L068 A:25395 T:26169 P:11604'},
[11933]={[0]="Stealing the Exodar's Flame",[1]='B0 HM FH'},
[11935]={[0]="Stealing Silvermoon's Flame",[1]='B0 HM FA'},
[11936]={[0]='Hatching a Plan',[1]='B486 K0710 L069 A:26117 T:26117 P:11918'},
[11938]={[0]='Buying Some Time',[1]='B486 FA K0720 L068 A:26170 T:26170 P:11956'},
[11940]={[0]='Drake Hunt',[1]='B486 +D K0710 L069 A:26117 T:26117 P:11919'},
[11941]={[0]='Puzzling...',[1]='B486 K0710 L069 A:100035648 T:26117'},
[11942]={[0]='Words of Power',[1]='B486 FA K0720 L068 A:26170 T:26170 P:11938'},
[11943]={[0]='The Cell',[1]='B486 K0710 L069 A:26117 T:26117 P:11941'},
[11944]={[0]='Surrounded!',[1]='B486 FA K0720 L068 A:26187 T:26187 P:12086'},
[11945]={[0]='Preparing for the Worst',[1]='B0 +D K0720 L068 A:26213 T:26213'},
[11946]={[0]='Keristrasza',[1]='B486 K0710 L069 A:26206 T:26206 P:11943'},
[11947]={[0]='Striking Back',[1]='B0 K0320 HM +D L029 M038'},
[11948]={[0]='Striking Back',[1]='B0 K0430 HM +D L039 M048'},
[11949]={[0]='Not Without a Fight!',[1]='B486 K0720 L068 A:26169 T:26169'},
[11950]={[0]="Muahit's Wisdom",[1]='B486 K0720 L068 A:26169 T:26218 P:11949'},
[11951]={[0]='Bait and Switch',[1]='B486 K0710 L069 A:26206 T:26206 P:11946'},
[11952]={[0]='Striking Back',[1]='B0 K0510 HM +D L049 M055'},
[11953]={[0]='Striking Back',[1]='B0 K0600 HM +D L056 M063'},
[11954]={[0]='Striking Back',[1]='B0 HM +D K0670 L064 A:26221'},
[11955]={[0]='Ahune, the Frost Lord',[1]='B0 K0700 HM L065'},
[11956]={[0]='Finding the Phylactery',[1]='B486 FA K0710 L068 A:26170 T:26170'},
[11957]={[0]="Saragosa's End",[1]='B486 K0710 L069 A:26206 T:26206 P:11951'},
[11958]={[0]='Let Nothing Go To Waste',[1]='B0 K0720 L071 A:26194 T:26194 O:12117'},
[11959]={[0]='Slay Loguhn',[1]='B488 K0730 L071 A:26194 T:26194 P:11958'},
[11960]={[0]='Planning for the Future',[1]='B0 +D K0720 L071 A:26228 T:26228'},
[11961]={[0]='Spirits Watch Over Us',[1]='B486 K0720 L068 A:26218 T:26218 P:11950'},
[11962]={[0]='One Last Delivery',[1]='B486 FA K0710 L068 A:26083 T:25235 P:11904'},
[11963]={[0]='Weapons for Farshire',[1]='B486 FA K0710 L068 A:25235 T:26083 P:11962'},
[11964]={[0]='Incense for the Summer Scorchlings',[1]='B0 HM FA K0850 A:16817 T:26401'},
[11965]={[0]='Call to Arms!',[1]='B486 FA K0710 L068 A:26083 T:26083 P:11963'},
[11966]={[0]='Incense for the Festival Scorchlings',[1]='B0 HM FH A:16818 T:26520'},
[11967]={[0]='Mustering the Reds',[1]='B486 K0710 L069 A:26206 T:26117 P:11957'},
[11968]={[0]='The Tides Turn',[1]='B486 K0710 L068 A:26218 T:26218 P:11961'},
[11969]={[0]='Springing the Trap',[1]='B486 K0710 L069 A:26117 T:26117 P:11967'},
[11970]={[0]='The Master of Summer Lore',[1]='B0 HM FA K0760 A:18927,19148,19171,19172,19173,20102 T:16817'},
[11971]={[0]='The Spinner of Summer Tales',[1]='B0 HM FH K0020 A:19169,19175,19176,19177,19178,20102 T:16818'},
[11972]={[0]='Shards of Ahune',[1]='B0 HM L065 A:100035723'},
[11973]={[0]='Prisoner of War',[1]='B0 K0710 L069 A:26117 T:26117 P:11969'},
[11975]={[0]='Now, When I Grow Up...',[1]='B0 HC FH L060 A:22914 T:22914 P:10945+10953+10951'},
[11977]={[0]='A Tauren Among Taunka',[1]='B488 K0720 FH L071 A:26156 T:26181 P:11930'},
[11978]={[0]='Into the Fold',[1]='B488 K0720 FH L071 A:26181 T:26181 P:11977,11979'},
[11979]={[0]='The Taunka and the Tauren',[1]='B488 K0720 FH L071 A:26415 T:26181 P:11977'},
[11980]={[0]='Pride of the Horde',[1]='B488 K0720 FH L071 A:26180 T:26180'},
[11981]={[0]='Find Kurun!',[1]='B490 K0750 L072 A:26335 T:26260 I:11982'},
[11982]={[0]='Raining Down Destruction',[1]='B490 K0750 L072 A:26260 T:26260 O:11981'},
[11983]={[0]='Blood Oath of the Horde',[1]='B488 K0720 FH L071 A:26181 T:26181 P:11978'},
[11984]={[0]='Filling the Cages',[1]='B490 K0740 L073 A:26424 T:26424 O:12208,12210'}, -- TODO: since 12210 only is available after 12212, must check if 11984 needs something like that too
[11985]={[0]='Into the Breach',[1]='B490 K0750 L072 A:26260 T:26260 P:12070'},
[11986]={[0]='The Damaged Journal',[1]='B490 FA K0750 L073 A:1188261 T:26361'},
[11988]={[0]='The Runic Keystone',[1]='B490 FA K0750 L073 A:26361 T:26361 P:11986'},
[11989]={[0]='Truce?',[1]='B490 K0730 L073 A:26423 T:26423 P:11984'},
[11990]={[0]='Vial of Visions',[1]='B490 K0740 L073 A:26423 T:26423 P:11989'},
[11991]={[0]='Subject to Interpretation',[1]='B490 K0740 L073 A:26423 T:26500 P:11990'},
[11993]={[0]='The Runic Prophecies',[1]='B490 FA K0750 L073 A:26361 T:26361 P:11988'},
[11995]={[0]="Your Presence is Required at Stars' Rest",[1]='B488 FA K0720 L071 A:26440 T:26673 P:12439'},
[11996]={[0]="Your Presence is Required at Agmar's Hammer",[1]='B488 K0720 FH L071 A:26441 T:26471'},
[11998]={[0]='Softening the Blow',[1]='B490 FA K0750 L073 A:26212 T:26226'},
[11999]={[0]='Rifle the Bodies',[1]='B488 K0720 FH L071 A:26471 T:26471 P:11996'},
[12000]={[0]='Rifle the Bodies',[1]='B488 FA K0720 L071 A:26673 T:26673 P:11995,12440'},
[12002]={[0]='Brothers in Battle',[1]='B490 FA K0750 L073 A:26226 T:26226 P:11998'},
[12003]={[0]='Uncovering the Tunnels',[1]='B490 FA K0750 L073 A:26226 T:26226 P:12002'},
[12004]={[0]='Prevent the Accord',[1]='B488 FA K0730 L071 A:26673 T:26673 P:12000'},
[12005]={[0]='Prevent the Accord',[1]='B488 K0730 FH L071 A:26471 T:26471 P:11999'},
[12006]={[0]='Avenge this Atrocity!',[1]='B488 K0720 L071 A:26501 T:26501'},
[12007]={[0]='Sacrifices Must be Made',[1]='B490 K0740 L073 A:26500 T:26543 P:11991'},
[12008]={[0]="Agmar's Hammer",[1]='B488 K0720 FH L071 A:26181 T:26379 P:11983'},
[12009]={[0]="Tua'kea's Crab Traps",[1]='B488 K0720 L071 A:26245 T:26245 P:11959'},
[12010]={[0]='The Fate of Orlond',[1]='B490 FA K0750 L073 A:26226 T:26514 P:12003'},
[12011]={[0]='Signs of Big Watery Trouble',[1]='B488 K0720 L071 A:1188364 T:26245'},
[12012]={[0]='Inform the Elder',[1]='B0 HM L016 A:25324 T:26221 P:11891'},
[12013]={[0]='End Arcanimus',[1]='B488 K0730 L071 A:26501 T:26501 P:12006'},
[12014]={[0]='Steady as a Rock?',[1]='B490 FA K0750 L073 A:26514 T:26226 P:12010'},
[12016]={[0]='The Bait',[1]='B488 K0720 L071 A:26245 T:26245 P:12011'},
[12017]={[0]='Meat on the Hook',[1]='B488 K0730 L071 A:26245 T:26245 P:12016'},
[12019]={[0]='Last Rites',[1]='B486 FA K0720 L068 A:26170 T:26170 P:11942'},
[12020]={[0]='This One Time, When I Was Drunk...',[1]='B0 FA HB +D A:1058917 T:27215'},
[12022]={[0]='Chug and Chuck!',[1]='B0 FA HB +Y K0000 A:27215 T:27215 I:12191'},
[12026]={[0]='The Damaged Journal',[1]='B490 K0750 FH L073 A:1188261 T:26584'},
[12027]={[0]="Mr. Floppy's Perilous Adventure",[1]='B490 FA K0740 L073 A:26588 T:26371'},
[12028]={[0]='Spiritual Insight',[1]='B488 K0720 L071 A:26595 T:26595 P:11959'},
[12029]={[0]='Seared Scourge',[1]='B490 K0740 L073 A:26604 T:26604 P:12484'},
[12030]={[0]="Elder Mana'loa",[1]='B488 K0720 L071 A:26595 T:1188419 P:12028'},
[12031]={[0]='Freedom for the Lingering',[1]='B488 K0720 L071 A:1188419 T:1188419 P:12030'},
[12032]={[0]='Conversing With the Depths',[1]='B488 K0720 L071 A:1188419 T:26595 P:12031'},
[12033]={[0]='Message from the West',[1]='B488 K0720 FH L071 A:26649 T:26649'},
[12034]={[0]='Victory Nears...',[1]='B488 K0720 FH L071 A:26379 T:26415'},
[12035]={[0]='Repurposed Technology',[1]='B486 FA K0710 L068 A:26084 T:26084 P:11908'},
[12036]={[0]='From the Depths of Azjol-Nerub',[1]='B488 K0720 FH L071 A:26415 T:26415 P:12034'},
[12037]={[0]='Search and Rescue',[1]='B504956 K07464 L072 A:26604 T:26664 P:12029'},
[12038]={[0]='Seared Scourge',[1]='B490 +D K0720 L070 A:26604 T:26604 P:12029'},
[12039]={[0]='Black Blood of Yogg-Saron',[1]='B488 K0720 FH L071 A:26564 T:26564'},
[12040]={[0]='An Enemy in Arthas',[1]='B488 K0720 FH L071 A:26653 T:26653'},
[12041]={[0]='The Lost Empire',[1]='B488 K0720 FH L071 A:26653 T:26379 P:12040'},
[12042]={[0]='Heart of the Ancients',[1]='B490 K0740 L073 A:26543 T:1057293 P:12007'},
[12043]={[0]='Nozzlerust Defense',[1]='B488 K0740 L072 A:26647 T:26647'},
[12044]={[0]='Stocking Up',[1]='B488 K0740 L072 A:26660 T:26660 P:12469'},
[12045]={[0]='Shaved Ice',[1]='B488 K0740 L072 A:26661 T:26661'},
[12046]={[0]='Soft Packaging',[1]='B488 K0740 L072 A:26661 T:26661 P:12045'},
[12047]={[0]="Something That Doesn't Melt",[1]='B488 K0740 L072 A:26661 T:26661 P:12046'},
[12048]={[0]='Scourge Armaments',[1]='B488 K0720 FH L071 A:26564 T:26564 P:12039'},
[12049]={[0]='Hard to Swallow',[1]='B488 K0740 L072 A:26660 T:26660 P:12046'},
[12050]={[0]='Lumber Hack',[1]='B488 K0740 L072 A:26660 T:26660 P:12047'},
[12052]={[0]='Harp on This!',[1]='B488 K0740 L072 A:26647 T:26647 P:12047'},
[12053]={[0]='The Might of the Horde',[1]='B488 K0720 FH L071 A:26415 T:26415 P:12036'},
[12054]={[0]='Deciphering the Journal',[1]='B490 K0750 FH L073 A:26584 T:26584 P:12026'},
[12055]={[0]='A Strange Device',[1]='B488 FA K0720 L071 A:100036742 T:26673'},
[12056]={[0]='Marked for Death: High Cultist Zangus',[1]='B488 K0720 FH L071 A:26618 T:26618'},
[12057]={[0]='The Flesh-Bound Tome',[1]='B488 K0720 FH L071 A:100036744 T:26618'},
[12058]={[0]='The Runic Prophecies',[1]='B490 K0750 FH L073 A:26584 T:26584'},
[12059]={[0]='A Strange Device',[1]='B488 K0720 FH L071 A:100036746 T:26471 P:12055'},
[12060]={[0]='Projections and Plans',[1]='B488 FA K0720 L071 A:26673 T:26673 P:12055'},
[12061]={[0]='Projections and Plans',[1]='B488 K0720 FH L071 A:26471 T:26471 P:12059'},
[12063]={[0]='Strength of Icemist',[1]='B488 K0720 FH L071 A:26652 T:26733'},
[12064]={[0]="Chains of the Anub'ar",[1]='B488 K0720 FH L071 A:26733 T:26733 P:12063'},
[12065]={[0]='The Focus on the Beach',[1]='B488 FA K0720 L071 A:26673 T:26673 P:12060'},
[12066]={[0]='The Focus on the Beach',[1]='B488 K0720 FH L071 A:26471 T:26471 P:12061'},
[12067]={[0]='A Letter for Home',[1]='B488 FA K0720 L071 A:100036756 T:26459'},
[12068]={[0]='Voices From the Dust',[1]='B490 K0750 L073 A:26701 T:26787 P:12802'},
[12069]={[0]='Return of the High Chief',[1]='B488 K0730 FH L071 A:26733 T:26379 P:12064'},
[12070]={[0]='Rallying the Troops',[1]='B490 K0750 L072 A:26260 T:26260 P:11982'},
[12071]={[0]='Attack by Air! ',[1]='B488 K0720 FH L071 A:26415 T:26574 P:12053'}, -- 4.2 has the extra space
[12072]={[0]='Blightbeasts be Damned!',[1]='B488 K0720 FH L071 A:26574 T:26574 P:12071'},
[12073]={[0]='Pounding the Iron',[1]='B490 K0750 FH L073 A:26666 T:26666'},
[12074]={[0]='An Expedient Ally',[1]='B490 K0750 FH L073 A:26666 T:26260'},
[12075]={[0]='Slim Pickings',[1]='B488 K0740 L072 A:26659 T:26659 P:12112'},
[12076]={[0]='Messy Business',[1]='B488 K0740 L072 A:26659 T:26659 P:12075'},
[12077]={[0]='Apply This Twice A Day',[1]='B488 K0740 L072 A:26659 T:26473 P:12076'},
[12078]={[0]='Worm Wrangler',[1]='B488 K0740 L072 A:26659 T:26659 P:12077'},
[12079]={[0]='Stomping Grounds',[1]='B488 K0740 L072 A:26473 T:26473 P:12075'},
[12080]={[0]='Really Big Worm',[1]='B488 K0740 L072 A:26473 T:26473 P:12077'},
[12081]={[0]='Gavrock',[1]='B490 K0750 L072 A:26260 T:26420 P:11985'},
[12082]={[0]='Dun-da-Dun-tah!',[1]='B490 K0750 L073 A:26814 T:26884'},
[12083]={[0]='Atop the Woodlands',[1]='B488 FA K0720 L071 A:26673 T:26673 P:12065'},
[12084]={[0]='Atop the Woodlands',[1]='B488 K0720 FH L071 A:26471 T:26471 P:12066'},
[12085]={[0]='A Letter for Home',[1]='B488 K0720 FH L071 A:100036780 T:26379'},
[12086]={[0]='The Son of Karkut',[1]='B486 FA K0720 L068 A:26169 T:26187 P:11932'},
[12088]={[0]='Thassarian, the Death Knight',[1]='B486 FA K0720 L068 A:26187 T:26170 P:11944'},
[12089]={[0]='Wanted: Magister Keldonus',[1]='B488 K0740 FH L071 A:1188418 T:26618'},
[12090]={[0]='Wanted: Gigantaur',[1]='B488 K0740 FH L071 A:1188418 T:26618'},
[12091]={[0]='Wanted: Dreadtalon',[1]='B488 K0740 FH L071 A:1188418 T:26618'},
[12092]={[0]='Strengthen the Ancients',[1]='B488 FA K0720 L071 A:26837 T:26837'},
[12093]={[0]='Runes of Compulsion',[1]='B490 K0750 L072 A:26420 T:26420 P:12081'},
[12094]={[0]='Latent Power',[1]='B490 K0750 L072 A:26420 T:26420 P:12093'},
[12095]={[0]="To Dragon's Fall",[1]='B488 K0750 FH L071 A:26618 T:26859'},
[12096]={[0]='Strengthen the Ancients',[1]='B488 K0720 FH L071 A:26854 T:26854'},
[12097]={[0]='Sarathstra, Scourge of the North',[1]='B488 K0750 FH L071 A:26859 T:26618 P:12095'},
[12098]={[0]="Search Indu'le Village",[1]='B488 FA K0720 L071 A:26673 T:26873 P:12083'},
[12099]={[0]='Free at Last',[1]='B490 K0750 L072 A:26420 T:26420 P:12094'},
[12100]={[0]='Containing the Rot',[1]='B488 K0720 FH L071 A:26504 T:26504'},
[12101]={[0]='The Good Doctor...',[1]='B488 K0720 FH L071 A:26504 T:26505 P:12100'},
[12102]={[0]='In Search of the Ruby Lilac',[1]='B488 K0730 FH L071 A:26505 T:26505 P:12101'},
[12104]={[0]='Return to Soar',[1]='B488 K0730 FH L071 A:26505 T:26504 P:12102'},
[12105]={[0]='Descent into Darkness',[1]='B490 FA K0740 L073 A:100036940 T:26875'},
[12106]={[0]="Search Indu'le Village",[1]='B488 K0720 FH L071 A:26471 T:26873 P:12084'},
[12107]={[0]='The End of the Line',[1]='B488 FA K0720 L071 A:26873 T:26673 P:12098,12106'},
[12109]={[0]='Report to Gryan Stoutmantle... Again',[1]='B490 FA K0740 L073 A:26875 T:26212 P:12105'},
[12110]={[0]='The End of the Line',[1]='B488 K0720 FH L071 A:26873 T:26471 P:12107'},
[12111]={[0]='Where the Wild Things Roam',[1]='B488 K0730 FH L071 A:26504 T:26504 P:12104'},
[12112]={[0]='Stiff Negotiations',[1]='B488 K0740 L072 A:26647 T:26659 P:12052'},
[12113]={[0]='Nice to Meat You',[1]='B490 K0750 L073 A:26884 T:26884'},
[12114]={[0]='Therapy',[1]='B490 K0750 L073 A:26884 T:26884'},
[12115]={[0]='Koltira and the Language of Death',[1]='B488 K0720 FH L071 A:26618 T:26581 P:12057'},
[12116]={[0]='It Takes Guts....',[1]='B490 K0750 L073 A:26886 T:26886'},
[12117]={[0]="Travel to Moa'ki Harbor",[1]='B488 K0720 L068 A:28382 T:26194 P:11968 B488'},
[12118]={[0]="Travel to Moa'ki Harbor",[1]='B488 K0720 L068 A:24810 T:26194 B488'},
[12119]={[0]='Gaining an Audience',[1]='B488 FA K0720 L071 A:26673 T:26443 P:12107'},
[12120]={[0]="Drak'aguul's Mallet",[1]='B490 K0750 L073 A:26886 T:26886 P:12116'},
[12121]={[0]='See You on the Other Side',[1]='B490 K0750 L073 A:26886 T:26924 P:12120'},
[12122]={[0]='Gaining an Audience',[1]='B488 K0720 FH L071 A:26471 T:26443 P:12110'},
[12123]={[0]='Informing the Queen',[1]='B488 FA K0750 L071 A:26443 T:26917 P:12768'},
[12124]={[0]='Informing the Queen',[1]='B488 K0750 FH L071 A:26443 T:26917 P:12769'},
[12125]={[0]='In Service of Blood',[1]='B488 K0730 FH L071 A:26581 T:26581'},
[12126]={[0]='In Service of the Unholy',[1]='B488 K0730 FH L071 A:26581 T:26581'},
[12127]={[0]='In Service of Frost',[1]='B488 K0730 FH L071 A:26581 T:26581'},
[12128]={[0]='Check Up on Raegar',[1]='B490 FA K0750 L073 A:26226 T:26883 P:12014'},
[12129]={[0]='The Perfect Plan',[1]='B490 FA K0750 L073 A:26883 T:26883 P:12128'},
[12130]={[0]='Why Fabricate When You Can Appropriate?',[1]='B490 FA K0750 L073 A:26883 T:26883 P:12129'},
[12131]={[0]='We Have the Power',[1]='B490 FA K0750 L073 A:26883 T:26883 P:12130'},
[12132]={[0]='The Power to Destroy',[1]='B488 K0730 FH L071 A:26581 T:26581'},
[12133]={[0]='Smash the Pumpkin',[1]='B0 HW +D FA A:1186887 T:24519'},
[12134]={[0]="Sasha's Hunt",[1]='B490 K0750 L073 A:26935 T:26935 P:12329'},
[12135]={[0]='"Let the Fires Come!"',[1]='B0 HW +D FA A:24519 T:24519 I:11131'},
[12136]={[0]='The Translated Tome',[1]='B488 K0730 FH L071 A:26581 T:26618 P:12132'},
[12137]={[0]='Chill Out, Mon',[1]='B490 K0750 L073 A:26924 T:26886 P:12121'},
[12138]={[0]="... Or Maybe We Don't",[1]='B490 FA K0750 L073 A:26883 T:26883 P:12131'},
[12139]={[0]='"Let the Fires Come!"',[1]='B0 HW +D FH A:23973 T:23973 P:11450'},
[12140]={[0]='All Hail Roanauk!',[1]='B488 K0730 FH L071 A:26379 T:26379 P:12069'},
[12141]={[0]='A Diplomatic Mission',[1]='B486 FA K0710 L068 A:25301 T:25435 P:11791'},
[12142]={[0]='Pest Control',[1]='B488 FA K0730 L072 A:26978 T:26978'},
[12143]={[0]='Canyon Chase',[1]='B488 FA K0730 L072 A:26978 T:26978 P:12142'},
[12144]={[0]='Pest Control',[1]='B488 K0730 FH L072 A:26979 T:26979'},
[12145]={[0]='Canyon Chase',[1]='B488 K0730 FH L072 A:26979 T:26979 P:12144'},
[12146]={[0]='Disturbing Implications',[1]='B488 FA K0730 L072 A:100036855 T:26983'},
[12147]={[0]='Disturbing Implications',[1]='B488 K0730 FH L072 A:100036856 T:26983'},
[12148]={[0]='One of a Kind',[1]='B488 K0730 L072 A:26983 T:26983 P:12146,12147'},
[12149]={[0]='Mighty Magnataur',[1]='B488 K0730 L072 A:26983 T:26983 P:12148'},
[12150]={[0]='Reclusive Runemaster',[1]='B488 K0740 L072 A:26983 T:26983 P:12149'},
[12151]={[0]='Wanton Warlord',[1]='B488 K0740 L072 A:26983 T:26983 P:12150'},
[12152]={[0]="Jin'arrak's End",[1]='B490 K0750 L073 A:26886 T:26886 P:12137'},
[12153]={[0]='The Iron Thane and His Anvil',[1]='B490 FA K0750 L073 A:26883 T:26883 P:12138'},
[12154]={[0]='Blackout',[1]='B490 FA K0750 L073 A:26883 T:26883 P:12138'},
[12155]={[0]='Smash the Pumpkin',[1]='B0 HW +D FH A:1186887 T:23973'},
[12157]={[0]='The Lost Courier',[1]='B488 FA K0720 L071 A:26186 T:27060 B488'},
[12158]={[0]='Hollowstone Mine',[1]='B490 FA K0750 L073 A:26212 T:26932 P:12109'},
[12159]={[0]='Souls at Unrest',[1]='B490 FA K0750 L073 A:26932 T:26932 P:12158'},
[12160]={[0]='A Name from the Past',[1]='B490 FA K0750 L073 A:26932 T:26212 P:12159'},
[12161]={[0]='Ruuna the Blind',[1]='B490 FA K0750 L073 A:27582 T:27581 P:12160'},
[12164]={[0]='Hour of the Worg',[1]='B490 K075512 L073 A:526935 T:26935 P:12411'},
[12165]={[0]='An Intriguing Plan',[1]='B490 K0750 FH L073 A:27221 T:27227 P:12195'},
[12166]={[0]='The Liquid Fire of Elune',[1]='B488 FA K0720 L071 A:26973 T:26973'},
[12167]={[0]='Kill the Cultists',[1]='B488 FA K0720 L071 A:26973 T:26973 P:12166'},
[12168]={[0]='The Favor of Zangus',[1]='B488 FA K0720 L071 A:100036958 T:26973'},
[12169]={[0]='The High Cultist',[1]='B488 FA K0720 L071 A:26973 T:26973 P:12168'},  -- ensure we do not need P:12167 as well
[12170]={[0]='Blackriver Brawl',[1]='B490 +D FH K0740 L073 A:27120 T:27120'},
[12171]={[0]='Of Traitors and Treason',[1]='B488 FA K0720 L071 A:27060 T:26881 O:12157 I:12297'},
[12172]={[0]='Attunement to Dalaran',[1]='B0 K0730 FA CM L071 A:26673 T:26673'},
[12173]={[0]='Attunement to Dalaran',[1]='B0 K0730 FH CM L071 A:26471 T:26471'},
[12174]={[0]='High Commander Halford Wyrmbane',[1]='B488 FA K0720 L071 A:26881 T:27136 P:12171'},
[12175]={[0]='Gray Worg Hides',[1]='B490 K0740 FH L073 A:27037 T:27037'},
[12176]={[0]='A Minor Substitution',[1]='B490 K0740 FH L073 A:27037 T:27037 P:12175'},
[12177]={[0]="Jun'ik's Coverup",[1]='B490 K0740 FH L073 A:27037 T:27037 P:12176'},
[12178]={[0]='Delivery to Krenna',[1]='B490 K0740 FH L073 A:27037 T:26860 P:12177'},
[12180]={[0]='The Captive Prospectors',[1]='B490 FA K0750 L073 A:26885 T:26885 P:12014'},
[12181]={[0]='Give it a Name',[1]='B491 K0720 FH L071 A:24251 T:24155'},
[12182]={[0]='To Venomspite!',[1]='B488 K0720 FH L071 A:24155 T:27172 P:12181 B488'},
[12183]={[0]='Looking the Part',[1]='B490 FA K0750 L073 A:26885 T:26885 P:12180'},
[12184]={[0]='Cultivating an Image',[1]='B490 FA K0750 L073 A:26885 T:26885 P:12183'},
[12185]={[0]='Put on Your Best Face for Loken',[1]='B490 FA K0750 L073 A:26885 T:26885 P:12184'},
[12188]={[0]='The Forsaken Blight and You: How Not to Die',[1]='B488 K0720 FH L071 A:27172 T:27172 P:12182,12189'},
[12189]={[0]='Imbeciles Abound!',[1]='B488 K0720 FH L071 A:26505 T:27172 P:12182'},
[12190]={[0]='Say Hello to My Little Friend',[1]='B490 K0740 L073 A:26519 T:26884 P:12483'},
[12191]={[0]='Chug and Chuck!',[1]='B0 FH HB +Y K0000 A:27216 T:27216 I:12022'},
[12192]={[0]='This One Time, When I Was Drunk...',[1]='B0 FH HB +D A:1058918 T:27216'},
[12193]={[0]="Say, There Wouldn't Happen to be a Souvenir This Year, Would There?",[1]='B0 FA HB A:24468 T:23710'},
[12194]={[0]="Say, There Wouldn't Happen to be a Souvenir This Year, Would There?",[1]='B0 FH HB A:24510 T:24495'},
[12195]={[0]="The Unexpected 'Guest'",[1]='B490 K0750 FH L073 A:27221 T:27221'},
[12196]={[0]='From the Ground Up',[1]='B490 K0750 FH L073 A:27227 T:27227 P:12165'},
[12197]={[0]='We Have the Power',[1]='B490 K0750 FH L073 A:27227 T:27227 P:12196'},
[12198]={[0]="... Or Maybe We Don't",[1]='B490 K0750 FH L073 A:27227 T:27227 P:12197'},
[12199]={[0]='Bringing Down the Iron Thane',[1]='B490 K0750 FH L073 A:27227 T:27221 P:12198'},
[12200]={[0]='Emerald Dragon Tears',[1]='B488 K0720 FH L071 A:27172 T:27172 P:12188'},
[12201]={[0]="The Overseer's Shadow",[1]='B490 K0750 FH L073 A:26666 T:26666 P:12204'},
[12202]={[0]='Cultivating an Image',[1]='B490 K0750 FH L073 A:26666 T:26666 P:12201'},
[12203]={[0]="Loken's Orders",[1]='B490 K0750 FH L073 A:26666 T:26666 P:12202'},
[12204]={[0]='In the Name of Loken',[1]='B490 K0750 FH L073 A:26666 T:26666'},
[12205]={[0]='Wanted: The Scarlet Onslaught',[1]='B488 K0720 FH L071 A:1188649 T:27243'},
[12206]={[0]='Blighted Last Rites',[1]='B488 K0720 FH L071 A:27248 T:27248'},
[12207]={[0]="Vordrassil's Fall",[1]='B490 K0740 FH L072 A:27262 T:27262'},
[12208]={[0]='Good Troll Hunting',[1]='B490 K0740 FH L073 A:27266 T:26424'},
[12209]={[0]='Materiel Plunder',[1]='B488 K0720 FH L071 A:27267 T:27267'},
[12210]={[0]='Troll Season!',[1]='B490 FA K0730 L073 A:26875 T:26424 P:12212 I:11984'},
[12211]={[0]='Let Them Not Rise!',[1]='B488 K0720 FH L071 A:27248 T:27248'},
[12212]={[0]='Replenishing the Storehouse',[1]='B490 FA K0740 L073 A:27277 T:27277'},
[12213]={[0]='The Darkness Beneath',[1]='B490 K0740 FH L072 A:27262 T:27262'},
[12214]={[0]='Fresh Remounts',[1]='B488 K0720 FH L071 A:27028 T:27028'},
[12215]={[0]='Them or Us!',[1]='B490 FA K0740 L073 A:27277 T:27277'},
[12216]={[0]='Take Their Rear!',[1]='B490 FA K0740 L073 A:27277 T:27277 P:12212'},
[12217]={[0]='Eagle Eyes',[1]='B490 FA K0740 L073 A:27277 T:27277 P:12215'},
[12218]={[0]='Spread the Good Word',[1]='B488 K0720 FH L071 A:27172 T:27172 P:12200'},
[12219]={[0]='The Failed World Tree',[1]='B490 FA K0740 L073 A:27295 T:27295 P:12310'},
[12220]={[0]='A Dark Influence',[1]='B490 FA K0740 L073 A:27295 T:27295 P:12310'},
[12221]={[0]='The Forsaken Blight',[1]='B488 K0720 FH L071 A:27172 T:26505 P:12218'},
[12222]={[0]='Secrets of the Flamebinders',[1]='B490 FA K0740 L073 A:27391 T:27391 P:12294'},
[12223]={[0]='Thinning the Ranks',[1]='B490 FA K0740 L073 A:27391 T:27391 P:12294'},
[12224]={[0]="The Kor'kron Vanguard!",[1]='B488 K0730 FH L071 A:26379 T:25257'},
[12225]={[0]='Mmm... Amberseeds!',[1]='B490 FA K0730 L073 A:1188667 T:27277'},
[12226]={[0]='Just Passing Through',[1]='B490 FA K0730 L073 A:27277 T:27277 P:12225'},
[12227]={[0]='Doing Your Duty',[1]='B490 FA K0730 L073 A:27277 T:27277 P:12226'},
[12229]={[0]='A Possible Link',[1]='B490 K0740 FH L072 A:27262 T:27262'},
[12230]={[0]='Stealing from the Siegesmiths',[1]='B488 K0720 FH L071 A:27320 T:27320'},
[12231]={[0]="The Bear God's Offspring",[1]='B490 K0750 FH L072 A:27262 T:27262'},
[12232]={[0]='Bombard the Ballistae',[1]='B488 K0720 FH L071 A:27320 T:27320 P:12230'},
[12234]={[0]='Need to Know',[1]='B488 K0720 FH L071 A:27337 T:27337'},
[12235]={[0]='Naxxramas and the Fall of Wintergarde',[1]='B488 FA K0720 L071 A:27136 T:27317 P:12174,12298'},  -- verify the P: really should not be O:
[12236]={[0]='Ursoc, the Bear God',[1]='B490 K0750 FH L072 A:27262 T:27262'},
[12237]={[0]='Flight of the Wintergarde Defender',[1]='B488 FA K0720 L071 A:27317 T:27317 P:12235'},
[12238]={[0]="Cleansing Drak'Tharon",[1]='B0 K07564 L073 A:26787 T:28016 P:12068'},
[12239]={[0]='The Spy in New Hearthglen',[1]='B488 K0720 FH L071 A:27337 T:27350 P:12234'},
[12240]={[0]='A Means to an End',[1]='B488 K0720 FH L071 A:27248 T:27248'},
[12241]={[0]='Destroy the Sapling',[1]='B490 K0750 FH L072 A:27262 T:27262'},
[12242]={[0]="Vordrassil's Seeds",[1]='B490 K0740 FH L073 A:27262 T:27262'},
[12243]={[0]='Fire Upon the Waters',[1]='B488 K0720 FH L071 A:27248 T:27248 P:12240'},
[12244]={[0]='Shredder Repair',[1]='B0 +D FA K0740 L073 A:27371 T:27371'},
[12245]={[0]='No Mercy for the Captured',[1]='B488 K0720 FH L071 A:27337 T:27243'},
[12246]={[0]='A Possible Link',[1]='B490 FA K0740 L073 A:27295 T:27295 P:12219+12220'},
[12247]={[0]='Children of Ursoc',[1]='B490 FA K0750 L073 A:27295 T:27295 P:12219+12220'},
[12248]={[0]="Vordrassil's Sapling",[1]='B490 FA K0750 L073 A:27295 T:27295 P:12246+12247'},
[12249]={[0]='Ursoc, the Bear God',[1]='B490 FA K075512 L073 A:27295 T:27295 P:12248+12250'},
[12250]={[0]="Vordrassil's Seeds",[1]='B490 FA K0750 L073 A:27295 T:27295 P:12246+12247'},
[12251]={[0]='Return to the High Commander',[1]='B488 FA K0720 L071 A:27317 T:27136 P:12237'},
[12252]={[0]='Torture the Torturer',[1]='B488 K0720 FH L071 A:27243 T:27243 P:12245'},
[12253]={[0]='Rescue from Town Square',[1]='B488 FA K0720 L071 A:27136 T:27136 P:12251'},
[12254]={[0]='Without a Prayer',[1]='B488 K0720 FH L071 A:27350 T:27350 P:12239'},
[12255]={[0]='The Thane of Voldrune',[1]='B490 FA K0740 L073 A:27391 T:27391 P:12222+12223'},
[12256]={[0]="The Flamebinders' Secrets",[1]='B490 K0740 FH L073 A:27388 T:27388'},
[12257]={[0]='A Show of Strength',[1]='B490 K0740 FH L073 A:27388 T:27388 P:12468'},
[12258]={[0]='The Fate of the Dead',[1]='B488 FA K0720 L071 A:27155 T:27155 P:12251'},
[12259]={[0]='The Thane of Voldrune',[1]='B490 K0740 FH L073 A:27388 T:27388'},
[12260]={[0]='The Perfect Dissemblance',[1]='B488 K0720 FH L071 A:27350 T:27350 P:12254'},
[12261]={[0]='No Place to Run',[1]='B488 K0740 L072 A:26593 T:26593 P:12447'},
[12262]={[0]='No One to Save You',[1]='B488 K0740 L072 A:26593 T:26593 P:12447'},
[12263]={[0]='The Best of Intentions',[1]='B488 K0740 L072 A:26593 T:26593 P:12261'},
[12264]={[0]='Culling the Damned',[1]='B488 K0740 L072 A:26593 T:26593 P:12263'},
[12265]={[0]='Defiling the Defilers',[1]='B488 K0740 L072 A:26593 T:26593 P:12263'},
[12266]={[0]='Tales of Destruction',[1]='B488 K0740 L072 A:26593 T:27765 P:12267'},
[12267]={[0]="Neltharion's Flame",[1]='B488 K0750 L072 A:26593 T:26593 P:12265'},
[12268]={[0]='Pieces Parts',[1]='B0 +D FA K0740 L073 A:27416 T:27416'},
[12269]={[0]='Not In Our Mine',[1]='B488 FA K0720 L071 A:27156 T:27156 P:12275'},
[12270]={[0]='Shred the Alliance',[1]='B0 +D FH K0740 L073 A:27423 T:27423'},
[12271]={[0]='The Rod of Compulsion',[1]='B488 K0720 FH L071 A:100037432 T:27243'},
[12272]={[0]='The Bleeding Ore',[1]='B488 FA K0720 L071 A:27159 T:27159 P:12275'},
[12273]={[0]='The Denouncement',[1]='B488 K0730 FH L071 A:27243 T:27243 P:12271'},
[12274]={[0]='A Fall From Grace',[1]='B488 K0730 FH L071 A:27350 T:27350 P:12260'},
[12275]={[0]='The Demo-gnome',[1]='B488 FA K0720 L071 A:27136 T:27159 P:12251'},
[12276]={[0]='The Search for Slinkin',[1]='B488 FA K0720 L071 A:27159 T:27412 P:12275'},
[12277]={[0]='Leave Nothing to Chance',[1]='B488 FA K0720 L071 A:27412 T:27159 P:12276'},
[12279]={[0]='A Bear of an Appetite',[1]='B490 K0750 L072 A:26484 T:26484'},
[12280]={[0]='Making Repairs',[1]='B0 +D FH K0740 L073 A:27422 T:27422'},
[12281]={[0]='Understanding the Scourge War Machine',[1]='B488 FA K0720 L071 A:27159 T:27136 P:12277'},  -- does this also require P:12272 ?
[12282]={[0]='Imprints on the Past',[1]='B488 FA K0720 L071 A:27314 T:27314 P:12251'},
[12283]={[0]='The Truth Will Out',[1]='B488 K0720 FH L071 A:27350 T:27243 P:12274'},
[12284]={[0]="Keep 'Em on Their Heels",[1]='B0 +D FH K0740 L073 A:27451 T:27451'},
[12285]={[0]='Do Unto Others',[1]='B488 K0730 FH L071 A:27243 T:27243 P:12283'},
[12286]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058231 T:1058231'},
[12287]={[0]='Orik Trueheart and the Forgotten Shore',[1]='B488 FA K0720 L071 A:27314 T:27347 P:12282'},
[12288]={[0]='Overwhelmed!',[1]='B0 +D FH K0740 L073 A:27464 T:27464'},
[12289]={[0]="Kick 'Em While They're Down",[1]='B0 +D FA K0740 L073 A:27468 T:27468'},
[12290]={[0]='The Murkweed Elixir',[1]='B488 FA K0720 L071 A:27347 T:27347 P:12287'},
[12291]={[0]='The Forgotten Tale',[1]='B488 FA K0720 L071 A:27347 T:27347 P:12290'},
[12292]={[0]='Local Support',[1]='B490 FA K0740 L073 A:26875 T:26875'},
[12293]={[0]='Close the Deal',[1]='B490 FA K0740 L073 A:26875 T:27469 P:12292'},
[12294]={[0]='A Tentative Pact',[1]='B490 FA K0740 L073 A:27469 T:26875 P:12293'},
[12295]={[0]='An Exercise in Diplomacy',[1]='B490 FA K0740 L073 A:26875 T:26821 P:12294'},
[12296]={[0]='Life or Death',[1]='B0 +D FA K0740 L073 A:27484 T:27484'},
[12297]={[0]='Of Traitors and Treason',[1]='B488 FA K0720 L071 A:23749 T:23859 P:11250 I:12157,12171'},
[12298]={[0]='High Commander Halford Wyrmbane',[1]='B488 FA K0720 L071 A:23859 T:27136 P:12297 I:12174 B488'},
[12299]={[0]='Northern Hospitality',[1]='B490 FA K0740 L073 A:27486 T:27486 P:12295'},
[12300]={[0]='Test of Mettle',[1]='B490 FA K0740 L073 A:27486 T:27497 P:12299+12307'},
[12301]={[0]='The Truth Shall Set Us Free',[1]='B488 FA K0720 L071 A:27347 T:27347 P:12291'},
[12302]={[0]='Words of Warning',[1]='B490 FA K0740 L073 A:27497 T:27499 P:12300'},
[12303]={[0]='Funding the War Effort',[1]='B488 K0720 FH L071 A:27267 T:27267'},
[12304]={[0]='Beachfront Property',[1]='B488 K0720 FH L071 A:32599 T:32599'},
[12305]={[0]='Parting Thoughts',[1]='B488 FA K0720 L071 A:27347 T:27314 P:12301'},
[12306]={[0]='Brew of the Month Club',[1]='B0 HB'},
[12307]={[0]='Wolfsbane Root',[1]='B490 FA K0740 L073 A:27545 T:27545'},
[12308]={[0]='Escape from Silverbrook',[1]='B490 FA K0740 L073 A:27499 T:26875 P:12302'},
[12309]={[0]='Find Durkon!',[1]='B488 FA K0720 L071 A:27136 T:27318 P:12253'},
[12310]={[0]='A Swift Response',[1]='B490 FA K0740 L073 A:26875 T:26875 P:12308'},
[12311]={[0]="The Noble's Crypt",[1]='B488 FA K0720 L071 A:27318 T:27318 P:12309'},
[12312]={[0]='Secrets of the Scourge',[1]='B488 FA K0730 L071 A:1189311 T:27318 P:12309'},
[12314]={[0]='Down With Captain Zorna!',[1]='B0 +D FA K074768 L073 A:27520 T:27520'},
[12315]={[0]='Crush Captain Brightwater!',[1]='B0 +D FH K074768 L073 A:27532 T:27532'},
[12316]={[0]='Keep Them at Bay!',[1]='B0 +D FA K0740 L073 A:27562 T:27562'},
[12317]={[0]='Keep Them at Bay',[1]='B0 +D FH K0740 L073 A:27563 T:27563'},
[12319]={[0]='Mystery of the Tome',[1]='B488 FA K0730 L071 A:27318 T:27136 P:12312'},
[12320]={[0]='Understanding the Language of Death',[1]='B488 FA K0730 L071 A:27136 T:27316 P:12319'},
[12321]={[0]='A Righteous Sermon',[1]='B488 FA K0730 L071 A:27316 T:27136 P:12320'},
[12323]={[0]="Smoke 'Em Out",[1]='B0 +D FA K074256 L073 A:27602 T:27602'},
[12324]={[0]="Smoke 'Em Out",[1]='B0 +D FH K074256 L073 A:27606 T:27606'},
[12325]={[0]='Into Hostile Territory',[1]='B488 FA K0730 L071 A:27136 T:27157 P:12281'},
[12326]={[0]='Steamtank Surprise',[1]='B488 FA K0730 L071 A:27157 T:1293 P:12325'},
[12327]={[0]='Out of Body Experience',[1]='B490 K0750 L073 A:27581 T:27581 P:12328'},
[12328]={[0]="Ruuna's Request",[1]='B490 K0750 L073 A:27581 T:27581 P:12161,12425'},
[12329]={[0]='Fate and Coincidence',[1]='B490 K0750 L073 A:27581 T:26935 P:12327'},
[12330]={[0]='Anatoly Will Talk',[1]='B490 K0750 L073 A:26935 T:26935 P:12329'},
[12331]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058962 T:1058962'},
[12332]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058964 T:1058964'},
[12333]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058965 T:1058965'},
[12334]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058966 T:1058966'},
[12335]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058967 T:1058967'},
[12336]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058968 T:1058968'},
[12337]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058969 T:1058969'},
--[12338]={[0]='Candy Bucket',[1]='HW FA A:1190042 T:1190042'},
[12339]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058971 T:1058971'},
[12340]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058975 T:1058975 I:512340 P:26322'},
[12341]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058973 T:1058973'},
[12342]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058974 T:1058974'},
[12343]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058972 T:1058972'},
[12344]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058976 T:1058976'},
[12345]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058963 T:1058963'},
[12347]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1058978 T:1058978'},
[12348]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058979 T:1058979'},
[12349]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058980 T:1058980'},
[12350]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058981 T:1058981'},
[12351]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058982 T:1058982'},
[12352]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058983 T:1058983'},
[12353]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058984 T:1058984'},
[12354]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058985 T:1058985'},
[12355]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058986 T:1058986'},
[12356]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058987 T:1058987'},
[12357]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058988 T:1058988'},
[12358]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058989 T:1058989'},
[12359]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058990 T:1058990'},
[12360]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1058991 T:1058991'},
[12361]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058992 T:1058992'},
[12362]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058993 T:1058993'},
[12363]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058994 T:1058994'},
[12364]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058995 T:1058995'},
[12365]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058996 T:1058996'},
[12366]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058997 T:1058997'},
[12367]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058998 T:1058998'},
[12368]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1058999 T:1058999'},
[12369]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059000 T:1059000'},
[12370]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059001 T:1059001'},
[12371]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059002 T:1059002'},
[12372]={[0]='Defending Wyrmrest Temple',[1]='B488 +D K0740 L071 A:27575 T:27575 P:12435'},
[12373]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059003 T:1059003'},
[12374]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059004 T:1059004'},
--[12375]={[0]='Candy Bucket',[1]='HW FH A:1190077 T:1190077'},
[12376]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059006 T:1059006'},
[12377]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059007 T:1059007'},
[12378]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059008 T:1059008'},
--[12379]={[0]='Candy Bucket',[1]='HW FH A:1190081 T:1190081'},
[12380]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059010 T:1059010'},
[12381]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059011 T:1059011'},
[12382]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059012 T:1059012'},
[12383]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059013 T:1059013'},
[12384]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059014 T:1059014'},
--[12385]={[0]='Candy Bucket',[1]='HW FH A:1190087 T:1190087'},
[12386]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059016 T:1059016'},
[12387]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059017 T:1059017'},
[12388]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059018 T:1059018'},
[12389]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059019 T:1059019'},
[12390]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059024 T:1059024'},
[12391]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059025 T:1059025'},
[12392]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059026 T:1059026'},
[12393]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059027 T:1059027'},
[12394]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059028 T:1059028'},
[12395]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1059029 T:1059029'},
[12396]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059030 T:1059030'},
[12397]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059031 T:1059031'},
[12398]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059032 T:1059032'},
[12399]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059033 T:1059033'},
[12400]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059034 T:1059034'},
[12401]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059035 T:1059035'},
[12402]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059036 T:1059036'},
[12403]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059037 T:1059037'},
[12404]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059038 T:1059038 V3541999 I:512404'},
--[12405]={[0]='Candy Bucket',[1]='HW'},
[12406]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059040 T:1059040'},
[12407]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059041 T:1059041'},
[12408]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059042 T:1059042'},
[12409]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059043 T:1059043 V3541999 I:512409'},
--[12410]={[0]='Candy Bucket',[1]='HW'},
[12411]={[0]="A Sister's Pledge",[1]='B490 K0750 L073 A:26935 T:27646 P:12330'},
[12412]={[0]="My Enemy's Friend",[1]='B490 K0750 FH L073 A:26860 T:26860'},
[12413]={[0]='Attack on Silverbrook',[1]='B490 K0740 FH L073 A:26860 T:26860 P:12412'},
[12414]={[0]='Mounting Up',[1]='B490 FA K0750 L073 A:26377 T:26377'},
[12415]={[0]='The Horse Hollerer',[1]='B490 K0750 FH L073 A:26944 T:26944'},
[12416]={[0]='Heated Battle',[1]='B488 FA K0740 L071 A:27506 T:27506 P:12460'},
[12417]={[0]='Return to the Earth',[1]='B488 FA K0740 L071 A:27506 T:27506 P:12416'},
[12418]={[0]='Through Fields of Flame',[1]='B488 FA K0750 L071 A:27506 T:27506 P:12417'},
[12419]={[0]='The Fate of the Ruby Dragonshrine',[1]='B488 K0750 L071 A:100037833 T:27990'},
[12420]={[0]='Brew of the Month Club',[1]='B0 HB FA K0000 A:100037736 T:27478'},
[12421]={[0]='Brew of the Month Club',[1]='B0 HB FH K0000 A:100037737 T:27489'},
[12422]={[0]='Tactical Clemency',[1]='B490 K0740 FH L073 A:27102 T:27497 P:12424'},
[12423]={[0]="Mikhail's Journal",[1]='B490 K0740 FH L073 A:100037830 T:26860'},
[12424]={[0]='Gorgonna',[1]='B490 K0740 FH L073 A:26860 T:27102 P:12423'},
[12425]={[0]='Ruuna the Blind',[1]='B490 K0750 FH L073 A:27102 T:27581'},
[12427]={[0]='The Conquest Pit: Bear Wrestling!',[1]='B490 K0740 FH L073 A:27719 T:27720'},
[12428]={[0]='The Conquest Pit: Mad Furbolg Fighting',[1]='B490 K0740 FH L073 A:27719 T:27720 P:12427'},
[12429]={[0]='The Conquest Pit: Blood and Metal',[1]='B490 K0740 FH L073 A:27719 T:27720 P:12428'},
[12430]={[0]='The Conquest Pit: Death Is Likely',[1]='B490 K0750 FH L073 A:27719 T:27720 P:12429'},
[12431]={[0]='The Conquest Pit: Final Showdown',[1]='B490 K0750 FH L073 A:27719 T:27102 P:12430'},
[12432]={[0]='Riding the Red Rocket',[1]='B0 +D FH K0740 L073 A:27708 T:27708'},
[12433]={[0]='Seeking Solvent',[1]='B0 K0740 FH L073 A:27565 T:27565'},
[12435]={[0]='Report to Lord Afrasastrasz',[1]='B488 K0740 L071 A:26917 T:27575 P:12123,12124'},
[12436]={[0]='Supplemental Income',[1]='B490 K0740 FH L073 A:26868 T:26868'},
[12437]={[0]='Riding the Red Rocket',[1]='B0 +D FA K0740 L073 A:27759 T:27759'},
[12438]={[0]='Wanted: Kreug Oathbreaker',[1]='B488 FA K0740 L071 A:1190020 T:27156'},
[12439]={[0]='A Disturbance In The West',[1]='B488 FA K0720 L071 A:27158 T:26878 I:11995'},
[12440]={[0]="To Stars' Rest!",[1]='B488 FA K0720 L071 A:26878 T:26673 I:11995 P:12439'},
[12441]={[0]='Wanted: High Shaman Bloodpaw',[1]='B488 FA K0740 L071 A:1190020 T:27156'},
[12442]={[0]='Wanted: Onslaught Commander Iustus',[1]='B488 FA K0740 L071 A:1190020 T:27156'},
[12443]={[0]='Seeking Solvent',[1]='B0 FA K0740 L073 A:27495 T:27495'},
[12444]={[0]='Blackriver Skirmish',[1]='B490 +D FA K074256 L073 A:27783 T:27783'},
[12447]={[0]='The Obsidian Dragonshrine',[1]='B488 K0740 L072 A:27765 T:26593'},
[12448]={[0]='Heated Battle',[1]='B488 K0740 FH L071 A:27763 T:27763 P:12461'},
[12449]={[0]='Return to the Earth',[1]='B488 K0740 FH L071 A:27763 T:27763 P:12448'},
[12450]={[0]='Through Fields of Flame',[1]='B488 K0750 FH L071 A:27763 T:27763 P:12449'},
[12451]={[0]='Onward to Camp Oneqwah',[1]='B490 K0740 FH L073 A:27388 T:26666'},
[12453]={[0]='Eyes Above',[1]='B490 K0740 FH L073 A:27262 T:27262'},
[12454]={[0]='Cycle of Life',[1]='B488 K0740 L072 A:27255 T:27255'},
[12455]={[0]='Scattered To The Wind',[1]='B488 FA K0730 L071 A:1293 T:1293 P:12326'},
[12456]={[0]='The Plume of Alystros',[1]='B488 K0740 L072 A:27255 T:27255 P:12454'},
[12457]={[0]='The Chain Gun And You',[1]='B488 FA K0730 L071 A:1293 T:1293 P:12455'},
[12458]={[0]='Seeds of the Lashers',[1]='B488 K0740 L072 A:27785 T:27785'},
[12459]={[0]='That Which Creates Can Also Destroy',[1]='B488 K0740 L072 A:27785 T:27785 P:12458'},
[12460]={[0]='Report to the Ruby Dragonshrine',[1]='B488 FA K0740 L071 A:27803 T:27506 P:12766'},
[12461]={[0]='Report to the Ruby Dragonshrine',[1]='B488 K0740 FH L071 A:27804 T:27763 P:12767'},
[12462]={[0]='Breaking Off A Piece',[1]='B488 FA K0730 L071 A:27319 T:27319 P:12326'},
[12463]={[0]='Plunderbeard Must Be Found!',[1]='B488 FA K0730 L071 A:1293 T:27828 P:12457'},
[12464]={[0]='My Old Enemy',[1]='B488 FA K0730 L071 A:27784 T:27784 P:12237'},
[12465]={[0]="Plunderbeard's Journal",[1]='B488 FA K0730 L071 A:27828 T:1293 P:12463'},
[12466]={[0]='Chasing Icestorm: The 7th Legion Front',[1]='B488 FA K0730 L071 A:1293 T:27844 P:12465'},
[12467]={[0]="Chasing Icestorm: Thel'zan's Phylactery",[1]='B488 FA K0730 L071 A:27844 T:27136 P:12466'},
[12468]={[0]="The Conqueror's Task",[1]='B490 K0740 FH L073 A:26860 T:27388 P:12487'},
[12469]={[0]='Return to Sender',[1]='B488 K0740 L072 A:26896 T:26660'},
[12470]={[0]='Mystery of the Infinite',[1]='B488 K0750 L072 A:27856 T:27856'},
[12471]={[0]='Cruelty of the Kvaldir',[1]='B486 K0710 L068 A:25636 T:25435'},
[12472]={[0]='Finality',[1]='B488 FA K0730 L071 A:27136 T:27857 P:12467'},
[12473]={[0]='An End And A Beginning',[1]='B488 FA K0730 L071 A:27857 T:27136 P:12472'},
[12474]={[0]='To Fordragon Hold!',[1]='B488 FA K0730 L071 A:27136 T:27872 P:12473'},
[12475]={[0]='What Secrets Men Hide',[1]='B488 FA K0730 L071 A:27314 T:27314 P:12305'},
[12476]={[0]='The Return of the Crusade?',[1]='B488 FA K0730 L071 A:27155 T:27155 P:12305'},
[12477]={[0]='The Path of Redemption',[1]='B488 FA K0730 L071 A:27136 T:27136 P:12305'},
[12478]={[0]='Frostmourne Cavern',[1]='B488 FA K0730 L071 A:27314 T:27314 P:12475'},
[12481]={[0]='Adding Injury to Insult',[1]='B491 K0710 FH L068 A:24458 T:24458 P:11303'},
[12482]={[0]='Against Nifflevar',[1]='B491 K0710 FH L068 A:27922 T:27922'},
[12483]={[0]='Shimmercap Stew',[1]='B490 K0750 L073 A:26519 T:26519 P:12484'},
[12484]={[0]='Scourgekabob',[1]='B490 K0740 L073 A:26519 T:26604 P:11990'},
[12486]={[0]="To Bor'gorok Outpost, Quickly!",[1]='B486 K0710 FH L069 A:25272 T:25339'},
[12487]={[0]='To Conquest Hold, But Be Careful!',[1]='B490 K0740 FH L073 A:27243 T:26860 P:12488 B490'},
[12488]={[0]='The High Executor Needs You',[1]='B488 K0740 FH L073 A:26415 T:27243'},
[12489]={[0]='Welcome to Sholazar Basin',[1]='B493 K0760 L076 A:27987 T:27986 P:12521'},
[12491]={[0]="Direbrew's Dire Brew",[1]='B0 L075 HB A:100038280'},
[12492]={[0]="Direbrew's Dire Brew",[1]='B0 L075 HB A:100038281'},
[12495]={[0]='Audience With The Dragon Queen',[1]='B488 FA K0740 L071 A:27872 T:26917 P:12474'},
[12496]={[0]='Audience With The Dragon Queen',[1]='B488 K0740 FH L071 A:25257 T:26917 P:12224'},
[12497]={[0]='Galakrond and the Scourge',[1]='B488 K0740 L071 A:26917 T:26949 P:12495,12496'},
[12498]={[0]='On Ruby Wings',[1]='B488 K0740 L071 A:26949 T:26917 P:12497'},
[12499]={[0]='Return To Angrathar',[1]='B488 FA K0740 L071 A:26917 T:27872 P:12498'},
[12500]={[0]='Return To Angrathar',[1]='B488 K0740 FH L071 A:26917 T:25257 P:12498'},
[12501]={[0]='Troll Patrol',[1]='B0 K0760 +D L074 A:28039 T:28039'},
[12502]={[0]='Troll Patrol: High Standards',[1]='B0 +D K0760 L074 A:28042 T:28042'},
[12503]={[0]='Defend the Stand',[1]='B496 K0760 L074 A:28059 T:28059 O:12795'},
[12504]={[0]='Argent Crusade, We Are Leaving!',[1]='B496 K0760 L074 A:28056 T:28056 P:12505'},
[12505]={[0]='New Orders for Sergeant Stackhammer',[1]='B496 K0760 L074 A:28039 T:28056 P:12740'},
[12506]={[0]='Trouble at the Altar of Sseratus',[1]='B496 K0760 L074 A:28062 T:28062 P:12740'},
[12507]={[0]='Strange Mojo',[1]='B496 K0760 L074 A:100038321 T:28062'},
[12508]={[0]='Mopping Up',[1]='B496 K0760 L074 A:28099 T:28099 P:12505'},
[12509]={[0]='Troll Patrol: Intestinal Fortitude',[1]='B0 +D K0760 L074 A:28044 T:28044'},
[12510]={[0]='Precious Elemental Fluids',[1]='B496 K0760 L074 A:28062 T:28062 P:12507'},
[12511]={[0]='The Hills Have Us',[1]='B490 FA K0730 L073 A:27317 T:26875 B490'},
[12512]={[0]='Leave No One Behind',[1]='B496 K0760 L074 A:28125 T:28125'},
[12513]={[0]='Nice Hat...',[1]='B0 FH K0680 L066 A:28126 T:28126'}, -- guessing at FH
[12514]={[0]='Mushroom Mixer',[1]='B496 K0760 L074 A:28062 T:28062 P:12510'},
[12515]={[0]='Nice Hat...',[1]='B0 FA K0680 L066 A:28126 T:28126'}, -- guessing at FA...was given to L85 NE Hunter
[12516]={[0]='Too Much of a Good Thing',[1]='B496 K0760 L074 A:28062 T:28062 P:12514'},
[12517]={[0]='Rogues Deck',[1]='B0 K0150 L010 A:100037163,100043039 T:30481'},
[12518]={[0]='Mages Deck',[1]='B0 K0350 L030 A:100044148 T:30481'},
[12519]={[0]='Troll Patrol: Whatdya Want, a Medal?',[1]='B0 +D K0760 L074 A:28043 T:28043'},
[12520]={[0]='Rhino Mastery: The Test',[1]='B493 K0760 L076 A:27986 T:27986'},
[12521]={[0]='Where in the World is Hemet Nesingwary?',[1]='B493 K0760 L076 A:28160 T:27987 B493'},
[12522]={[0]='Need an Engine, Take an Engine',[1]='B493 K0760 L076 A:28033 T:28033'},
[12523]={[0]='Have a Part, Give a Part',[1]='B493 K0760 L076 A:28033 T:28033 P:12522'},
[12524]={[0]='Venture Co. Misadventure',[1]='B493 K0760 L076 A:28032 T:28032'},
[12525]={[0]='Wipe That Grin Off His Face',[1]='B493 K0760 L076 A:28032 T:28032 P:12524'},
[12526]={[0]='Rhino Mastery: The Chase',[1]='B493 K0760 L076 A:27986 T:28191 P:12520'},
[12527]={[0]='Gluttonous Lurkers',[1]='B496 K0760 L074 A:28204 T:28205 P:12510'},
[12528]={[0]='Playing Along',[1]='B493 K0770 FA L076 A:28095 T:28082'},
[12529]={[0]="The Ape Hunter's Slave",[1]='B493 K0770 L076 A:28082 T:28082 P:12528'},
[12530]={[0]='Tormenting the Softknuckles',[1]='B493 K0770 L076 A:28214 T:28082'},
[12531]={[0]='The Underground Menace',[1]='B493 K0770 L076 A:28138 T:28082 P:12532'},
[12532]={[0]='Flown the Coop!',[1]='B493 K0770 L076 A:28138 T:28138'},
[12533]={[0]="The Wasp Hunter's Apprentice",[1]='B493 K0770 L076 A:28082 T:28082'},
[12534]={[0]='The Sapphire Queen',[1]='B493 K0770 L076 A:28138 T:28082'},
[12535]={[0]='Mischief in the Making',[1]='B493 K0770 L076 A:28082 T:28082'},
[12536]={[0]='A Rough Ride',[1]='B493 K0770 L076 A:28082 T:28216'},
[12537]={[0]='Lightning Definitely Strikes Twice',[1]='B493 K0770 L076 A:28216 T:28216'},
[12538]={[0]="The Mist Isn't Listening",[1]='B493 K0770 L076 A:28216 T:28216'},
[12539]={[0]='Hoofing It',[1]='B493 K0770 L076 A:28216 T:28082'},
[12540]={[0]='Just Following Orders',[1]='B493 K0770 L076 A:28082 T:28217 P:12539'},
[12541]={[0]="Troll Patrol: The Alchemist's Apprentice",[1]='B0 +D K0760 L074 A:28205 T:28205'},
[12542]={[0]='The Call Of The Crusade',[1]='B488 K0740 L074 A:27348 T:28228'},
[12543]={[0]='An Offering for Soo-rahm',[1]='B493 K0760 L076 A:28191 T:28191 P:12526'},
[12544]={[0]='The Bones of Nozronn',[1]='B493 K0760 L076 A:28191 T:27986 P:12543'},
[12545]={[0]="The Cleansing Of Jintha'kalar",[1]='B488 K0740 L074 A:28228 T:28228 P:12542'},
[12546]={[0]='Reclamation',[1]='B493 K0780 L077 A:27801 T:27801 P:12797'},
[12547]={[0]='The Activation Rune',[1]='B201 K0780 L077 A:28092 T:28092 P:12548'},
[12548]={[0]='The Etymidian',[1]='B493 K0780 L077 A:27801 T:28092 P:12613'},
[12549]={[0]='Dreadsaber Mastery: Becoming a Predator',[1]='B493 K0760 L076 A:28031 T:28031'},
[12550]={[0]='Dreadsaber Mastery: Stalking the Prey',[1]='B493 K0760 L076 A:28031 T:28031 P:12549'},
[12551]={[0]='Crocolisk Mastery: The Trial',[1]='B493 K0760 L076 A:28032 T:28032'},
[12552]={[0]='Death to the Necromagi',[1]='B496 K0760 L074 A:28283 T:28283 P:12598'},
[12553]={[0]='Skimmer Spinnerets',[1]='B496 K0760 L074 A:28284 T:28284 P:12598'},
[12554]={[0]='Malas the Corrupter',[1]='B496 K0760 L074 A:28283 T:28283 P:12552'},
[12555]={[0]='A Tangled Skein',[1]='B496 K0760 L074 A:28284 T:28284 P:12583'},
[12556]={[0]='Rhino Mastery: The Kill',[1]='B493 K0760 L076 A:27986 T:27986'},
[12557]={[0]='Lab Work',[1]='B496 K0760 L074 A:28205 T:28205 PL:12596'},
[12558]={[0]='Dreadsaber Mastery: Ready to Pounce',[1]='B493 K0760 L076 A:28031 T:28031 P:12550'},
[12559]={[0]="Powering the Waygate - The Makers' Perch",[1]='B493 K0770 L077 A:27801 T:27801 P:12621'},
[12560]={[0]='Crocolisk Mastery: The Plan',[1]='B493 K0760 L076 A:28032 T:28032 P:12551'},
[12561]={[0]='An Issue of Trust',[1]='B493 K0770 L077 A:27801 T:27801 P:12803'},
[12562]={[0]='The Drakkari Do Not Need Water Elementals!',[1]='B496 K0760 L074 A:28309 T:28309 P:1'}, -- TODO: Determine real P:
[12563]={[0]='Troll Patrol',[1]='B0 K0760 +D L074 A:28039 T:28039'},
[12564]={[0]='Troll Patrol: Something for the Pain',[1]='B0 +D K0760 L074 A:28042 T:28042'},
[12565]={[0]="The Blessing of Zim'Abwa",[1]='B496 K0760 L074 A:28062 T:1190535'},
[12566]={[0]='Help for Camp Winterhoof',[1]='B491 K0710 FH L068 A:28314 T:24129'},
[12567]={[0]="Blessing of Zim'Abwa",[1]='B496 K0760 ++ L074 A:1190535 T:1190535 P:12565'},
[12568]={[0]='Troll Patrol: Done to Death',[1]='B0 +D K0760 L074 A:28044 T:28044'},
[12569]={[0]='Crocolisk Mastery: The Ambush',[1]='B493 K0760 L076 A:28032 T:28032 P:12560'},
[12570]={[0]='Fortunate Misunderstandings',[1]='B493 K0770 L076 A:28217 T:28027'},
[12571]={[0]='Make the Bad Snake Go Away',[1]='B493 K0770 L076 A:28027 T:28027 P:12570'},
[12572]={[0]='Gods like Shiny Things',[1]='B493 K0770 L076 A:28120 T:28027'},
[12573]={[0]='Making Peace',[1]='B493 K0770 L076 A:28027 T:28027 P:12571'},
[12574]={[0]='Back So Soon?',[1]='B493 K0770 L076 A:28027 T:28114'},
[12575]={[0]='The Lost Mistwhisper Treasure',[1]='B493 K0770 L076 A:28114 T:28114'},
[12576]={[0]='Forced Hand',[1]='B493 K0770 L076 A:28114 T:28114'},
[12577]={[0]='Home Time!',[1]='B493 K0770 L076 A:28114 T:28027'},
[12578]={[0]='The Angry Gorloc',[1]='B493 K0770 L076 A:28027 T:28122 P:12577'},
[12579]={[0]='Lifeblood of the Mosswalker Shrine',[1]='B493 K0770 L076 A:28122 T:28122'},
[12580]={[0]='The Mosswalker Savior',[1]='B493 K0770 L076 A:28122 T:28122'},
[12581]={[0]="A Hero's Burden",[1]='B493 K0770 L076 A:28122 T:1190777'},
[12582]={[0]='Frenzyheart Champion',[1]='B493 K0770 +D L076 A:28668 T:28668'},
[12583]={[0]='Crashed Sprayer',[1]='B496 K0760 L074 A:28284 T:28284 P:12553'},
[12584]={[0]='Pure Evil',[1]='B496 K0760 L074 A:28044 T:28244 P:12552'},
[12585]={[0]='Troll Patrol: Creature Comforts',[1]='B0 +D K0760 L074 A:28043 T:28043'},
[12587]={[0]='Troll Patrol',[1]='B0 +D K0760 L074 A:28039 T:28039 P:12596'},
[12588]={[0]='Troll Patrol: Can You Dig It?',[1]='B0 +D K0760 L074 A:28042 T:28042'},
[12589]={[0]='Kick, What Kick?',[1]='B493 K0760 L076 A:28328 T:28328'},
[12591]={[0]='Troll Patrol: Throwing Down',[1]='B0 +D K0760 L074 A:28044 T:28044'},
[12592]={[0]="The Great Hunter's Challenge",[1]='B493 K0760 L076 A:28328 T:28328 P:12589'},
[12593]={[0]='In Service Of The Lich King',[1]='B0 K0550 CK L055 A:25462 T:28357'},
[12594]={[0]="Troll Patrol: Couldn't Care Less",[1]='B0 +D K0760 L074 A:28043 T:28043'},
[12595]={[0]='In Search of Bigger Game',[1]='B493 K0770 L076 A:27986 T:28376'},
[12596]={[0]="Pa'Troll",[1]='B496 K0760 L074 A:28039 T:28039 P:12740'},
[12597]={[0]='Something for the Pain',[1]='B496 K0760 L074 A:28042 T:28042 PL:12596'},
[12598]={[0]='Throwing Down',[1]='B496 K0760 L074 A:28044 T:28044 PL:12596'},
[12599]={[0]='Creature Comforts',[1]='B496 K0760 L074 A:28043 T:28043 PL:12596'},
[12603]={[0]='Sharpening Your Talons',[1]='B493 K0770 L076 A:28376 T:28376'},
[12604]={[0]='Congratulations!',[1]='B0 +D K0760 L074 A:28039 T:28039'},
[12605]={[0]='Securing the Bait',[1]='B493 K0770 L076 A:28376 T:28376'},
[12606]={[0]='Cocooned!',[1]='B496 K0760 L074 A:28044 T:28044 P:12598'},
[12607]={[0]='A Mammoth Undertaking',[1]='B493 K0770 L076 A:28374 T:28374'},
[12608]={[0]='Cultist Incursion',[1]='B493 K0780 L077 A:28464 T:27801 P:12612'},
[12609]={[0]='Stocking the Shelves',[1]='B496 K0760 L074 A:28045 T:28045 P:12799'},
[12610]={[0]='Clipping Their Wings',[1]='B496 K0760 L074 A:28045 T:28045 P:12799'},
[12611]={[0]='Returned Sevenfold',[1]='B493 K0770 L077 A:27801 T:27801 P:12561'},
[12612]={[0]='The Fallen Pillar',[1]='B493 K0770 L077 A:27801 T:28464 P:12611'},
[12613]={[0]="Powering the Waygate - The Makers' Overlook",[1]='B493 K0770 L077 A:27801 T:27801 P:12559'},
[12614]={[0]='Post-partum Aggression',[1]='B493 K0770 L076 A:28376 T:28376'},
[12615]={[0]="The Blessing of Zim'Torga",[1]='B496 K0770 L074 A:28479 T:1190602 P:1'},
[12617]={[0]='Exterminate the Intruders',[1]='B493 K0770 L077 A:27801 T:27801'},
[12618]={[0]="Blessing of Zim'Torga",[1]='B496 SP K0770 ++ L074 A:1190602 T:1190602 P:12615'},
[12619]={[0]='The Emblazoned Runeblade',[1]='B0 K0550 CK L055 A:28357 T:28357 P:12593'},
[12620]={[0]="The Lifewarden's Wrath",[1]='B493 K0770 L077 A:27801 T:27801'},
[12621]={[0]="Freya's Pact",[1]='B493 K0770 L077 A:27801 T:27801 P:12620'},
[12622]={[0]="The Leaders at Jin'Alai",[1]='B496 K0770 L074 A:28484 T:28484 P:1'},
[12623]={[0]='To the Witch Doctor',[1]='B496 K0770 L074 A:28062 T:28479 P:12516'},
[12624]={[0]='It Could Be Anywhere!',[1]='B493 K0760 L076 A:28497 T:28497'},
[12627]={[0]="Breaking Through Jin'Alai",[1]='B496 K0770 L074 A:28479 T:28479 P:12623'},
[12628]={[0]="To Speak With Har'koa",[1]='B496 K0770 L074 A:28479 T:28401 P:12627'},
[12629]={[0]="You Can Run, But You Can't Hide",[1]='B496 K0750 L074 A:28518 T:28518 P:12637'},
[12630]={[0]="Kickin' Nass and Takin' Manes",[1]='B496 K0750 L074 A:28518 T:28518 P:12884'},
[12631]={[0]='An Invitation, of Sorts...',[1]='B496 K0750 L074 A:100038660 T:28518 I:12633'}, -- TODO: Determine the P:
[12632]={[0]='But First My Offspring',[1]='B496 K0770 L074 A:28401 T:28401 P:12628'},
[12633]={[0]='Darkness Calling',[1]='B496 K0750 L074 A:100038673 T:28518 I:12631'}, -- TODO: Determine the P: (seems you need to have gone through Drak'Tharon first, otherwise you get the other one)
[12634]={[0]='Some Make Lemonade, Some Make Liquor',[1]='B493 K0760 L076 A:29157 T:29157'},
[12635]={[0]='Relics of the Snow Leopard Goddess',[1]='B496 K0770 L074 A:28527 T:28527 P:12627'},
[12636]={[0]='The Eye Of Acherus',[1]='B0 K0550 CK L055 A:28357 T:28357 P:12848'},
[12637]={[0]='Near Miss',[1]='B496 K0750 L074 A:28518 T:28518 P:12631'},
[12638]={[0]='Close Call',[1]='B496 K0750 L074 A:28518 T:28518 P:12633'},
[12639]={[0]='The Frozen Earth',[1]='B496 K0770 L074 A:28480 T:28480 P:12622'},
[12640]={[0]='Sealing the Rifts',[1]='B496 K0770 L074 A:28484 T:28484 P:12622'},
[12641]={[0]='Death Comes From On High',[1]='B0 K0550 CK L055 A:25462 T:25462 P:12636'},
[12642]={[0]='Spirit of Rhunok',[1]='B496 K0770 L074 A:28401 T:28561 P:12632'},
[12643]={[0]='Silver Lining',[1]='B496 K0750 L074 A:28518 T:28518 P:12638'},
[12644]={[0]='Still At It',[1]='B493 K0760 L076 A:29157 T:29157 P:12634'},
[12645]={[0]='The Taste Test',[1]='B493 K0760 L076 A:29157 T:29157 P:12644'},
[12646]={[0]='My Prophet, My Enemy',[1]='B496 K0770 L074 A:28561 T:28561 P:12642'},
[12647]={[0]='An End to the Suffering',[1]='B496 K0770 L074 A:28561 T:28561 P:12646'},
[12648]={[0]='Dressing Down',[1]='B496 K0750 L074 A:28518 T:28518 P:12629'},
[12649]={[0]='Suit Up!',[1]='B496 K0750 L074 A:28518 T:28518 P:12643'},
[12650]={[0]='Plundering Their Own',[1]='B496 K0770 L074 A:28527 T:28527 P:12635'},
[12651]={[0]='Lakeside Landing',[1]='B493 K0770 L076 A:27986 T:28568'},
[12652]={[0]="Feedin' Da Goolz",[1]='B496 K0750 L074 A:28589 T:28589 PL:12648,12649'},
[12653]={[0]="Back to Har'koa",[1]='B496 K0770 L074 A:28561 T:28401 P:12647'},
[12654]={[0]='The Part-time Hunter',[1]='B493 K0760 L076 A:28568 T:28568'},
[12655]={[0]="The Blessing of Zim'Rhuk",[1]='B496 K0770 L074 A:28479 T:1190657 P:12632'},
[12656]={[0]="Blessing of Zim'Rhuk",[1]='B496 K0770 ++ L074 A:1190657 T:1190657 P:12655'},
[12657]={[0]='The Might Of The Scourge',[1]='B0 K0550 CK L055 A:25462 T:28444 P:12641'},
[12658]={[0]='My Pet Roc',[1]='B493 K0770 L076 A:28374 T:28374'},
[12659]={[0]='Scalps!',[1]='B496 K0770 L074 A:28484 T:28484 P:12640'},
[12660]={[0]='Weapons of Destruction',[1]='B493 K0770 L077 A:27801 T:27801'},
[12661]={[0]='Infiltrating Voltarus',[1]='B496 K0750 L074 A:28518 T:528518 P:12648,12649'},
[12662]={[0]="Bringing Down Heb'Jin",[1]='B496 K0770 L074 A:28480 T:28480 P:12640'},
[12663]={[0]='Reunited',[1]='B496 K0750 L074 A:28503 T:28503 P:1'},
[12664]={[0]='Dark Horizon',[1]='B496 K0750 L074 A:28503 T:28503 PL:12661'},
[12665]={[0]='I Sense a Disturbance',[1]='B496 K0770 L074 A:28401 T:28401 P:12653'},
[12666]={[0]='Preparations for the Underworld',[1]='B496 K0770 L074 A:28401 T:28401 P:12665'},
[12667]={[0]='Seek the Wind Serpent Goddess',[1]='B496 K0770 L074 A:28401 T:28030 P:12666'},
[12668]={[0]='Foundation for Revenge',[1]='B496 K0770 L074 A:28030 T:28030 P:12672'},
[12669]={[0]='So Far, So Bad',[1]='B496 K0750 L074 A:528518 T:528518 P:12661'},
[12670]={[0]='The Scarlet Harvest',[1]='B0 K0550 CK L055 A:28510 T:28377 P:12850'},
[12671]={[0]='Reconnaissance Flight',[1]='B493 K0770 L077 A:28746 T:28746 P:12699'},
[12672]={[0]='Setting the Stage',[1]='B496 K0770 L074 A:28030 T:28030 P:12667'},
[12673]={[0]='It Rolls Downhill',[1]='B496 K0750 L074 A:28503 T:28503 PL:12669'},
[12674]={[0]='Hell Hath a Fury',[1]='B496 K0770 L074 A:28030 T:28030 P:12668'},
[12675]={[0]='One Last Thing',[1]='B496 K0770 L074 A:28030 T:28401 P:12674'},
[12676]={[0]='Sabotage',[1]='B496 K0750 L074 A:528518 T:528518 P:12677'},
[12677]={[0]='Hazardous Materials',[1]='B496 K0750 L074 A:528518 T:528518 P:12669'},
[12678]={[0]='If Chaos Drives, Let Suffering Hold The Reins',[1]='B0 K0550 CK L055 A:28377 T:28377 P:12670'},
[12679]={[0]='Tonight We Dine In Havenshire',[1]='B0 K0550 CK L055 A:28647 T:28647'},
[12680]={[0]='Grand Theft Palomino',[1]='B0 K0550 CK L055 A:28653 T:28653'},
[12681]={[0]='Reagent Agent',[1]='B493 K0770 L076 A:28771 T:28771'},
[12683]={[0]='Burning to Help',[1]='B493 K0770 L076 A:28771 T:28771'},
[12684]={[0]='Blood of a Dead God',[1]='B496 K0770 L074 A:28401 T:28401 P:12675'},
[12685]={[0]='You Reap What You Sow',[1]='B496 K0770 L074 A:28401 T:28479 P:12684'},
[12686]={[0]='Zero Tolerance',[1]='B496 K0750 L074 A:28503 T:28503 PL:12677'},
[12687]={[0]='Into the Realm of Shadows',[1]='B0 K0550 CK L055 A:28653 T:28653 P:12680'},
[12688]={[0]='Engineering a Disaster',[1]='B493 K0760 L076 A:28787 T:27986'},
[12689]={[0]='Hand of the Oracles',[1]='B493 +D FH K0770 L076 A:28667 T:28667'},
[12690]={[0]='Fuel for the Fire',[1]='B496 K0750 L074 A:28503 T:28503 PL:12676'},
[12691]={[0]='A Timeworn Coffer',[1]='B493 K0780 L077 A:1190768 T:1190768'},
[12692]={[0]='Return of the Lich Hunter',[1]='B0 K0770 L076 A:28668 T:28138'},
[12695]={[0]='Return of the Friendly Dryskin',[1]='B0 K0770 FH L076 A:28667 T:28027'},
[12696]={[0]='Aerial Surveillance',[1]='B493 K0770 L077 A:28266 T:28746'},
[12697]={[0]='Gothik the Harvester',[1]='B0 K0550 CK L055 A:28658 T:28658'},
[12698]={[0]='The Gift That Keeps On Giving',[1]='B0 K0550 CK L055 A:28658 T:28658 P:12697'},
[12699]={[0]='An Embarassing Incident',[1]='B493 K0770 L077 A:28746 T:28746'},
[12700]={[0]='An Attack Of Opportunity',[1]='B0 K0550 CK L055 A:28658 T:28377 P:12698'},
[12701]={[0]="Massacre At Light's Point",[1]='B0 K0550 CK L055 A:28377 T:28377 P:12700'},
[12702]={[0]='Chicken Party!',[1]='B0 +D K0770 L076 A:28138 T:28138'},	-- TODO:	Make it Frenzyheart only
[12703]={[0]="Kartak's Rampage",[1]='B0 +D K0780 L076 A:29146 T:28106'},
[12704]={[0]='Appeasing the Great Rain Stone',[1]='B0 +D K0770 L076 A:28027 T:28027'},
[12705]={[0]='Will of the Titans',[1]='B0 +D K0780 L076 A:29149 T:28107'},
[12706]={[0]="Victory At Death's Breach!",[1]='B0 K0550 CK L055 A:28377 T:28444 P:12701'},
[12707]={[0]='Wooly Justice',[1]='B496 K0770 L074 A:28484 T:28484 P:12685'},
[12708]={[0]='Enchanted Tiki Warriors',[1]='B496 K0770 L074 A:28480 T:28480 P:12662+12685'},
[12709]={[0]='Hexed Caches',[1]='B496 K0770 L074 A:28527 T:28527 P:12685+13549'},
[12710]={[0]='Disclosure',[1]='B496 K0750 L074 A:28503 T:28503 P:12690'},
[12711]={[0]='Abandoned Mail',[1]='B0 K0550 CK L055 A:1190917 T:1190917'},
[12712]={[0]="The Key of Warlord Zol'Maz",[1]='B496 K0770 L074 A:528401 T:528401 P:12685'},
[12713]={[0]='Betrayal',[1]='B496 K0760 L074 A:528518 T:528518 P:12676'},
[12714]={[0]='The Will Of The Lich King',[1]='B0 K0550 CK L055 A:28444 T:28907 P:12706'},
[12715]={[0]='The Crypt of Remembrance',[1]='B0 K0550 CK L055 A:28907 T:28911 P:12714'},
[12716]={[0]="The Plaguebringer's Request",[1]='B0 K0550 CK L055 A:28919 T:28919'},
[12717]={[0]="Noth's Special Brew",[1]='B0 K0550 CK L055 A:28919 T:28919 P:12716'},
[12718]={[0]='More Skulls For Brew',[1]='B0 K0550 CK ++ L055 A:1190936 T:1190936'},
[12719]={[0]='Nowhere To Run And Nowhere To Hide',[1]='B0 K0550 CK L055 A:28911 T:28911 P:12715'},
[12720]={[0]='How To Win Friends And Influence Enemies',[1]='B0 K0550 CK L055 A:28911 T:28911 P:12719'},
[12721]={[0]='Rampage',[1]='B496 K0770 L074 A:28401 T:28479 P:12712'},
[12722]={[0]='Lambs To The Slaughter',[1]='B0 K0550 CK L055 A:28910 T:28910'},
[12723]={[0]='Behind Scarlet Lines',[1]='B0 K0550 CK L055 A:28911 T:28914'},
[12724]={[0]='The Path Of The Righteous Crusader',[1]='B0 K0550 CK L055 A:28914 T:28914 P:12723'},
[12725]={[0]='Brothers In Death',[1]='B0 K0550 CK L055 A:28913 T:28912'},
[12726]={[0]='Song of Wind and Water',[1]='B0 +D K0800 L077 A:29006 T:29006'},
[12727]={[0]='Bloody Breakout',[1]='B0 K0550 CK L055 A:28912 T:28913 P:12725'},
[12728]={[0]='Monitoring the Rift: Winterfin Cavern',[1]='B486 K0710 L069 A:25291 T:25291 P:11582'},
[12729]={[0]='The Gods Have Spoken',[1]='B496 K0770 L074 A:28479 T:28401 P:12721'},
[12730]={[0]="Convocation at Zol'Heb",[1]='B496 K0780 L074 A:28401 T:28401 P:12729'},
[12732]={[0]="The Heartblood's Strength",[1]='B0 +D K0800 L077 A:29043 T:29043'},	--	TODO: Make this Frenzyheart only
[12733]={[0]="Death's Challenge",[1]='B0 K0550 CK L055 A:29047 T:29047'},
[12734]={[0]='Rejek: First Blood',[1]='B0 +D K0800 L077 A:29043 T:29043'},
[12735]={[0]='A Cleansing Song',[1]='B0 +D K0800 L077 A:29006 T:29006'},
[12736]={[0]='Song of Reflection',[1]='B0 +D K0800 L077 A:29006 T:29006'},
[12737]={[0]='Song of Fecundity',[1]='B0 +D K0800 L077 A:29006 T:29006'},
[12738]={[0]='A Cry For Vengeance!',[1]='B0 K0550 CK L055 A:28913 T:29053 P:12727'},
[12739]={[0]='A Special Surprise',[1]='B0 K0550 RT CK L055 A:29053 T:29053'},
[12740]={[0]='Parachutes for the Argent Crusade',[1]='B496 K0760 L074 A:28059 T:28059'},
[12741]={[0]='Strength of the Tempest',[1]='B0 +D K0800 L077 A:29043 T:29043'},
[12742]={[0]='A Special Surprise',[1]='B0 K0550 RH CK L055 A:29053 T:29053'},
[12743]={[0]='A Special Surprise',[1]='B0 K0550 RE CK L055 A:29053 T:29053'},
[12744]={[0]='A Special Surprise',[1]='B0 K0550 RF CK L055 A:29053 T:29053'},
[12745]={[0]='A Special Surprise',[1]='B0 K0550 RN CK L055 A:29053 T:29053'},
[12746]={[0]='A Special Surprise',[1]='B0 K0550 RD CK L055 A:29053 T:29053'},
[12747]={[0]='A Special Surprise',[1]='B0 K0550 RB CK L055 A:29053 T:29053'},
[12748]={[0]='A Special Surprise',[1]='B0 K0550 RO CK L055 A:29053 T:29053'},
[12749]={[0]='A Special Surprise',[1]='B0 K0550 RL CK L055 A:29053 T:29053'},
[12750]={[0]='A Special Surprise',[1]='B0 K0550 RU CK L055 A:29053 T:29053'},
[12751]={[0]='A Sort Of Homecoming',[1]='B0 K0550 CK L055 A:29053 T:28913 P:12739,12742,12743,12744,12745,12746,12747,12748,12749,12750,28649,28650'},
[12754]={[0]='Ambush At The Overlook',[1]='B0 K0550 CK L055 A:28914 T:28914'},
[12755]={[0]='A Meeting With Fate',[1]='B0 K0550 CK L055 A:28914 T:29077 P:12754'},
[12756]={[0]='The Scarlet Onslaught Emerges',[1]='B0 K0550 CK L055 A:29077 T:28914 P:12755'},
[12757]={[0]='Scarlet Armies Approach...',[1]='B0 K0550 CK L055 A:28914 T:28444 P:12756'},
[12758]={[0]="A Hero's Headgear",[1]='B0 +D K0800 L077 A:29043 T:29043'},
[12759]={[0]='Tools of War',[1]='B0 +D K0780 L076 A:29146 T:28106'},
[12760]={[0]='Secret Strength of the Frenzyheart',[1]='B0 +D K0780 L076 A:29146 T:28106'},
[12761]={[0]='Mastery of the Crystals',[1]='B0 +D K0780 L076 A:29149 T:28107'},
[12762]={[0]='Power of the Great Ones',[1]='B0 +D K0780 L076 A:29149 T:28107'},
[12763]={[0]='Shifting Priorities',[1]='B490 K0750 FH L074 A:26666 T:29137 B496'},
[12766]={[0]='Speak with your Ambassador',[1]='B488 FA K0720 L071 A:26443 T:27803 P:12119'},
[12767]={[0]='Speak with your Ambassador',[1]='B488 K0720 FH L071 A:26443 T:27804 P:12122'},
[12768]={[0]='The Steward of Wyrmrest Temple',[1]='B488 FA K0750 L071 A:27506 T:26443 P:12418'},
[12769]={[0]='The Steward of Wyrmrest Temple',[1]='B488 K0750 FH L071 A:27763 T:26443 P:12450'},
[12770]={[0]='Reallocating Resources',[1]='B490 FA K0750 L074 A:26212 T:29137 B496'},
[12778]={[0]='The Scarlet Apocalypse',[1]='B0 K0550 CK L055 A:28444 T:29110'},
[12779]={[0]='An End To All Things...',[1]='B0 K0550 CK L055 A:25462 T:25462 P:12778'},
[12789]={[0]='Into the Breach!',[1]='B496 K0750 L074 A:28228 T:29137 P:12545 B496'},
[12790]={[0]='Learning to Leave and Return: the Magical Way',[1]='B0 K0740 L068 A:29156 T:29156 P:12791,12794,12796'},
[12791]={[0]='The Magical Kingdom of Dalaran',[1]='B0 K0740 FH L074 A:26471,29155,29159,29160,29162 T:29156'},
[12792]={[0]='First Things First',[1]='B496 K0750 L074 A:28039 T:29137 P:1'},
[12793]={[0]='Smoke on the Horizon',[1]='B496 K0750 L074 A:28479 T:29137 P:1'},
[12794]={[0]='The Magical Kingdom of Dalaran',[1]='B0 FA K0740 L074 A:23729,26673,27158,29158,29161 T:29156 I:12796'}, -- perhaps not the I:
[12795]={[0]='Taking a Stand',[1]='B496 K0750 L074 A:28532 T:28059 P:12630 I:12503'}, -- need to verify I:12503 should be here
[12796]={[0]='The Magical Kingdom of Dalaran',[1]='B0 K0740 L074 A:29169 T:29156 P:12791,12794'},
[12797]={[0]='Back Through the Waygate',[1]='B493 K0780 L077 A:28092 T:27801 P:12547 B493'},
[12798]={[0]='Swords Deck',[1]='B0 K0250 L020 A:100037164 T:30481'},
[12799]={[0]='Siphoning the Spirits',[1]='B496 K0750 L074 A:28045 T:28045'},
[12800]={[0]="The Lich King's Command",[1]='B0 K0550 CK L055 A:29110 T:31082 P:12779'},
[12801]={[0]='The Light of Dawn',[1]='B0 K0550 CK L055 A:31082 T:29173'},
[12802]={[0]='My Heart is in Your Hands',[1]='B490 K0740 L073 A:1057293 T:26701 P:12042'},
[12803]={[0]='Force of Nature',[1]='B493 K0780 L077 A:28746 T:27801'},
[12804]={[0]='A Steak Fit for a Hunter',[1]='B493 K0760 L076 A:28046 T:28046'},
[12805]={[0]="Salvaging Life's Strength",[1]='B493 K0770 L077 A:27801 T:27801'},
[12806]={[0]='To the Rise with all Due Haste!',[1]='B492 K0800 L077 A:29343 T:29344'},
[12807]={[0]='The Story Thus Far...',[1]='B492 K0800 L077 A:29344 T:29344 P:12806'},
[12810]={[0]='Blood in the Water',[1]='B492 K0800 L077 A:29344 T:29344 P:12807'},
[12813]={[0]='From Their Corpses, Rise!',[1]='B0 +D K0800 L077 A:29396 T:29396'},
[12814]={[0]="You'll Need a Gryphon",[1]='B492 K0800 L077 A:29344 T:29405 P:12810'},
[12815]={[0]='No Fly Zone',[1]='B0 +D K0800 L077 A:29405 T:29405'},
[12818]={[0]='Clean Up',[1]='B495 K0780 L077 A:29431 T:29431'},
[12819]={[0]='Just Around the Corner',[1]='B495 K0780 L077 A:29431 T:29431 P:12818'},
[12820]={[0]='A Delicate Touch',[1]='B495 K0780 L077 A:29428 T:29428 P:12826'},
[12821]={[0]='Opening the Backdoor',[1]='B495 K0780 L077 A:29428 T:29428'},
[12822]={[0]='Know No Fear',[1]='B495 K0780 L077 A:29428 T:29428 P:12821'},
[12823]={[0]='A Flawless Plan',[1]='B495 K0780 L077 A:29432 T:29432'},
[12824]={[0]='Demolitionist Extraordinaire',[1]='B495 K0780 L077 A:29432 T:29428 P:12823'},
[12826]={[0]='Slightly Unstable',[1]='B495 K0780 L077 A:29431 T:29428 P:12819'},
[12827]={[0]='Reclaimed Rations',[1]='B495 K0780 L077 A:29428 T:29428'},
[12828]={[0]='Ample Inspiration',[1]='B495 K0780 L077 A:29428 T:29428'},
[12829]={[0]='Moving In',[1]='B495 K0780 L077 A:29430 T:29430'},
[12830]={[0]='Ore Repossession',[1]='B495 K0780 L077 A:29430 T:29430'},
[12831]={[0]='Only Partly Forgotten',[1]='B495 K0780 L077 A:29434 T:29434'},
[12832]={[0]='Bitter Departure',[1]='B495 K0780 L077 A:29434 T:29428 P:12831'},
[12833]={[0]='Overstock',[1]='B495 +D K0780 L077 A:29428 T:29428'},
[12836]={[0]='Expression of Gratitude',[1]='B495 K0780 L077 A:29428 T:29428'},
[12838]={[0]='Intelligence Gathering',[1]='B0 +D K0800 L077 A:29456 T:29456'},
[12839]={[0]="The Grand (Admiral's) Plan",[1]='B492 K0800 L077 A:100040666 T:29344'},
[12840]={[0]='In Strict Confidence',[1]='B492 K0800 L077 A:29344 T:29344 P:12839'},
[12841]={[0]="The Crone's Bargain",[1]='B495 K0790 L077 A:29481 T:29481 P:12846'},
[12842]={[0]='Runeforging: Preparation For Battle',[1]='B0 K0550 CK L055 A:28357 T:28357 P:12619'},
[12843]={[0]='They Took Our Men!',[1]='B495 K0790 L077 A:29473 T:29473'},
[12844]={[0]='Equipment Recovery',[1]='B495 K0790 L077 A:29473 T:29473'},
[12846]={[0]='Leave No Goblin Behind',[1]='B495 K0780 L077 A:29473 T:29481 P:12843'},
[12847]={[0]='Second Chances',[1]='B492 K0800 L077 A:29344 T:29560 P:12840'},
[12848]={[0]='The Endless Hunger',[1]='B0 K0550 CK L055 A:28357 T:28357 P:12842'},
[12849]={[0]='The Power Of Blood, Frost And Unholy',[1]='B0 K0550 CK L055 A:28472 T:28472'},
[12850]={[0]='Report To Scourge Commander Thalanor',[1]='B0 K0550 CK L055 A:28444 T:28510 P:12657'},
[12851]={[0]='Going Bearback',[1]='B495 K0800 L077 A:29592 T:29592 P:12972'},
[12852]={[0]='The Admiral Revealed',[1]='B492 K0800 L077 A:29560 T:29344 P:12847'},
[12853]={[0]='Luxurious Getaway!',[1]='B495 K0780 L077 A:30490 T:29431 B495'},
[12854]={[0]="On Brann's Trail",[1]='B495 FA K0800 L077 A:29650 T:29650'},
[12855]={[0]='Sniffing Out the Perpetrator',[1]='B495 FA K0800 L077 A:29650 T:29579'},
[12856]={[0]='Cold Hearted',[1]='B495 K0800 L077 A:29592 T:29592 P:12851'},
[12857]={[0]="Wanted: Ragemane's Flipper",[1]='B496 K0750 L074 A:1191728 T:29690'},
[12858]={[0]='Pieces to the Puzzle',[1]='B495 K0800 FA L077 A:29579 T:29579 P:12855'},
[12859]={[0]='This Just In: Fire Still Hot!',[1]='B496 K0750 L074 A:29733 T:29733'},
[12860]={[0]='Data Mining',[1]='B495 K0800 FA L077 A:29579 T:29579 P:12858'},
[12861]={[0]='Trolls Is Gone Crazy!',[1]='B496 K0750 L074 A:29690 T:29690'},
[12862]={[0]='When All Else Fails',[1]='B495 FA K0780 L077 A:29428 T:29744'},
[12863]={[0]='Offering Thanks',[1]='B495 FA K0780 L077 A:29743 T:29727'},
[12864]={[0]='Missing Scouts',[1]='B495 FA K0780 L077 A:29727 T:29727 P:12863'},
[12865]={[0]='Loyal Companions',[1]='B495 FA K0780 L077 A:29732 T:29732'},
[12866]={[0]='Stemming the Aggressors',[1]='B495 FA K0780 L077 A:29727 T:29727 P:12864'},
[12867]={[0]='Baby Stealers',[1]='B495 FA K0780 L077 A:29732 T:29732 P:12865'},
[12868]={[0]='Sirana Iceshriek',[1]='B495 FA K0780 L077 A:29727 T:29727 P:12866'},
[12869]={[0]='Pushed Too Far',[1]='B0 +D FA K0780 L077 A:29732 T:29732'},
[12870]={[0]='Ancient Relics',[1]='B495 FA K0780 L077 A:29744 T:29744'},
[12871]={[0]="Aid from the Explorers' League",[1]='B495 K0800 FA L077 A:29579 T:29743'},
[12872]={[0]="Norgannon's Shell",[1]='B495 FA K0800 L077 A:1191760 T:29579 P:13415'},
[12873]={[0]='The Frostborn King',[1]='B495 FA K0800 L077 A:29743 T:29593 P:12871'},
[12874]={[0]='Fervor of the Frostborn',[1]='B495 FA K0800 L077 A:29593 T:29593 P:12873'},
[12875]={[0]='An Experienced Guide',[1]='B495 FA K0800 L077 A:29593 T:29751 P:12874'},
[12876]={[0]='Unwelcome Guests',[1]='B495 FA K0800 L077 A:29732 T:29732'},
[12877]={[0]='The Lonesome Watcher',[1]='B495 FA K0800 L077 A:29751 T:30052 P:12875'},
[12878]={[0]='The Hidden Relic',[1]='B495 FA K0800 L077 A:30052 T:30548 P:12986'},
[12879]={[0]='Fury of the Frostborn King',[1]='B495 FA K0800 L077 A:30548 T:30082 P:12878'},
[12880]={[0]='The Master Explorer',[1]='B495 FA K0800 L077 A:30082 T:30382 P:12879'},
[12882]={[0]='Ancient Relics',[1]='B495 K0780 FH L077 A:30472 T:30472'},
[12883]={[0]='Orders From Drakuru',[1]='B496 K0750 L074 A:1191766 T:29687 P:12902'},
[12884]={[0]='The Ebon Watch',[1]='B496 K0750 L074 A:29687 T:28518 P:12883'},
[12885]={[0]='The Exiles of Ulduar',[1]='B495 K0800 FA L077 A:29579 T:29801'},
[12886]={[0]='The Drakkensryd',[1]='B495 K0800 L077 A:29796 T:29445 P:13062'},
[12887]={[0]="It's All Fun and Games",[1]='B492 FA K0800 L077 A:29799 T:29804'},
[12888]={[0]='SCRAP-E',[1]='B495 K0800 L077 PN415 A:100041267 T:29806'},
[12889]={[0]='The Prototype Console',[1]='B495 K0800 L077 A:29806 T:1191761 P:12888'},
[12891]={[0]='I Have an Idea, But First...',[1]='B492 K0800 L077 A:29804 T:29804 P:12887,12892'},
[12892]={[0]="It's All Fun and Games",[1]='B492 K0800 FH L077 A:29795 T:29804 P:12887'},
[12893]={[0]='Free Your Mind',[1]='B492 K0800 L077 A:29804 T:29804 P:12891'},
[12894]={[0]='Crusader Forward Camp',[1]='B496 K0750 L074 A:29687 T:29689 P:12883'},
[12895]={[0]='The Missing Bronzebeard',[1]='B495 K0800 FH L077 A:29651 T:29651'},
[12896]={[0]='If He Cannot Be Turned',[1]='B492 FA K0800 L077 A:29804 T:29799'},
[12897]={[0]='If He Cannot Be Turned',[1]='B492 K0800 FH L077 A:29804 T:29795 P:12896'},
[12898]={[0]='The Shadow Vault',[1]='B492 FA K0800 L077 A:29799 T:29343 P:12896,12897'},
[12899]={[0]='The Shadow Vault',[1]='B492 K0800 FH L077 A:29795 T:29343 P:12898'},
[12900]={[0]='Making a Harness',[1]='B495 K0800 L077 A:29839 T:29839 P:13063'},
[12901]={[0]='Making Something Out Of Nothing',[1]='B496 K0760 L074 A:29688 T:29688 P:12894'},
[12902]={[0]='In Search Of Answers',[1]='B496 K0750 L074 A:29687 T:1191766'},
[12903]={[0]="That's What Friends Are For...",[1]='B496 K0760 L074 A:29689 T:29689 P:12894'},
[12904]={[0]="Light Won't Grant Me Vengeance",[1]='B496 K0760 L074 A:29455 T:29455 P:12894'},
[12905]={[0]='Mildred the Cruel',[1]='B495 K0790 L077 A:29481 T:29885 P:12841'},
[12906]={[0]='Discipline',[1]='B495 K0790 L077 A:29885 T:29885 P:12905'},
[12907]={[0]='Examples to be Made',[1]='B495 K0790 L077 A:29885 T:29885 P:12906'},
[12908]={[0]='A Certain Prisoner',[1]='B495 K0790 L077 A:29885 T:29481 P:12907'},
[12909]={[0]='The Nose Knows',[1]='B495 K0800 FH L077 A:29651 T:29855 P:12895'},
[12910]={[0]='Sniffing Out the Perpetrator',[1]='B495 K0800 FH L077 A:29855 T:29579 P:12909'},
[12912]={[0]='A Great Storm Approaches',[1]='B496 K0760 L074 A:29647 T:29688 P:12894'},
[12913]={[0]='Speak Orcish, Man!',[1]='B495 K0800 FH L077 A:29579 T:29937 P:12910'},
[12914]={[0]="Gymer's Salvation",[1]='B496 K0760 L074 A:29688 T:29688 P:12912'},
[12915]={[0]='Mending Fences',[1]='B495 K0800 L077 A:29445 T:29445 P:13064'},
[12916]={[0]='Our Only Hope',[1]='B496 K0760 L074 A:29688 T:29647 P:12914'},
[12917]={[0]="Speaking with the Wind's Voice",[1]='B495 K0800 FH L077 A:29937 T:29937 P:12913'},
[12919]={[0]="The Storm King's Vengeance",[1]='B496 K0760 L074 A:29647 T:29689 P:12916'},
[12920]={[0]='Catching up with Brann',[1]='B495 K0800 FH L077 A:29651 T:29651'},
[12921]={[0]='A Change of Scenery',[1]='B495 K0790 L077 A:29481 T:29975 P:12908'},
[12922]={[0]="The Refiner's Fire",[1]='B495 K0800 L077 A:100041556 T:1192060 P:13064'},
[12924]={[0]='Forging an Alliance',[1]='B495 K0800 L077 A:29445 T:30127'},
[12925]={[0]='Aberrations',[1]='B495 K0800 L077 A:30041 T:30041'},
[12926]={[0]='Pieces of the Puzzle',[1]='B495 K0800 FH L077 A:29651 T:29579 P:12920'},
[12927]={[0]='Data Mining',[1]='B495 K0800 FH L077 A:29579 T:29579 P:12926'},
[12928]={[0]="Norgannon's Shell",[1]='B495 K0800 FH L077 A:1191760 T:29579 P:13416'},
[12929]={[0]='The Earthen of Ulduar',[1]='B495 K0800 FH L077 A:29579 T:29801'},
[12930]={[0]='Rare Earth',[1]='B495 K0800 L077 A:29801 T:29801'},
[12931]={[0]='Fighting Back',[1]='B495 K0800 L077 A:29801 T:29801'},
[12932]={[0]='The Amphitheater of Anguish: Yggdras!',[1]='B496 K0770 L075 A:30007 T:30009 P:12974'},
[12933]={[0]='The Amphitheater of Anguish: Magnataur!',[1]='B496 K0770 L075 A:30007 T:30009 P:12932'},
[12934]={[0]='The Amphitheater of Anguish: From Beyond!',[1]='B496 K0770 L075 A:30007 T:30009 P:12933'},
[12935]={[0]='The Amphitheater of Anguish: Tuskarrmageddon!',[1]='B496 K0770 L075 A:30007 T:30009 P:12934'},
[12936]={[0]='The Amphitheater of Anguish: Korrak the Bloodrager!',[1]='B496 K0770 L075 A:30007 T:30009 P:12935'},
[12937]={[0]='Relief for the Fallen',[1]='B495 K0800 L077 A:29801 T:29801'},
[12938]={[0]='The Duke',[1]='B492 K0800 L077 A:29343 T:30002 P:12898,12899'},
[12939]={[0]='Honor Challenge',[1]='B492 K0800 L077 A:30002 T:30002 P:12938'},
[12940]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1060806 T:1060806'},
[12941]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1060807 T:1060807'},
[12942]={[0]='Off With Their Black Wings',[1]='B495 K0800 L077 A:29997 T:29997'},
[12943]={[0]='Shadow Vault Decree',[1]='B492 K0800 L077 A:30002 T:30002 P:12939'},
[12944]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1060810 T:1060810'},
[12945]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1060811 T:1060811'},
[12946]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1060808 T:1060808'},
[12947]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1060809 T:1060809'},
[12948]={[0]='The Champion of Anguish',[1]='B496 K0780 L075 A:30007 T:30009 P:12936'},
[12949]={[0]='Get the Key',[1]='B492 K0800 L077 A:30056 T:30056'},
[12950]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1060946 T:1060946'},
[12951]={[0]='Let the Baron Know',[1]='B492 K0800 L077 A:30056 T:29343 P:12949'},
[12953]={[0]='Valkyrion Must Burn',[1]='B495 K0800 L077 A:1192072 T:29997'},
[12954]={[0]='The Amphitheater of Anguish: Yggdras!',[1]='B496 K0770 L075 A:30007 T:30009'}, -- supposedly there is an O: from Dalaran sewers for this
[12955]={[0]='Eliminate the Competition',[1]='B492 K0800 L077 A:30074 T:30074'},
[12956]={[0]='A Spark of Hope',[1]='B495 K0800 L077 A:1192060 T:29445 P:12922'},
[12957]={[0]='Slaves of the Stormforged',[1]='B495 K0800 L077 A:29801 T:29801'},
[12958]={[0]='Shipment: Blood Jade Amulet ',[1]='B0 +D L065 PJ375 A:28701 T:28701 P:13041 I:12959,12960,12961,12962,12963'}, -- note that 4.2 has the space at the end of the name
[12959]={[0]='Shipment: Glowing Ivory Figurine',[1]='B0 +D L065 PJ375 A:28701 T:28701 P:13041 I:12958,12960,12961,12962,12963'},
[12960]={[0]='Shipment: Wicked Sun Brooch',[1]='B0 +D L065 PJ375 A:28701 T:28701 P:13041 I:12958,12959,12961,12962,12963'},
[12961]={[0]='Shipment: Intricate Bone Figurine',[1]='B0 +D L065 PJ375 A:28701 T:28701 P:13041 I:12958,12959,12960,12962,12963'},
[12962]={[0]='Shipment: Bright Armor Relic',[1]='B0 +D L065 PJ375 A:28701 T:28701 P:13041 I:12958,12959,12960,12961,12963'},
[12963]={[0]='Shipment: Shifting Sun Curio ',[1]='B0 +D L065 PJ375 A:28701 T:28701 P:13041 I:12958,12959,12960,12961,12962'}, -- note that 4.2 has the space at the end of the name
[12964]={[0]='The Dark Ore',[1]='B495 K0800 L077 A:29801 T:29801'},
[12965]={[0]='The Gifts of Loken',[1]='B495 K0800 L077 A:29801 T:29801'},
[12966]={[0]="You Can't Miss Him",[1]='B495 K0800 L077 A:30105 T:30099'},
[12967]={[0]='Battling the Elements',[1]='B495 K0800 L077 A:30099 T:30099 P:12966'},
[12968]={[0]="Yulda's Folly",[1]='B495 K0800 L077 A:29997 T:29997'},
[12969]={[0]='Is That Your Goblin?',[1]='B495 K0800 L077 A:29975 T:29975 P:12921'},
[12970]={[0]='The Hyldsmeet',[1]='B495 K0800 L077 A:29975 T:29975 P:12969'},
[12971]={[0]='Taking on All Challengers',[1]='B495 K0800 L077 A:29975 T:29975 P:12970'},
[12972]={[0]="You'll Need a Bear",[1]='B495 K0800 L077 A:29975 T:29592 P:12971'},
[12973]={[0]='The Brothers Bronzebeard',[1]='B495 FA K0800 L077 A:30107,30382 T:30401'},
[12974]={[0]="The Champion's Call!",[1]='B496 K0770 L075 A:30137 T:30007 B496'},
[12975]={[0]='In Memoriam',[1]='B495 K0800 L077 A:30105 T:30105'},
[12976]={[0]='A Monument to the Fallen',[1]='B495 K0800 L077 A:30105 T:30127 P:12975'},
[12977]={[0]="Blowing Hodir's Horn",[1]='B0 +D K0800 L077 A:1192078 T:1192078'},
[12978]={[0]='Facing the Storm',[1]='B495 K0800 L077 A:30152 T:30152'},
[12979]={[0]='Armor of Darkness',[1]='B495 K0800 L077 A:100042203 T:30152'},
[12980]={[0]="The Armor's Secrets",[1]='B495 K0800 L077 A:30152 T:30152 P:12979'},
[12981]={[0]='Hot and Cold',[1]='B0 +D K0800 L077 A:1192071 T:1192071'},
[12982]={[0]='Ebon Blade Prisoners',[1]='B492 K0800 L077 A:30218 T:30218 P:13085'},
[12983]={[0]='The Last of Her Kind',[1]='B495 K0800 L077 A:29839 T:29839'},
[12984]={[0]='Valduran the Stormborn',[1]='B495 K0800 L077 A:29801 T:29801'},
[12985]={[0]='Forging a Head',[1]='B495 K0800 L077 A:30127 T:30127'},
[12986]={[0]='Fate of the Titans',[1]='B495 FA K0800 L077 A:30052 T:30052 P:12877'},
[12987]={[0]="Mounting Hodir's Helm",[1]='B495 K0800 L077 A:30127 T:30127 P:12985'},
[12988]={[0]='Destroy the Forges!',[1]='B495 K0800 L077 A:29801 T:29801 P:12984'},
[12989]={[0]='The Slithering Darkness',[1]='B495 K0800 L077 A:29839 T:29839'},
[12991]={[0]='Hit Them Where it Hurts',[1]='B495 K0800 L077 A:30152 T:30152'},
[12992]={[0]='Crush Dem Vrykuls!',[1]='B492 K0800 L077 A:30216 T:30216'},
[12993]={[0]='A Colossal Threat',[1]='B495 K0800 L077 A:29801 T:29801'},
[12994]={[0]='Spy Hunter',[1]='B0 +D K0800 L077 A:30294 T:30294'},
[12995]={[0]='Leave Our Mark',[1]='B0 +D K0800 L077 A:29343 T:29343'},
[12996]={[0]='The Warm-Up ',[1]='B495 K0800 L077 A:29839 T:29839 P:12983'}, -- note that 4.2 has the space at the end of the name
[12997]={[0]='Into the Pit',[1]='B495 K0800 L077 A:29839 T:29839 P:12996'},
[12998]={[0]='The Heart of the Storm',[1]='B495 K0800 L077 A:29801 T:29801 P:12993'},
[12999]={[0]='The Bone Witch',[1]='B492 K0800 L077 A:30074 T:30232 P:12955'},
[13000]={[0]='Emergency Measures',[1]='B495 K0790 FH L077 A:30247 T:30247'},
[13001]={[0]="Raising Hodir's Spear",[1]='B495 K0800 L077 A:30252 T:30252'},
[13003]={[0]="Thrusting Hodir's Spear",[1]='B0 +D K0800 L077 A:1192079 T:1192079'},
[13005]={[0]='The Earthen Oath',[1]='B495 K0800 L077 A:30295 T:30295'},
[13006]={[0]='Polishing the Helm',[1]='B0 +D K0800 L077 A:1192080 T:1192080'},
[13007]={[0]='The Iron Colossus',[1]='B495 K0800 L077 A:29801 T:29801 P:12998'},
[13008]={[0]='Scourge Tactics',[1]='B492 K0780 L077 A:30223 T:30223 P:13036'},
[13009]={[0]='A New Beginning',[1]='B495 K0800 L077 A:30127 T:29445 P:12924'},
[13010]={[0]='Krolmir, Hammer of Storms',[1]='B495 K0800 L077 A:29445 T:30390 P:13051'},
[13011]={[0]='Jormuttar is Soo Fat...',[1]='B495 K0800 L077 A:30105 T:30105'},
[13012]={[0]='Sardis the Elder',[1]='B0 SP HL +Y A:30348 T:30348'},
[13013]={[0]='Beldak the Elder',[1]='B0 SP HL +Y A:30357 T:30357'},
[13014]={[0]='Morthie the Elder',[1]='B0 SP HL +Y A:30358 T:30358'},
[13015]={[0]='Fargal the Elder',[1]='B0 SP HL +Y A:30359 T:30359'},
[13016]={[0]='Northal the Elder',[1]='B0 SP HL +Y A:30360 T:30360'},
[13017]={[0]='Jarten the Elder',[1]='B0 SP HL +Y A:30531 T:30531'},
[13018]={[0]='Sandrene the Elder',[1]='B0 SP HL +Y A:30362 T:30362'},
[13019]={[0]='Thoim the Elder',[1]='B0 SP HL +Y A:30363 T:30363'},
[13020]={[0]='Stonebeard the Elder',[1]='B0 SP HL +Y A:30375 T:30375'},
[13021]={[0]='Igasho the Elder',[1]='B0 SP HL +Y A:30536 T:30536'},
[13022]={[0]='Nurgen the Elder',[1]='B0 SP HL +Y A:30533 T:30533'},
[13023]={[0]='Kilias the Elder',[1]='B0 SP HL +Y A:30534 T:30534'},
[13024]={[0]='Wanikaya the Elder',[1]='B0 SP HL +Y A:30365 T:30365'},
[13025]={[0]='Lunaro the Elder',[1]='B0 SP HL +Y A:30367 T:30367'},
[13026]={[0]='Bluewolf the Elder',[1]='B0 SP HL +Y A:30368 T:30368'},
[13027]={[0]='Tauros the Elder',[1]='B0 SP HL +Y A:30369 T:30369'},
[13028]={[0]='Graymane the Elder',[1]='B0 SP HL +Y A:30370 T:30370'},
[13029]={[0]='Pamuya the Elder',[1]='B0 SP HL +Y A:30371 T:30371'},
[13030]={[0]='Whurain the Elder',[1]='B0 SP HL +Y A:30372 T:30372'},
[13031]={[0]='Skywarden the Elder',[1]='B0 SP HL +Y A:30373 T:30373'},
[13032]={[0]='Muraco the Elder',[1]='B0 SP HL +Y A:30374 T:30374'},
[13033]={[0]='Arp the Elder',[1]='B0 SP HL +Y A:30364 T:30364'},
[13034]={[0]='The Witness and the Hero',[1]='B495 K0800 FH L077 A:30381 T:30381 P:13426'},
[13035]={[0]="Loken's Lackeys",[1]='B495 K0800 L077 A:30295 T:30295'},
[13036]={[0]='Honor Above All Else',[1]='B492 K0780 L077 A:28179 T:30223'},
[13037]={[0]='Memories of Stormhoof',[1]='B495 K0800 FH L077 A:30381 T:30381'},
[13038]={[0]='Distortions in Time',[1]='B495 K0800 FH L077 A:30395 T:30381'},
[13039]={[0]='Defending The Vanguard',[1]='B492 K0780 L077 A:30224 T:30224'},
[13040]={[0]='Curing The Incurable',[1]='B492 K0780 L077 A:30226 T:30226'},
[13041]={[0]='Finish the Shipment',[1]='B0 L065 PJ375 A:28701 T:28701'},
[13042]={[0]='Deep in the Bowels of The Underhalls',[1]='B492 K0800 L077 A:30232 T:30232'},
[13043]={[0]='The Sum is Greater than the Parts',[1]='B492 K0800 L077 A:100042772 T:30232'},
[13044]={[0]='If There Are Survivors...',[1]='B492 K0780 L077 A:30223 T:30227'},
[13045]={[0]='Into The Wild Green Yonder',[1]='B492 K0780 L077 A:30227 T:28179 P:13044'},
[13046]={[0]='Feeding Arngrim',[1]='B0 +D K0800 L077 A:1192524 T:1192524'},
[13047]={[0]='The Reckoning',[1]='B495 K0800 L077 A:30295 T:30105'},
[13048]={[0]='Where Time Went Wrong',[1]='B495 K0800 FH L077 A:30381 T:30381'},
[13049]={[0]="The Hero's Arms",[1]='B495 K0800 FH L077 A:30381 T:30381'},
[13050]={[0]='Veranus',[1]='B495 K0800 L077 A:29445 T:29445 P:13009'},
[13051]={[0]='Territorial Trespass',[1]='B495 K0800 L077 A:29445 T:29445 P:13050'},
[13054]={[0]='The Missing Tracker',[1]='B495 K0800 FH L077 A:30247 T:30469'},
[13055]={[0]='Cave Medicine',[1]='B495 K0800 FH L077 A:30469 T:30469 P:13054'},
[13056]={[0]="There's Always Time for Revenge",[1]='B495 K0800 FH L077 A:30469 T:30469 P:13055'},
[13057]={[0]='The Terrace of the Makers',[1]='B495 K0800 L077 A:30390 T:30295 P:13010'},
[13058]={[0]="Changing the Wind's Course",[1]='B495 K0800 FH L077 A:30381 T:30381'},
[13059]={[0]='Revenge for the Vargul',[1]='B492 K0800 L077 A:30406 T:30406'},
[13060]={[0]='When All Else Fails',[1]='B495 K0780 FH L077 A:29428 T:30472'},
[13061]={[0]='Prepare for Glory',[1]='B495 K0790 L077 A:29839 T:29975 P:12997'},
[13062]={[0]="Lok'lira's Parting Gift",[1]='B495 K0800 L077 A:29975 T:29796 P:13061'},
[13063]={[0]='Deemed Worthy',[1]='B495 K0800 L077 A:29592 T:29839 P:12856'},
[13064]={[0]='Sibling Rivalry',[1]='B495 K0800 L077 A:29445 T:29445 P:12886'},
[13065]={[0]='Ohanzee the Elder',[1]='B0 SP HL +Y A:30537 T:30537'},
[13066]={[0]='Yurauk the Elder',[1]='B0 SP HL +Y A:30535 T:30535'},
[13067]={[0]="Chogan'gada the Elder",[1]='B0 SP HL +Y A:30538 T:30538'},
[13068]={[0]='A Tale of Valor',[1]='B492 K0800 L077 A:31044 T:30562'},
[13069]={[0]="Shoot 'Em Up",[1]='B0 +D K0800 L077 A:30074 T:30074'},
[13070]={[0]='A Cold Front Approaches',[1]='B492 K0780 L077 A:28179 T:30657 P:13045'},
[13071]={[0]='Vile Like Fire!',[1]='B0 +D K0800 L077 A:30216 T:30216 P:12992'},
[13072]={[0]='A Hero Remains',[1]='B492 K0800 L077 A:30562 T:31044 P:13068'},
[13073]={[0]="The Keeper's Favor",[1]='B492 K0800 L077 A:31044 T:11832 P:13072'},
[13074]={[0]='Hope Within the Emerald Nightmare',[1]='B492 K0800 L077 A:11832 T:11832 P:13073'},
[13075]={[0]='The Boon of Remulos',[1]='B492 K0800 L077 A:11832 T:30562 P:13074 B492'},
[13076]={[0]='Time Yet Remains',[1]='B492 K0800 L077 A:30562 T:31044'},
[13077]={[0]='The Touch of an Aspect',[1]='B492 K0800 L077 A:31044 T:26917 P:13076 B488'},
[13078]={[0]="Dahlia's Tears",[1]='B488 K0800 L077 A:26917 T:26917 P:13077'},
[13079]={[0]='The Boon of Alexstrasza',[1]='B492 K0800 L077 A:26917 T:30562 P:13078 B492'},
[13080]={[0]='Hope Yet Remains',[1]='B492 K0800 L077 A:30562 T:31044'},
[13081]={[0]='The Will of the Naaru',[1]='B492 K0800 L077 A:31044 T:18481 P:13080'},
[13082]={[0]="The Boon of A'dal",[1]='B492 K0800 L077 A:18481 T:30562 P:13081 B492'},
[13083]={[0]='Light Within the Darkness',[1]='B492 K0800 L077 A:1192833 T:31044'},
[13084]={[0]='Vandalizing Jotunheim',[1]='B492 K0800 L077 A:30002 T:30002'},
[13085]={[0]='Vaelen Has Returned',[1]='B492 K0800 L077 A:29343 T:30218'},
[13086]={[0]='The Last Line Of Defense',[1]='B492 K0780 L077 A:30657 T:30657 P:13070'},
[13087]={[0]='Northern Cooking',[1]='B0 FA L065 PC350 A:26905 T:26905'},
[13088]={[0]='Northern Cooking',[1]='B0 FA L065 PC350 A:26989 T:26989'},
[13089]={[0]='Northern Cooking',[1]='B0 FH L065 PC350 A:26953 T:26953'},
[13090]={[0]='Northern Cooking',[1]='B0 FH L065 PC350 A:26972 T:26972'},
[13091]={[0]='The Art of Being a Water Terror',[1]='B492 K0800 L077 A:30232 T:30232 P:13043'},
[13092]={[0]='Reading the Bones',[1]='B492 K0800 L077 A:30232 T:30232'},
[13093]={[0]='Reading the Bones',[1]='B0 K0800 ++ L077 A:30232 T:30232'},
[13094]={[0]='Have They No Shame?',[1]='B0 K0710 FA L068 A:26110 T:26110'},
[13095]={[0]='Have They No Shame?',[1]='B0 K0710 FH L068 A:26110 T:26110'},
[13096]={[0]="Gal'darah Must Pay",[1]='B0 K0780 L074 A:30671 T:30671 P:13097'},
[13097]={[0]='Unfinished Business',[1]='B496 K0780 L074 A:28401 T:30671 P:1'},
[13098]={[0]='For Posterity',[1]='B0 K0780 L074 A:30676 T:30676 O:13099'},
[13099]={[0]="Just Checkin'",[1]='B496 K0780 L074 A:28527 T:30676 I:13098'},
[13100]={[0]='Infused Mushroom Meatloaf',[1]='B0 +D FA K0770 L065 A:28705 T:29527 I:13101,13102,13103,13107'},
[13101]={[0]='Convention at the Legerdemain',[1]='B0 +D FA K0770 L065 A:28705 T:29049 I:13100,13102,13103,13107'},
[13102]={[0]='Sewer Stew',[1]='B0 +D FA K0770 L065 A:28705 T:29532 I:13100,13101,13103,13107'},
[13103]={[0]='Cheese for Glowergold',[1]='B0 +D FA K0770 L065 A:28705 T:28718 I:13100,13101,13102,13107'},
[13104]={[0]='Once More Unto The Breach, Hero',[1]='B492 XK K0780 L077 A:30677 T:30596'},
[13105]={[0]='Once More Unto The Breach, Hero',[1]='B492 CK K0780 L077 A:30677 T:30596'},
[13106]={[0]='Blackwatch',[1]='B492 K0800 L077 A:29343 T:30631'},
[13107]={[0]='Mustard Dogs!',[1]='B0 +D FA K0800 L065 A:28705 T:28160 I:13100,13101,13102,13103'},
[13108]={[0]='Whatever it Takes!',[1]='B0 K0800 L077 A:30105 T:30105 P:13047'},
[13109]={[0]='Diametrically Opposed',[1]='B0 K0800 L077 A:30105 T:30105'},
[13110]={[0]='The Restless Dead',[1]='B492 K0780 L077 A:30683 T:30683'},
[13111]={[0]='One of a Kind',[1]='B0 K0780 L074 A:30676 T:30676'},
[13112]={[0]='Infused Mushroom Meatloaf',[1]='B0 +D FH K0010 L065 A:29631 T:29527 I:13113,13114,13115,13116'},
[13113]={[0]='Convention at the Legerdemain',[1]='B0 +D FH K0010 L065 A:29631 T:29049 I:13112,13114,13115,13116'},
[13114]={[0]='Sewer Stew',[1]='B0 +D FH K0010 L065 A:29631 T:29532 I:13112,13113,13115,13116'},
[13115]={[0]='Cheese for Glowergold',[1]='B0 +D FH K0010 L065 A:29631 T:28718 I:13112,13113,13114,13116'},
[13116]={[0]='Mustard Dogs!',[1]='B0 +D FH K0010 L065 A:29631 T:28160 I:13112,13113,13114,13115'},
[13117]={[0]='Where Are They Coming From?',[1]='B492 K0800 L077 A:30631 T:30631'},
[13118]={[0]='The Purging Of Scourgeholme',[1]='B492 K0780 L077 A:30596 T:30596'},
[13119]={[0]='Destroying the Altars',[1]='B492 K0800 L077 A:30631 T:30631'},
[13120]={[0]="Death's Gaze",[1]='B492 K0800 L077 A:30631 T:30631'},
[13121]={[0]='Through the Eye',[1]='B492 K0800 L077 A:30232 T:30232 P:13091'},
[13122]={[0]='The Scourgestone',[1]='B492 K0780 L077 A:30596 T:30596'},
[13124]={[0]='The Struggle Persists',[1]='B504956 K0800 L077 A:26117 T:27658'},
[13125]={[0]='The Air Stands Still',[1]='B492 K0790 L077 A:30596 T:30596'},
[13126]={[0]='A Unified Front',[1]='B0 K0800 L077 A:27658 T:28012 P:13124'},
[13127]={[0]='Mage-Lord Urom',[1]='B0 K0800 L077 A:28012 T:28012 P:13126'},
[13128]={[0]='A Wing and a Prayer',[1]='B0 K0800 L077 A:28012 T:26117 P:13127'},
[13129]={[0]='Head Games',[1]='B0 K0740 L072 A:26664 T:26604 P:12037'},
[13130]={[0]='The Stone That Started A Revolution',[1]='B492 K0790 L077 A:30686 T:30686'},
[13131]={[0]='Junk in My Trunk',[1]='B504956 K0800 L078 A:30871 T:30871'},
[13132]={[0]='Vengeance Be Mine!',[1]='B0 K0800 L078 A:30871 T:30871'},
[13133]={[0]='Find the Ancient Hero',[1]='B492 K0800 L077 A:30232 T:30232 P:13121'},
[13134]={[0]='Spill Their Blood',[1]='B492 K0800 L077 A:30631 T:30631'},
[13135]={[0]='It Could Kill Us All',[1]='B492 K0790 L077 A:30714 T:30714'},
[13136]={[0]='Jagged Shards',[1]='B492 K0800 L077 A:100043242 T:30708'},
[13137]={[0]='Not-So-Honorable Combat',[1]='B492 K0800 L077 A:30232 T:30232 P:13133'},
[13138]={[0]="I'm Smelting... Smelting!",[1]='B492 K0800 L077 A:30708 T:30708'},
[13139]={[0]='Into The Frozen Heart Of Northrend',[1]='B492 K0790 L077 A:30683 T:30677'},
[13140]={[0]='The Runesmiths of Malykriss',[1]='B492 K0800 L077 A:30708 T:30708'},
[13141]={[0]="The Battle For Crusaders' Pinnacle",[1]='B492 K0790 L077 A:30677 T:30683 P:13139'},
[13142]={[0]="Banshee's Revenge",[1]='B492 K0800 L077 A:30232 T:30232 P:13137'},
[13143]={[0]='New Recruit',[1]='B492 K0800 L077 A:30944 T:30944 P:13155'},
[13144]={[0]='Killing Two Scourge With One Skeleton',[1]='B492 K0800 L077 A:30631 T:30631'},
[13145]={[0]='The Vile Hold',[1]='B492 K0800 L077 A:30944 T:30944 P:13143'},
[13146]={[0]='Generosity Abounds',[1]='B492 K0800 L077 A:30944 T:30944'},
[13147]={[0]='Matchmaker',[1]='B492 K0800 L077 A:30944 T:30944'},
[13148]={[0]='Necklace Repair',[1]='B0 L077 PJ375 A:100043297 T:28701'},
[13149]={[0]='Dispelling Illusions',[1]='B504956 K0800 L078 A:26527 T:27915'},
[13151]={[0]='A Royal Escort',[1]='B0 K0800 L078 A:27915 T:30997 P:13149'},
[13152]={[0]='A Visit to the Doctor',[1]='B492 K0800 L077 A:30631 T:30631'},
[13153]={[0]='Warding the Warriors',[1]='B0 K0800 +W FA L078 A:31051 T:31051'},
[13154]={[0]='Bones and Arrows',[1]='B0 K0800 +W FA L078 A:31052 T:31052'},
[13155]={[0]='Vereth the Cunning',[1]='B492 K0800 L077 A:30946 T:30944'},
[13156]={[0]='A Rare Herb',[1]='B0 K0800 +W FA L078 A:31054 T:31054'},
[13157]={[0]="The Crusaders' Pinnacle",[1]='B492 K0790 L077 A:30683 T:31044 P:13141'},
[13158]={[0]='Discretion is Key',[1]='B504956 K0770 L075 A:16128 T:31080'},
[13159]={[0]='Containment',[1]='B504956 K0770 L075 A:31080 T:31080 P:13158'},
[13160]={[0]='Stunning View',[1]='B492 K0800 L077 A:30944 T:30944'},
[13161]={[0]='The Rider of the Unholy',[1]='B492 K0800 L077 A:30944 T:30944'},
[13162]={[0]='The Rider of Frost',[1]='B492 K0800 L077 A:30944 T:30944'},
[13163]={[0]='The Rider of Blood',[1]='B492 K0800 L077 A:30944 T:30944'},
[13164]={[0]='The Fate of Bloodbane',[1]='B492 K0800 L077 A:30944 T:30944'},
[13165]={[0]='Taking Back Acherus',[1]='B0 K0550 CK L055 A:29173 T:31084 P:12801'},
[13166]={[0]='The Battle For The Ebon Hold',[1]='B0 K0550 CK L055 A:31084 T:31084 P:13165'},
[13167]={[0]='Death to the Traitor King',[1]='B0 K0740 L072 A:26653 T:26653'},
[13168]={[0]='Parting Gifts',[1]='B492 K0800 L077 A:30946 T:30946'},
[13169]={[0]="An Undead's Best Friend",[1]='B492 K0800 L077 A:30946 T:30946'},
[13170]={[0]='Honor is for the Weak',[1]='B492 K0800 L077 A:30946 T:30946'},
[13171]={[0]='From Whence They Came',[1]='B492 K0800 L077 A:30946 T:30946'},
[13172]={[0]='Seeds of Chaos',[1]='B492 K0800 L077 A:30946 T:30946'},
[13174]={[0]='Amidst the Confusion',[1]='B492 K0800 L077 A:30946 T:30946'},
[13177]={[0]='No Mercy for the Merciless',[1]='B0 K0800 +W FA L078 A:31036 T:31036'},
[13178]={[0]='Slay them all!',[1]='B0 K0800 +W FH L078 A:31091 T:31091'},
[13179]={[0]='No Mercy for the Merciless',[1]='B0 K0800 +W FA L078 A:31036 T:31036'},
[13180]={[0]='Slay them all!',[1]='B0 K0800 +W FH L078 A:31091 T:31091'},
[13181]={[0]='Victory in Wintergrasp',[1]='B0 K0800 +W FA L078 A:31153 T:31153'},
[13182]={[0]="Don't Forget the Eggs!",[1]='B0 K0740 L072 A:26653 T:26653'},
[13183]={[0]='Victory in Wintergrasp',[1]='B0 K0800 +W FH L078 A:31151 T:31151'},
[13185]={[0]='Stop the Siege',[1]='B0 K0800 +W FH L078 A:31107 T:31107'},
[13186]={[0]='Stop the Siege',[1]='B0 K0800 +W FA L078 A:31109 T:31109'},
[13187]={[0]='The Faceless Ones',[1]='B0 K0760 L073 A:26653 T:26653'},
[13188]={[0]='Where Kings Walk',[1]='B0 K0550 FA CK L055 A:31084 T:29611'},
[13189]={[0]="Warchief's Blessing",[1]='B0 K0550 FH CK L055 A:31084 T:39605,45530'},
[13190]={[0]='All Things in Good Time',[1]='B0 +D K08064 L080 A:26653 T:26653'},
[13191]={[0]='Fueling the Demolishers',[1]='B0 K0800 +W FH L078 A:31106 T:31106'},
[13192]={[0]='Warding the Walls',[1]='B0 K0800 +W FH L078 A:31101 T:31101'},
[13193]={[0]='Bones and Arrows',[1]='B0 K0800 +W FH L078 A:31102 T:31102'},
[13194]={[0]='Healing with Roses',[1]='B0 K0800 +W FH L078 A:31053 T:31053'},
[13195]={[0]='A Rare Herb',[1]='B0 K0800 +W FA L078 A:31054 T:31054'},
[13196]={[0]='Bones and Arrows',[1]='B0 K0800 +W FA L078 A:31052 T:31052'},
[13197]={[0]='Fueling the Demolishers',[1]='B0 K0800 +W FA L078 A:31108 T:31108'},
[13198]={[0]='Warding the Warriors',[1]='B0 K0800 +W FA L078 A:31051 T:31051'},
[13199]={[0]='Bones and Arrows',[1]='B0 K0800 +W FH L078 A:31102 T:31102'},
[13200]={[0]='Fueling the Demolishers',[1]='B0 K0800 +W FH L078 A:31106 T:31106'},
[13201]={[0]='Healing with Roses',[1]='B0 K0800 +W FH L078 A:31053 T:31053'},
[13202]={[0]='Jinxing the Walls',[1]='B0 K0800 +W FH L078 A:31101 T:31101'},
[13203]={[0]='A Winter Veil Gift',[1]='B0 HV L010'},
[13204]={[0]='Funky Fungi',[1]='B0 K0760 L073 A:100043512 T:26653'},
[13205]={[0]='Disarmament',[1]='B504956 K0710 FA L068 A:24111 T:24111'},
[13206]={[0]='Disarmament',[1]='B0 K0710 FH L068 A:24137 T:23780'},
[13207]={[0]='Halls of Stone',[1]='B504956 K0780 L076 A:28070 T:28070'},
[13211]={[0]='By Fire Be Purged',[1]='B492 K0800 L077 A:30708 T:30708'},
[13212]={[0]="He's Gone to Pieces",[1]='B492 K0800 L077 A:30631 T:30631'},
[13213]={[0]='Battle at Valhalas',[1]='B492 K0800 L077 A:30232 T:31135 P:13142'},
[13214]={[0]='Battle at Valhalas: Fallen Heroes',[1]='B492 K0800 L077 A:31135 T:31154'},
[13215]={[0]="Battle at Valhalas: Khit'rix the Dark Master",[1]='B492 K0800 L077 A:31135 T:31154'},
[13216]={[0]='Battle at Valhalas: The Return of Sigrid Iceborn',[1]='B492 K0800 L077 A:31135 T:31154'},
[13217]={[0]='Battle at Valhalas: Carnage!',[1]='B492 K0800 L077 A:31135 T:31154'},
[13218]={[0]='Battle at Valhalas: Thane Deathblow',[1]='B492 K0800 L077 A:31135 T:31154'},
[13219]={[0]='Battle at Valhalas: Final Challenge',[1]='B492 K0800 L077 A:31135 T:31154'},
[13220]={[0]='Putting Olakin Back Together Again',[1]='B492 K0800 L077 A:30631 T:30631 P:13212'},
[13221]={[0]="I'm Not Dead Yet!",[1]='B492 FA K0800 L077 A:31279 T:31259'},
[13222]={[0]='Defend the Siege',[1]='B0 K0800 +W FA L078 A:31109 T:31109'},
[13223]={[0]='Defend the Siege',[1]='B0 K0800 +W FH L078 A:31107 T:31107'},
[13224]={[0]="Orgrim's Hammer",[1]='B492 K0790 FH L077 A:31240 T:30824'},
[13225]={[0]='The Skybreaker',[1]='B492 FA K0790 L077 A:31241 T:30344'},
[13226]={[0]='Judgment Day Comes!',[1]='B492 FA K0780 L077 A:31259 T:28179'},
[13227]={[0]='Judgment Day Comes!',[1]='B492 K0780 FH L077 A:31261 T:28179'},
[13228]={[0]='The Broken Front',[1]='B492 K0800 FH L077 A:30824 T:30824'},
[13229]={[0]="I'm Not Dead Yet!",[1]='B492 K0800 FH L077 A:31279 T:31261'},
[13230]={[0]='Avenge Me!',[1]='B492 K0800 FH L077 A:31273 T:30824'},
[13231]={[0]='The Broken Front',[1]='B492 FA K0800 L077 A:30344 T:30344'},
[13232]={[0]='Finish Me!',[1]='B492 FA K0800 L077 A:31304 T:30344'},
[13233]={[0]='No Mercy!',[1]='B0 +D FA K080256 L077 A:30344 T:30344'},
[13234]={[0]='Make Them Pay!',[1]='B0 +D FH K080256 L077 A:30824 T:30824'},
[13235]={[0]='The Flesh Giant Champion',[1]='B492 K0800 L077 A:30631 T:30631 P:13220'},
[13236]={[0]='Army of the Damned',[1]='B492 K0800 FH L077 A:32404 T:32404 P:13305'},
[13237]={[0]='Poke and Prod',[1]='B492 K0800 FH L077 A:29795 T:29795 P:13260,14447,14448'},
[13238]={[0]='Good For Something?',[1]='B492 K0800 FH L077 A:30824 T:30825'},
[13239]={[0]='Volatility',[1]='B492 K0800 FH L077 A:30825 T:30825 P:13238'},
[13258]={[0]='Opportunity',[1]='B492 K0800 FH L077 A:29795 T:31440'},
[13259]={[0]='Establishing Superiority',[1]='B492 K0800 FH L077 A:31440 T:31440 P:13258'},
[13260]={[0]='Takes One to Know One',[1]='B492 K0800 FH L077 A:30824 T:29795'},
[13261]={[0]='Volatility',[1]='B0 +D FH K0800 L077 A:30825 T:30825'},
[13262]={[0]='Blow it Up!',[1]='B0 K0800 FH L077 A:31440 T:1193400 P:13259'},
[13263]={[0]='A Short Fuse',[1]='B492 K0800 FH L077 A:1193400 T:1193195 P:13262'},
[13264]={[0]="That's Abominable!",[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13265]={[0]='Cloth Scavenging',[1]='B0 FA A:27001 T:27001'},
[13268]={[0]='Cloth Scavenging',[1]='B0 FA A:26914 T:26914'},
[13269]={[0]='Cloth Scavenging',[1]='B0 FH A:26964 T:26964'},
[13270]={[0]='Cloth Scavenging',[1]='B0 FH A:26969 T:26969'},
[13271]={[0]='A Voice in the Dark',[1]='B492 K0800 FH L077 A:1193195 T:31237 P:13263'},
[13272]={[0]='Cloth Scavenging',[1]='B0 A:28699 T:28699'},
[13273]={[0]='Going After the Core',[1]='B495 K0800 FH L077 A:29579 T:29579'},
[13274]={[0]="The Core's Keeper",[1]='B495 K0800 FH L077 A:29579 T:29579 P:13273'},
[13275]={[0]='Time to Hide',[1]='B492 K0800 FH L077 A:31237 T:31237 P:13271'},
[13276]={[0]="That's Abominable!",[1]='B0 +D FH K0800 L077 A:29795 T:29795'},
[13277]={[0]='Against the Giants',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13278]={[0]='Coprous the Defiled',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13279]={[0]='Basic Chemistry',[1]='B492 K0800 FH L077 A:29795 T:29795 P:13277'},
[13280]={[0]='King of the Mountain',[1]='B492 +D FA K080256 L077 A:31776 T:31776 P:13296'},
[13281]={[0]='Neutralizing the Plague',[1]='B0 +D FH K0800 L077 A:29795 T:29795'},
[13282]={[0]='Return to the Surface',[1]='B492 K0800 FH L077 A:31237 T:29795 P:13275'},
[13283]={[0]='King of the Mountain',[1]='B492 +D FH K080256 L077 A:31781 T:31781 P:13293'},
[13284]={[0]='Assault by Ground',[1]='B0 +D FA K0800 L077 A:31737 T:31808'},
[13285]={[0]='Forging the Keystone',[1]='B495 K0800 FH L077 A:29579 T:29651 P:13274'},
[13286]={[0]='...All the Help We Can Get.',[1]='B492 FA K0800 L077 A:30344 T:29799'},
[13287]={[0]='Poke and Prod',[1]='B492 FA K0800 L077 A:29799 T:29799 P:13286'},
[13288]={[0]="That's Abominable!",[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13289]={[0]="That's Abominable!",[1]='B0 +D FA K0800 L077 A:29799 T:29799'},
[13290]={[0]='Your Attention, Please',[1]='B492 FA K0800 L077 A:30344 T:30345'},
[13291]={[0]='Borrowed Technology',[1]='B492 FA K0800 L077 A:30345 T:30345 P:13290'},
[13292]={[0]='The Solution Solution',[1]='B0 +D FA K0800 L077 A:30345 T:30345'},
[13293]={[0]='Get to Ymirheim!',[1]='B492 K0800 FH L077 A:30825 T:31781'},
[13294]={[0]='Against the Giants',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13295]={[0]='Basic Chemistry',[1]='B492 FA K0800 L077 A:29799 T:29799 P:13294'},
[13296]={[0]='Get to Ymirheim!',[1]='B492 FA K0800 L077 A:30345 T:31776'},
[13297]={[0]='Neutralizing the Plague',[1]='B0 +D FA K0800 L077 A:29799 T:29799'},
[13298]={[0]='Coprous the Defiled',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13300]={[0]='Slaves to Saronite',[1]='B0 +D FA K0800 L077 A:31259 T:31259'},
[13301]={[0]='Assault by Ground',[1]='B0 +D FH K0800 L077 A:31833 T:31834'},
[13302]={[0]='Slaves to Saronite',[1]='B0 +D FH K0800 L077 A:31261 T:31261'},
[13304]={[0]='Field Repairs',[1]='B492 K0800 FH L077 A:29795 T:31868 P:13282'},
[13305]={[0]='Do Your Worst',[1]='B492 K0800 FH L077 A:32408 T:32404'},
[13306]={[0]='Raise the Barricades',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13307]={[0]='Bloodspattered Banners',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13308]={[0]='Mind Tricks',[1]='B492 K0800 L077 A:31892 T:31892'},
[13309]={[0]='Assault by Air',[1]='B0 +D FA K0800 L077 A:31808 T:31808'},
[13310]={[0]='Assault by Air',[1]='B0 +D FH K0800 L077 A:31834 T:31834'},
[13311]={[0]='Demons Deck',[1]='B0 K0450 L040 A:100044158 T:30481'},
[13312]={[0]='The Ironwall Rampart',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13313]={[0]='Blinding the Eyes in the Sky',[1]='B492 K0800 FH L077 A:30824 T:30824'},
[13314]={[0]='Get the Message',[1]='B492 FA K0800 L077 A:30344 T:30344'},
[13315]={[0]='Sneak Preview',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13316]={[0]="The Guardians of Corp'rethar",[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13318]={[0]='Drag and Drop',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13319]={[0]='Chain of Command',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13320]={[0]='Cannot Reproduce',[1]='B492 FA K0800 L077 A:29799 T:30345'},
[13321]={[0]='Retest Now',[1]='B492 FA K0800 L077 A:30345 T:30345 P:13320'},
[13322]={[0]='Retest Now',[1]='B0 +D FA K0800 L077 A:30345 T:30345'},
[13323]={[0]='Drag and Drop',[1]='B0 +D FA K0800 L077 A:29799 T:29799'},
[13324]={[0]='Darkmoon Prisms Deck',[1]='B0 K0800 A:100044259 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[13325]={[0]='Darkmoon Chaos Deck',[1]='B0 K0800 A:100044276 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[13326]={[0]='Darkmoon Nobles Deck',[1]='B0 K0800 A:100044326 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[13327]={[0]='Darkmoon Undeath Deck',[1]='B0 K0800 A:100044294 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[13328]={[0]='Shatter the Shards',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13329]={[0]='Before the Gate of Horror',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13330]={[0]='Blood of the Chosen',[1]='B0 +D FH K0800 L077 A:32301 T:32301'},
[13331]={[0]='Keeping the Alliance Blind',[1]='B0 +D FH K0800 L077 A:30824 T:30824'},
[13332]={[0]='Raise the Barricades',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13333]={[0]='Capture More Dispatches',[1]='B0 +D FA K0800 L077 A:30344 T:30344'},
[13334]={[0]='Bloodspattered Banners',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13335]={[0]='Before the Gate of Horror',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13336]={[0]='Blood of the Chosen',[1]='B0 +D FA K0800 L077 A:32302 T:32302'},
[13337]={[0]='The Ironwall Rampart',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13338]={[0]="The Guardians of Corp'rethar",[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13339]={[0]='Shatter the Shards',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13340]={[0]='Joining the Assault',[1]='B492 K0800 FH L077 A:32301 T:31834'},
[13341]={[0]='Joining the Assault',[1]='B492 FA K0800 L077 A:32302 T:31808'},
[13342]={[0]='Not a Bug',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13343]={[0]='Mystery of the Infinite, Redux',[1]='B488 K0800 L080 A:27856 T:27856'},
[13344]={[0]='Not a Bug',[1]='B0 +D FA K0800 L077 A:29799 T:29799'},
[13345]={[0]='Need More Info',[1]='B492 FA K0800 L077 A:29799 T:29799'},
[13346]={[0]='No Rest For The Wicked',[1]='B492 FA K0800 L077 A:29799 T:29799 P:13345'},
[13348]={[0]='Futility',[1]='B492 K0800 FH L077 A:32404 T:29795 P:13236'},
[13349]={[0]='Cradle of the Frostbrood',[1]='B492 K0800 FH L077 A:29795 T:29795 P:13348'},
[13350]={[0]='No Rest For The Wicked',[1]='B0 +D FA K0800 L077 A:29799 T:29799'},
[13351]={[0]='Sneak Preview',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13352]={[0]='Drag and Drop',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13353]={[0]='Drag and Drop',[1]='B0 +D FH K0800 L077 A:29795 T:29795'},
[13354]={[0]='Chain of Command',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13355]={[0]='Cannot Reproduce',[1]='B492 K0800 FH L077 A:29795 T:30825'},
[13356]={[0]='Retest Now',[1]='B492 K0800 FH L077 A:30825 T:30825 P:13355'},
[13357]={[0]='Retest Now',[1]='B0 +D FH K0800 L077 A:30825 T:30825'},
[13358]={[0]='Not a Bug',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13359]={[0]='Where Dragons Fell',[1]='B492 K0800 FH L077 A:32423 T:32423'},
[13360]={[0]='Time for Answers',[1]='B492 K0800 FH L077 A:32423 T:32497'},
[13361]={[0]='The Hunter and the Prince',[1]='B492 K0800 FH L077 A:32497 T:32497 P:13360'},
[13362]={[0]='Knowledge is a Terrible Burden',[1]='B492 K0800 FH L077 A:32497 T:29795 P:13361'},
[13363]={[0]='Argent Aid',[1]='B492 K0800 FH L077 A:29795 T:31044'},
[13364]={[0]="Tirion's Gambit",[1]='B492 K0800 FH L077 A:31044 T:31044 P:13363'},
[13365]={[0]='Not a Bug',[1]='B0 +D FH K0800 L077 A:29795 T:29795'},
[13366]={[0]='Need More Info',[1]='B492 K0800 FH L077 A:29795 T:29795'},
[13367]={[0]='No Rest For The Wicked',[1]='B492 K0800 FH L077 A:29795 T:29795 P:13366'},
[13368]={[0]='No Rest For The Wicked',[1]='B0 +D FH K0800 L077 A:29795 T:29795'},
[13372]={[0]='The Key to the Focusing Iris',[1]='B488 K0800 L080 A:100044569 T:26917'},
[13373]={[0]='Fringe Science Benefits',[1]='B492 K0800 FH L077 A:32430 T:32430 P:13379'},
[13375]={[0]='The Heroic Key to the Focusing Iris',[1]='B488 K0800 L080 A:100044577 T:26917'},
--[13376]={[0]='Total Ohmage: The Valley of Lost Hope!',[1]='+D FH K0800 L077 A:32430 T:32430 P:13374'},
[13379]={[0]='Green Technology',[1]='B492 K0800 FH L077 A:30825 T:32430'},
[13380]={[0]='Leading the Charge',[1]='B492 FA K0800 L077 A:32444 T:32444 P:13383'},
--[13382]={[0]='Putting the Hertz: The Valley of Lost Hope',[1]='+D FA K0800 L077 A:32444 T:32444 P:13381'},
[13383]={[0]='Killohertz',[1]='B492 FA K0800 L077 A:30345 T:32444'},
[13384]={[0]='Judgment at the Eye of Eternity',[1]='B0 K0800 L080 A:27990 T:27990'},
[13385]={[0]='Heroic Judgment at the Eye of Eternity',[1]='B0 K0800 L080 A:27990 T:27990'},
[13386]={[0]='Exploiting an Opening',[1]='B492 FA K0800 L077 A:29799 T:31444'},
[13387]={[0]='Securing the Perimeter',[1]='B492 FA K0800 L077 A:31444 T:31444 P:13386'},
[13388]={[0]='Set it Off!',[1]='B0 FA K0800 L077 A:31444 T:1193400 P:13387'},
[13389]={[0]='A Short Fuse',[1]='B492 FA K0800 L077 A:1193400 T:1193195 P:13388'},
[13390]={[0]='A Voice in the Dark',[1]='B492 FA K0800 L077 A:1193195 T:31237 P:13389'},
[13391]={[0]='Time to Hide',[1]='B492 FA K0800 L077 A:31237 T:31237 P:13390'},
[13392]={[0]='Return to the Surface',[1]='B492 FA K0800 L077 A:31237 T:29799 P:13391'},
[13393]={[0]='Field Repairs',[1]='B492 FA K0800 L077 A:29799 T:31868 P:13392'},
[13394]={[0]='Do Your Worst',[1]='B492 FA K0800 L077 A:32408 T:32404'},
[13395]={[0]='Army of the Damned',[1]='B492 FA K0800 L077 A:32404 T:32404 P:13394'},
[13396]={[0]='Futility',[1]='B492 FA K0800 L077 A:32404 T:29799 P:13395'},
[13397]={[0]="Sindragosa's Fall",[1]='B492 FA K0800 L077 A:29799 T:29799 P:13396'},
[13398]={[0]='Where Dragons Fell',[1]='B492 FA K0800 L077 A:32423 T:32423'},
[13399]={[0]='Time for Answers',[1]='B492 FA K0800 L077 A:32423 T:32497 P:13398'},
[13400]={[0]='The Hunter and the Prince',[1]='B492 FA K0800 L077 A:32497 T:32497 P:13399'},
[13401]={[0]='Knowledge is a Terrible Burden',[1]='B492 FA K0800 L077 A:32497 T:29799 P:13400'},
[13402]={[0]="Tirion's Help",[1]='B492 FA K0800 L077 A:29799 T:31044 P:13401'},
[13403]={[0]="Tirion's Gambit",[1]='B492 FA K0800 L077 A:31044 T:31044 P:13402'},
[13404]={[0]='Static Shock Troops: the Bombardment',[1]='B0 +D FA K0800 L077 A:32444 T:32444'},
[13406]={[0]='Riding the Wavelength: The Bombardment',[1]='B0 +D FH K0800 L077 A:32430 T:32430'},
[13408]={[0]='Hellfire Fortifications',[1]='B465 FA XK K060256 L055 A:18266 T:18266'},
[13409]={[0]='Hellfire Fortifications',[1]='B465 FH XK K060256 L055 A:18267 T:18267'},
[13410]={[0]='Hellfire Fortifications',[1]='B465 FA CK K060256 L055 A:18266 T:18266'},
[13411]={[0]='Hellfire Fortifications',[1]='B465 FH CK K060256 L055 A:18267 T:18267'},
[13412]={[0]='Corastrasza',[1]='B0 K0800 L080 A:26110 T:32548 P:11919'},
[13413]={[0]='Aces High!',[1]='B486 K0800 L080 A:32548 T:32548 P:13412'},
[13414]={[0]='Aces High!',[1]='B0 +D K0800 L080 A:32548 T:32548 P:13413'},
[13415]={[0]='The Library Console',[1]='B495 K0800 FA L077 A:29579 T:1191760 P:12860'},
[13416]={[0]='The Library Console',[1]='B495 K0800 FH L077 A:29579 T:1191760 P:12927'},
[13418]={[0]='Preparations for War',[1]='B492 K0800 FA L077 A:31081 T:30344 B492'},
[13419]={[0]='Preparations for War',[1]='B492 K0800 FH ++ L077 A:31085 T:30824 B492'},
[13420]={[0]='Everfrost',[1]='B495 K0770 L077 A:100044725 T:32594'},
[13421]={[0]='Remember Everfrost!',[1]='B0 K0770 ++ L077 A:32594 T:32594'},
[13422]={[0]='Maintaining Discipline',[1]='B0 +D K0790 L077 A:29796 T:29796'},
[13423]={[0]='Defending Your Title',[1]='B0 +D K0800 L077 A:29796 T:29796'},
[13424]={[0]='Back to the Pit',[1]='B0 +D K0800 L077 A:29796 T:29796'},
[13425]={[0]='The Aberrations Must Die',[1]='B0 +D K0800 L077 A:29796 T:29796'},
[13426]={[0]='Xarantaur, the Witness',[1]='B495 K0800 FH L077 A:29651 T:30381'},
[13429]={[0]='A Distraction for Akama',[1]='B0 K0700 L070 A:18528 T:18528 P:10949'}, -- just a copy of 10985
[13430]={[0]='Trial of the Naaru: Magtheridon',[1]='B0 K0700 L070 A:18481 T:18481'},
[13431]={[0]="The Cudgel of Kar'desh",[1]='B504956 K0700 FH L070 A:22421'},
[13432]={[0]='The Vials of Eternity',[1]='B0 K0700 L070 A:19935,19936 T:19935 P:1'},
[13433]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062984 T:1062984'},
[13434]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062985 T:1062985'},
[13435]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062986 T:1062986'},
[13436]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062987 T:1062987'},
[13437]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062988 T:1062988'},
[13438]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062989 T:1062989'},
[13439]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062990 T:1062990'},
[13440]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062960'},
[13441]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062961'},
[13442]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062963'},
[13443]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062964'},
[13444]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062966'},
[13445]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062969'},
[13446]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062972'},
[13447]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062973'},
[13448]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062991 T:1062991'},
[13449]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1062977'},
[13450]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062962'},
[13451]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062965'},
[13452]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062993 T:1062993'},
[13453]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062967'},
[13454]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062970'},
[13455]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062971'},
[13456]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062994 T:1062994'},
[13457]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062974'},
[13458]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1062976'},
[13459]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062995 T:1062995'},
[13460]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062996 T:1062996'},
[13461]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062997 T:1062997'},
[13462]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062998 T:1062998'},
[13463]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1062999 T:1062999'},
[13464]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063001 T:1063001'},
[13465]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063002 T:1063002'},
[13466]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063003 T:1063003'},
[13467]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063004 T:1063004'},
[13468]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063005 T:1063005'},
[13469]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063006 T:1063006'},
[13470]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063007 T:1063007'},
[13471]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063008 T:1063008'},
[13472]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1063000 T:1063000'},
[13473]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1062992 T:1062992'},
[13474]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063009 T:1063009'},
[13479]={[0]='The Great Egg Hunt',[1]='B0 FH HN +D A:32798 T:32798'},
[13480]={[0]='The Great Egg Hunt',[1]='B0 FA HN +D A:32799 T:32799'},
[13481]={[0]="Let's Get Out of Here!",[1]='B492 K0800 FH L077 A:32800 T:31261'},
[13482]={[0]="Let's Get Out of Here",[1]='B492 FA K0800 L077 A:32800 T:31259'},
[13483]={[0]='Spring Gatherers',[1]='B0 FH HN T:32798'},
[13484]={[0]='Spring Collectors',[1]='B0 FA HN A:19148,19172 T:32799'},
[13485]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32801'},
[13486]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32802'},
[13487]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32803'},
[13488]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32804'},
[13489]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32805'},
[13490]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32806'},
[13491]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32807'},
[13492]={[0]='Honor the Flame',[1]='B0 HM FA SP A:32808'},
[13493]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32809'},
[13494]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32810'},
[13495]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32811'},
[13496]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32812'},
[13497]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32813'},
[13498]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32814'},
[13499]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32815'},
[13500]={[0]='Honor the Flame',[1]='B0 HM FH SP A:32816'},
[13501]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063012 T:1063012'},
[13502]={[0]='A Tisket, a Tasket, a Noblegarden Basket',[1]='B0 HN A:32837 T:32837'},
[13503]={[0]='A Tisket, a Tasket, a Noblegarden Basket',[1]='B0 HN A:32836 T:32836'},
[13504]={[0]='Shatterspear Laborers',[1]='B42 K0130 FA L010 A:32965 T:32965 P:13589'},
[13505]={[0]='Remnants of the Highborne',[1]='B42 K0130 FA L010 A:32966 T:32966 P:13589'},
[13506]={[0]='Reason to Worry',[1]='B42 K0130 FA L010 A:100044979 T:32963'},
[13507]={[0]='Denying Manpower',[1]='B42 K0130 FA L010 A:32965 T:32965 P:13505'},
[13508]={[0]='Swift Response',[1]='B42 K0130 FA L010 A:32963 T:33055 P:13506'},
[13509]={[0]='War Supplies',[1]='B42 K0130 FA L010 A:32963 T:32963 P:13504'},
[13510]={[0]='Timely Arrival',[1]='B42 K0130 FA L010 A:32964 T:32963 P:13511'},
[13511]={[0]='One Bitter Wish',[1]='B42 K0130 FA L010 A:33055 T:32963 P:13508'},
[13512]={[0]='Strategic Strikes',[1]='B42 K0140 FA L010 A:32963 T:32963 P:13507+13509'},
[13513]={[0]='On the Brink',[1]='B42 K0140 FA L010 A:32966 T:32966 P:13507+13509'},
[13514]={[0]="The Ancients' Ire",[1]='B42 K0140 FA L010 A:33176 T:33176 P:13590'},
[13515]={[0]='Ending the Threat',[1]='B42 K0140 FA L010 A:33178 T:33178 P:13590'},
[13518]={[0]='The Last Wave of Survivors',[1]='B42 K0100 FA L008 A:32973 T:32973 O:26383,26385,28490'},
[13519]={[0]="The Twilight's Hammer",[1]='B42 K0130 FA L013 A:32912 T:32912 P:13591'},
[13520]={[0]='The Boon of the Seas',[1]='B42 K0100 FA L008 A:32972 T:532972 P:13518+13522'},
[13521]={[0]='Buzzbox 413',[1]='B42 K0100 FA L008 A:32977 T:1194105 P:13518+13522'},
[13522]={[0]='Threat from the Water',[1]='B42 K0100 FA L008 A:32971 T:32971'},
[13523]={[0]='Power Over the Tides',[1]='B42 K0130 FA L013 A:32932 T:32932'},
[13525]={[0]="What's Happening to the Blackwood Furbolg?",[1]='B42 K0190 FA L017 A:33250 T:32967 I:13526'},
[13526]={[0]="The Bear's Paw",[1]='B42 K0190 FA L017 A:32967 T:32967 O:13525'},
[13527]={[0]='No Accounting for Taste',[1]='B42 K0110 FA L008 A:1194105 T:32977 P:13521'},
[13528]={[0]='Buzzbox 723',[1]='B42 K0110 FA L008 A:32977 T:1194122 P:13527'},
[13529]={[0]="The Corruption's Source",[1]='B42 K0110 FA L008 A:32978 T:32978 P:13528'},
[13537]={[0]='A Taste for Grouper',[1]='B42 K0110 FA L008 A:33175 T:33175 P:13518+13522'},
[13538]={[0]='Southern Sabotage',[1]='B0 K0800 +W FA L078 A:31153 T:31153'},
[13539]={[0]='Toppling the Towers',[1]='B0 K0800 +W FH L078 A:31151 T:31151'},
[13542]={[0]='Against the Wind',[1]='B42 K0150 FA L013 A:3694 T:3694'},
[13543]={[0]='Three Hammers to Break',[1]='B42 K0150 FA L013 A:32987 T:32987'},
[13544]={[0]="The Bear's Blessing",[1]='B42 K0190 FA L017 A:32967 T:32967 P:13526'},
[13545]={[0]='Cleansing the Afflicted',[1]='B42 K0190 FA L017 A:32967 T:32967 P:13544'},
[13546]={[0]='The Defiler',[1]='B42 K0190 FA L017 A:32967 T:32967 P:13545'},
[13547]={[0]='Coaxing the Spirits',[1]='B42 K0150 FA L013 A:6887 T:6887'},
[13548]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1063047 T:1063047'},
[13549]={[0]='Tails Up',[1]='B496 K0770 L074 A:28527 T:28527 P:12635'},
[13554]={[0]='A Cure In The Dark',[1]='B42 K0110 FA L008 A:1194122 T:32977 P:13528'},
[13556]={[0]="Eggs for Dubra'Jin",[1]='B496 K0770 L074 A:33025 T:33025'},
[13557]={[0]='Bearer of Good Fortune',[1]='B42 K0110 FA L008 A:100044927 T:32978'},
[13558]={[0]='Call Down the Thunder',[1]='B42 K0160 FA L013 A:6887 T:32987 P:13547'},
[13559]={[0]="Hodir's Tribute",[1]='B0 K0800 ++ L077 A:32540 T:32540'},
[13560]={[0]='An Ocean Not So Deep',[1]='B42 K0130 FA L008 A:32979 T:32979 P:13569'},
[13561]={[0]='Solace for the Highborne',[1]='B42 K0110 FA L008 A:33177 T:33177'},
[13562]={[0]="The Final Flame of Bashal'Aran",[1]='B42 K0110 FA L008 A:32971 T:32971 P:13529'},
[13563]={[0]='A Love Eternal',[1]='B42 K0110 FA L008 A:32959,532959 T:32959,532959 P:13529'},
[13564]={[0]='A Lost Companion',[1]='B42 K0110 FA L008 A:32960 T:33048 P:13529'},
[13565]={[0]='Twice Removed',[1]='B42 K0120 FA L010 A:33126 T:33126 P:13564'},
[13566]={[0]='Ritual Materials',[1]='B42 K0120 FA L010 A:33048 T:33048 P:13564'},
[13567]={[0]='Spirit of the Stag',[1]='B42 SP FA A:33133 T:-42 PL:13569 I:13568,13597'},
[13568]={[0]='Spirit of the Moonstalker',[1]='B42 SP FA A:33131 T:-42 PL:13569 I:13567,13597'},
[13569]={[0]='The Ritual Bond',[1]='B42 K0120 FA L010 A:33048 T:33048 P:13565+13566+13598'},
[13570]={[0]='Remembrance of Auberdine',[1]='B42 K0150 FA L010 A:32959,532959 T:32959,532959 P:13591'},
[13571]={[0]="Fletcher's Lost and Found",[1]='B0 K0800 A:32516 T:32516'},
[13572]={[0]='Jadefire Braziers',[1]='B42 K0190 FA L017 A:32968 T:32968 P:13544'},
[13573]={[0]="Malfurion's Return",[1]='B42 K0150 FA L013 A:32987 T:33091'},
[13575]={[0]='The Land Is in Their Blood',[1]='B42 K0150 FA L013 A:33091 T:33117'},
[13576]={[0]='Mutual Aid',[1]='B42 K0150 FA L013 A:33117 T:33117 P:13575'},
[13577]={[0]='The Last Wildkin',[1]='B42 K0160 FA L013 A:33091 T:33119'},
[13578]={[0]="Aroom's Farewell",[1]='B42 K0170 FA L013 A:33119 T:33119 P:13577'},
[13579]={[0]="Protector of Ameth'Aran",[1]='B42 K0150 FA L013 A:33091 T:33112'},
[13580]={[0]='Soothing the Elements',[1]='B42 K0170 FA L013 A:33117 T:33117 P:13576'},
[13581]={[0]='The Blackwood Pledge',[1]='B42 K0150 FA L013 A:33117 T:33091 P:13580'},
[13582]={[0]="Elune's Fire",[1]='B42 K0150 FA L013 A:33119 T:33119 P:13578'},
[13583]={[0]="The Wildkin's Oath",[1]='B42 K0160 FA L013 A:33119 T:33091 P:13582'},
[13584]={[0]='Calming the Earth',[1]='B42 K0160 FA L013 A:33112 T:33112 P:13579'},
[13585]={[0]='Sworn to Protect',[1]='B42 K0170 FA L013 A:33112 T:33091 P:13584'},
[13586]={[0]='The Emerald Dream',[1]='B42 K0170 FA L013 A:33091 T:33166 P:13581+13583+13585'},
[13587]={[0]='The Waking Nightmare',[1]='B42 K0170 FA L013 A:33166 T:33166 P:13586'},
[13588]={[0]='The Eye of All Storms',[1]='B42 K0170 FA L013 A:33091 T:33091 P:13940'},
[13589]={[0]='The Shatterspear Invaders',[1]='B42 K0130 FA L010 A:32971 T:32963 P:13569'},
[13590]={[0]='The Front Line',[1]='B42 K0140 FA L010 A:32963 T:33178 P:13512+13513'},
[13591]={[0]='Disturbing Connections',[1]='B42 K0150 FA L010 A:100046318 T:32971 PL:13515'},
[13592]={[0]="A Valiant's Field Training",[1]='B0 +D FA K0800 L077 A:33222 T:33222'},
[13593]={[0]='Valiant Of Stormwind',[1]='B0 K0800 FA L077 A:33225 T:33225'},
[13594]={[0]="Don't Forget the Horde",[1]='B43 K0210 FA L019 A:33187 T:33187 P:28492'},
[13595]={[0]='Of Their Own Design',[1]='B43 K0210 FA L019 A:33182 T:33182'},
[13596]={[0]='Twilight Plans',[1]='B42 K0130 FA L013 A:32912 T:32912 P:13591'},
[13597]={[0]='Spirit of the Thistle Bear',[1]='B42 SP FA A:33132 T:-42 PL:13569 I:13567,13568'},
[13598]={[0]='Unsavory Remedies',[1]='B42 K0120 FA L010 A:33048 T:33048 P:13564'},
[13599]={[0]="Grimclaw's Return",[1]='B42 K0120 FA L010 A:33048 T:32972 P:13569'},
[13600]={[0]='A Worthy Weapon',[1]='B0 +D FA K0800 L077 A:33225 T:33225'},
[13601]={[0]='In Aid of the Refugees',[1]='B42 K0150 FA L013 A:32912 T:33107 P:13596'},
[13602]={[0]='Naga of the Strand',[1]='B43 K0210 FA L019 A:3845 T:3845'},
[13603]={[0]='A Blade Fit For A Champion',[1]='B0 +D FA K0800 L077 A:33225 T:33225'},
[13604]={[0]='Archivum Data Disc',[1]='B0 K0800 L080 A:100045506 T:1194555'},
[13605]={[0]='The Last Refugee',[1]='B42 K0150 FA L013 A:33232 T:33231'},
[13606]={[0]="Freya's Sigil",[1]='B0 K0800 L080 A:33956 T:33956'},
[13607]={[0]='The Celestial Planetarium',[1]='B0 K0800 L080 A:33956 T:33956'},
[13609]={[0]="Hodir's Sigil",[1]='B0 K0800 L080 A:33956 T:33956'},
[13610]={[0]="Thorim's Sigil",[1]='B0 K0800 L080 A:33956 T:33956'},
[13611]={[0]="Mimiron's Sigil",[1]='B0 K0800 L080 A:33956 T:33956'},
[13612]={[0]="Mor'shan Defense",[1]='B43 K0210 FH L019 A:8582 T:8582 P:28493,28876'},
[13613]={[0]='Rescue the Fallen',[1]='B43 K0210 FH L019 A:33263 T:33263'},
[13614]={[0]='Algalon',[1]='B0 K0800 L080 A:33956 T:1194555'},
[13615]={[0]='Empty Quivers',[1]='B43 K0210 FH L019 A:33284 T:33284'},
[13616]={[0]='The Edge Of Winter',[1]='B0 +D FA K0800 L077 A:33225 T:33225'},
[13617]={[0]='West to the Strand',[1]='B43 K0210 FA L019 A:33187 T:3846 P:13594 I:26465'},
[13618]={[0]='Find Gorat!',[1]='B43 K0210 FH L019 A:8582 T:33294'},
[13619]={[0]='Final Report',[1]='B43 K0210 FH L019 A:33294 T:8582 P:13618 B11'},
[13620]={[0]='To Dinah, at Once!',[1]='B43 K0210 FH L019 A:8582 T:33263 P:13619'},
[13621]={[0]="Gorat's Vengeance",[1]='B43 K0210 FH L019 A:33263 T:8582'},
[13623]={[0]='Delivery for Orendil',[1]='B43 K0210 FA L019 A:33204 T:3847 P:26473'},
[13624]={[0]='A Squad of Your Own',[1]='B43 K0210 FA L019 A:11806 T:11806'},
[13625]={[0]='Learning The Reins',[1]='B0 +D FA K0800 L077 A:33647 T:33647'},
[13626]={[0]='Respect for the Fallen',[1]='B43 K0210 FA L019 A:11806 T:11806 P:13624'},
[13628]={[0]='Got Wood?',[1]='B43 K0210 FH L019 A:33284 T:33421'},
[13630]={[0]='The Reason Why',[1]='B43 K0210 FA L019 A:33276 T:33276'},
[13631]={[0]='All Is Well That Ends Well',[1]='B0 K0800 L080 A:100046052 T:16128'},
[13632]={[0]='Rear Guard Duty',[1]='B43 K0210 FA L019 A:11219 T:11219'},
[13633]={[0]='The Black Knight of Westfall?',[1]='B0 K0800 FA L077 A:33417 T:33417'},
[13634]={[0]='The Black Knight of Silverpine?',[1]='B0 K0800 FH L077 A:33417 T:33417 P:13633'},
[13635]={[0]='South Gate Status Report',[1]='B0 FA K0110 L010 A:1960 T:1092 P:26855 I:26146'},
[13636]={[0]="Stormpike's Orders",[1]='B35 FA K0130 L012 A:1340 T:1343 I:26843'},
[13639]={[0]='Resupplying the Excavation',[1]='B35 FA K0160 L014 A:1105 T:2057 P:26868'},
[13640]={[0]='Management Material',[1]='B43 K0210 FH L019 A:33421 T:33421 P:13628'},
[13641]={[0]="The Seer's Crystal",[1]='B0 K0800 L077 A:33417 T:33417 P:13633,13634'},
[13642]={[0]='Bathed in Light',[1]='B43 K0210 FA L019 A:3847 T:3847 P:13623'},
[13643]={[0]='The Stories Dead Men Tell',[1]='B0 K0800 L077 A:33417 T:33417 P:13641'},
[13644]={[0]='That Which Has Risen',[1]='B43 K0220 FA L019 A:33443 T:33443'},
[13645]={[0]='To Raene Wolfrunner',[1]='B43 K0230 FA L019 A:3847 T:3691 P:26464'},
[13646]={[0]='Astranaar Bound',[1]='B43 K0230 FA L019 A:33445 T:33454 P:26464'},
[13647]={[0]='Joining the Hunt',[1]='B35 FA K0160 L012 A:1345 T:1154 P:13650+26961'}, -- TODO: Determine which I: needs to be added here
[13648]={[0]='WANTED: The Dark Iron Spy',[1]='B35 FA K0120 L008 A:1000256 T:1139'},
[13650]={[0]='Keep Your Hands Off The Goods!',[1]='B35 FA K0160 L012 A:1344 T:1344 P:309'},
[13651]={[0]='Needs a Little Lubrication',[1]='B43 K0210 FH L019 A:33421 T:33421 P:13640'},
[13653]={[0]='Crisis at Splintertree',[1]='B43 K0210 FH L019 A:33421 T:8582 P:13651 B11'},
[13654]={[0]="There's Something About the Squire",[1]='B0 K0800 L077 A:33417 T:33417 P:13643'},
[13655]={[0]="Explorers' League Document (2 of 6)",[1]='B35 FA K0160 L008 A:1194378 T:1153'},
[13656]={[0]="Explorers' League Document (1 of 6)",[1]='B35 FA K0160 L008 A:1194387 T:1153'},
[13657]={[0]="Explorers' League Document (3 of 6)",[1]='B35 FA K0160 L008 A:1194388 T:1153'},
[13658]={[0]="Explorers' League Document (4 of 6)",[1]='B35 FA K0160 L008 A:1194389 T:1153'},
[13659]={[0]="Explorers' League Document (6 of 6)",[1]='B35 FA K0170 L008 A:1194390 T:1153'},
[13660]={[0]="Explorers' League Document (5 of 6)",[1]='B35 FA K0160 L008 A:1194391 T:1153'},
[13661]={[0]='Heartfelt Appreciation',[1]='B35 FA K0180 L008 A:-35 T:1153 P:13655+13656+13657+13658+13659+13660'},
[13662]={[0]='Gaining Acceptance',[1]='B0 K0500 ++ L046 A:14624 T:14624 P:28064 W7583999'},
[13663]={[0]="The Black Knight's Orders",[1]='B0 K0800 L077 A:33417 T:33417'},
[13664]={[0]="The Black Knight's Fall",[1]='B0 K0800 L077 A:33417 T:33417 P:13663'},
[13665]={[0]='The Grand Melee',[1]='B0 +D FA K0800 L077 A:33223 T:33223'},
[13666]={[0]='A Blade Fit For A Champion',[1]='B0 +D FA K0800 L077 A:33625 T:33625'},
[13667]={[0]='The Argent Tournament',[1]='B0 K0800 FA L077 A:33817 T:33625'},
[13668]={[0]='The Argent Tournament',[1]='B0 K0800 FH L077 A:33817 T:33542'},
[13669]={[0]='A Worthy Weapon',[1]='B0 +D FA K0800 L077 A:33625 T:33625'},
[13670]={[0]='The Edge Of Winter',[1]='B0 +D FA K0800 L077 A:33625 T:33625'},
[13671]={[0]='Training In The Field',[1]='B0 +D FA K0800 L077 A:33646 T:33646'},
[13672]={[0]='Up To The Challenge',[1]='B0 K0800 FA L077 A:33625 T:33625'},
[13673]={[0]='A Blade Fit For A Champion',[1]='B0 +D FH K0800 L077 A:33542 T:33542'},
[13674]={[0]='A Worthy Weapon',[1]='B0 +D FH K0800 L077 A:33542 T:33542'},
[13675]={[0]='The Edge Of Winter',[1]='B0 +D FH K0800 L077 A:33542 T:33542'},
[13676]={[0]='Training In The Field',[1]='B0 +D FH K0800 L077 A:33658 T:33658'},
[13677]={[0]='Learning The Reins',[1]='B0 +D FH K0800 L077 A:33659 T:33659'},
[13678]={[0]='Up To The Challenge',[1]='B0 K0800 FH L077 A:33542 T:33542'},
[13679]={[0]="The Aspirant's Challenge",[1]='B0 K0800 FA L077 A:33625 T:33625 P:13672'},
[13680]={[0]="The Aspirant's Challenge",[1]='B0 K0800 FH L077 A:33542 T:33542 P:13678'},
[13682]={[0]='Threat From Above',[1]='B0 +D FA XK K0800 L077 A:33759 T:33759'},
[13683]={[0]='Stopping the Rituals',[1]='B43 K0210 FA L019 A:33727 T:33727 P:26468'},
[13684]={[0]='A Valiant Of Stormwind',[1]='B0 K0800 FA RD L077 A:33625 T:33225'},
[13685]={[0]='A Valiant Of Ironforge',[1]='B0 K0800 FA L077 A:33625 T:33312'},
[13688]={[0]='A Valiant Of Gnomeregan',[1]='B0 K0800 FA L077 A:33625 T:33335'},
[13689]={[0]='A Valiant Of Darnassus',[1]='B0 K0800 FA RE L077 A:33625 T:33592'},
[13690]={[0]='A Valiant Of The Exodar',[1]='B0 K0800 FA RD L077 A:33625 T:33593'},
[13691]={[0]='A Valiant Of Orgrimmar',[1]='B0 K0800 FH L077 A:33542 T:33361'},
[13693]={[0]="A Valiant Of Sen'jin",[1]='B0 K0800 FH RT RL L077 A:33542 T:33372'},
[13694]={[0]='A Valiant Of Thunder Bluff',[1]='B0 K0800 FH RT RB L077 A:33542 T:33403'},
[13695]={[0]='A Valiant Of Undercity',[1]='B0 K0800 FH L077 A:33542 T:33373'},
[13696]={[0]='A Valiant Of Silvermoon',[1]='B0 K0800 FH RB L077 A:33542 T:33379'},
[13697]={[0]="The Valiant's Charge",[1]='B0 K0800 FH L077 A:33361 T:33361'},
[13698]={[0]='Explosives Shredding',[1]='B43 K0210 FA L019 A:17287 T:17287 P:26457'},
[13699]={[0]="The Valiant's Challenge",[1]='B0 K0800 FA L077 A:33225 T:33225 P:13718'},
[13702]={[0]='A Champion Rises',[1]='B0 K0800 FA L077 A:33225 T:33817'},
[13703]={[0]='Valiant Of Ironforge',[1]='B0 K0800 FA L077 A:33312 T:33312'},
[13704]={[0]='Valiant Of Gnomeregan',[1]='B0 K0800 FA L077 A:33335 T:33335'},
[13705]={[0]='Valiant Of The Exodar',[1]='B0 K0800 FA L077 A:33593 T:33593'},
[13706]={[0]='Valiant Of Darnassus',[1]='B0 K0800 FA L077 A:33592 T:33592'},
[13707]={[0]='Valiant Of Orgrimmar',[1]='B0 K0800 FH L077 A:33361 T:33361'},
[13708]={[0]="Valiant Of Sen'jin",[1]='B0 K0800 FH L077 A:33372 T:33372'},
[13709]={[0]='Valiant Of Thunder Bluff',[1]='B0 K0800 FH L077 A:33403 T:33403'},
[13710]={[0]='Valiant Of Undercity',[1]='B0 K0800 FH L077 A:33373 T:33373'},
[13711]={[0]='Valiant Of Silvermoon',[1]='B0 K0800 FH L077 A:33379 T:33379'},
[13712]={[0]='To the Rescue!',[1]='B43 K0210 FH L019 A:8582 T:33837 P:13653'},
[13713]={[0]="The Valiant's Challenge",[1]='B0 K0800 FA L077 A:33312 T:33312 P:13714'},
[13714]={[0]="The Valiant's Charge",[1]='B0 K0800 FA L077 A:33312 T:33312'},
[13715]={[0]="The Valiant's Charge",[1]='B0 K0800 FA L077 A:33335 T:33335'},
[13716]={[0]="The Valiant's Charge",[1]='B0 K0800 FA L077 A:33593 T:33593'},
[13717]={[0]="The Valiant's Charge",[1]='B0 K0800 FA L077 A:33592 T:33592'},
[13718]={[0]="The Valiant's Charge",[1]='B0 K0800 FA L077 A:33225 T:33225'},
[13719]={[0]="The Valiant's Charge",[1]='B0 K0800 FH L077 A:33372 T:33372'},
[13720]={[0]="The Valiant's Charge",[1]='B0 K0800 FH L077 A:33403 T:33403'},
[13721]={[0]="The Valiant's Charge",[1]='B0 K0800 FH L077 A:33373 T:33373'},
[13722]={[0]="The Valiant's Charge",[1]='B0 K0800 FH L077 A:33379 T:33379'},
[13723]={[0]="The Valiant's Challenge",[1]='B0 K0800 FA L077 A:33335 T:33335 P:13715'},
[13724]={[0]="The Valiant's Challenge",[1]='B0 K0800 FA L077 A:33593 T:33593 P:13716'},
[13725]={[0]="The Valiant's Challenge",[1]='B0 K0800 FA L077 A:33592 T:33592 P:13717'},
[13726]={[0]="The Valiant's Challenge",[1]='B0 K0800 FH L077 A:33361 T:33361 P:13697'},
[13727]={[0]="The Valiant's Challenge",[1]='B0 K0800 FH L077 A:33372 T:33372 P:13719'},
[13728]={[0]="The Valiant's Challenge",[1]='B0 K0800 FH L077 A:33403 T:33403 P:13720'},
[13729]={[0]="The Valiant's Challenge",[1]='B0 K0800 FH L077 A:33373 T:33373 P:13721'},
[13730]={[0]='Playing With Felfire',[1]='B43 K0210 FH L019 A:33726 T:33726'},
[13731]={[0]="The Valiant's Challenge",[1]='B0 K0800 FH L077 A:33379 T:33379 P:13722'},
[13732]={[0]='A Champion Rises',[1]='B0 K0800 FA L077 A:33312 T:33817'},
[13733]={[0]='A Champion Rises',[1]='B0 K0800 FA L077 A:33335 T:33817'},
[13734]={[0]='A Champion Rises',[1]='B0 K0800 FA RD L077 A:33593 T:33817'},
[13735]={[0]='A Champion Rises',[1]='B0 K0800 FA RE L077 A:33592 T:33817'},
[13736]={[0]='A Champion Rises',[1]='B0 K0800 FH L077 A:33361 T:33817'},
[13737]={[0]='A Champion Rises',[1]='B0 K0800 FH L077 A:33372 T:33817'},
[13738]={[0]='A Champion Rises',[1]='B0 K0800 FH L077 A:33403 T:33817'},
[13739]={[0]='A Champion Rises',[1]='B0 K0800 FH L077 A:33373 T:33817'},
[13740]={[0]='A Champion Rises',[1]='B0 K0800 FH RB L077 A:33379 T:33817'},
[13741]={[0]='A Blade Fit For A Champion',[1]='B0 +D FA K0800 L077 A:33312 T:33312'},
[13742]={[0]='A Worthy Weapon',[1]='B0 +D FA K0800 L077 A:33312 T:33312'},
[13743]={[0]='The Edge Of Winter',[1]='B0 +D FA K0800 L077 A:33312 T:33312'},
[13744]={[0]="A Valiant's Field Training",[1]='B0 +D FA K0800 L077 A:33315 T:33315'},
[13745]={[0]='The Grand Melee',[1]='B0 +D FA K0800 L077 A:33309 T:33309'},
[13746]={[0]='A Blade Fit For A Champion',[1]='B0 +D FA K0800 L077 A:33335 T:33335'},
[13747]={[0]='A Worthy Weapon',[1]='B0 +D FA K0800 L077 A:33335 T:33335'},
[13748]={[0]='The Edge Of Winter',[1]='B0 +D FA K0800 L077 A:33335 T:33335'},
[13749]={[0]="A Valiant's Field Training",[1]='B0 +D FA K0800 L077 A:33648 T:33648'},
[13750]={[0]='The Grand Melee',[1]='B0 +D FA K0800 L077 A:33649 T:33649'},
[13751]={[0]='Tell No One!',[1]='B43 K0220 FH L019 A:33726 T:33760 P:13730'},
[13752]={[0]='A Blade Fit For A Champion',[1]='B0 +D FA K0800 L077 A:33593 T:33593'},
[13753]={[0]='A Worthy Weapon',[1]='B0 +D FA K0800 L077 A:33593 T:33593'},
[13754]={[0]='The Edge Of Winter',[1]='B0 +D FA K0800 L077 A:33593 T:33593'},
[13755]={[0]="A Valiant's Field Training",[1]='B0 +D FA K0800 L077 A:33655 T:33655'},
[13756]={[0]='The Grand Melee',[1]='B0 +D FA K0800 L077 A:33656 T:33656'},
[13757]={[0]='A Blade Fit For A Champion',[1]='B0 +D FA K0800 L077 A:33592 T:33592'},
[13758]={[0]='A Worthy Weapon',[1]='B0 +D FA K0800 L077 A:33592 T:33592'},
[13759]={[0]='The Edge Of Winter',[1]='B0 +D FA K0800 L077 A:33592 T:33592'},
[13760]={[0]="A Valiant's Field Training",[1]='B0 +D FA K0800 L077 A:33652 T:33652'},
[13761]={[0]='The Grand Melee',[1]='B0 +D FA K0800 L077 A:33654 T:33654'},
[13762]={[0]='A Blade Fit For A Champion',[1]='B0 +D FH K0800 L077 A:33361 T:33361'},
[13763]={[0]='A Worthy Weapon',[1]='B0 +D FH K0800 L077 A:33361 T:33361'},
[13764]={[0]='The Edge Of Winter',[1]='B0 +D FH K0800 L077 A:33361 T:33361'},
[13765]={[0]="A Valiant's Field Training",[1]='B0 +D FH K0800 L077 A:33405 T:33405'},
[13766]={[0]='Closure is Only Natural',[1]='B43 K0210 FA L019 A:17310 T:17310 P:26446'},
[13767]={[0]='The Grand Melee',[1]='B0 +D FH K0800 L077 A:33544 T:33544'},
[13768]={[0]='A Blade Fit For A Champion',[1]='B0 +D FH K0800 L077 A:33372 T:33372'},
[13769]={[0]='A Worthy Weapon',[1]='B0 +D FH K0800 L077 A:33372 T:33372'},
[13770]={[0]='The Edge Of Winter',[1]='B0 +D FH K0800 L077 A:33372 T:33372'},
[13771]={[0]="A Valiant's Field Training",[1]='B0 +D FH K0800 L077 A:33540 T:33540'},
[13772]={[0]='The Grand Melee',[1]='B0 +D FH K0800 L077 A:33545 T:33545'},
[13773]={[0]='A Blade Fit For A Champion',[1]='B0 +D FH K0800 L077 A:33403 T:33403'},
[13774]={[0]='A Worthy Weapon',[1]='B0 +D FH K0800 L077 A:33403 T:33403'},
[13775]={[0]='The Edge Of Winter',[1]='B0 +D FH K0800 L077 A:33403 T:33403'},
[13776]={[0]="A Valiant's Field Training",[1]='B0 +D FH K0800 L077 A:33539 T:33539'},
[13777]={[0]='The Grand Melee',[1]='B0 +D FH K0800 L077 A:33549 T:33549'},
[13778]={[0]='A Blade Fit For A Champion',[1]='B0 +D FH K0800 L077 A:33373 T:33373'},
[13779]={[0]='A Worthy Weapon',[1]='B0 +D FH K0800 L077 A:33373 T:33373'},
[13780]={[0]='The Edge Of Winter',[1]='B0 +D FH K0800 L077 A:33373 T:33373'},
[13781]={[0]="A Valiant's Field Training",[1]='B0 +D FH K0800 L077 A:33541 T:33541'},
[13782]={[0]='The Grand Melee',[1]='B0 +D FH K0800 L077 A:33547 T:33547'},
[13783]={[0]='A Blade Fit For A Champion',[1]='B0 +D FH K0800 L077 A:33379 T:33379'},
[13784]={[0]='A Worthy Weapon',[1]='B0 +D FH K0800 L077 A:33379 T:33379'},
[13785]={[0]='The Edge Of Winter',[1]='B0 +D FH K0800 L077 A:33379 T:33379'},
[13786]={[0]="A Valiant's Field Training",[1]='B0 +D FH K0800 L077 A:33538 T:33538'},
[13787]={[0]='The Grand Melee',[1]='B0 +D FH K0800 L077 A:33548 T:33548'},
[13788]={[0]='Threat From Above',[1]='B0 +D FA CK K0800 L077 A:33762 T:33762'},
[13789]={[0]='Taking Battle To The Enemy',[1]='B0 +D FA K0800 L077 A:33763 T:33763'},
[13790]={[0]='Among the Champions',[1]='B0 +D FA K0800 L077 A:33771 T:33771'},
[13791]={[0]='Taking Battle To The Enemy',[1]='B0 +D FA CK K0800 L077 A:33769 T:33769'},
[13792]={[0]='The Shadewalker',[1]='B43 K0210 FA L019 A:17310 T:33777 P:13766'},
[13793]={[0]='Among the Champions',[1]='B0 +D FA CK K0800 L077 A:33770 T:33770'},
[13794]={[0]='Eadric the Pure',[1]='B0 K0800 L077 A:33817 T:33759'},
[13795]={[0]='The Scourgebane',[1]='B0 K0800 L077 A:33817 T:33762'},
[13796]={[0]='The Forest Heart',[1]='B43 K0210 FA L019 A:33777 T:17310 P:13792'},
[13797]={[0]='Dirty Deeds',[1]='B43 K0220 FH L019 A:33760 T:33760 P:13751'},
[13798]={[0]='Rain of Destruction',[1]='B43 K0220 FH L019 A:33760 T:33977 P:13797'},
[13801]={[0]='Dead Elves Walking',[1]='B43 K0210 FH L019 A:12724 T:12724'},
[13803]={[0]='Blood of the Weak',[1]='B43 K0220 FH L019 A:33837 T:33760 P:13712'},
[13805]={[0]='Pierce Their Heart!',[1]='B43 K0220 FH L019 A:33760 T:33837 P:13803'},
[13806]={[0]='Demon Duty',[1]='B43 K0220 FH L019 A:11820 T:11820'},
[13808]={[0]='Mission Improbable',[1]='B43 K0220 FH L019 A:33837 T:33889'},
[13809]={[0]='Threat From Above',[1]='B0 +D FH XK K0800 L077 A:33759 T:33759'},
[13810]={[0]='Taking Battle To The Enemy',[1]='B0 +D FH K0800 L077 A:33763 T:33763'},
[13811]={[0]='Among the Champions',[1]='B0 +D FH K0800 L077 A:33771 T:33771'},
[13812]={[0]='Threat From Above',[1]='B0 +D FH CK K0800 L077 A:33762 T:33762'},
[13813]={[0]='Taking Battle To The Enemy',[1]='B0 +D FH CK K0800 L077 A:33769 T:33769'},
[13814]={[0]='Among the Champions',[1]='B0 +D FH CK K0800 L077 A:33770 T:33770'},
[13815]={[0]='Making Stumps',[1]='B43 K0220 FH L019 A:33889 T:33889 P:13808'},
[13816]={[0]='Heroic: The Celestial Planetarium',[1]='B0 K0800 L080 A:33957 T:33957'},
[13817]={[0]='Heroic: Archivum Data Disc',[1]='B0 K0800 L080 A:100045857 T:1194555'},
[13818]={[0]='Heroic: Algalon',[1]='B0 K0800 L080 A:33957 T:1194555'},
[13819]={[0]='Heroic: All Is Well That Ends Well',[1]='B0 K0800 L080 A:100046053 T:16128'},
[13821]={[0]="Heroic: Freya's Sigil",[1]='B0 K0800 L080 A:33957 T:33957'},
[13822]={[0]="Heroic: Hodir's Sigil",[1]='B0 K0800 L080 A:33957 T:33957'},
[13823]={[0]="Heroic: Thorim's Sigil",[1]='B0 K0800 L080 A:33957 T:33957'},
[13824]={[0]="Heroic: Mimiron's Sigil",[1]='B0 K0800 L080 A:33957 T:33957'},
[13825]={[0]='Clamlette Surprise',[1]='B0 A:40589 T:40589'},
[13826]={[0]='Nat Pagle, Angler Extreme',[1]='B0 A:12919 T:12919 P:6607'},
[13828]={[0]='Mastery Of Melee',[1]='B0 K0800 FA L077 A:33625 T:33625 P:13667'},
[13829]={[0]='Mastery Of Melee',[1]='B0 K0800 FH L077 A:33542 T:33542 P:13668'},
[13830]={[0]='The Ghostfish',[1]='B0 +D L070 A:28742 T:28742'},
[13831]={[0]='A Troubling Prescription',[1]='B42 K0110 FA L008 A:1194714 T:32978 P:13528'},
[13832]={[0]='Jewel Of The Sewers',[1]='B0 +D L070 A:28742 T:28742'},
[13833]={[0]='Blood Is Thicker',[1]='B0 +D L070 A:28742 T:28742'},
[13834]={[0]='Dangerously Delicious',[1]='B0 +D L070 A:28742 T:28742'},
[13835]={[0]='Mastery Of The Shield-Breaker',[1]='B0 K0800 FA L077 A:33647 T:33647'},
[13836]={[0]='Disarmed!',[1]='B0 +D L070 A:28742 T:28706'},
[13837]={[0]='Mastery Of The Charge',[1]='B0 K0800 FA L077 A:33646 T:33646'},
[13838]={[0]='Mastery Of The Shield-Breaker',[1]='B0 K0800 FH L077 A:33659 T:33659'},
[13839]={[0]='Mastery Of The Charge',[1]='B0 K0800 FH L077 A:33658 T:33658'},
[13841]={[0]='All Apologies',[1]='B43 K0220 FH L019 A:33726 T:39605'},
[13842]={[0]='Dread Head Redemption',[1]='B43 K0230 FH L019 A:39605 T:39605 P:13841'},
[13844]={[0]='The Looting of Althalaxx',[1]='B42 K0140 FA L010 A:34041 T:34041 P:13507+13509'},
[13845]={[0]='Sealed Vial of Poison',[1]='B0 K0800 L070 A:100046004 T:29535'},
[13846]={[0]="Contributin' To The Cause",[1]='B0 +D K0800 L077 A:34210 T:34210'},
[13847]={[0]="At The Enemy's Gates",[1]='B0 +D FA K0800 L077 A:33223 T:33223'},
[13848]={[0]='Bad News Bear-er',[1]='B43 K0220 FH L019 A:33837 T:34122'},
[13849]={[0]="Astranaar's Burning!",[1]='B43 K0230 FA L020 A:4079 T:4079'},
[13850]={[0]='Toxic Tolerance',[1]='B201 FH L048 A:11701 T:11701'},
[13851]={[0]="At The Enemy's Gates",[1]='B0 +D FA K0800 L077 A:33309 T:33309'},
[13852]={[0]="At The Enemy's Gates",[1]='B0 +D FA K0800 L077 A:33649 T:33649'},
[13853]={[0]='Return Fire',[1]='B43 K0230 FA L020 A:4079 T:4079 P:13849'},
[13854]={[0]="At The Enemy's Gates",[1]='B0 +D FA K0800 L077 A:33656 T:33656'},
[13855]={[0]="At The Enemy's Gates",[1]='B0 +D FA K0800 L077 A:33654 T:33654'},
[13856]={[0]="At The Enemy's Gates",[1]='B0 +D FH K0800 L077 A:33544 T:33544'},
[13857]={[0]="At The Enemy's Gates",[1]='B0 +D FH K0800 L077 A:33545 T:33545'},
[13858]={[0]="At The Enemy's Gates",[1]='B0 +D FH K0800 L077 A:33549 T:33549'},
[13859]={[0]="At The Enemy's Gates",[1]='B0 +D FH K0800 L077 A:33548 T:33548'},
[13860]={[0]="At The Enemy's Gates",[1]='B0 +D FH K0800 L077 A:33547 T:33547'},
[13861]={[0]='Battle Before The Citadel',[1]='B0 +D FA XK K0800 L077 A:33759 T:33759'},
[13862]={[0]='Battle Before The Citadel',[1]='B0 +D FH XK K0800 L077 A:33759 T:33759'},
[13863]={[0]='Battle Before The Citadel',[1]='B0 +D FH CK K0800 L077 A:33762 T:33762'},
[13864]={[0]='Battle Before The Citadel',[1]='B0 +D FA CK K0800 L077 A:33762 T:33762'},
[13865]={[0]='Wet Work',[1]='B43 K0220 FH L019 A:33889 T:33889'},
[13866]={[0]='To The Ramparts!',[1]='B43 K0200 FH L018 A:34195 T:8582 P:24463 B11'},
[13867]={[0]='Culling the Furbolg Threat',[1]='B43 K0230 FA L021 A:3691 T:3691'},
[13868]={[0]='Corrupting Influence?',[1]='B43 K0230 FA L021 A:100046128 T:3691'},
[13869]={[0]='Recover the Remains',[1]='B43 K0210 FA L019 A:17310 T:17310 P:26454'},
[13870]={[0]='As Good as it Gets',[1]='B43 K0220 FH L019 A:33889 T:17304'},
[13871]={[0]='Security!',[1]='B43 K0220 FH L019 A:17304 T:17304'},
[13872]={[0]='Worgen Wisdom',[1]='B43 K0230 FA L021 A:3691 T:34239 P:13868'},
[13873]={[0]="Sheelah's Last Wish",[1]='B43 K0220 FH L019 A:34233 T:34242'},
[13874]={[0]='A Not-So-Charmed Life',[1]='B43 K0230 FA L021 A:34239 T:34239 P:13872'},
[13875]={[0]="Gurtar's Request",[1]='B43 K0220 FH L019 A:34242 T:33726 P:13873'},
[13876]={[0]='Too Far Gone',[1]='B43 K0240 FA L021 A:34251 T:34251 P:13868'},
[13877]={[0]='Go With The Flow',[1]='B43 K0230 FA L021 A:34239 T:34283 P:13874'},
[13878]={[0]='Through Fire and Flames',[1]='B11 K0110 FH L009 A:34284 T:34284'},
[13879]={[0]='Thunder Peak',[1]='B43 K0230 FH L021 A:34510 T:34512'},
[13880]={[0]='Hot Lava',[1]='B43 K0230 L021 A:34290 T:34290 P:13877'},
[13881]={[0]='Consumed',[1]='B42 K0180 FA L016 A:34301 T:34301'},
[13882]={[0]='The Seeds of Life',[1]='B42 K0180 FA L016 A:34301 T:34301 P:13881'},
[13883]={[0]='Lousy Pieces of Ship',[1]='B43 K0220 FH L019 A:34303 T:34303'},
[13884]={[0]='Put Out The Fire',[1]='B43 K0230 L021 A:34292 T:34292 P:13877'},
[13885]={[0]='In Defense of Darkshore',[1]='B42 K0190 FA L016 A:34301 T:34301 P:13925'},
[13886]={[0]='Vortex',[1]='B43 K0240 FA L021 A:34289 T:34283 P:13880+13884'},
[13887]={[0]='Venomhide Eggs',[1]='B201 K0530 FH L048 A:11701 T:11701 P:13850'},
[13888]={[0]='Vortex',[1]='B43 K0240 FH L021 A:34289 T:34512'},
[13889]={[0]='Hungry, Hungry Hatchling',[1]='B201 +D FH RO RB K0530 L048 A:34320 T:34320'},
[13890]={[0]='Keep the Fires Burning',[1]='B43 K0220 FH L019 A:34122 T:34122'},
[13891]={[0]='The Devourer of Darkshore',[1]='B42 K0180 FA L016 A:34301 T:34301 P:13885'},
[13892]={[0]='Leave No Tracks',[1]='B42 K0190 FA L017 A:34402 T:34402'},
[13893]={[0]='Soggoth and Kronn',[1]='B42 K0190 FA L017 A:34340 T:34404 P:13896'},
[13895]={[0]='The Slumbering Ancients',[1]='B42 K0190 FA L017 A:33072 T:34446 P:13893'},
[13896]={[0]='Unearthed Knowledge',[1]='B42 K0190 FA L017 A:34404 T:34340 P:13948'},
[13897]={[0]='The Battle for Darkshore',[1]='B42 K0190 FA L017 A:34422 T:34402 P:13900'},
[13898]={[0]='The Tides Turn Against Us',[1]='B42 K0200 FA L017 A:34403 T:34403 P:13953'},
[13899]={[0]='The Darkscale Warlord',[1]='B42 K0200 FA L017 A:34402 T:34423 P:13953'},
[13900]={[0]='The Offering to Azshara',[1]='B42 K0200 FA L017 A:34423 T:34422 P:13899'},
[13901]={[0]='Deep Despair',[1]='B43 K0220 FH L019 A:12719 T:12719'},
[13902]={[0]='Mounting the Offensive',[1]='B42 K0180 FA L017 A:33091 T:34402 P:13588'},
[13903]={[0]='Gorishi Grub',[1]='B201 +D FH RO RB K0530 L048 A:34320 T:34320'},
[13904]={[0]='Poached, Scrambled, Or Raw?',[1]='B201 +D FH RO RB K0530 L048 A:34320 T:34320'},
[13905]={[0]='Searing Roc Feathers',[1]='B201 +D FH RO RB K0530 L048 A:34320 T:34320'},
[13906]={[0]='They Grow Up So Fast',[1]='B0 K0530 FH L048 A:11701 T:11701 P:13887'},
[13907]={[0]='Sweeping Clean the Ruins',[1]='B42 K0180 FA L016 A:34340 T:34340'},
[13909]={[0]='Got Some Flotsam?',[1]='B42 K0180 FA L016 A:34340 T:34340 P:13907'},
[13910]={[0]='A New Home',[1]='B42 K0180 FA L016 A:34340 T:34340 P:13909'},
[13911]={[0]='The Absent-Minded Prospector',[1]='B42 K0180 FA L016 A:34343 T:34342'},
[13912]={[0]='Swamped Secrets',[1]='B42 K0180 FA L016 A:34342 T:34342'},
[13913]={[0]='They Took Our Gnomes',[1]='B43 K0250 FA L024 A:34354 T:34354'},
[13914]={[0]='Searing Roc Feathers',[1]='B201 K0530 +D FH L048 A:34320 T:34320'},
[13915]={[0]='Hungry, Hungry Hatchling',[1]='B201 K0530 +D FH L048 A:34320 T:34320'},
[13916]={[0]='Poached, Scrambled, Or Raw?',[1]='B201 K0530 +D FH L048 A:34320 T:34320'},
[13917]={[0]='Gorishi Grub',[1]='B201 K0530 +D FH L048 A:34320 T:34320'},
[13918]={[0]="The Titans' Terminal",[1]='B42 K0180 FA L016 A:34342 T:34342 P:13912'},
[13919]={[0]='A Trip to the Moonwell',[1]='B0 K0230 FA L019 A:3894 T:-43 P:26475'}, -- after about 5 seconds
[13920]={[0]='Before You Go...',[1]='B43 K0220 FH L019 A:34122 T:34122 P:13890'},
[13921]={[0]='He Who Would Be Forgiven',[1]='B43 FA K0230 L019 A:-43 T:34335 P:13919 I:14018'},
[13922]={[0]='In the Hands of the Perverse',[1]='B43 K0230 FA L019 A:34335 T:34335 P:13921,14018'},
[13923]={[0]="To Hellscream's Watch",[1]='B43 K0220 FH L019 A:34122 T:34359'},
[13924]={[0]="All's Well",[1]='B43 K0230 FA L019 A:34358 T:3894 P:13922'}, -- after a few seconds
[13925]={[0]='An Ounce of Prevention',[1]='B42 K0180 FA L016 A:34301 T:34301 P:13882'},
[13926]={[0]='Little Orphan Roo Of The Oracles',[1]='B0 HC L070 A:34365 T:6 V4744999 I:13927'},
[13927]={[0]='Little Orphan Kekek Of The Wolvar',[1]='B0 HC L070 A:34365 T:33532 V4144999 I:13926'},
[13928]={[0]='Recover the Fallen',[1]='B43 K0230 FA L021 A:3880 T:34377'},
[13929]={[0]='The Biggest Tree Ever!',[1]='B0 HC L070 A:6 T:6 P:13926'},
[13930]={[0]='Home Of The Bear-Men',[1]='B0 HC L070 A:33532 T:500010 P:13927'},
--[13931]={[0]='Another Year, Another Souvenir.',[1]='FH HB'},
--[13932]={[0]='Another Year, Another Souvenir.',[1]='FA HB'},
[13933]={[0]='The Bronze Dragonshrine',[1]='B0 HC L070 A:6 T:6 P:13926'},
[13934]={[0]='The Bronze Dragonshrine',[1]='B0 HC L070 A:33532 T:500009 P:13927'},
[13935]={[0]='Defend the Tree!',[1]='B43 K0230 FA L021 A:34377 T:3880 P:13928'},
[13936]={[0]="Tweedle's Dumb",[1]='B43 K0230 FH L021 A:34359 T:34395'},
[13937]={[0]='A Trip To The Wonderworks',[1]='B0 HC L070 A:6 T:6 P:13956+13954'},
[13938]={[0]='A Visit To The Wonderworks',[1]='B0 HC L070 A:33532 T:33532 P:13955+13957'},
[13940]={[0]='Leaving the Dream',[1]='B42 K0170 FA L013 A:33166 T:33091 P:13587'},
[13942]={[0]='Set Us Up the Bomb',[1]='B43 K0230 FH L021 A:34395 T:34395 P:13936'},
[13943]={[0]='Breathing Room',[1]='B43 K0230 FH L021 A:34359 T:34359'},
[13944]={[0]='Small Hands, Short Fuse',[1]='B43 K0230 FH L021 A:34395 T:34359 P:13942'},
[13945]={[0]='Resident Danger',[1]='B0 FA K0070 L004 A:2081 T:2081 P:476'},
[13946]={[0]="Nature's Reprisal",[1]='B0 FA K0070 L004 A:2083 T:2083 P:476+489'},
[13947]={[0]='Blastranaar!',[1]='B43 K0230 FH L021 A:34359 T:34359 P:13944'},
[13948]={[0]='Stepping Up Surveillance',[1]='B42 K0190 FA L017 A:34402 T:34402 P:13892'},
[13949]={[0]='Crossroads Caravan Pickup',[1]='B11 K0120 FH L009 A:34258 T:5907'},
[13950]={[0]='Playmates!',[1]='B0 HC L070 A:6 T:6 P:13926'},
[13951]={[0]='Playmates!',[1]='B0 HC L070 A:33532 T:533532 P:13927'},
[13952]={[0]='The Grateful Dead',[1]='B0 HD K00016 FA RH A:34435 T:34435 I:14166,14167,14168,14169,14170,14171,14172,14173,14174,14175,14176,14177,27841,27846'},
[13953]={[0]='Naga In Our Midst',[1]='B42 K0190 FA L017 A:34498 T:34402 P:13895'},
[13954]={[0]='The Dragon Queen',[1]='B0 HC L070 A:6 T:6 P:13929+13933+13950'},
[13955]={[0]='The Dragon Queen',[1]='B0 HC L070 A:33532 T:500011 P:13930+13934+13951'},
[13956]={[0]='Meeting a Great One',[1]='B0 HC L070 A:6 T:6 P:13929+13933+13950'},
[13957]={[0]='The Mighty Hemet Nesingwary',[1]='B0 HC L070 A:33532 T:500012 P:13930+13934+13951'},
[13958]={[0]='Condition Critical!',[1]='B43 K0230 FH L021 A:34359 T:34518'},
[13959]={[0]='Back To The Orphanage',[1]='B0 HC L070 A:6 T:34365 P:13937'},
[13960]={[0]='Back To The Orphanage',[1]='B0 HC L070 A:33532 T:34365 P:13938'},
[13961]={[0]='Drag it Out of Them',[1]='B11 K0120 FH L010 A:34513 T:34513'},
[13962]={[0]='Stalemate',[1]='B43 K0240 FH L022 A:34518 T:34518 P:13958'},
[13963]={[0]='By Hook Or By Crook',[1]='B11 K0120 FH L010 A:34513 T:34513 P:13961'},
[13964]={[0]='To the Spire',[1]='B43 K0250 FA L023 A:4079 T:3885 P:26478 I:26470'},
[13965]={[0]='Check in on the Edunes',[1]='B43 K0250 FA L023 A:3996 T:24739 P:26478 I:13976'},
[13966]={[0]='A Winter Veil Gift',[1]='B0 HV L010'},
[13967]={[0]='Thinning the... Herd?',[1]='B43 K0250 FH L023 A:12696 T:12696'},
[13968]={[0]='The Tortusk Takedown',[1]='B11 K0120 FH L010 A:34513 T:34513 P:13963'},
[13969]={[0]="Grol'dom's Missing Kodo",[1]='B11 K0120 FH L010 A:5907 T:34547'},
[13970]={[0]='Animal Services',[1]='B11 K0120 FH L010 A:34547 T:34547 P:13969'},
[13971]={[0]="The Kodo's Return",[1]='B11 K0120 FH L010 A:34547 T:5907 P:13970'},
[13973]={[0]="The Grol'dom Militia",[1]='B11 K0120 FH L010 A:34560 T:34560'},
[13974]={[0]="Tweedle's Tiny Package",[1]='B43 K0230 FH L021 A:34395 T:34569'},
[13975]={[0]='Crossroads Caravan Delivery',[1]='B11 K0130 FH L011 A:34578 T:3429'},
[13976]={[0]='Three Friends of the Forest',[1]='B43 K0250 FA L023 A:24739 T:3698 O:13965'},
[13977]={[0]='Mass Production',[1]='B43 K0240 FH L021 A:34569 T:34596'},
[13979]={[0]='The Goblin Braintrust',[1]='B43 K0250 FA L023 A:34354 T:34354'},
[13980]={[0]="They're Out There!",[1]='B43 K0250 FH L023 A:34596 T:34596 P:13977'},
[13981]={[0]='They Set Them Up The Bomb!',[1]='B43 K0250 FA L023 A:1195134 T:34354'},
[13982]={[0]='In a Bind',[1]='B43 K0260 FA L023 A:3698 T:3698 P:13976'},
[13983]={[0]='Building Your Own Coffin',[1]='B43 K0250 FH L023 A:34596 T:34596'},
[13985]={[0]='Clear the Shrine',[1]='B43 K0250 FA L023 A:34599 T:34604 P:13982'},
[13986]={[0]='An Injured Colleague',[1]='B0 K0730 FH L071 A:35471 T:34526'},
[13987]={[0]='The Last Stand',[1]='B43 K0250 FA L023 A:34604 T:34604 P:13985'},
[13988]={[0]='A Growing Problem',[1]='B11 K0130 FH L010 A:3448 T:34626 P:870'},
[13989]={[0]='King of the Foulweald',[1]='B43 K0260 L019 A:3897 T:3897 P:26480'},
[13991]={[0]='The Purloined Payroll',[1]='B11 K0150 FH L013 A:3338 T:3464 P:905'},
[13992]={[0]='A Little Diversion',[1]='B11 K0130 FH L011 A:34613 T:34613'},
[13995]={[0]='King of Centaur Mountain',[1]='B11 K0140 FH L012 A:34634 T:34638'},
[13998]={[0]='In Fungus We Trust',[1]='B11 K0140 FH L010 A:3390 T:3390 P:848'},
[13999]={[0]="Who's Shroomin' Who?",[1]='B11 K0140 FH L010 A:3390 T:34651 P:13998'},
[14001]={[0]='Goblin Escape Pods',[1]='B0 K0060 FH RG A:36600 T:35650'},
[14003]={[0]='Samophlange Repair',[1]='B11 K0160 FH L010 A:3442 T:34674'},
[14004]={[0]='Return to Samophlanger',[1]='B11 K0160 FH L010 A:9316 T:3442'},
[14005]={[0]='The Vengeance of Elune',[1]='B0 FA K0100 A:1992 T:1992 P:933'},
[14006]={[0]='Read the Manual',[1]='B11 K0160 FH L010 A:3442 T:3442 P:14004'},
[14007]={[0]='Steady Shot',[1]='B0 K0030 RG CH L003 A:34673 T:34673'},
[14008]={[0]='Arcane Missiles',[1]='B0 K0030 RG CM L003 A:34689 T:34689'},
[14009]={[0]='Flash Heal',[1]='B0 K0030 RG CT L003 A:34692 T:34692'},
[14010]={[0]='Eviscerate',[1]='B0 K0030 RG CR L003 A:34693 T:34693'},
[14011]={[0]='Primal Strike',[1]='B0 K0030 RG CS L003 A:34695 T:34695'},
[14012]={[0]='Immolate',[1]='B0 K0030 RG CL L003 A:34696 T:34696'},
[14013]={[0]='Charge',[1]='B0 K0030 RG CW L003 A:34697 T:34697'},
[14014]={[0]='Get Our Stuff Back!',[1]='B0 K0060 FH RG A:35650 T:35650 P:14001,14474'},
[14016]={[0]="The Black Knight's Curse",[1]='B0 K0800 L077 A:33417 T:33417 P:13664'},
[14017]={[0]="The Black Knight's Fate",[1]='B0 K0800 L077 A:33417 T:33417 P:14016'},
[14018]={[0]='He Who Would Be Forgiven',[1]='B0 FA K0230 L019 A:-43 T:34335 P:13919 I:13921'},
[14019]={[0]='Monkey Business',[1]='B0 K0060 FH RG A:35758 T:35758'},
[14021]={[0]='Miner Troubles',[1]='B0 K0060 FH RG A:35769 T:35769'},
[14022]={[0]="Pilgrim's Bounty",[1]='B0 HY +Y FA A:18927,19148,19171,19172,19173,20102 T:34675'},
[14023]={[0]='Spice Bread Stuffing',[1]='B0 HY +Y FA A:34675 T:34744'},
[14024]={[0]='Pumpkin Pie',[1]='B0 HY FA A:34744 T:34644 P:14023'},
[14028]={[0]='Cranberry Chutney',[1]='B0 HY +Y FA A:34644 T:34744 P:14024'},
[14030]={[0]="They're Ravenous In Darnassus",[1]='B0 HY +Y FA A:34744 T:34676 P:14028'},
[14031]={[0]='Capturing the Unknown',[1]='B0 K0060 FH RG A:35769 T:35650'},
[14033]={[0]='Candied Sweet Potatoes',[1]='B0 HY +Y FA A:34676 T:34675 P:14030'},
[14034]={[0]='Club Foote',[1]='B11 K0160 FH L014 A:3391 T:3391'},
[14035]={[0]='Slow-roasted Turkey',[1]='B0 HY +Y FA A:34675 T:34676 P:14033'},
[14036]={[0]="Pilgrim's Bounty",[1]='B0 HY FH A:19169,19175,19176,19177,19178,20102 T:34677'},
[14037]={[0]='Spice Bread Stuffing',[1]='B0 HY +Y FH A:34677 T:34768'},
[14038]={[0]='Love it or Limpet',[1]='B11 K0160 +W FH L014 A:3391 T:3391 P:14034'},
[14039]={[0]='Home of the Kaldorei',[1]='B0 FA K0110 A:503515 T:7999 P:935'},
[14040]={[0]='Pumpkin Pie',[1]='B0 HY +Y FH A:34768 T:34679 P:14037'}, -- technically requires PC100, but one can obtain the quest prior to the skill being there, however, one can never complete the skill unless one knows the recipe which is skill 100 minimum
[14041]={[0]='Cranberry Chutney',[1]='B0 HY +Y FH A:34679 T:34678 P:14040'}, -- PC160 (see 14040)
[14042]={[0]='Ammo Kerblammo',[1]='B11 K0160 FH L014 A:3391 T:3391 P:14038'},
[14043]={[0]='Candied Sweet Potatoes',[1]='B0 HY +Y FH A:34678 T:34679 P:14041'}, -- PC220 (see 14040)
[14044]={[0]='Undersupplied in the Undercity',[1]='B0 HY +Y FH A:34679 T:34677 P:14043'},
[14045]={[0]='Find Baron Longshore',[1]='B11 FH K0160 L014 A:3391 T:3467'},
[14046]={[0]="The Baron's Demands",[1]='B11 K0160 +W L014 A:3467 T:3467 P:14045'},
[14047]={[0]='Slow-roasted Turkey',[1]='B0 HY +Y FH A:34677 T:34679 P:14044'}, -- PC280 (see 14040)
[14048]={[0]="Can't Get Enough Turkey",[1]='B0 HY +D FA A:34708 T:34708'},
[14049]={[0]='A Most Unusual Map',[1]='B11 K0160 L014 A:3467 T:3391 P:14046'},
[14050]={[0]="Gazlowe's Fortune",[1]='B11 K0160 FH L014 A:3391 T:3391'},
[14051]={[0]="Don't Forget The Stuffing!",[1]='B0 HY +D FA A:34708 T:34708'},
[14052]={[0]='Take it up with Tony',[1]='B11 K0160 FH L014 A:3453 T:34749'},
[14053]={[0]="We're Out of Cranberry Chutney Again?",[1]='B0 HY +D FA A:34710 T:34710'},
[14054]={[0]='Easy As Pie',[1]='B0 HY +D FA A:34711 T:34711'},
[14055]={[0]='She Says Potato',[1]='B0 HY +D FA A:34744 T:34744'},
[14056]={[0]='Glomp is Sitting On It',[1]='B11 K0160 FH L014 A:34749 T:34749 P:14052'},
[14057]={[0]='Guns. We Need Guns.',[1]='B11 K0160 FH L014 A:34749 T:34749 P:14056'},
[14058]={[0]='She Says Potato',[1]='B0 HY +D FH A:34768 T:34768'},
[14059]={[0]="We're Out of Cranberry Chutney Again?",[1]='B0 HY +D FH A:34712 T:34712'},
[14060]={[0]='Easy As Pie',[1]='B0 HY +D FH A:34714 T:34714'},
[14061]={[0]="Can't Get Enough Turkey",[1]='B0 HY +D FH A:34713 T:34713'},
[14062]={[0]="Don't Forget The Stuffing!",[1]='B0 HY +D FH A:34713 T:34713'},
[14063]={[0]='Mutiny, Mon!',[1]='B11 K0170 FH L014 A:34749 T:3453 P:14057'},
[14064]={[0]='Sharing a Bountiful Feast',[1]='B0 HY FA A:34653 T:34653'},
[14065]={[0]='Sharing a Bountiful Feast',[1]='B0 HY FH A:34654 T:34654'},
[14066]={[0]='Investigate the Wreckage',[1]='B11 K0150 +W FH L013 A:3464 T:3464 P:13991'},
[14067]={[0]='The Stolen Silver',[1]='B11 K0150 FH L013 A:3464 T:3464 P:869'},
[14068]={[0]='Waptor Twapping',[1]='B11 K0160 FH L014 A:34828 T:34828'},
[14069]={[0]='Good Help is Hard to Find',[1]='B0 K0010 RG A:34872 T:34872'},
[14070]={[0]='Do it Yourself',[1]='B0 K0030 RG A:34668 T:34668 P:14071'},
[14071]={[0]='Rolling with my Homies',[1]='B0 K0030 RG A:34874 T:34874 P:28349'},
[14072]={[0]='Flushing Out Verog',[1]='B11 K0150 FH L013 A:34638 T:34638'},
[14073]={[0]="Deathgate's Reinforcements",[1]='B11 K0180 FH L016 A:3429 T:3389'},
[14074]={[0]='A Leg Up',[1]='B0 +D FA K0800 L077 A:34880 T:34880'},
[14075]={[0]='Trouble in the Mines',[1]='B0 K0010 RG A:34865 AH:34872 TH:14336,34872'},
[14076]={[0]='Breakfast Of Champions',[1]='B0 +D FA K0800 L077 A:34912 T:34912'},
[14077]={[0]="The Light's Mercy",[1]='B0 +D FA K0800 L077 A:34880 T:34880'},
[14078]={[0]='Lockdown!',[1]='B0 FA RW K0010 A:34850 T:34863'},
--[14079]={[0]='Learn to Ride in Elwynn Forest',[1]='K0200 FA L020 A:100046875 T:4732'},
[14080]={[0]='Stop The Aggressors',[1]='B0 +D FA K0800 L077 A:34880 T:34880'},
--[14081]={[0]='Learn to Ride in the Eversong Woods',[1]='K0200 FH L020 A:100046882 T:16280'},
--[14085]={[0]='Learn to Ride in Darnassus',[1]='K0200 FA L020 A:100046876 T:4753'},
--[14087]={[0]='Learn to Ride in Mulgore',[1]='K0200 FH L020 A:100046884 T:3690'},
[14090]={[0]='Gormok Wants His Snobolds',[1]='B0 +D FA K0800 L077 A:34912 T:34912'},
[14091]={[0]="Something's Amiss",[1]='B0 FA RW K0020 A:34863 T:34913 P:14078'},
[14092]={[0]='Breakfast Of Champions',[1]='B0 +D FH K0800 L077 A:34914 T:34914'},
[14093]={[0]='All Hell Breaks Loose',[1]='B0 K0020 RW A:34913 T:34913 P:14091'},
[14094]={[0]='Salvage the Supplies',[1]='B0 FA RW K0020 A:34936 T:34936 P:14078'},
[14095]={[0]='Identifying the Remains',[1]='B0 K0800 +D L078 A:100046955 T:35094'},
[14096]={[0]="You've Really Done It This Time, Kul",[1]='B0 +D FA K0800 L077 A:34880 T:34880'},
[14098]={[0]='Evacuate the Merchant Square',[1]='B0 K0020 RW A:34913 T:34913 P:14091'},
[14099]={[0]='Royal Orders',[1]='B0 FA RW K0030 A:34913 T:35840 P:14094+14093+14098'},
[14101]={[0]='Drottinn Hrothgar',[1]='B0 +D K0800 L077 A:34882 T:34882'},
[14102]={[0]='Mistcaller Yngvar',[1]='B0 +D K0800 L077 A:34882 T:34882'},
[14103]={[0]='Titanium Powder',[1]='B0 ++ L065 A:28701 T:28701'},
[14104]={[0]='Ornolf The Scarred',[1]='B0 +D K0800 L077 A:34882 T:34882'},
[14105]={[0]='Deathspeaker Kharos',[1]='B0 +D K0800 L077 A:34882 T:34882'},
[14107]={[0]='The Fate Of The Fallen',[1]='B0 +D K0800 L077 A:35094 T:35094'},
[14108]={[0]='Get Kraken!',[1]='B0 +D K0800 L078 A:35094 T:35094'},
[14109]={[0]='The New You',[1]='B0 K0030 FH RG A:35120,535120 T:35053 P:26712'},
[14110]={[0]='The New You',[1]='B0 K0030 FH RG A:35120,535120 T:35054 P:26711'},
[14112]={[0]='What Do You Feed a Yeti, Anyway?',[1]='B0 +D FA K0800 L077 A:34912 T:34912'},
[14113]={[0]='Life of the Party',[1]='B0 K0030 RG AH:35053 T:34668 P:14070'},
[14115]={[0]='Pirate Party Crashers',[1]='B0 K0040 RG A:34668 T:34668 P:14113,14153'},
[14116]={[0]='The Uninvited Guest',[1]='B0 K0040 FH RG A:34668 T:35222 P:14115'},
[14117]={[0]='The Eyes of Ashenvale',[1]='B181 K0100 FH L008 A:8576 T:8576'},
[14118]={[0]='Venison for the Troops',[1]='B181 K0100 FH L008 A:8576 T:8576'},
[14120]={[0]='A Bazillion Macaroons?!',[1]='B0 K0040 FH RG A:35222 T:534668 P:14116'},
[14121]={[0]='Robbing Hoods',[1]='B0 K0040 FH RG A:534874 T:34874 P:14120'},
[14122]={[0]='The Great Bank Heist',[1]='B0 K0040 RG A:534668 T:34668 P:14120'},
[14123]={[0]='Waltz Right In',[1]='B0 K0040 FH RG A:34693 T:34693 P:14120'},
[14124]={[0]="Liberate the Kaja'mite",[1]='B0 K0040 FH RG A:534872 T:34872 P:14120'},
[14125]={[0]='447',[1]='B0 K0050 RG A:37598 AH:34668 T:37602'},
[14126]={[0]='Life Savings',[1]='B0 K0050 FH RG A:34668 T:35222'},
[14127]={[0]='Return of the Highborne?',[1]='B181 K0100 FH L008 A:100047039 T:8576'},
[14128]={[0]='Return of the Highborne?',[1]='B181 K0100 FH L008 A:8576 T:35087 P:14127'},
[14129]={[0]='Runaway Shredder!',[1]='B181 K0110 FH L009 A:35086 T:-181,35086 P:25275,28496'},
[14130]={[0]='Friends Come In All Colors',[1]='B181 K0170 FH L015 A:35867 T:35142 P:14407'},
[14131]={[0]='A Little Pick-me-up',[1]='B181 K0170 FH L015 A:35142 T:35142 P:14130'},
[14132]={[0]="That's Just Rude!",[1]='B181 K0170 FH L015 A:35142 T:35142 P:14130'},
[14134]={[0]="The Captain's Logs",[1]='B181 K0110 FH L009 A:-181,35086 T:-181,35086 P:14129'},
[14135]={[0]='Up a Tree',[1]='B181 K0110 FH L009 A:-181,35086 T:-181,35086 P:14134'},
[14136]={[0]='Rescue at Sea',[1]='B0 +D FH K0800 L078 A:34771 T:34771'},
[14138]={[0]='Taking Care of Business',[1]='B0 K0010 FH RG A:27648,34668 T:14336,34872'},
[14140]={[0]='Stop The Aggressors',[1]='B0 +D FH K0800 L077 A:34771 T:34771'},
[14141]={[0]='Gormok Wants His Snobolds',[1]='B0 +D FH K0800 L077 A:34914 T:34914'},
[14142]={[0]="You've Really Done It This Time, Kul",[1]='B0 +D FH K0800 L077 A:34771 T:34771'},
[14143]={[0]='A Leg Up',[1]='B0 +D FH K0800 L077 A:34771 T:34771'},
[14144]={[0]="The Light's Mercy",[1]='B0 +D FH K0800 L077 A:34771 T:34771'},
[14145]={[0]='What Do You Feed a Yeti, Anyway?',[1]='B0 +D FH K0800 L077 A:34914 T:34914'},
[14146]={[0]='Defend the Gates!',[1]='B0 K0110 FH L009 A:-181 T:-181 P:14135'},
[14151]={[0]='Cardinal Ruby',[1]='B0 ++ L065 A:28703 T:28703'},
[14152]={[0]='Rescue at Sea',[1]='B0 +D FA K0800 L078 A:34880 T:34880'},
[14153]={[0]='Life of the Party',[1]='B0 K0030 RG A:35054 T:34668 P:14070'},
[14154]={[0]='By the Skin of His Teeth',[1]='B0 FA RW K0040 A:35077 T:35077 P:28850'},
[14155]={[0]='Arborcide',[1]='B181 K0110 FH L009 A:-181 T:35086 P:14146'},
[14157]={[0]='Old Divisions',[1]='B0 FA RW K0040 A:35112 T:50371 P:14291'},
[14159]={[0]="The Rebel Lord's Arsenal",[1]='B0 FA RW K0040 A:35112 T:35369 P:26129'},
[14161]={[0]="Basilisk Bashin'",[1]='B181 K0110 FH L009 A:35091 T:35091 P:14162'},
[14162]={[0]='Report to Horzak',[1]='B181 K0110 FH L009 A:35086 T:35091 P:14155'},
[14165]={[0]='Stone Cold',[1]='B181 K0110 FH L009 A:35091 T:35091'},
[14166]={[0]='The Grateful Dead',[1]='B0 HD K00016 A:35256 T:35256 I:13952,14167,14168,14169,14170,14171,14172,14173,14174,14175,14176,14177,27841,27846'},
[14167]={[0]='The Grateful Dead',[1]='B0 HD K00016 FA RF A:34478 T:34478 I:13952,14166,14168,14169,14170,14171,14172,14173,14174,14175,14176,14177,27841,27846'},
[14168]={[0]='The Grateful Dead',[1]='B0 HD K00016 FA RN A:34481 T:34481 I:13952,14166,14167,14169,14170,14171,14172,14173,14174,14175,14176,14177,27841,27846'},
[14169]={[0]='The Grateful Dead',[1]='B0 HD K00016 FA RD A:34484 T:34484 I:13952,14166,14167,14168,14170,14171,14172,14173,14174,14175,14176,14177,27841,27846'},
[14170]={[0]='The Grateful Dead',[1]='B0 HD K00016 FA RE A:34479 T:34479 I:13952,14166,14167,14168,14169,14171,14172,14173,14174,14175,14176,14177,27841,27846'},
[14171]={[0]='The Grateful Dead',[1]='B0 HD K00016 FH RB A:34483 T:34483 I:13952,14166,14167,14168,14169,14170,14172,14173,14174,14175,14176,14177,27841,27846'},
[14172]={[0]='The Grateful Dead',[1]='B0 HD K00016 V3544999 A:35260 T:35260 I:13952,14166,14167,14168,14169,14170,14171,14173,14174,14175,14176,14177,27841,27846'},
[14173]={[0]='The Grateful Dead',[1]='B0 HD K00016 V3644999 A:35261 T:35261 I:13952,14166,14167,14168,14169,14170,14171,14172,14174,14175,14176,14177,27841,27846'},
[14174]={[0]='The Grateful Dead',[1]='B0 HD K00016 FH RU A:34476 T:34476 I:13952,14166,14167,14168,14169,14170,14171,14172,14173,14175,14176,14177,27841,27846'},
[14175]={[0]='The Grateful Dead',[1]='B0 HD K00016 FH RO A:34477 T:34477 I:13952,14166,14167,14168,14169,14170,14171,14172,14173,14174,14176,14177,27841,27846'},
[14176]={[0]='The Grateful Dead',[1]='B0 HD K00016 FH RT A:34480 T:34480 I:13952,14166,14167,14168,14169,14170,14171,14172,14173,14174,14175,14177,27841,27846'},
[14177]={[0]='The Grateful Dead',[1]='B0 HD K00016 FH RL A:34482 T:34482 I:13952,14166,14167,14168,14169,14170,14171,14172,14173,14174,14175,14176,27841,27846'},
[14184]={[0]='My Time Has Passed',[1]='B0 K0300 FH L027 A:35286 T:35295 P:28548'},
[14188]={[0]='Avenge Furien!',[1]='B0 K0300 FH L027 A:35295 T:35298 P:14184'},
[14189]={[0]='Translation',[1]='B0 K0300 FH L027 A:35298 T:1195433 P:14188'},
[14190]={[0]='The Perfect Prism',[1]='B181 K0110 FH L009 A:35091 T:1195431 P:14165'},
[14191]={[0]="Furien's Footsteps",[1]='B0 K0300 FH L027 A:1195433 T:1195433 P:14189'},
[14192]={[0]='Prismbreak',[1]='B181 K0110 FH L009 A:1195431 T:1195435 P:14190'},
[14193]={[0]="Nothing a Couple of Melons Won't Fix",[1]='B0 FA K0300 L027 A:1195438 T:1195438'},
[14194]={[0]='Refleshification',[1]='B181 K0110 FH L009 A:1195435 T:35091 P:14192'},
[14195]={[0]='All Becoming Clearer',[1]='B0 K0310 L027 A:1195433 T:1195445 P:14360'},
[14196]={[0]='Firestarter',[1]='B101 K0310 FH L027 A:1195445 T:1195445 P:14195'},
[14197]={[0]='A Quota to Meet',[1]='B181 K0110 FH L009 A:35085 T:35085'},
[14198]={[0]='Rider on the Storm',[1]='B0 K0310 FH L027 A:35506,35510,1195445 T:35295 P:14196'},
[14201]={[0]='A Thousand Stories in the Sand',[1]='B181 K0120 FH L010 A:35087 T:35087 P:24453'},
[14202]={[0]='Survey the Lakeshore',[1]='B181 K0120 FH L010 A:35088 T:35088 P:24453'},
[14203]={[0]='Waterlogged Recipe',[1]='B0 K0800 FA ++ L070 A:100048679 T:32337'},
[14204]={[0]='From the Shadows',[1]='B0 K0040 RW A:35463 AA:35378 T:35378'},
[14209]={[0]='Gunk in the Trunk',[1]='B181 K0120 FH L010 A:35088 T:35088 P:14202'},
[14212]={[0]='Sacrifices',[1]='B0 K0050 RW A:35552 T:35618 P:14294'},
[14213]={[0]='Ten Pounds of Flesh',[1]='B0 K0310 FH L027 A:1195497 T:1195497'},
[14214]={[0]='Message to Greymane',[1]='B0 FA RW K0040 A:35378 T:35550 P:14204'},
[14215]={[0]='Memories of the Dead',[1]='B181 K0120 FH L010 A:35087 T:-181,35087 P:14201'},
[14216]={[0]='Mystery of the Sarcen Stone',[1]='B181 K0120 FH L010 A:-181,35087 T:35087 P:14215'},
[14217]={[0]='Satyrical Offerings',[1]='B0 K0310 FH L027 A:1195497 T:1195497'},
[14218]={[0]='By Blood and Ash',[1]='B0 K0050 RW A:35229 AA:35618 T:35618 P:14212'},
[14219]={[0]='To the Hilt!',[1]='B0 K0310 FH L027 A:1195517 T:1195517'},
[14221]={[0]='Never Surrender, Sometimes Retreat',[1]='B0 FA RW K0050 A:35618 T:35566 P:14218'},
[14222]={[0]='Last Stand',[1]='B0 K0050 RW A:35627 AA:35566 T:35566 P:14221'},
[14223]={[0]='Peace of Mind',[1]='B0 K0300 FH L027 A:35298 T:35298'},
[14225]={[0]="You'll Know It When You See It",[1]='B0 K0310 FH L027 A:35298 T:35298 P:14223'},
[14226]={[0]='Trouble Under Foot',[1]='B181 K0180 FH L015 A:35187 T:35187'},
[14227]={[0]='Putting Their Heads Together',[1]='B0 K0310 FH L027 A:35298 T:35298 P:14225'},
[14230]={[0]='Manual Labor',[1]='B181 K0180 FH L015 A:35756 T:35756'},
[14232]={[0]='Ears Are Burning',[1]='B0 K0310 FH L027 A:100049010 T:35298'},
[14233]={[0]='Orcs Can Write?',[1]='B0 K0060 FH RG A:35837 T:35650 P:14031'},
[14234]={[0]='The Enemy of My Enemy',[1]='B0 K0060 FH RG A:35650 T:35875 P:14031,14233'},
[14235]={[0]='The Vicious Vale',[1]='B0 K0060 FH RG A:35875 T:35893 P:14234'},
[14236]={[0]='Weed Whacker',[1]='B0 K0060 FH RG A:35893 T:35893 P:14235'},
[14237]={[0]='Forward Movement',[1]='B0 K0070 FH RG A:35875 T:35917 P:14303'},
[14238]={[0]='Infrared = Infradead',[1]='B0 K0070 FH RG A:35917 T:35917 P:14237'},
[14240]={[0]='To the Cliffs',[1]='B0 K0070 FH RG A:35917 T:36112 P:14238'},
[14241]={[0]='Get to the Gyrochoppa!',[1]='B0 K0070 FH RG A:36112 T:36127 P:14240'},
[14242]={[0]='Precious Cargo',[1]='B0 K0070 FH RG A:36127 T:36145 P:14241'},
[14243]={[0]="Warchief's Revenge",[1]='B0 K0070 FH RG A:36161 T:36188 P:14326'},
[14244]={[0]='Up, Up & Away!',[1]='B0 K0070 FH RG A:36425 T:36470 P:14445'},
[14245]={[0]="It's a Town-In-A-Box",[1]='B0 K0070 FH RG A:36470 T:36471 P:14244'},
[14246]={[0]='Early Adoption',[1]='B0 K0310 L027 A:35661 T:35661'},
[14247]={[0]='Stubborn Lands',[1]='B0 K0310 L027 A:35661 T:1195600'},
[14248]={[0]='Help Wanted',[1]='B0 K0060 FH RG A:35650 T:35769 P:14014'},
[14249]={[0]='Shear Will',[1]='B181 K0180 FH L015 A:35648 T:35648'},
[14250]={[0]='Renewable Resource',[1]='B181 K0180 FH L015 A:35755 T:35755'},
[14251]={[0]='New Beginnings',[1]='B0 K0310 L027 A:35757 T:35757'},
[14252]={[0]='Good Gold For Bad Tail',[1]='B0 K0310 L027 A:35757 T:35757'},
[14253]={[0]='Fletch Me Some Plumage!',[1]='B0 K0310 L027 A:35757 T:35757'},
[14254]={[0]='Heavy Metal',[1]='B0 K0310 L027 A:1195600 T:35757 P:14247'},
[14255]={[0]='Ethel Rethor',[1]='B0 K0310 FH L027 A:35295 T:35773 I:14256'},
[14256]={[0]='The Emerging Threat',[1]='B0 K0320 L028 A:35773 T:35773 O:14255,14365'},
[14257]={[0]='Slitherblade Slaughter',[1]='B0 K0320 L028 A:35773 T:35773 P:14256'},
[14258]={[0]='Mortar the Point',[1]='B181 K0120 FH L010 A:35817 T:35817'},
[14260]={[0]='Going Deep',[1]='B0 K0320 L028 A:35773 T:35827 P:14257'},
[14261]={[0]='Ice Cold',[1]='B181 K0190 FH L015 A:37064 T:37064'},
[14262]={[0]='To Gut a Fish',[1]='B181 K0130 FH L011 A:35657 T:35657 P:14258'},
[14263]={[0]='Waste of Thyme',[1]='B181 K0180 FH L015 A:35754 T:35754'},
[14264]={[0]='Wetter Than Wet',[1]='B0 K0320 L028 A:35827 T:35827 P:14260'},
[14265]={[0]='Your Instructor',[1]='B0 FA RW CW K0020 A:35840 T:35839'},
[14266]={[0]='Charge',[1]='B0 K0030 FA RW CW A:35839 T:35839 P:14265'},
[14267]={[0]='Investigating the Sea Shrine',[1]='B181 K0130 FH L011 A:35657 T:1195642 P:14258'},
[14268]={[0]='Deep Impact',[1]='B0 K0320 L028 A:35827 T:35773 P:14264'},
[14269]={[0]="Someone's Looking for You",[1]='B0 FA RN RW CR K0020 A:35840 T:35871'},
[14270]={[0]='The Keystone Shard',[1]='B181 K0130 FH L011 A:1195642 T:1195642 P:14267'},
[14271]={[0]='Report to Twocrush',[1]='B181 K0130 FH L011 A:1195642 T:35657 P:14270'},
[14272]={[0]='Eviscerate',[1]='B0 K0020 FA RN RW CR A:35871 T:35871 P:14269'},
[14273]={[0]='Shady Associates',[1]='B0 FA RW CL K0020 A:35840 T:35869'},
[14274]={[0]='Immolate',[1]='B0 K0020 FA RW CL A:35869 T:35869 P:14273'},
[14275]={[0]="Someone's Keeping Track of You",[1]='B0 FA RW CH K0020 A:35840 T:35874'},
[14276]={[0]='Steady Shot',[1]='B0 K0020 FA RW CH A:35874 T:35874 P:14275'},
[14277]={[0]='Arcane Inquiries',[1]='B0 FA RW CM K0020 A:35840 T:35872'},
[14278]={[0]='Seek the Sister',[1]='B0 FA RW CT K0020 A:35840 T:35870'},
[14279]={[0]='Flash Heal',[1]='B0 K0020 FA RW CT A:35870 T:35870 P:14278'},
[14280]={[0]='The Winds Know Your Name... Apparently',[1]='B0 FA RE RW CD K0020 A:35840 T:35873 P:14099'},
[14281]={[0]='Arcane Missiles',[1]='B0 FA RW CM K0020 A:35872 T:35872 P:14277'},
[14282]={[0]='Mystery Solved',[1]='B0 K0320 L028 A:35773 T:35773 P:14268'},
[14283]={[0]='A Rejuvenating Touch',[1]='B0 K0020 FA RE RW CD A:35873 T:35873 P:14280'},
[14284]={[0]="A Revenant's Vengeance",[1]='B0 K0320 L028 A:35902 T:35902 P:14292'},
[14285]={[0]='Safety in Numbers',[1]='B0 FA RN RW CR K0030 A:35871 T:35112 P:14272'},
[14286]={[0]='Safety in Numbers',[1]='B0 FA RW CW K0030 A:35839 T:35112 P:14266'},
[14287]={[0]='Safety in Numbers',[1]='B0 FA RW CL K0030 A:35869 T:35112 P:14274'},
[14288]={[0]='Safety in Numbers',[1]='B0 FA RW CM K0030 A:35872 T:35112 P:14281'},
[14289]={[0]='Safety in Numbers',[1]='B0 FA RW CT K0030 A:35870 T:35112 P:14279'},
[14290]={[0]='Safety in Numbers',[1]='B0 FA RW CH K0030 A:35874 T:35112 P:14276'},
[14291]={[0]='Safety in Numbers',[1]='B0 FA RE RW CD K0030 A:35873 T:35112 P:14283'},
[14292]={[0]='The Enemy of Our Enemy',[1]='B0 K0320 L028 A:35773 T:35902 P:14282'},
[14293]={[0]='Save Krennan Aranas',[1]='B0 FA RW K0040 A:35550 T:35906 P:14214'},
[14294]={[0]='Time to Regroup',[1]='B0 FA RW K0040 A:35906 T:35911 P:14293'},
[14295]={[0]='Sisters of the Sea',[1]='B181 K0130 FH L011 A:35657 T:35657 P:14271'},
[14296]={[0]='Watch Your Step',[1]='B181 K0180 FH L015 A:36334 T:36361 P:14413'},
[14297]={[0]='Pro-liberation',[1]='B181 K0190 FH L015 A:37061 T:37061'},
[14299]={[0]="Xylem's Asylum",[1]='B181 K0180 FH L015 A:36361 T:36372'},
[14300]={[0]='The Trial of Fire',[1]='B181 K0180 FH L015 A:36361 T:36335'},
[14301]={[0]='Return and Report',[1]='B0 K0320 L028 A:35902 T:35773 P:14284'},
[14302]={[0]='Official Assessment',[1]='B0 K0320 L028 A:35773 T:36034 P:14301'},
[14303]={[0]='Back to Aggra',[1]='B0 K0070 FH RG A:35893 T:35875 P:14236'},
[14304]={[0]='Blood Theory',[1]='B0 K0330 L029 A:36048 T:36048'},
[14305]={[0]='A Time to Reap',[1]='B0 K0320 L029 A:36060 T:36060'},
[14306]={[0]='Pulling Weeds',[1]='B0 K0320 L029 A:36060 T:36060'},
[14307]={[0]='Stubborn Winds',[1]='B0 K0320 L029 A:36034 T:36034'},
[14308]={[0]='When Science Attacks',[1]='B181 K0130 FH L011 A:36077 T:1195676 P:14424'},
[14309]={[0]='Calming the Kodo',[1]='B0 K0320 L029 A:36048 T:36048 P:14304'},
[14310]={[0]='Segmentation Fault: Core Dumped',[1]='B181 K0130 FH L011 A:1195676 T:36077 P:14308'},
[14311]={[0]='Taking Part',[1]='B0 K0320 L029 A:36060 T:36060 P:14305'},
[14312]={[0]='An Introduction Is In Order',[1]='B0 K0320 L029 A:36052 T:36056 P:14311'},
[14313]={[0]='Among Humans Again',[1]='B0 K0050 FA RW L005 A:36170 T:36132 P:14375'},
[14314]={[0]='Breakout!',[1]='B0 K0320 L029 A:36056 T:36056 P:14312'},
[14316]={[0]='Cenarion Property',[1]='B0 K0320 L029 A:36052 T:36052 P:14312'},
[14318]={[0]='Delicate Negotiations',[1]='B0 K0330 L029 A:36056 T:36163 P:14314+14316'},
[14320]={[0]='In Need of Ingredients',[1]='B0 K0050 FA RW L005 A:36132 T:1196394 P:14313'},
[14321]={[0]='Invasion',[1]='B0 K0050 FA RW L005 A:36205 T:34571 P:14320'},
[14322]={[0]='Bad Science! Bad!',[1]='B181 K0130 FH L011 A:36146 T:36146'},
[14323]={[0]='Absorbent',[1]='B181 K0170 FH L015 A:35142 T:-181,35142 P:14130'},
[14324]={[0]='Full of Hot Water',[1]='B181 K0170 FH L015 A:-181,35142 T:35142 P:14323'},
[14325]={[0]='Will Work For Food',[1]='B0 K0330 L029 A:36163,536163 T:536163 P:14318'},
[14326]={[0]='Meet Me Up Top',[1]='B0 K0070 FH RG A:36145 T:36161 P:14242'},
[14327]={[0]='My Word is My Bond',[1]='B0 K0330 L029 A:536163 T:36056 P:14325'},
[14328]={[0]='Three Princes',[1]='B0 K0340 L029 A:36056 T:36185 P:14327'},
[14329]={[0]='Not So Fast!',[1]='B0 K0340 L029 A:36185 T:36185 P:14328'},
[14330]={[0]='Behind Closed Doors',[1]='B0 K0350 FH L030 A:100038567 T:36196 P:14328'},
[14332]={[0]='Time For Change',[1]='B0 K0350 FH L029 A:36196 T:36398 P:14330'},
[14333]={[0]="While You're Here",[1]='B0 K0350 L029 A:1196393 T:36185 P:14328'},
[14334]={[0]='Blubbergut',[1]='B0 K0350 FH L030 A:12031 T:12031'},
[14335]={[0]='Chipping In',[1]='B0 K0350 FH L031 A:11624 T:11624'},
[14336]={[0]='Kill or Be Killed',[1]='B0 K0050 FA RW L005 A:34571 T:36140 P:14321'},
[14337]={[0]='Shadowprey Village',[1]='B0 K0340 FH L030 A:36034 T:12031'},
[14338]={[0]='Ghost Walker Post',[1]='B0 K0320 FH L029 A:36034 T:4498'},
[14339]={[0]='Delivery Device',[1]='B0 K0330 FH L029 A:4498 T:4498 P:14338'},
[14340]={[0]='Dressed to Impress',[1]='B181 K0180 FH L015 A:36210 T:35187 P:14345'},
[14341]={[0]="Smeed's Harnesses",[1]='B0 K0320 FH L029 A:11259 T:11596'},
[14342]={[0]='Infernal Encroachment',[1]='B0 K0350 FH L031 A:5395 T:5395'},
[14343]={[0]="Maurin's Concoction",[1]='B0 K0340 FH L030 A:4498 T:36034 P:14339'},
[14344]={[0]="Jugkar's Undoing",[1]='B0 K0350 FH L030 A:100049200 T:5395'},
[14345]={[0]='Wash Out',[1]='B181 K0170 FH L015 A:35142 T:36210 P:14131+14132+14324'},
[14346]={[0]='Cleansing Our Crevasse',[1]='B0 K0340 FH L030 A:36034 T:36034 P:14343,14379'},
[14347]={[0]='Hold the Line',[1]='B0 K0050 FA RW L005 A:36140 T:36140 P:14346'},
[14348]={[0]="You Can't Take 'Em Alone",[1]='B0 K0050 FA RW L005 A:36140 T:36140 P:14346'},
[14354]={[0]="Elune's Gifts",[1]='B0 FA K0310 L027 A:5642 T:5642 P:14387'},
[14357]={[0]='To the Hilt!',[1]='B0 FA K0310 L027 A:1195517 T:1195517'},
[14358]={[0]='Ten Pounds of Flesh',[1]='B0 FA K0310 L027 A:1195497 T:1195497'},
[14359]={[0]='Blessings From Above',[1]='B0 ++ FA K0310 L027 A:1195497 T:1195497 P:14358'},
[14360]={[0]="Nothing a Couple of Melons Won't Fix",[1]='B0 K0300 L027 A:1195433 T:1195433 P:14191'},
[14361]={[0]='Peace of Mind',[1]='B0 FA K0300 L027 A:5396 T:5396 P:14354'},
[14362]={[0]='Ears Are Burning',[1]='B0 FA K0310 L027 A:100049203 T:5396'},
[14363]={[0]="You'll Know It When You See It",[1]='B0 FA K0310 L027 A:5396 T:5396 P:14361'},
[14364]={[0]='Putting Their Heads Together',[1]='B0 FA K0310 L027 A:5396 T:5396 P:14363'},
[14365]={[0]='Ethel Rethor',[1]='B0 FA K0310 L027 A:5752 T:35773 P:14354 I:14256'},
[14366]={[0]='Holding Steady',[1]='B0 K0050 FA RW L005 A:36140 T:34571 P:14347+14348'}, -- at least P:14347 is correct
[14367]={[0]="The Allens' Storm Cellar",[1]='B0 K0060 FA RW L005 A:34571 T:36290 P:14366'},
[14368]={[0]='Save the Children!',[1]='B0 K0060 FA RW L005 A:36291 T:36291 P:14367'},
[14369]={[0]='Unleash the Beast',[1]='B0 K0060 FA RW L004 A:36290 T:36290 P:14367'},
[14370]={[0]='Mysterious Azsharite',[1]='B181 K0130 FH L011 A:36077 T:36077 P:14310'},
[14371]={[0]='A Gigantic Snack',[1]='B181 K0130 FH L011 A:36077 T:36077 P:14310'},
[14372]={[0]="Thargad's Camp",[1]='B0 FA K0340 L031 A:36034 T:36329 P:14327 I:14373'},
[14373]={[0]='Infernal Encroachment',[1]='B0 FA K0350 L031 A:36329 T:36329 O:14372'},
[14374]={[0]='Portals of the Legion',[1]='B0 FA K0350 L031 A:36329 T:36329'},
[14375]={[0]='Last Chance at Humanity',[1]='B0 K0050 SP FA A:36332 T:36332'},
[14376]={[0]="Jugkar's Undoing",[1]='B0 FA K0350 L030 A:100049220 T:36329'},
[14377]={[0]='Befriending Giants',[1]='B181 K0130 FH L011 A:36077 T:36077 P:14370+14371'}, -- 14371 required, guessing that 14370 is also required
[14378]={[0]='Hunting Brendol',[1]='B0 FA K0340 L031 A:36329 T:36329 P:14373+14374'},
[14379]={[0]='Rock Lobstrock!',[1]='B0 FA K0340 L031 A:36378 T:36378 P:14373+14374'},
[14380]={[0]='An Impactful Discovery',[1]='B0 FA K0340 L031 A:36329 T:36034 P:14378'},
[14381]={[0]='Cleansing Our Crevasse',[1]='B0 FA K0340 L030 A:36034 T:36034 P:14380'},
[14382]={[0]='Two By Sea',[1]='B0 K0060 FA RW L004 A:36290 T:36290 P:14367'},
[14383]={[0]='The Terrible Tinkers of the Ruined Reaches',[1]='B181 K0140 FH L011 A:36379 T:36379 P:14377'},
[14384]={[0]='Rerouted!',[1]='B101 FA K0300 L027 A:36410 T:5752 O:25938,28531'},
[14385]={[0]='Azsharite Experiment Number One',[1]='B181 K0140 FH L011 A:36077 T:36077 P:14377'},
[14386]={[0]='Leader of the Pack',[1]='B0 K0060 FA RW L004 A:36290 T:36290 P:14369+14382'}, -- P:14369 is at a minimum
[14387]={[0]='Lay of the Land',[1]='B0 FA K030 L027 A:5396 T:5642 P:14384'},
[14388]={[0]='Azsharite Experiment Number Two',[1]='B181 K0140 FH L011 A:36077 T:36077 P:14385'},
[14389]={[0]="Wasn't It Obvious?",[1]='B181 K0190 FH L015 A:36372 T:36436 P:14299'},
[14390]={[0]='Easy is Boring',[1]='B181 K0190 FH L015 A:36436 T:36436 P:14389'},
[14391]={[0]='Turning the Tables',[1]='B181 K0190 FH L015 A:36436 T:35867 P:14390'},
[14392]={[0]='Farewell, Minnow',[1]='B181 K0190 FH L015 A:36676 T:36210'},
[14393]={[0]='Into the Fray!',[1]='B0 K0350 L031 A:36398 T:36398 P:14332'},
[14394]={[0]='Death to Agogridon',[1]='B0 K0350 L031 A:36398 T:36444 P:14393'},
[14395]={[0]='Gasping for Breath',[1]='B0 K0060 FA RW L004 A:36451 T:36451 P:14396'},
[14396]={[0]='As the Land Shatters',[1]='B0 K0060 FA RW L004 A:36290 T:36451 P:14386'},
[14397]={[0]='Evacuation',[1]='B0 K0070 FA RW L004 A:36451 T:36452 P:14395'},
[14398]={[0]='Grandma Wahl',[1]='B0 K0070 FA RW L004 A:36452 T:36458 P:14397'},
[14399]={[0]="Grandma's Lost It Alright",[1]='B0 K0070 FA RW L004 A:36458 T:36458 P:14398'},
[14400]={[0]="I Can't Wear This",[1]='B0 K0070 FA RW L004 A:36458 T:36458 P:14399'},
[14401]={[0]="Grandma's Cat",[1]='B0 K0070 FA RW L004 A:36458 T:36458 P:14400'},
[14402]={[0]='Ready to Go',[1]='B0 K0070 FA RW L004 A:36458 T:36452 P:14401 I:14405,14463'}, -- TODO: Figure out exact relationship between three quest lines
[14403]={[0]='The Hayward Brothers',[1]='B0 K0070 FA RW L004 A:36452 T:36456 P:14397'},
[14404]={[0]='Not Quite Shipshape',[1]='B0 K0070 FA RW L004 A:36456 T:36456 P:14403'},
[14405]={[0]='Escape By Sea',[1]='B0 K0070 FA RW L004 A:36456 T:36452 P:14404+14412 I:14402,14463'}, -- TODO: Figure out exact relationship between three quest lines
[14406]={[0]='The Crowley Orchard',[1]='B0 K0070 FA RW L004 A:36452 T:36457 P:14397'},
[14407]={[0]='Azshara Blues',[1]='B181 K0170 FH L015 A:36999 T:35867'}, -- TODO: Determine the proper P code
[14408]={[0]="Nine's Plan",[1]='B181 K0140 FH L012 A:36500 T:36500 O:14442'},
--[14409]={[0]='A Cautious Return',[1]='K0730 FA L071 A:36506 T:36479'},
[14410]={[0]='The Wilds of Feralas',[1]='B0 FA K0350 L031 A:36487 T:40032 P:14381+14394 I:25447,28511 B121'},
[14411]={[0]='Feralas Breadcrumb [PH]',[1]='B0 K0350 FH L031 A:11624'},
[14412]={[0]='Washed Up',[1]='B0 K0070 FA RW L004 A:36456 T:36456 P:14403'},
[14413]={[0]='The Pinnacle of Learning',[1]='B181 K0180 FH L015 A:35187 T:36334'},
[14416]={[0]='The Hungry Ettin',[1]='B0 K0070 FA RW L004 A:36457 T:36457 P:14406'},
[14422]={[0]='Raptor Raptor Rocket',[1]='B181 K0140 FH L012 A:36500 T:36500 P:14408'},
[14423]={[0]='Dozercism',[1]='B181 K0120 FH L010 A:35088 T:35088 P:14209'},
[14424]={[0]='Need More Science',[1]='B181 K0130 FH L011 A:35088 T:36077 P:14423'},
[14428]={[0]="Amberwind's Journal",[1]='B181 K0180 FH L016 A:36596 T:1196832'},
[14429]={[0]='Arcane De-Construction',[1]='B181 K0180 FH L016 A:1196832 T:1196833 P:14428'},
[14430]={[0]='Hacking the Construct',[1]='B181 K0180 FH L016 A:1196833 T:36596 P:14429'},
[14431]={[0]='The Blackmaw Scar',[1]='B181 K0170 FH L015 A:8586 T:8586'},
[14432]={[0]='A Pale Brew',[1]='B181 K0170 FH L015 A:8586 T:8586'},
[14433]={[0]='Diplomacy by Another Means',[1]='B181 K0170 FH L015 A:8586 T:8586'},
[14434]={[0]="Rut'theran Village",[1]='B0 K0120 SP FA L005 A:36616 T:36616'},
[14435]={[0]='The Blackmaw Doublecross',[1]='B181 K0170 FH L015 A:8586 T:8586'},
[14438]={[0]='Sharing the Land',[1]='B0 K0060 FH L004 A:36644 T:36644'},
[14441]={[0]="Garrosh's Autograph",[1]='B0 HC FH L010 A:4 T:4 P:911+910+1800'},
[14442]={[0]='My Favorite Subject',[1]='B181 K0130 FH L011 A:36146 T:36500 P:14322 I:14408'},
[14443]={[0]='The Battered Hilt',[1]='B492 K0800 FA L080 A:100050379 T:36624'},
[14444]={[0]='What The Dragons Know',[1]='B0 FA K0800 L080 A:36624 T:36669 P:14443'},
[14445]={[0]='Farewell, For Now',[1]='B0 K0070 FH RG A:36188 T:36425 P:14243'},
[14447]={[0]='Takes One to Know One',[1]='B0 K0800 FH L077 A:30824 T:29795'}, -- this just copy of 13260 because I do not know what is actually out there now
[14448]={[0]='Takes One to Know One',[1]='B0 K0800 FH L077 A:30824 T:29795'}, -- this just copy of 13260 because I do not know what is actually out there now
[14449]={[0]='The First Step',[1]='B0 K0010 FH A:2981 T:2980'},
[14452]={[0]='Rite of Strength',[1]='B0 K0020 FH A:2980 T:2980 P:14449'},
[14455]={[0]='Stop the Thorncallers',[1]='B0 K0030 FH A:36694 T:36694 P:14458'},
[14456]={[0]='Rite of Courage',[1]='B0 K0030 FH A:36694 T:36694 P:14458'},
[14457]={[0]='The Sunreaver Plan',[1]='B0 FA K0800 L080 A:36669 T:36669 P:14444'},
[14458]={[0]='Go to Adana',[1]='B0 K0020 FH A:2980 T:36694 P:24852'},
[14459]={[0]='The Battleboars',[1]='B0 K0040 FH A:36694 T:36694 P:14455+14456'},
[14460]={[0]='Rite of Honor',[1]='B0 K0050 FH A:36694 T:2981 P:14459+14461'},
[14461]={[0]='Feed of Evil',[1]='B0 K0040 FH A:36694 T:36694 P:14455+14456'},
[14462]={[0]="Where's My Head?",[1]='B181 K0200 FH L018 A:36730 T:36729'},
[14463]={[0]='Horses for Duskhaven',[1]='B0 K0070 FA RW L004 A:36457 T:36452 P:14416 I:14402,14405'}, -- TODO: Figure out exact relationship between three quest lines (looks like the last of 14416,(14404+14412),14401 dictates which is available)
[14464]={[0]='Lightning Strike Assassination',[1]='B181 K0200 FH L018 A:36729 T:36730 P:14462'},
[14465]={[0]='To Greymane Manor',[1]='B0 K0070 FA RW L004 A:36452 T:36606 P:14402,14405,14463'},
[14466]={[0]="The King's Observatory",[1]='B0 K0070 FA RW L004 A:36606 T:36743 P:14465'},
[14467]={[0]='Alas, Gilneas!',[1]='B0 K0070 SP FA L004 A:36743 T:36743 P:14466'},
[14468]={[0]='Another Warm Body',[1]='B181 K0130 FH L010 A:36752 T:36749 P:14194'},
[14469]={[0]='Hand-me-downs',[1]='B181 K0130 FH L010 A:36749 T:36749 P:14468'},
[14470]={[0]='Military Breakthrough',[1]='B181 K0130 FH L010 A:36744 T:36744 P:14468'},
[14471]={[0]='First Degree Mortar',[1]='B181 K0130 FH L010 A:36746 T:36746 P:14468'},
[14472]={[0]='In The Face!',[1]='B181 K0130 FH L010 A:36744 T:36744 P:14469+14470+14471'},
[14473]={[0]="It's Our Problem Now",[1]='B0 K0060 FH RG A:35786 T:35786'},
[14474]={[0]='Goblin Escape Pods',[1]='B0 K0060 FH RG A:36600 T:35650 P:14001'},
[14475]={[0]='Grounded!',[1]='B181 K0200 FH L018 A:36728 T:36785'},
[14476]={[0]='Rigged to Blow',[1]='B181 K0200 FH L018 A:36785 T:36785 P:14475'},
[14477]={[0]='Push the Button!',[1]='B181 K0200 FH L018 A:36785 T:36728 P:14476'},
[14478]={[0]='Operation Fishgut',[1]='B181 K0160 FH L012 A:1201578,1203755 T:536749'},
[14479]={[0]='There Are Many Like It',[1]='B181 K0160 FH L012 A:36956 T:36920 P:24455'},
[14480]={[0]='Extermination',[1]='B181 K0170 FH L012 A:36895 T:36895 P:24448'},
[14481]={[0]='Into The Abyss',[1]='B0 K0800 L078 I:27724,28827'},
[14482]={[0]='Call of Duty',[1]='B0 FA K0800 L080 A:36799 T:36915 P:14481,27724,28827'},
[14483]={[0]="Something is in the Air (and it Ain't Love)",[1]='B0 K0800 HA FH L075 A:100050320 T:37172'},
[14484]={[0]='Head of the Snake',[1]='B181 K0170 FH L012 A:36895 T:36895 P:24448'},
[14485]={[0]='Ticker Required',[1]='B181 K0170 FH L012 A:36895 T:36895 P:24448'},
[14486]={[0]='Handling the Goods',[1]='B181 K0170 FH L012 A:36894 T:36894 P:24448'},
[14487]={[0]='Still Beating Heart',[1]='B181 K0170 FH L012 A:36745 T:36745 P:24448'},
[14491]={[0]='The Restless Earth',[1]='B0 K0070 FH L005 A:36644 T:36644 P:14438'},
[20438]={[0]='A Suitable Disguise',[1]='B0 FA K0800 L080 A:36669 T:36669 P:14457'},
[20439]={[0]='A Meeting With The Magister',[1]='B0 FA K0800 L080 A:36669 T:36669 P:20438'},
[20440]={[0]='Poison Water',[1]='B0 K0050 FH RT RB L004 A:2948 T:2948'},
[20441]={[0]='Rite of Vision',[1]='B0 K0070 FH RT L004 A:3054 T:37024 P:24457'},
[23733]={[0]='Rites of the Earthmother',[1]='B0 K0050 FH A:2981 T:36803 P:24861'},
[24215]={[0]='Rite of the Winds',[1]='B0 K0050 FH A:36803 T:36644 P:23733'},
[24428]={[0]='A Most Puzzling Circumstance',[1]='B0 K0800 FA L080 A:100049644 T:1435'},
[24429]={[0]='A Most Puzzling Circumstance',[1]='B0 K0800 FH L080 A:100049643 T:3216'},
[24430]={[0]='Blacken the Skies',[1]='B181 K0200 FH L018 A:36903 T:36903'},
[24431]={[0]='Waterlogged Recipe',[1]='B0 K0800 L070 A:100049667 T:32337'},
[24432]={[0]='Sea Legs',[1]='B0 FA K0810 L080 A:36915 T:36915 P:14482'},
[24433]={[0]='Let Them Feast on Fear',[1]='B181 K0200 FH L018 A:36730 T:36730'},
[24434]={[0]='Commando Drop',[1]='B181 K0200 FH L018 A:36919 T:36918'},
[24435]={[0]='Mop Up',[1]='B181 K0160 FH L012 A:36920 T:36920 P:14479'},
[24436]={[0]='Halo Drops',[1]='B181 K0160 FH L012 A:36921 T:36921'}, -- need to determine proper P code
[24437]={[0]='First Come, First Served',[1]='B181 K0160 FH L012 A:36795 T:36795'},
[24438]={[0]='Exodus',[1]='B0 K0080 FA RW L004 A:36743 T:37065 P:14467'},
[24439]={[0]='The Conquest of Azshara',[1]='B181 K0200 FH L018 A:36730 T:36730'},
[24440]={[0]='Winterhoof Cleansing',[1]='B0 K0060 FH RT RB L004 A:2948 T:2948 P:20440'},
[24441]={[0]='Thunderhorn Totem',[1]='B0 K0070 FH RT RB L004 A:2948 T:2948 P:24440'},
[24442]={[0]='Battle Plans Of The Kvaldir',[1]='B0 K0800 L077 A:100049676 T:33817'},
[24448]={[0]='Field Promotion',[1]='B181 K0170 FH L012 A:36920 T:36745 P:24435+24436'}, -- 24436 is correct, and assuming 24435 also required
[24449]={[0]='Shore Leave',[1]='B181 K0170 FH L012 A:36745 T:36959 P:14480+14484+14485+14486+14487'},
[24451]={[0]='An Audience With The Arcanist',[1]='B0 K0800 FH L080 A:36670 T:36670 P:24556'},
[24452]={[0]='Profitability Scouting',[1]='B181 K0130 FH L010 A:36749 T:36749 P:14472'},
[24453]={[0]='Private Chat',[1]='B181 K0130 FH L010 A:36749 T:36752 P:24452'},
[24454]={[0]='Return To Caladis Brightspear',[1]='B0 FA K0800 L080 A:36669 T:36624 P:20439'},
[24455]={[0]='Rapid Deployment',[1]='B181 K0160 FH L012 A:536749 T:36956 P:14478'},
[24456]={[0]='Thunderhorn Cleansing',[1]='B0 K0080 FH RT RB L004 A:2948 T:2948 P:24441'},
[24457]={[0]='Rite of Vision',[1]='B0 K0060 FH RT L003 A:2948 T:3054 P:24456'},
[24458]={[0]='A Hello to Arms',[1]='B181 K0150 FH L013 A:36379 T:37009 P:14383+14388'}, -- 14388 is correct, assuming also requires 14383
[24459]={[0]='Morin Cloudstalker',[1]='B0 K0080 FH L006 A:36644 T:2988 I:749'},
[24461]={[0]='Reforging The Sword',[1]='B0 K0800 FA L080 A:36624 T:36624'},
[24463]={[0]='Probing into Ashenvale',[1]='B181 K0200 FH L018 A:36728 T:34195'},
[24467]={[0]='Fade to Black',[1]='B181 K0190 FH L015 A:35867 T:35867,36689'},
[24468]={[0]='Stranded at the Marsh',[1]='B0 K0080 FA RW L005 A:37065 T:37065 P:24438'},
[24469]={[0]='Hold the Line!',[1]='B0 FA K0010 A:37081 T:37081'},
[24470]={[0]="Give 'em What-For",[1]='B0 FA K0020 A:37081 T:37081 P:24469'},
[24471]={[0]='Aid for the Wounded',[1]='B0 FA K0020 A:658 T:658 P:24469'},
[24472]={[0]='Introductions Are in Order',[1]='B0 K0080 FA RW L005 A:37065 T:37065 P:24468'},
[24473]={[0]='Lockdown in Anvilmar',[1]='B0 FA K0020 A:37081 T:37087 P:24470+24471'},
[24474]={[0]="First Things First: We're Gonna Need Some Beer",[1]='B0 FA K0020 A:37087 T:37087 P:24473'},
[24475]={[0]='All the Other Stuff',[1]='B0 FA K0020 A:37087 T:37087 P:24474'},
[24476]={[0]='Tempering The Blade',[1]='B0 FA K08064 L080 A:36624 T:36624 P:24461'},
[24477]={[0]='Dwarven Artifacts',[1]='B0 FA K0020 A:1104 T:1104 P:24473'},
[24478]={[0]='The Trial of Frost',[1]='B181 K0180 FH L015 A:36361 T:36336,36361'},
[24479]={[0]='The Trial of Shadow',[1]='B181 K0180 FH L015 A:36361 T:36337,36361'},
[24480]={[0]='The Halls Of Reflection',[1]='B0 K0800 FA L080 A:36624 T:36624 P:24476'},
[24483]={[0]='Stormglen',[1]='B0 K0080 FA RW L005 A:37065 T:37102 P:24472'},
[24484]={[0]='Pest Control',[1]='B0 K0080 FA RW L005 A:37102 T:37102 P:24483'},
[24486]={[0]='Make Hay While the Sun Shines',[1]='B0 FA K0020 A:1104 T:1104 P:24477'},
[24487]={[0]='Whitebeard Needs Ye',[1]='B0 FA K0030 A:37087 T:786 P:24475+24486'},
[24488]={[0]='The Replacements',[1]='B0 K0030 RG A:37106 T:37106 P:24567'},
[24489]={[0]='Trolling for Information',[1]='B0 FA K0030 A:1354 T:1354 P:24487'},
[24490]={[0]='A Trip to Ironforge',[1]='B0 FA K0050 A:786 T:6782 P:218'},
[24491]={[0]='Follow that Gyro-Copter!',[1]='B0 FA K0050 A:6782 T:37113 P:24490'},
[24492]={[0]='Pack Your Bags',[1]='B0 FA K0050 A:37113 T:37113 P:24491'},
[24493]={[0]="Don't Forget About Us",[1]='B0 FA K0050 A:37087 T:1872 PL:24492'},
[24494]={[0]='Empowered Rune',[1]='B0 FA RF RD CS K0030 L003 A:37087 T:37115'},
[24495]={[0]='Pieces of the Past',[1]='B0 K0080 FA RW L005 A:37815 T:37815 P:24483'},
[24496]={[0]='Arcane Rune',[1]='B0 FA RF RE CM K0030 L003 A:37087 T:37121'},
[24497]={[0]='Airborne Again',[1]='B181 K0200 FH L018 A:37142 T:36730'},
[24498]={[0]='The Path to the Citadel',[1]='B0 K0800 FA L078 A:36993 T:37591 P:24683'},
[24499]={[0]='Echoes of Tortured Souls',[1]='B0 K0800 FA L078 A:37597 T:38160 P:24510'},
[24500]={[0]='Wrath of the Lich King',[1]='B0 K0800 FA L078 A:37582 T:36955'},
[24501]={[0]='Queen-Sized Troubles',[1]='B0 K0090 FA RW L005 A:37102 T:37102 P:24484'},
[24502]={[0]='Necessary Roughness',[1]='B0 K0030 RG A:37106 T:-605 P:24488'},
[24503]={[0]='Fourth and Goal',[1]='B0 K0030 RG A:-605,37106 T:37106 P:24502'},
[24504]={[0]='Clear the High Road',[1]='B607 K0300 FH L028 A:37135 T:37137 P:28549'},
[24505]={[0]="Holdout at Hunter's Hill",[1]='B607 K0300 FH L028 A:37137 T:37138 P:24504'},
[24506]={[0]='Inside the Frozen Citadel',[1]='B504956 K0800 FH L078 A:37780 T:37596'},
[24507]={[0]='The Path to the Citadel',[1]='B0 K0800 FH L078 A:36990 T:37592 P:24682'},
[24510]={[0]='Inside the Frozen Citadel',[1]='B504956 K0800 FA L078 A:37776 T:37597'},
[24511]={[0]='Echoes of Tortured Souls',[1]='B0 K0800 FH L078 A:37596 T:38161 P:24506'},
[24512]={[0]="Warriors' Redemption",[1]='B607 K0300 FH L028 A:37153 T:37153'},
[24513]={[0]='Eye for an Eye',[1]='B607 K0300 FH L028 A:37136 T:37136'},
[24514]={[0]='Raptor Scraps',[1]='B607 K0300 FH L028 A:37138 T:37138'},
[24515]={[0]='Signals in the Sky',[1]='B607 K0310 FH L029 A:37138 T:11857'},
[24517]={[0]='Put the Fear in Them',[1]='B607 K0310 FH L029 A:37154 T:37154'},
[24518]={[0]='The Low Road',[1]='B607 K0310 FH L029 A:100049776 T:37154'},
[24519]={[0]='Stalling the Survey',[1]='B607 K0310 FH L029 A:37154 T:37154 P:24518'},
[24520]={[0]='Give Sassy the News',[1]='B0 K0030 FH RG A:37106 T:34668 P:24503,28414'},
[24522]={[0]='Journey To The Sunwell',[1]='B0 K0800 FA L080 A:36624 T:37527 P:24480'},
[24523]={[0]='Wildmane Totem',[1]='B0 K0100 FH RT L004 A:37024 T:37024 P:20441'},
[24524]={[0]='Wildmane Cleansing',[1]='B0 K0100 FH RT L004 A:37024 T:37024 P:24523'},
[24525]={[0]='Keeping the Dogs at Bay',[1]='B607 K0310 FH L029 A:11857 T:11857'},
[24526]={[0]='Filling Up the Spellbook',[1]='B0 K0030 RF RE CM L003 A:37121 T:37121 P:24496'},
[24527]={[0]='Your Path Begins Here',[1]='B0 K0030 RF RD CS L003 A:37115 T:37115 P:24494'},
[24528]={[0]='The Power of the Light',[1]='B0 K0030 RF CP L003 A:926 T:926 P:3107'},
[24529]={[0]='Bad to Worse',[1]='B607 K0320 FH L030 A:11857 T:11857'},
[24530]={[0]="Oh, A Hunter's Life For Me",[1]='B0 K0030 RF CH L003 A:895 T:895'},
[24531]={[0]='Getting Battle-Ready',[1]='B0 K0030 RF CW L003 A:912 T:912 P:3106'},
[24532]={[0]="Evisceratin' the Enemy",[1]='B0 K0030 CR L003 A:916 T:916 P:3109'},
[24533]={[0]='Words of Power',[1]='B0 K0030 RF CT L003 A:837 T:837 P:3110'},
[24534]={[0]='Speaking Their Language',[1]='B607 K0320 FH L030 A:11857 T:11857 P:24529'},
[24535]={[0]='Thalorien Dawnseeker',[1]='B0 K0800 FA L080 A:37527 T:37527 P:24522'},
[24536]={[0]='Something Stinks',[1]='B0 HA FH A:37172 T:37172 O:24805'},
[24539]={[0]='When Plants Attack',[1]='B607 K0310 FH L029 A:37515 T:37515'},
[24540]={[0]='War Dance',[1]='B0 K0100 FH RT L008 A:36648 T:36648 P:24550'},
[24541]={[0]='Pilfering Perfume',[1]='B0 HA FH A:37172 T:37172 P:24536'},
[24542]={[0]='A Curious Bloom',[1]='B607 K0310 FH L029 A:37515 T:37570 P:24539'},
[24543]={[0]='A Family Divided',[1]='B607 K0320 FH L030 A:37516 T:3418'},
[24545]={[0]='The Sacred and the Corrupt',[1]='B0 K0800 CW CP CK L080 A:37120 T:1201742'},
[24546]={[0]='A Line in the Dirt',[1]='B607 K0320 FH L030 A:3418 T:3418 P:24543'},
[24547]={[0]='A Feast of Souls',[1]='B0 K0800 L080 A:37120 T:37120 P:24743'},
[24548]={[0]='The Splintered Throne',[1]='B0 K0800 L080 A:37120 T:37120 P:24757'},
[24549]={[0]='Shadowmourne...',[1]='B0 K0800 L080 A:37120 T:37120 P:24548'},
[24550]={[0]='Journey into Thunder Bluff',[1]='B0 K0100 FH RT L003 A:37024 T:36648 P:24524'},
[24551]={[0]='Meet the New Boss',[1]='B607 K0320 FH L030 A:3433 T:37679'},
[24552]={[0]="Lion's Pride",[1]='B607 K0330 FH L031 A:3387 T:3387'},
[24553]={[0]="The Purification of Quel'Delar",[1]='B0 K0800 FA L080 A:37527 T:36624'},
[24554]={[0]='The Battered Hilt',[1]='B492 K0800 FH L080 A:100050380 T:36642'},
[24555]={[0]='What The Dragons Know',[1]='B0 K0800 FH L080 A:36642 T:36670 P:24554'},
[24556]={[0]='A Suitable Disguise',[1]='B0 K0800 FH L080 A:36670 T:36670 P:24557'},
[24557]={[0]="The Silver Covenant's Scheme",[1]='B0 K0800 FH L080 A:36670 T:36670 P:24555'},
[24558]={[0]='Return To Myralion Sunblaze',[1]='B0 K0800 FH L080 A:36670 T:36642 P:24451'},
[24559]={[0]='Reforging The Sword',[1]='B0 K0800 FH L080 A:36642 T:36642'},
[24560]={[0]='Tempering The Blade',[1]='B0 K0800 FH L080 A:36642 T:36642 P:24559'},
[24561]={[0]='The Halls Of Reflection',[1]='B0 K0800 FH L080 A:36642 T:36642 P:24560'},
[24562]={[0]='Journey To The Sunwell',[1]='B0 K0800 FH L080 A:36642 T:37527 P:24561'},
[24563]={[0]='Thalorien Dawnseeker',[1]='B0 K0800 FH L080 A:37527 T:37527 P:24562'},
[24564]={[0]="The Purification of Quel'Delar",[1]='B0 K0800 FH L080 A:37527 T:36642'},
[24565]={[0]='Biological Intervention',[1]='B607 K0310 L029 A:37570 T:37570'},
[24566]={[0]='Sowing a Solution',[1]='B607 K0310 L029 A:38314 T:38314 P:24570+24571'},
[24567]={[0]='Report for Tryouts',[1]='B0 K0030 FH RG A:34874 T:37106 P:14071'},
[24569]={[0]='Siegebreaker',[1]='B607 K0320 FH L030 A:37679 T:37679'},
[24570]={[0]='Adder Subtraction',[1]='B607 K0310 L029 A:38314 T:38314'},
[24571]={[0]='Lashvine Seeds',[1]='B607 K0310 L029 A:38314 T:38314'},
[24572]={[0]='Taking Back Taurajo',[1]='B607 K0330 FH L030 A:37679 T:37679 P:24569'},
[24573]={[0]='Honoring the Dead',[1]='B607 K0330 FH L030 A:37717 T:37717'},
[24574]={[0]='To Harvest Chaos',[1]='B607 K0320 L029 A:37570 T:37570 P:24565'},
[24575]={[0]='Liberation Day',[1]='B0 K0100 FA RW L005 A:37783 T:37783 P:24677'},
[24576]={[0]='A Friendly Chat...',[1]='B0 HA FH A:38328 T:37172 P:24851'},
[24577]={[0]='Desolation Hold Inspection',[1]='B607 K0330 FH L030 A:37679 T:37811 P:24572'},
[24578]={[0]='The Blackwald',[1]='B0 K0080 FA RW L005 A:37815 T:37822 P:24501'}, -- does this also need P:24495 ?
[24579]={[0]='Sartharion Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24580]={[0]="Anub'Rekhan Must Die!",[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24581]={[0]='Noth the Plaguebringer Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24582]={[0]='Instructor Razuvious Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24583]={[0]='Patchwerk Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24584]={[0]='Malygos Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24585]={[0]='Flame Leviathan Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24586]={[0]='Razorscale Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24587]={[0]='Ignis the Furnace Master Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24588]={[0]='XT-002 Deconstructor Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24589]={[0]='Lord Jaraxxus Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24590]={[0]='Lord Marrowgar Must Die!',[1]='B0 K0800 +W L080 A:20735 T:20735'},
[24591]={[0]="Changing of the Gar'dul",[1]='B0 K0330 L030 A:37811 P:24577'},
[24592]={[0]="Betrayal at Tempest's Reach",[1]='B0 K0100 FA RE RW L005 A:37874 T:37876 P:24672'},
[24593]={[0]='Neither Human Nor Beast',[1]='B0 K0090 FA RE RW L005 A:37195 T:37195 P:24646'},
[24594]={[0]="The Purification of Quel'Delar",[1]='B0 K0800 FH L080 A:37527 T:36642'},
[24595]={[0]="The Purification of Quel'Delar",[1]='B0 K0800 FA L080 A:37527 T:36624'},
[24597]={[0]='A Gift for the King of Stormwind',[1]='B0 HA FA +D A:37887 T:29611'},
[24598]={[0]="The Purification of Quel'Delar",[1]='B0 K0800 FH L080 A:37527 T:36642'},
[24601]={[0]='The Nightmare Scar',[1]='B607 K0320 L029 A:37570 T:37570 P:24574'},
[24602]={[0]='Laid to Rest',[1]='B0 K0110 FA RW L005 A:38144 T:38144 P:24678'},
[24603]={[0]="Don't Stop Bereavin'",[1]='B607 K0340 FH L032 A:37847 T:37847'},
[24604]={[0]='Concern for Mankrik',[1]='B607 K0340 FH L032 A:37812 T:37847'},
[24606]={[0]='Blood of the Barrens',[1]='B607 K0340 L032 A:100049932 T:37812'},
[24607]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CW A:37951 T:38037'},
[24608]={[0]='Mangletooth',[1]='B607 K0340 FH L032 A:37847 T:37847 P:24603'},
[24609]={[0]='A Gift for a Lord of Ironforge',[1]='B0 HA FA +D A:38041 T:42928'},
[24610]={[0]='A Gift for the High Priestess of Elune',[1]='B0 HA FA +D A:38039 T:7999'},
[24611]={[0]='A Gift for the Prophet',[1]='B0 HA FA +D A:38040 T:17468'},
[24612]={[0]='A Gift for the Warchief',[1]='B0 HA FH +D A:38042 T:39605'},
[24613]={[0]='A Gift for the Banshee Queen',[1]='B0 HA FH +D A:38045 T:10181'},
[24614]={[0]='A Gift for the High Chieftain',[1]='B0 HA FH +D A:38044 T:36648'},
[24615]={[0]="A Gift for the Regent Lord of Quel'Thalas",[1]='B0 HA FH +D A:38043 T:16802'},
[24616]={[0]='Losing Your Tail',[1]='B0 K0090 FA RE RW L005 A:37822 T:37822 P:24578'},
[24617]={[0]="Tal'doren, the Wild Home",[1]='B0 K0090 FA RW L005 A:37822 T:37195 P:24616'},
[24618]={[0]='Claim the Battle Scar',[1]='B607 K0340 FH L032 A:37837 T:37837'},
[24619]={[0]='Parts-is-Parts',[1]='B607 K0340 FH L032 A:37908 T:37908'},
[24620]={[0]='Hearts-is-Hearts',[1]='B607 K0340 FH L032 A:37908 T:37908 P:24619'},
[24621]={[0]='Smarts-is-Smarts',[1]='B607 K0340 FH L032 A:37908 T:37908 P:24620'},
[24622]={[0]="A Troll's Truest Companion",[1]='B0 K0030 FH A:38005 T:37969 P:25064'},
[24623]={[0]='Saving the Young',[1]='B0 K0030 A:37969 T:37969 P:24622'},
[24624]={[0]='Mercy for the Lost',[1]='B0 FH K0030 A:37987 T:37987 P:24622'},
[24625]={[0]='Consort of the Sea Witch',[1]='B0 K0030 FH A:37987 T:37987 P:24622'},
[24626]={[0]='Young and Vicious',[1]='B0 K0030 A:37969 T:38005 P:24623+24624+24625'},
[24627]={[0]='At Our Doorstep',[1]='B0 K0090 FA RE RW L005 A:37195 T:37195 P:24617'},
[24628]={[0]='Preparations',[1]='B0 K0110 FA RW L005 A:37873 T:37873 P:24617'},
[24629]={[0]='A Perfect Puff of Perfume',[1]='B0 HA FA +D GF A:37675 T:37675 I:24635,24636,524629'},
[24631]={[0]='Flightmare',[1]='B607 K0340 FH L032 A:37909 T:37909'},
[24632]={[0]='Tauren Vengeance',[1]='B607 K0340 FH L032 A:37909 T:3341 P:24631'},
[24633]={[0]="Mahka's Plea",[1]='B607 K0350 FH L033 A:37812 T:37812'},
[24634]={[0]='Intelligence Warfare',[1]='B607 K0340 FH L032 A:37837 T:37837'},
[24635]={[0]='A Cloudlet of Classy Cologne',[1]='B0 HA FA +D GM A:37675 T:37675 I:24636,24629,524635'},
[24636]={[0]='Bonbon Blitz',[1]='B0 HA FA +D A:37675 T:37675 I:24635,24629,524636'},
[24637]={[0]='The Butcher of Taurajo',[1]='B607 K0340 FH L032 A:37837 T:37837 P:24634'},
[24638]={[0]='Crushing the Crown',[1]='B0 HA FH +D L005 M013 A:37172 T:37172 P:24576'},
[24639]={[0]='The Basics: Hitting Things',[1]='B0 K0020 CW A:38037 T:38037 P:24607'},
[24640]={[0]='The Arts of a Warrior',[1]='B0 K0030 CW A:38037 T:38037 P:24642'},
[24641]={[0]='A Rough Start',[1]='B0 K0030 FH CW A:38037 T:38037 P:24639'},
[24642]={[0]='Proving Pit',[1]='B0 K0030 CW A:38037 T:38037 P:24641'},
[24643]={[0]='More Than Expected',[1]='B0 K0030 FH CW A:38037 T:38966 P:24640'},
[24645]={[0]='Crushing the Crown',[1]='B0 HA FH +D L014 M022 A:37172 T:37172 P:24576'},
[24646]={[0]="Take Back What's Ours",[1]='B0 K0090 FA RW L005 A:37195 T:37195 P:24627'},
[24647]={[0]='Crushing the Crown',[1]='B0 HA FH +D L023 M031 A:37172 T:37172 P:24576'},
[24648]={[0]='Crushing the Crown',[1]='B0 HA FH +D L032 M040 A:37172 T:37172 P:24576'},
[24649]={[0]='Crushing the Crown',[1]='B0 HA FH +D L041 M050 A:37172 T:37172 P:24576'},
[24650]={[0]='Crushing the Crown',[1]='B0 HA FH +D L051 M060 A:37172 T:37172 P:24576'},
[24651]={[0]='Crushing the Crown',[1]='B0 HA FH +D L061 M070 A:37172 T:37172 P:24576'},
[24652]={[0]='Crushing the Crown',[1]='B0 HA FH +D L071 M080 A:37172 T:37172 P:24576'},
[24653]={[0]='Echoes of Agamaggan',[1]='B607 K0350 L033 A:37812 T:37812 P:24606'},
[24654]={[0]='Silithissues',[1]='B607 K0340 FH L032 A:37910 T:37910'},
[24655]={[0]='Something Stinks',[1]='B0 HA FA A:38066 T:38066 P:24804'},
[24656]={[0]='Pilfering Perfume',[1]='B0 HA FA A:38066 T:38066 P:24655'},
[24657]={[0]='A Friendly Chat...',[1]='B0 HA FA A:38325 T:38066 P:24849'},
[24658]={[0]='Crushing the Crown',[1]='B0 HA FA +D L005 M013 A:38066 T:38066 P:24657'},
[24659]={[0]='Crushing the Crown',[1]='B0 HA FA +D L014 M022 A:38066 T:38066 P:24657'},
[24660]={[0]='Crushing the Crown',[1]='B0 HA FA +D L023 M031 A:38066 T:38066 P:24657'},
[24662]={[0]='Crushing the Crown',[1]='B0 HA FA +D L032 M040 A:38066 T:38066 P:24657'},
[24663]={[0]='Crushing the Crown',[1]='B0 HA FA +D L041 M050 A:38066 T:38066 P:24657'},
[24664]={[0]='Crushing the Crown',[1]='B0 HA FA +D L051 M060 A:38066 T:38066 P:24657'},
[24665]={[0]='Crushing the Crown',[1]='B0 HA FA +D L061 M070 A:38066 T:38066 P:24657'},
[24666]={[0]='Crushing the Crown',[1]='B0 HA FA +D L071 M080 A:38066 T:38066 P:24657'},
[24667]={[0]='Firestone Point',[1]='B607 K0340 FH L032 A:37910 T:37834 P:24654'},
[24671]={[0]='Cluster Cluck',[1]='B0 K0070 FH RG A:38120 T:38120 P:27139'},
[24672]={[0]='Onwards and Upwards',[1]='B0 K0090 FA RW L005 A:37102 T:37874 P:24673'},
[24673]={[0]='Return to Stormglen',[1]='B0 K0090 FA RE RW L005 A:37195 T:37102 P:24593'},
[24674]={[0]='Slaves to No One',[1]='B0 K0110 RW L005 A:37803 T:37803 P:24592'}, -- TODO: Verify P:
[24675]={[0]='Last Meal',[1]='B0 K0100 FA RW L005 A:38143 T:38143 P:24592'}, -- TODO: Verify P:
[24676]={[0]='Push Them Out',[1]='B0 K0110 FA RW L005 A:37783 T:37783 P:24575+24674+24675'},
[24677]={[0]='Flank the Forsaken',[1]='B0 K0100 FA RE RW L005 A:37876 T:37783 P:24592'},
[24678]={[0]='Knee-Deep',[1]='B0 FA RW K0110 L005 A:38539 T:38144 P:24920'},
[24679]={[0]="Patriarch's Blessing",[1]='B0 K0110 FA RW L005 A:38144 T:38144 P:24602'},
[24680]={[0]='Keel Harbor',[1]='B0 K0120 FA RW L005 A:38144 T:38149 P:24679'},
[24681]={[0]='They Have Allies, But So Do We',[1]='B0 K0120 FA RW L005 A:38149 T:38149 P:24680'},
[24682]={[0]='The Pit of Saron',[1]='B0 K0800 FH L078 A:38161 T:36990 P:24511'},
[24683]={[0]='The Pit of Saron',[1]='B0 K0800 FA L078 A:38160 T:36993 P:24499'},
[24684]={[0]='A Weezil in the Henhouse',[1]='B607 K0350 FH L032 A:3341 T:38140 P:24632'},
[24685]={[0]='Dwarf Fortress',[1]='B607 K0350 FH L032 A:38140 T:38140 P:24684'},
[24686]={[0]='Carried on the Waves',[1]='B201 K0510 L049 A:38274 T:38274 P:24719'},
[24687]={[0]='Bouquets of Death',[1]='B201 K0510 L049 A:38263 T:38263 P:24689'},
[24689]={[0]='Flowing to the North',[1]='B201 K0510 L049 A:38274 T:38263 P:24686'},
[24690]={[0]='Blazerunner',[1]='B201 K0530 L049 A:9270 T:9270 P:24740'},
[24691]={[0]='Peculiar Delicacies',[1]='B201 K0520 L049 A:10977 T:10977 P:1'},
[24692]={[0]='The Fledgling Colossus',[1]='B201 K0530 L049 A:9271 T:9271'},
[24693]={[0]='Mossy Pile',[1]='B201 K0520 L049 A:10977 T:38275 P:24691'},
[24694]={[0]="The Shaper's Terrace",[1]='B201 K0550 L051 A:38504 T:38502 P:1'},
[24695]={[0]='Ever Watching From Above',[1]='B201 K0550 L051 A:38502 T:38502 P:24694'},
[24697]={[0]='How to Make Meat Fresh Again',[1]='B201 K0520 L050 A:38270 T:38270'},
[24698]={[0]='Adventures in Archaeology',[1]='B201 K0530 L051 A:38270 T:9272 P:1'},
[24699]={[0]='Gormashh the Glutinous',[1]='B201 K0540 L049 A:38276 T:38276 P:24737'},
[24700]={[0]='Hard to Harvest',[1]='B201 K0520 L049 A:38276 T:38276'},
[24701]={[0]="Marshal's Refuse",[1]='B201 K0530 L049 A:38277 T:38277'},
[24703]={[0]='An Important Lesson',[1]='B201 K0540 L051 A:38237 T:38237'},
[24704]={[0]="The Evil Dragons of Un'Goro Crater",[1]='B201 K0540 L051 A:38237,38255 T:38237'},
[24705]={[0]='Damsels Were Made to be Saved',[1]='B201 K0540 L051 A:38237,38255 T:38237'},
[24706]={[0]='The Spirits of Golakka Hot Springs',[1]='B201 K0540 L051 A:38237,38255 T:38237'},
[24707]={[0]='The Ballad of Maximillian',[1]='B201 K0550 L051 A:38237 AH:38343 T:38237'},
[24708]={[0]='The Fossil-Finder 3000',[1]='B201 K0540 L051 A:9272 T:9272 P:24730'},
[24709]={[0]='A Tale of Two Shovels',[1]='B201 K0550 L051 A:9272 T:9272 P:24708'},
[24710]={[0]='Deliverance from the Pit',[1]='B0 K0800 FA L078 A:37591 T:38188 P:24498'},
[24711]={[0]='Frostmourne',[1]='B0 K0800 FA L078 A:38188 T:37221 P:24710'},
[24712]={[0]='Deliverance from the Pit',[1]='B0 K0800 FH L078 A:37592 T:38189 P:24507'},
[24713]={[0]='Frostmourne',[1]='B0 K0800 FH L078 A:38189 T:37223 P:24712'},
[24714]={[0]='Chasing A-Me 01',[1]='B201 K0520 L050 A:9618 T:9623'},
[24715]={[0]='Repairing A-Me 01',[1]='B201 K0520 L050 A:9623 T:9623 P:24714'},
[24717]={[0]="The Apes of Un'Goro",[1]='B201 K0520 L049 A:38275 T:38275'},
[24719]={[0]='Claws of White',[1]='B201 K0510 L049 A:38274 T:38274 O:24854'},
[24720]={[0]='Crystals of Power',[1]='B201 K0520 L049 A:9117 T:9117'},
--
--	Note that with 24721, 24865 and 24911 in the quest log, the Marshall's Refuge
--	has nothing in it except golems.
--
[24721]={[0]='The Eastern Pylon',[1]='B201 K0530 L049 A:38263 T:9117 P:24855'},
[24722]={[0]='The Northern Pylon',[1]='B201 K0530 L049 A:38275 T:9117'},
[24723]={[0]='The Western Pylon',[1]='B201 K0550 L051 A:9272 T:9117 P:24709'},
[24724]={[0]='Crystal Restore',[1]='B0 K0550 L051 A:1164955 T:1164955'},
[24726]={[0]='Crystal Force',[1]='B0 K0550 FA L051 A:1164957 T:1164957 P:1'},
[24727]={[0]='Crystal Spire',[1]='B0 FA K0550 L051 A:1164957 T:1164957 P:1'},
[24728]={[0]='Crystal Ward',[1]='B0 K0550 FA L051 A:1164956 T:1164956'},
[24729]={[0]='Crystal Yield',[1]='B0 K0550 FA L051 A:1164956 T:1164956'},
[24730]={[0]='Roll the Bones',[1]='B201 K0530 L051 A:9272 T:9272 P:24698'},
[24731]={[0]="The Fare of Lar'korwi",[1]='B201 K0510 L049 A:9619 T:9619'},
[24732]={[0]="The Scent of Lar'korwi",[1]='B201 K0520 L049 A:9619 T:9619 P:24731'},
[24733]={[0]="The Bait for Lar'korwi",[1]='B201 K0530 L049 A:9619 T:9619 P:24732'},
[24734]={[0]='Lost!',[1]='B201 K0520 L049 A:9997 T:1202264 P:24794'},
[24735]={[0]='A Little Help From My Friends',[1]='B201 K0520 L049 A:9999 T:9997'},
[24736]={[0]="Shizzle's Flyer",[1]='B201 K0530 L049 A:9998 T:9998'},
[24737]={[0]='Super Sticky',[1]='B201 K0520 L049 A:38276 T:38276'},
[24740]={[0]='Volcanic Activity',[1]='B201 K0520 L049 A:9270 T:9270 P:24911,28525,28526'},
[24741]={[0]='Trading Up',[1]='B0 K0080 FH RG A:38122 T:38122'},
[24742]={[0]='Finding the Source',[1]='B201 K0520 L049 A:10302 T:10302'},
[24743]={[0]="Shadow's Edge",[1]='B0 K0800 L080 A:37120 T:37120 P:24545'},
[24744]={[0]='The Biggest Egg Ever',[1]='B0 K0080 FH RG A:38120 T:38120'},
[24745]={[0]="Something is in the Air (and it Ain't Love)",[1]='B0 K0800 HA FA L075 A:100050320 T:38066'},
[24747]={[0]='Sabotage!',[1]='B607 K0350 FH L032 A:38140 T:3341 P:24685'},
[24748]={[0]="The Lich King's Last Stand",[1]='B0 K0800 L080 A:37120 T:37120 P:24549'},
[24749]={[0]='Unholy Infusion',[1]='B0 K0800 CW CP CK L080 A:37120 T:37120 P:24547'},
[24750]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CS CM A:37951 T:38246'},
[24751]={[0]='The Basics: Hitting Things',[1]='B0 K0020 FH CS CM A:38246 T:38246 P:24750'},
[24752]={[0]='The Arts of a Mage',[1]='B0 K0030 FH CM A:38246 T:38246 P:24754'},
[24753]={[0]='A Rough Start',[1]='B0 K0030 FH CM A:38246 T:38246 P:24751'},
[24754]={[0]='Proving Pit',[1]='B0 K0030 FH CM A:38246 T:38246 P:24753'},
[24755]={[0]='More Than Expected',[1]='B0 K0030 FH CM A:38246 T:38966 P:24752'},
[24756]={[0]='Blood Infusion',[1]='B0 K0800 L080 A:37120 T:37120 P:24749'},
[24757]={[0]='Frost Infusion',[1]='B0 K0800 L080 A:37120 T:37120 P:24756'},
[24758]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CS A:37951 T:38242'},
[24759]={[0]='The Basics: Hitting Things',[1]='B0 K0020 CS A:38242 T:38242 P:24758'},
[24760]={[0]='The Arts of a Shaman',[1]='B0 K0030 CS A:38242 T:38242 P:24762'},
[24761]={[0]='A Rough Start',[1]='B0 K0030 FH CS A:38242 T:38242 P:24759'},
[24762]={[0]='Proving Pit',[1]='B0 K0030 CS A:38242 T:38242 P:24761'},
[24763]={[0]='More Than Expected',[1]='B0 K0030 FH CS A:38242 T:38966 P:24760'},
[24764]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH RT RL CD A:37951 T:38243'},
[24765]={[0]='The Basics: Hitting Things',[1]='B0 K0020 RT RL CD A:38243 T:38243 P:24764'},
[24766]={[0]='The Arts of a Druid',[1]='B0 K0030 RT RL CD A:538243 T:38243 P:24768'},
[24767]={[0]='A Rough Start',[1]='B0 K0030 FH RT RL CD A:38243 T:38243 P:24765'},
[24768]={[0]='Proving Pit',[1]='B0 K0030 RT RL CD A:38243 T:538243 P:24767'},
[24769]={[0]='More Than Expected',[1]='B0 K0030 FH RT RL CD A:38243 T:38966 P:24766'},
[24770]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CR A:37951 T:38244'},
[24771]={[0]='The Basics: Hitting Things',[1]='B0 K0020 RU RL RB CR A:38244 T:38244 P:24770'},
[24772]={[0]='The Arts of a Rogue',[1]='B0 K0030 RU RL RB CR A:38244 T:38244 P:24774'},
[24773]={[0]='A Rough Start',[1]='B0 K0030 FH RU RL RB CR A:38244 T:38244 P:24771'},
[24774]={[0]='Proving Pit',[1]='B0 K0030 RU RL RB CR A:38244 T:38244 P:24773'},
[24775]={[0]='More Than Expected',[1]='B0 K0030 FH RU RL RB CR A:38244 T:38966 P:24772'},
[24776]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CH A:37951 T:38247'},
[24777]={[0]='The Basics: Hitting Things',[1]='B0 K0020 CH A:38247 T:38247 P:24776'},
[24778]={[0]='The Arts of a Hunter',[1]='B0 K0030 CH A:38247 T:38247 P:24780'},
[24779]={[0]='A Rough Start',[1]='B0 K0030 FH CH A:38247 T:38247 P:24777'},
[24780]={[0]='Proving Pit',[1]='B0 K0030 CH A:38247 T:38247 P:24779'},
[24781]={[0]='More Than Expected',[1]='B0 K0030 FH CH A:38247 T:38966 P:24778'},
[24782]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CT A:37951 T:38245'},
[24783]={[0]='The Basics: Hitting Things',[1]='B0 K0020 CT A:38245 T:38245 P:24782'},
[24784]={[0]='The Arts of a Priest',[1]='B0 K0030 CT A:38245 T:38245 P:24786'},
[24785]={[0]='A Rough Start',[1]='B0 K0030 FH CT A:38245 T:38245 P:24783'},
[24786]={[0]='Proving Pit',[1]='B0 K0030 CT A:38245 T:38245 P:24785'},
[24787]={[0]='More Than Expected',[1]='B0 K0030 FH CT A:38245 T:38966 P:24784'},
[24794]={[0]='Speak With Spraggle',[1]='B201 K0530 L049 A:10302 T:9997 P:24742'},
[24795]={[0]='A Victory For The Silver Covenant',[1]='B0 FA K0800 L080 A:36624 T:33817 P:24595'},
[24796]={[0]='A Victory For The Silver Covenant',[1]='B0 FA K0800 L080 A:36624 T:30115 P:24553'},
[24799]={[0]='A Victory For The Sunreavers',[1]='B0 K0800 FH L080 A:36642 T:33817 P:24598'},
[24800]={[0]='A Victory For The Sunreavers',[1]='B0 K0800 FH L080 A:36642 T:30116 P:24594'},
[24801]={[0]='A Victory For The Sunreavers',[1]='B0 K0800 FH L080 A:36642 T:30116 P:24564'},
[24802]={[0]='Wrath of the Lich King',[1]='B0 K0800 FH L078 A:37779 T:37554'},
[24803]={[0]="Kalu'ak Fishing Derby",[1]='B0 ++ A:38294 T:38294'},
[24804]={[0]='Uncommon Scents',[1]='B0 HA FA A:38293 T:38066'},
[24805]={[0]='Uncommon Scents',[1]='B0 HA FH A:38295 T:37172'},
[24806]={[0]='Better Luck Next Time',[1]='B0 ++ A:38294 T:38294'},
[24807]={[0]='Winnoa Pineforest',[1]='B607 K0320 FH L029 A:37570 T:37717'},
[24812]={[0]='No More Mercy',[1]='B0 K0040 FH A:38442 T:38442 P:25035'},
[24813]={[0]='Territorial Fetish',[1]='B0 K0040 FH A:38442 T:38442 P:25035'},
[24814]={[0]='An Ancient Enemy',[1]='B0 K0050 A:38442 T:38966 P:24812+24813'},
[24815]={[0]='Choose Your Path',[1]='B0 K0800 L080 A:38316 T:38316'},
[24816]={[0]="Who's Top of the Food Chain Now?",[1]='B0 K0080 FH RG A:38120 T:38124'},
[24817]={[0]="A Goblin in Shark's Clothing",[1]='B0 K0080 FH RG A:38124 T:38120 P:24816'},
[24819]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24820]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24821]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24822]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24823]={[0]='Path of Destruction',[1]='B0 K0800 L080 A:38316 T:38316'},
[24824]={[0]='The Disturbed Earth',[1]='B607 K0340 L032 A:37834 T:37834'},
[24825]={[0]='Path of Wisdom',[1]='B0 K0800 L080 A:38316 T:38316'},
[24826]={[0]='Path of Vengeance',[1]='B0 K0800 L080 A:38316 T:38316'},
[24827]={[0]='Path of Courage',[1]='B0 K0800 L080 A:38316 T:38316'},
[24828]={[0]='Path of Destruction',[1]='B0 K0800 L080 A:38316 T:38316'},
[24829]={[0]='Path of Destruction',[1]='B0 K0800 L080 A:38316 T:38316'},
[24830]={[0]='Path of Wisdom',[1]='B0 K0800 L080 A:38316 T:38316'},
[24831]={[0]='Path of Wisdom',[1]='B0 K0800 L080 A:38316 T:38316'},
[24832]={[0]='Path of Vengeance',[1]='B0 K0800 L080 A:38316 T:38316'},
[24833]={[0]='Path of Vengeance',[1]='B0 K0800 L080 A:38316 T:38316'},
[24834]={[0]='Path of Courage',[1]='B0 K0800 L080 A:38316 T:38316'},
[24835]={[0]='Path of Courage',[1]='B0 K0800 L080 A:38316 T:38316'},
[24836]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24837]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24838]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24839]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24840]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24841]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24842]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24843]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24844]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24845]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24846]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24847]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[24848]={[0]='Fireworks At The Gilded Rose',[1]='B0 HA FA A:38066 T:38325 P:24656'},
[24849]={[0]='Hot On The Trail',[1]='B0 HA FA A:38325 T:38325 P:24848'},
[24850]={[0]="Snivel's Sweetheart",[1]='B0 HA FH A:37172 T:38328 P:24541'},
[24851]={[0]='Hot On The Trail',[1]='B0 HA FH A:38328 T:38328 P:24850'},
[24852]={[0]='Our Tribe, Imprisoned',[1]='B0 K0020 FH A:2980 T:2980 P:14452'},
[24854]={[0]='Finding Stormclaw',[1]='B201 K0510 L049 A:38269 T:38274 I:24719'},
[24855]={[0]='Aberrant Flora',[1]='B201 K0520 L049 A:38263 T:38263 P:24687'},
[24856]={[0]='Invasion Imminent!',[1]='B0 K0080 FH RG A:38120 P:24817'},
[24858]={[0]='Bilgewater Cartel Represent',[1]='B0 K0080 FH RG A:38432 T:38432 P:24856'},
[24859]={[0]='Naga Hide',[1]='B0 K0080 FH RG A:38381 T:38381'},
[24861]={[0]='Last Rites, First Rites',[1]='B0 K0050 FH A:2981 T:2981 P:14460'},
[24862]={[0]='Running the Gauntlet',[1]='B607 K0300 FA L028 A:38378 T:38380 O:28550'},
[24863]={[0]='Breaking the Siege',[1]='B607 K0300 FA L028 A:38378 T:38380'},
[24864]={[0]='Irresistible Pool Pony',[1]='B0 K0080 FH RG A:38432 T:38432 P:24858'},
[24865]={[0]='Is This Stuff Still Good?',[1]='B201 K0510 L049 A:1161526 T:9270'},
[24866]={[0]='An Abandoned Research Camp',[1]='B201 K0510 L049 A:1161521 T:9271'},
[24868]={[0]='Surrender or Else!',[1]='B0 K0080 FH RG A:38432 T:38432 P:24864'},
[24897]={[0]='Get Back to Town',[1]='B0 K0080 FH RG A:38432 T:38387 P:24868'},
[24901]={[0]='Town-In-A-Box: Under Attack',[1]='B0 K0080 FH RG A:38387 T:38387 P:24897'},
[24902]={[0]='The Hunt For Sylvanas',[1]='B0 FA RW K0110 L005 A:38611 T:38611 P:24904'},
[24903]={[0]='Vengeance or Survival',[1]='B0 FA RW K0110 L005 A:38611 T:38539 P:24902'},
[24904]={[0]='The Battle for Gilneas City',[1]='B0 K0110 FA RE RW L005 A:37783 T:38611 P:24676'},
[24905]={[0]='Returning a Favor',[1]='B161 K0470 FH L045 A:38706 T:38849'},
[24906]={[0]='Seaside Salvage',[1]='B161 K0450 FH L043 A:38534 T:38534'},
[24907]={[0]='Puddle Stomping',[1]='B161 K0450 FH L043 A:38534 T:38534'},
[24910]={[0]='Rocket Rescue',[1]='B161 K0450 FH L043 A:38534 T:38534'},
[24911]={[0]='Tropical Paradise Beckons',[1]='B201 K0520 L049 AA:38578 AH:44374 T:9270 I:28525,28526 B201'},
[24912]={[0]='Empowerment',[1]='B0 K0800 L080 A:37120 T:37120'},
[24913]={[0]='Remember the Light',[1]='B38 FA K0550 L053 A:17127 T:17127 P:27902+27904'},
[24914]={[0]='Personal Property',[1]='B0 K0800 L080 A:100051315 T:37120'},
[24915]={[0]="Mograine's Reunion",[1]='B0 K0800 L080 A:37120 T:37120'},
[24916]={[0]="Jaina's Locket",[1]='B0 K0800 L080 A:38606 T:38606'},
[24917]={[0]="Muradin's Lament",[1]='B0 K0800 L080 A:38607 T:38607'},
[24918]={[0]="Sylvanas' Vengeance",[1]='B0 K0800 L080 A:38609 T:38609'},
[24919]={[0]="The Lightbringer's Redemption",[1]='B0 K0800 L080 A:38608 T:38608'},
[24920]={[0]='Slowing the Inevitable',[1]='B0 FA RE RW K0110 L005 A:38539 T:38539 P:24903'},
[24921]={[0]='Report to Aubrey',[1]='B607 K0300 FA L028 A:38623 T:38619 O:28551 I:24934,25197'},
[24924]={[0]='Oomlot Village',[1]='B0 K0080 FH RG A:38387 T:38647 P:24901'},
[24925]={[0]='Free the Captives',[1]='B0 K0080 FH RG A:38647 T:38647'},
[24926]={[0]='Serving A-Me 01',[1]='B201 K0520 L050 A:9623 T:9618 P:24715'},
[24927]={[0]="Dead Man's Chest",[1]='B161 K0460 FH L044 A:38703 T:38703'},
[24928]={[0]='To The Ground!',[1]='B161 K0460 FH L044 A:38703 T:38703 P:24927+24949'},
[24929]={[0]='Send a Message',[1]='B0 K0080 FH RG A:38647 T:38647 P:24925'},
[24930]={[0]="While You're At It",[1]='B0 K0030 RW A:35118 AA:35115 T:35115'},
[24931]={[0]='Gazer Tag',[1]='B161 K0470 L045 A:11811 T:11811 P:25072'},
[24932]={[0]='Cutting Losses',[1]='B161 K0470 L045 A:38706 T:38706 P:26889'},
[24933]={[0]='Chicken of the Desert',[1]='B161 K0470 L045 A:38706 T:38706 P:24932'},
[24934]={[0]='Repel Boarders!',[1]='B607 K0300 FA L028 A:38619 T:38622 O:24921,25197'},
[24937]={[0]='Oomlot Dealt With',[1]='B0 K0080 FH RG A:38647 T:38387 P:24925,24929'},
[24938]={[0]='The Guns of Northwatch',[1]='B607 K0300 FA L028 A:38619 T:3454 P:24934'},
[24939]={[0]='Run Out the Guns',[1]='B607 K0300 FA L028 A:3454 T:3454 P:24938'},
[24940]={[0]='Up the Volcano',[1]='B0 K0080 FH RG A:38387 T:38738 P:24937'},
[24941]={[0]='Langridge Shot',[1]='B607 K0300 FA L028 A:38620 T:1202335'},
[24942]={[0]='Zombies vs. Super Booster Rocket Boots',[1]='B0 K0080 FH RG A:38738 T:38738 P:24940'},
[24943]={[0]='Re-Take the Courtyard',[1]='B607 K0300 FA L028 A:38620 T:38620 P:24941'},
[24944]={[0]='Back in the Fight',[1]='B607 K0300 FA L028 A:38804 T:38804 P:24941'},
[24945]={[0]='Three Little Pygmies',[1]='B0 K0090 FH RG A:36471 T:36471'},
[24946]={[0]="Rockin' Powder",[1]='B0 K0080 FH RG A:38124 T:38124'},
[24947]={[0]='Momentum',[1]='B161 K0460 FH L044 A:38534 T:38703 P:24910'},
[24948]={[0]='Lifting the Siege',[1]='B607 K0300 FA L028 A:38620 T:38620 P:24943'},
[24949]={[0]='Booty Duty',[1]='B161 K0460 FH L044 A:38703 T:38703 P:24927'},
[24950]={[0]='Captain Dreadbeard',[1]='B161 K0460 FH L044 A:38703 T:38703 P:24928+25534+25541'},
[24951]={[0]='A Great Idea',[1]='B161 K0470 L045 A:38706 T:38706 P:24933'},
[24952]={[0]='Rocket Boot Boost',[1]='B0 K0080 FH RG A:38738 T:38120 P:24942'},
[24953]={[0]='Just Trying to Kill Some Bugs',[1]='B161 K0470 L045 A:38706 T:38706 P:24951'},
[24954]={[0]='Children of a Turtle God',[1]='B0 K0080 FH RG A:38120 T:38120 P:24952'},
[24955]={[0]='Un-Chartered',[1]='B161 K0480 FH L046 A:38849 T:38849 P:24905'},
[24956]={[0]='Silencing Rageroar',[1]='B607 K0310 FA L028 A:38804 T:38804 P:24944'},
[24957]={[0]='Get The Centipaarty Started',[1]='B161 K0480 FH L046 A:38849 T:38849'},
[24958]={[0]='Volcanoth!',[1]='B0 K0090 FH RG A:38120 T:38928 P:24954'},
[24959]={[0]='Fresh out of the Grave',[1]='B0 K0010 FH RU A:49044 T:1568'},
[24960]={[0]='The Wakening',[1]='B0 K0010 RU A:2307 T:2307 P:28608 O:28652'},
[24961]={[0]='The Truth of the Grave',[1]='B0 FH K0030 L002 A:1661 T:1661 P:26801 O:28651'},
[24962]={[0]='Trail-Worn Scroll',[1]='B0 K0030 FH RU CH L003 A:1569 T:38911 P:26801'},
[24963]={[0]="Maul 'Em With Kindness",[1]='B161 K0480 FH L046 A:38849 T:38849 P:24957'},
[24964]={[0]='The Thrill of the Hunt',[1]='B0 K0030 RU CH L003 A:38911 T:38911 P:24962'},
[24965]={[0]='Magic Training',[1]='B0 K0030 RU CM L003 A:2124 T:2124 P:3098'},
[24966]={[0]='Of Light and Shadows',[1]='B0 K0030 RU CT L003 A:2123 T:2123 P:3097'},
[24967]={[0]='Stab!',[1]='B0 K0030 RU CR L003 A:2122 T:2122 P:3096'},
[24968]={[0]='Dark Deeds',[1]='B0 K0030 RU CL L003 A:2126 T:2126 P:3099'},
[24969]={[0]='Charging into Battle',[1]='B0 K0030 RU CW L003 A:2119 T:2119 P:3095'},
[24970]={[0]='No Better Than the Zombies',[1]='B0 K0040 FH L003 A:1570 T:49425 P:24973'},
[24971]={[0]='Assault on the Rotbrain Encampment',[1]='B0 K0050 FH L002 A:49425 T:1569 P:24970'},
[24972]={[0]='Vital Intelligence',[1]='B0 K0050 FH RU L002 A:1569 T:1519 P:24971'},
[24973]={[0]="Night Web's Hollow",[1]='B0 K0040 FH L002 A:1570 T:1570 P:26802'},
[24974]={[0]='Ever So Lonely',[1]='B0 K0060 FH L005 A:38925 T:38925'},
[24975]={[0]='Fields of Grief',[1]='B0 K0060 FH L005 A:1518 T:1518'},
[24976]={[0]='Variety is the Spice of Death',[1]='B0 K0060 FH L005 A:1518 T:1518 P:24975'},
[24977]={[0]="Johaan's Experiment",[1]='B0 K0060 FH L005 A:1518 T:1931 P:24976'},
[24978]={[0]='Reaping the Reapers',[1]='B0 K0060 FH L005 A:1519 T:1519'},
[24979]={[0]='A Scarlet Letter',[1]='B0 K0060 FH L005 A:100052079 T:1519'},
[24980]={[0]='The Scarlet Palisade',[1]='B0 K0060 FH L005 A:1519 T:1519 P:24978'},
[24981]={[0]='A Thorn in our Side',[1]='B0 K0080 FH L005 A:1515 T:1515'},
[24982]={[0]='The New Forsaken',[1]='B0 K0070 FH L005 A:1496 T:1499 I:24983'},
[24983]={[0]='Forsaken Duties',[1]='B0 K0080 FH L005 A:1499 T:1495 O:24982'},
[24988]={[0]='The Chill of Death',[1]='B0 K0080 FH L005 A:1521 T:1521 P:24983'},
[24989]={[0]='Return to the Magistrate',[1]='B0 K0080 FH L005 A:1495 T:1499 P:24988'},
[24990]={[0]='Darkhound Pounding',[1]='B0 K0060 FH L006 A:10665 T:10665 P:24977'},
[24991]={[0]="Garren's Haunt",[1]='B0 K0080 FH L005 A:10665 T:38977 P:24996 I:24994'},
[24992]={[0]='Escaped From Gilneas',[1]='B0 FH K0070 L005 AK:1547,1548 T:1515 I:25039 OAC:25040 PLT:24990'}, -- this autoaccepts after the kill...I cannot remember if that is the case with all AK: codes *** there is a P: needed, but not sure what it is
[24993]={[0]='Annihilate the Worgen',[1]='B0 K0080 FH L005 A:1515 T:1515 P:24992,25039'},
[24994]={[0]='Doom Weed',[1]='B0 K0070 FH L006 A:38977 T:38977 O:24991'},
[24995]={[0]='Off the Scales',[1]='B0 K0080 FH L006 A:38977 T:38977 P:24994'},
[24996]={[0]="Holland's Experiment",[1]='B0 K0060 FH L005 A:10665 T:2211 P:24990'},
[24997]={[0]='Graverobbers',[1]='B0 K0070 FH L006 A:38978 T:38978'},
[24998]={[0]='Maggot Eye',[1]='B0 K0090 FH L006 A:38978 T:38978 P:24997'},
[24999]={[0]='Planting the Seed of Fear',[1]='B0 K0080 FH L006 A:38978 T:38978 P:24994'},
[25000]={[0]="Teegan's People",[1]='B607 K0310 FA L029 A:38621 T:38873'},
[25001]={[0]='Sandscraper',[1]='B161 K0480 FH L046 A:38849 T:38849 P:24963'},
[25002]={[0]='Scavenged',[1]='B607 K0310 FA L029 A:38878 T:38871'},
[25003]={[0]='The Family Crypt',[1]='B0 K0090 FH L006 A:1500 T:1500 O:25031'},
[25004]={[0]='The Mills Overrun',[1]='B0 K0080 FH L006 A:1500 T:1500 P:25003'},
[25005]={[0]='Speak with Sevren',[1]='B0 K0090 FH L006 A:1500 T:1499 P:25004+25029'},
[25006]={[0]='The Grasp Weakens',[1]='B0 K0090 FH L006 A:1499 T:1499 P:25005'},
[25007]={[0]='East... Always to the East',[1]='B0 K0090 FH L006 A:1499 T:10837 P:25006'},
[25008]={[0]='Filthy Animals',[1]='B607 K0310 FA L029 A:38873 T:38873'},
[25009]={[0]='At War With The Scarlet Crusade',[1]='B0 K0090 FH L006 A:10837 T:10837 P:25007'},
[25010]={[0]='A Deadly New Ally',[1]='B0 K0100 FH L006 A:10837 T:13158 P:25009'},
[25011]={[0]='To Bigger and Better Things',[1]='B0 K0100 FH L006 A:10837 T:37915 P:25046'},
[25012]={[0]='Take to the Skies',[1]='B0 K0100 FH L006 A:37915 T:1515 P:25011'},
[25013]={[0]='A Little Oomph',[1]='B0 K0100 FH L007 A:11057 T:11057 P:25056'},
[25014]={[0]="Sandscraper's Treasure",[1]='B161 K0480 FH L046 A:1202407 T:38849'},
[25015]={[0]="Make 'em Squeal",[1]='B607 K0310 FA L029 A:38871 T:38871'},
[25017]={[0]='Ancient Obstacles',[1]='B161 K0490 FH L047 A:38922 T:38922 P:25019,25020'},
[25018]={[0]='Andoren Will Know',[1]='B161 K0480 FH L046 A:38849 T:38922 P:25014'},
[25019]={[0]='Laying Claim',[1]='B161 K0490 FH L047 A:38922 T:38922'},
[25020]={[0]='Fragments of Language',[1]='B161 K0490 FH L047 A:38922 T:38922 P:25019'},
[25021]={[0]='Blood to Thrive',[1]='B161 K0450 L043 A:38927 T:38927'},
[25022]={[0]='A Failure to Communicate',[1]='B607 K0310 FA L029 A:38871 T:38871'},
[25023]={[0]='Old Friends',[1]='B0 K0090 FH RG A:38928 T:38935 P:24958'},
[25024]={[0]='Repel the Paratroopers',[1]='B0 K0090 FH RG A:38935 T:38935 P:25023'},
[25025]={[0]="Sang'thraze the Deflector",[1]='B161 K0450 L043 A:38927 T:38927 P:25021'},
[25026]={[0]='Darkest Mojo',[1]='B161 K0450 L043 A:38927 T:38927 P:25025'},
[25027]={[0]='You Flicked a Fine Vine to Leaf Me',[1]='B607 K0310 FA L029 A:38871 T:38871 P:25015+25022'},
[25028]={[0]='Trouble From the Ground Up',[1]='B607 K0310 FA L029 A:38876 T:37570 P:25015+25022'},
[25029]={[0]='Deaths in the Family',[1]='B0 K0090 FH L006 A:1500 T:1500 P:25003'},
[25030]={[0]='The Haunted Mills',[1]='B0 K0090 FH L006 A:100003082 T:1500'},
[25031]={[0]='Head for the Mills',[1]='B0 K0090 FH L006 A:38977 T:1500 I:25003 P:24995'},
[25032]={[0]='Secrets in the Oasis',[1]='B161 K0460 L044 A:38927 T:7804 P:25026'},
[25034]={[0]='To the Front!',[1]='B607 K0310 FA L029 A:38871 T:38986 P:25027'},
[25035]={[0]='Breaking the Line',[1]='B0 K0040 FH A:38440 T:38442 P:1'},
[25036]={[0]="Teegan's Troubles",[1]='B607 K0310 FA L029 A:38620 T:38871 P:24948+24956'},
[25037]={[0]="Crab Fishin'",[1]='B0 K0030 FH A:39007 T:39007 P:24769'},
[25038]={[0]="Gordo's Task",[1]='B0 K0060 FH L005 A:10666 T:10665 P:24976'},
[25039]={[0]='Have You Seen Anything Weird Out There?',[1]='B0 FH K0070 L005 A:6785 T:1515 P:25040 I:24992'},
[25040]={[0]='FLAG - Worgen Attacked',[1]='B0 '}, -- special flag that Blizzard uses to trigger the ability to get 25039 if 24992 is ever dropped
[25041]={[0]="Lion's Pride",[1]='B607 K0320 FA L030 A:39003 T:39003'},
[25042]={[0]='Marching On Our Stomachs',[1]='B607 K0320 FA L030 A:39003 T:39003 P:25041'},
[25043]={[0]='Fields of Blood',[1]='B607 K0320 FA L030 A:38323 T:38323'},
[25044]={[0]='Diplomacy By Another Means',[1]='B607 K0320 FA L030 A:38986 T:38986 P:25022'},
[25045]={[0]='A Line in the Dirt',[1]='B607 K0320 FA L030 A:38323 T:38323'},
[25046]={[0]="A Daughter's Embrace",[1]='B0 K0100 FH L006 A:13158 T:10837 P:25010'},
[25047]={[0]='Broken Panther Figurine',[1]='B0 PJ475 A:100052197'},
[25048]={[0]='Seaside Salvage',[1]='B161 FA K0450 L043 A:38535 T:38535 O:27446,28507'},
[25049]={[0]='Puddle Stomping',[1]='B161 FA K0450 L043 A:38535 T:38535'},
[25050]={[0]='Rocket Rescue',[1]='B161 FA K0450 L043 A:38535 T:38535 P:25048+25049'},
[25051]={[0]='Darkmist Extermination',[1]='B141 K0360 FH L034 A:4926 T:4926'},
[25052]={[0]="Dead Man's Chest",[1]='B161 FA K0460 L044 A:38704 T:38704 P:25050'},
[25053]={[0]='To The Ground!',[1]='B161 FA K0460 L044 A:38704 T:38704 P:25050'},
[25054]={[0]="Lootin' Plunder",[1]='B161 FA K0460 L044 A:38704 T:38704 P:25050'},
--[25055]={[0]='Subduing the Elements',[1]='FA L005 A:45712 T:45712'},
[25056]={[0]='Grisly Grizzlies',[1]='B0 K0090 FH L007 A:11057 T:11057'},
[25057]={[0]="Clap 'Em In Irons",[1]='B607 K0320 FA L030 A:38323 T:38323 P:25043+25045'},
[25058]={[0]='Mine Disposal, the Goblin Way',[1]='B0 K0090 FH RG A:38387 T:38387'},
[25059]={[0]='The Taurajo Briefs',[1]='B607 K0320 FA L030 A:38986 T:38986 P:25043+25045'},
[25060]={[0]='Define "Crazy"',[1]='B161 FA K0480 L046 A:39059 T:39059 P:25166 O:25061'},
[25061]={[0]="Land's End",[1]='B161 FA K0470 L045 A:11811 T:39059 P:24953 I:25060'},
[25062]={[0]='What We Came For',[1]='B161 FA K0480 L046 A:39059 T:39059 P:25166'},
[25063]={[0]='Terrapination',[1]='B161 FA K0480 L046 A:39059 T:39059 P:25060+25062'},
[25064]={[0]='Moraya',[1]='B0 K0030 FH A:38966 T:38005 P:24769'},
[25065]={[0]='You Too, Brute?',[1]='B161 FA K0480 L046 A:39059 T:39059 P:25063'},
[25066]={[0]='The Pride of Kezan',[1]='B0 K0090 FH RG A:38387 T:38387 P:25058'},
[25067]={[0]='Thunderdrome: The Ginormus!',[1]='B161 K0490 L047 A:39034 T:19860 O:26895,26896'},
[25068]={[0]='The Crumbling Past',[1]='B161 K0490 FH L047 A:38922 T:38922'},
[25069]={[0]='The Secrets of Uldum',[1]='B161 K0490 FH L047 A:38922 T:1202474'},
[25070]={[0]='What Lies Within',[1]='B161 K0490 L047 A:1202474 T:1202474 P:25069,25566'},
[25072]={[0]='A Few Good Goblins',[1]='B161 K0470 L045 A:38706 T:38706 P:26889'},
[25073]={[0]="Sen'jin Village",[1]='B0 K0050 FH A:38966 T:3188 P:24814 I:25167'},
[25074]={[0]='Meet Me at Triumph',[1]='B607 K0330 FA L030 A:38323 T:39083 P:25057'},
[25075]={[0]='Pick-a-Part',[1]='B607 K0330 FA L031 A:39084 T:39084'},
[25079]={[0]='Powder Play',[1]='B607 K0330 FA L031 A:39084 T:39084 P:25075'},
[25080]={[0]='Batteries Not Yet Included',[1]='B607 K0330 FA L031 A:39084 T:39084 P:25079'},
[25081]={[0]='Claim the Battlescar',[1]='B607 K0340 FA L032 A:39083 T:39083'},
[25082]={[0]='Working the Bugs Out',[1]='B607 K0340 FA L032 A:39085 T:39085'},
[25084]={[0]='A Growing Threat',[1]='B607 K0340 FA L032 A:37835 T:37835'},
[25085]={[0]='Mangletooth',[1]='B607 K0340 FA L032 A:37835 T:37835 P:25084'},
[25086]={[0]='Firestone Point',[1]='B607 K0340 FA L032 A:39085 T:37835 P:25082'},
[25087]={[0]='Report to Twinbraid',[1]='B607 K0340 FA L032 A:39083 T:39118 P:25081'},
[25089]={[0]='Beyond the Graves',[1]='B0 K0010 FH RU A:2307 T:1740 P:24960'},
[25090]={[0]='A Putrid Task',[1]='B0 K0060 FH L004 A:1496 T:1496'},
[25091]={[0]='Sandsorrow Watch',[1]='B161 K0450 L043 A:39178 T:7804 P:25115'},
--[25092]={[0]='Subduing the Elements',[1]='FH L005 A:39283 T:39283'},
[25093]={[0]='The Heads of the SI:7',[1]='B0 K0100 FH RG A:39065 T:39065'},
[25094]={[0]='Thunderdrome: Zumonga!',[1]='B161 K0490 L047 A:39034 T:19860 P:25067'},
[25095]={[0]='Thunderdrome: Sarinexx!',[1]='B161 K0490 L047 A:39034 T:19860 P:25094'},
[25098]={[0]='The Warchief Wants You',[1]='B0 K0090 FH RG A:38387 T:38935 P:25066'},
[25099]={[0]='Borrow Bastia',[1]='B0 K0090 FH RG A:38935 T:39066 P:25098'},
[25100]={[0]="Let's Ride",[1]='B0 K0090 FH RG A:39066 T:38517 P:25099'},
[25102]={[0]='No Bull',[1]='B607 K0340 FA L032 A:39154 T:39154'},
[25103]={[0]='Bootlegger Outpost',[1]='B161 K0460 FH L044 A:38703 T:38706 P:24950'},
[25104]={[0]='Digsite Status',[1]='B607 K0340 FA L032 A:39118 T:39155'},
[25105]={[0]='Nibbler!  No!',[1]='B0 +D FA K0010 PJ475 A:50480 T:50480 I:25154,25155,25156,25157'},
[25106]={[0]='Hands Off Me Dig!',[1]='B607 K0340 FA L032 A:39155 T:39155 P:25104'},
[25107]={[0]='The Grand Tablet',[1]='B161 K0490 FH L047 A:1202474 T:38922'},
[25108]={[0]='Feegly the Exiled',[1]='B607 K0340 FA L032 A:39155 T:39155 P:25104'},
[25109]={[0]='The Gallywix Labor Mine',[1]='B0 K0090 FH RG A:38517 T:38124 P:25100'},
[25110]={[0]="Kaja'Cola Gives You IDEAS! (TM)",[1]='B0 K0090 FH RG A:38124 T:38124 P:25109'},
[25111]={[0]='Scavengers Scavenged',[1]='B161 K0450 L043 A:39178 T:39178 P:25112'},
[25112]={[0]='Butcherbot',[1]='B161 K0450 L043 A:39178 T:39178'},
[25115]={[0]='Blisterpaw Butchery',[1]='B161 K0450 L043 A:39178 T:39178 P:25111'},
[25118]={[0]='Looking for Lurkers',[1]='B35 FA K0130 L011 A:1777 T:1777'},
[25120]={[0]="Marley's Final Flight",[1]='B607 K0340 FA L032 A:39155 T:39188 P:25106+25108'},
[25121]={[0]='Momentum',[1]='B161 FA K0460 L044 A:38535 T:38704 P:25050'},
[25122]={[0]='Morale Boost',[1]='B0 K0090 FH RG A:39199 T:39199'},
[25123]={[0]='Throw It On the Ground!',[1]='B0 K0100 FH RG A:39199 T:39199 P:25122'},
[25125]={[0]='Light at the End of the Tunnel',[1]='B0 K0090 FH RG A:39199 T:39341 P:25122,25123'},
[25126]={[0]='Cutting Teeth',[1]='B0 K0020 A:3143 T:3143 P:25152'},
[25127]={[0]='Sting of the Scorpid',[1]='B0 FH K0030 A:3143 T:3143 P:25172'},
[25128]={[0]="Hana'zua",[1]='B0 K0050 FH L003 A:5887 T:3287 P:25127'},
[25129]={[0]='Sarkoth',[1]='B0 K0050 FH A:3287 T:3287'},
[25130]={[0]='Back to the Den',[1]='B0 K0050 FH A:3287 T:3143 P:25129'},
[25131]={[0]='Vile Familiars',[1]='B0 K0040 L003 A:3145 T:3145 P:25127'},
[25132]={[0]='Burning Blade Medallion',[1]='B0 K0050 A:3145 T:3145 P:25131'},
[25133]={[0]="Report to Sen'jin Village",[1]='B0 K0050 FH A:3145 T:3188 P:25132'},
[25134]={[0]='Lazy Peons',[1]='B0 FH K0040 L003 A:11378 T:11378'},
[25135]={[0]="Thazz'ril's Pick",[1]='B0 K0040 FH L003 A:11378 T:11378 P:25131'},
[25136]={[0]="Galgar's Cactus Apple Surprise",[1]='B0 FH K0030 A:9796 T:9796 P:25126'},
[25138]={[0]='Glyphic Parchment',[1]='B0 FH RO CM K0030 L003 A:3143 T:39206'},
[25139]={[0]='Steady Shot',[1]='B0 K0030 RO CH L003 A:39214 T:39214 P:3087'},
[25141]={[0]='Eviscerate',[1]='B0 K0030 RO RE CR L003 A:3155 T:3155 P:3088'},
[25143]={[0]='Primal Strike',[1]='B0 K0030 RO CS L003 A:3157 T:3157 P:3089'},
[25145]={[0]='Immolate',[1]='B0 K0030 RO RL CL L003 A:3156 T:3156 P:3090'},
[25147]={[0]='Charge',[1]='B0 K0030 RO CW L003 A:3153 T:3153 P:2383'},
[25149]={[0]='Arcane Missiles',[1]='B0 RO CM K0030 L003 A:39206 T:39206 P:25138'},
[25151]={[0]='He Needs Ale!',[1]='B607 K0340 FA L032 A:39188 T:39188 P:25120'},
[25152]={[0]='Your Place In The World',[1]='B0 K0010 FH A:10176 T:3143'},
[25153]={[0]="Bael'dun Rescue",[1]='B607 K0340 FA L032 A:39218 T:39218 P:25120'},
[25154]={[0]='A Present for Lila',[1]='B0 +D FA K0010 PJ475 A:50480 T:50480 I:25105,25155,25156,25157'},
[25155]={[0]='Ogrezonians in the Mood',[1]='B0 +D FA K0010 PJ475 A:50480 T:50480 I:25105,25154,25156,25157'},
[25156]={[0]='Elemental Goo',[1]='B0 +D FA K0010 PJ475 A:50480 T:50480 I:25105,25154,25155,25157'},
[25157]={[0]='The Latest Fashion!',[1]='B0 +D FA K0010 PJ475 A:50480 T:50480 I:25105,25154,25155,25156'},
[25158]={[0]='Nibbler!  No!',[1]='B0 +D FH K0010 A:50482 T:50482 PJ475 I:25159,25160,25161,25162'},
[25159]={[0]='The Latest Fashion!',[1]='B0 +D FH K0010 A:50482 T:50482 PJ475 I:25158,25160,25161,25162'},
[25160]={[0]='A Present for Lila',[1]='B0 +D FH K0010 A:50482 T:50482 PJ475 I:25158,25159,25161,25162'},
[25161]={[0]='Ogrezonians in the Mood',[1]='B0 +D FH K0010 A:50482 T:50482 PJ475 I:25158,25159,25160,25162'},
[25162]={[0]='Elemental Goo',[1]='B0 +D FH K0010 A:50482 T:50482 PJ475 I:25158,25159,25160,25161'},
[25163]={[0]='Who Did This?',[1]='B607 K0340 FA L032 A:39220 T:38152 P:25120'},
[25164]={[0]='Backed Into a Corner',[1]='K0810 L080 A:39226 T:39226 P:25334'},
[25165]={[0]='Never Trust a Big Barb and a Smile',[1]='B0 K0060 FH L004 A:10578 T:10578 P:25170'},
[25166]={[0]='Captain Dreadbeard',[1]='B161 FA K0460 L044 A:38704 T:38704 P:25053+26886+26887'},
[25167]={[0]='Breaking the Chain',[1]='B0 K0060 FH L004 A:3188 T:3188 O:25073'},
[25168]={[0]='Purge the Valley',[1]='B0 K0060 FH L004 A:3188 T:3188 P:25167'},
[25169]={[0]='The War of Northwatch Aggression',[1]='B0 K0060 FH L004 A:3140 T:3140 P:25167'},
[25170]={[0]='Cleaning Up the Coastline',[1]='B0 K0060 FH L004 A:10578 T:10578'},
[25171]={[0]='Riding On',[1]='B0 K0060 FH L004 A:3188 T:3139 P:25168+25169'},
[25172]={[0]='Invaders in Our Home',[1]='B0 K0030 A:3143 T:3143 P:25126'},
[25173]={[0]='From Bad to Worse',[1]='B0 K0070 FH L004 A:3139 T:3139 P:25171'},
[25174]={[0]='Twinbraid Needs to Know',[1]='B607 K0340 FA L032 A:38152 T:39118 P:25163'},
[25175]={[0]='The Bad News',[1]='B607 K0340 FA L032 A:39188 T:39118 P:25151'},
[25176]={[0]='Exploiting the Situation',[1]='B0 FH K0070 L004 A:39423 T:39423 P:25171'},
[25177]={[0]='Storming the Beaches',[1]='B0 K0070 FH L004 A:3139 T:3139 P:25173'},
[25178]={[0]='Shipwreck Searching',[1]='B0 K0070 FH L004 A:39423 T:39423 P:25176'},
[25179]={[0]='Loss Reduction',[1]='B0 FH A:39270 T:3139'},
--[25180]={[0]='Tablets of the Earth',[1]='FA K0800 L005 A:45702 T:2918'},
--[25181]={[0]='Tablets of Fire',[1]='FH L005 A:39283 T:39283'},
[25182]={[0]="Kill 'em All!",[1]='B607 K0350 FA L032 A:39118 T:39118 P:25174'},
[25183]={[0]='...And Bury the Rest',[1]='B607 K0350 FA L032 A:39118 T:1202598 P:25174'},
[25184]={[0]='Wild Mine Cart Ride',[1]='B0 K0090 FH RG A:39341 T:38124 P:25125'},
[25185]={[0]='The Deed Is Done',[1]='B607 K0350 FA L032 A:1202598 T:39118 P:25183'},
[25186]={[0]='Futile Resistance',[1]='B607 K0310 FA L029 A:38380 T:38379 P:24862+24863'},
[25187]={[0]='Lost in the Floods',[1]='B0 K0080 FH L004 A:39323 T:39323 P:25227'},
[25188]={[0]='Watershed Patrol',[1]='B0 K0080 FH L004 A:39323 T:39323 P:25187'},
[25189]={[0]='Spirits Be Praised',[1]='B0 K00832 FH L004 A:39325 T:39326'},
[25190]={[0]="Raggaran's Rage",[1]='B0 K0080 FH L004 A:39326 T:39326'},
[25191]={[0]='Survey the Destruction',[1]='B607 K0300 FA L028 A:38383 T:39322'},
[25192]={[0]="Raggaran's Fury",[1]='B0 K0090 FH L004 A:39326 T:39326 P:25190'},
[25193]={[0]='Lost But Not Forgotten',[1]='B0 K0080 FH L004 A:3193 T:3193'},
[25194]={[0]='Unbidden Visitors',[1]='B0 K0080 FH L004 A:39324 T:39324'},
[25195]={[0]="That's the End of That Raptor",[1]='B0 K0090 FH L004 A:39324 T:39324 P:25194'},
[25196]={[0]="The Dranosh'ar Blockade",[1]='B0 K0100 FH L008 A:3142 T:39379 P:25232'},
[25197]={[0]="The Admiral Won't Back Down",[1]='B607 K0300 FA L028 A:39322 T:38619 P:25191 I:24921,24934'},
[25200]={[0]='Shredder Shutdown',[1]='B0 K0100 FH RG A:38124 T:38124 P:25184'},
[25201]={[0]='The Ultimate Footbomb Uniform',[1]='B0 K0100 FH RG A:38738 T:38738'},
[25202]={[0]='The Fastest Way to His Heart',[1]='B0 K0110 FH RG A:38647 T:38647'},
[25203]={[0]='What Kind of Name is Chip, Anyway?',[1]='B0 K0110 FH RG A:38441 T:38441'},
[25204]={[0]='Release the Valves',[1]='B0 K0100 FH RG A:38124 T:1202613 P:25200'},
[25205]={[0]='The Wolf and The Kodo',[1]='B0 K0100 FH L008 A:39380 T:39380'},
[25206]={[0]='Ignoring the Warnings',[1]='B0 K0100 FH L008 A:39379 T:39379'},
[25207]={[0]='Good-bye, Sweet Oil',[1]='B0 K0100 FH RG A:1202613 T:38124 P:25204'},
[25208]={[0]='Tell Silvia',[1]='B121 K0360 FA L034 A:40052 T:39653 P:25403'},
[25209]={[0]='The Gordunni Threat',[1]='B121 K0360 FH L034 A:39656 T:39656'},
[25210]={[0]='Signs of Change',[1]='B121 K0360 FH L034 A:39377 T:39377'},
[25211]={[0]='Cleaning Hovel',[1]='B40 FA K0210 L018 A:41074 T:41074'},
[25213]={[0]='The Slave Pits',[1]='B0 K0100 FH RG A:38124 T:38387 P:25207'},
[25214]={[0]='Escape Velocity',[1]='B0 K0100 FH RG A:38120 T:38120'},
[25215]={[0]='A Distracting Scent',[1]='K0810 L080 A:39876 T:39876 P:25222'},
[25216]={[0]='The Great Sambino',[1]='K0810 L080 A:39876 T:39882 P:25222'},
[25217]={[0]='Totem Modification',[1]='K0810 L080 A:39882 T:39882 P:25218'},
[25218]={[0]='Undersea Inflation',[1]='K0810 L080 A:39882 T:39882 P:25216'},
[25219]={[0]="Don't be Shellfish",[1]='K0810 L080 A:39875 T:39875 TH:49920 P:25222'},
[25220]={[0]='Slippery Threat',[1]='K0810 L080 A:39878 T:39878 P:25222'},
[25221]={[0]='Rundown',[1]='K0810 L080 A:39877 T:539877 P:25164'},
[25222]={[0]='Silver Tide Hollow',[1]='K0810 L080 A:539877 T:39876 P:25221'},
[25223]={[0]='Trial By Fire',[1]='B606 K0810 L080 A:39442 T:39442 P:25276'},
[25224]={[0]='In Bloom',[1]='B606 K0810 L080 A:39442 T:39442 P:25276'},
[25227]={[0]='Thonk',[1]='B0 K0080 FH L004 A:39423 T:39323 P:25178'},
[25230]={[0]='More Than Illness',[1]='B121 K0360 FH L034 A:39377 T:39377 P:25210'},
[25232]={[0]='The Burning Blade',[1]='B0 K0100 FH L008 A:3142 T:3142'},
[25233]={[0]='End of the Supply Line',[1]='B606 K0810 L080 A:39427 T:39427 P:25584'},
[25234]={[0]='In the Rear With the Gear',[1]='B606 K0810 L080 A:39427 T:39427 P:25584'},
[25235]={[0]="Vulgar Vul'Gol",[1]='B34 FA K0220 L020 A:888 T:888 I:26137'}, -- It is reported that this I: is really a glitch with Blizzard's current implementation and should be removed in the future when Blizzard fixes it.
[25236]={[0]='Thunder Down Under',[1]='B0 K0100 FH L008 A:39379 T:39379'},
[25237]={[0]='Tears of Stone',[1]='B121 K0360 FH L034 A:39377 T:39377'},
[25239]={[0]='Path of Might',[1]='B0 K0800 L080 A:38316 T:38316'},
[25240]={[0]='Path of Might',[1]='B0 K0800 L080 A:38316 T:38316'},
[25241]={[0]='The Land, Corrupted',[1]='B121 K0360 FH L034 A:39377 T:39377 P:25237'},
[25242]={[0]='Path of Might',[1]='B0 K0800 L080 A:38316 T:38316'},
[25243]={[0]='She Loves Me, She Loves Me NOT!',[1]='B0 K0110 FH RG A:38387 T:38387'},
[25244]={[0]='What Kind of Name is Candy, Anyway?',[1]='B0 K0110 FH RG A:38387 T:38387 P:25243'},
[25246]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[25247]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[25248]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[25249]={[0]='A Change of Heart',[1]='B0 K0800 ++ L080 A:39509 T:39509'},
[25250]={[0]='Sealing the Dream',[1]='B121 K0360 FH L034 A:39377 T:39377 P:25237,25241'},
[25251]={[0]='Final Confrontation',[1]='B0 K0100 FH RG A:38387 T:38387 P:25243,25244'},
[25252]={[0]='Rulers of Dire Maul',[1]='B121 K0370 FH L034 A:39656 T:39656 P:25209'},
[25255]={[0]='Harrying the Hunters',[1]='B606 K0810 L080 A:39429 T:39429 P:25584'},
[25256]={[0]='Sent for Help',[1]='B0 K0100 FH L008 A:39604 T:39590'},
[25257]={[0]='Ghislania',[1]='B0 K0100 FH L008 A:39590 T:39590'},
[25258]={[0]='Griswold Hanniston',[1]='B0 K0100 FH L008 A:39590 T:39590'},
[25259]={[0]='Gaur Icehorn',[1]='B0 K0100 FH L008 A:39590 T:39590'},
[25260]={[0]='Fizzled',[1]='B0 K0100 FH L008 A:39379 T:39379 P:25196'},
[25261]={[0]='Margoz',[1]='B0 K0100 FH L008 A:39379 T:3208 P:25260'},
[25262]={[0]='Skull Rock',[1]='B0 K0120 FH L004 A:3208 T:3208 P:25261'},
[25263]={[0]='Neeru Fireblade',[1]='B0 K0120 FH L004 A:3208 T:3216'},
[25264]={[0]="Ak'Zeloth",[1]='B0 K0130 FH L004 A:3216 T:3521 P:25263'},
[25265]={[0]='Victory!',[1]='B0 K0110 FH RG A:38387 T:38935 P:25251'},
[25266]={[0]="Warchief's Emissary",[1]='B0 K0110 FH RG A:38935 T:39609 P:25265'},
[25267]={[0]='Message for Garrosh',[1]='B0 K0110 FH RG A:39609 T:39605 P:25266'},
[25268]={[0]='The Voice of Goldrinn',[1]='B606 FA K0810 L080 A:39427 T:39433 P:25233'},
[25269]={[0]="The Voice of Lo'Gosh",[1]='B606 FH K0810 L080 A:39429 T:39432'},
[25270]={[0]='Howling Mad',[1]='B606 FH K0810 L080 A:39432 T:39432 P:25269'},
[25271]={[0]="Goldrinn's Ferocity",[1]='B606 FA K0810 L080 A:39433 T:39433 P:25268'},
[25272]={[0]='Lycanthoth the Corruptor',[1]='B606 FH K0810 L080 A:39432 T:39622 P:25270'},
[25273]={[0]='Lycanthoth the Corruptor',[1]='B606 FA K0810 L080 A:39433 T:39627 P:25271'},
[25274]={[0]='Signed in Blood',[1]='B606 K0810 L080 A:39621 T:39621 P:25597'},
[25275]={[0]='Report to the Labor Captain',[1]='B0 K0110 FH RG A:39605 T:35086 P:25267'},
[25276]={[0]='Your New Identity',[1]='B606 K0810 L080 A:39621 T:39442 P:25274'},
[25277]={[0]='Cleaning House',[1]='B606 FH K0810 L080 A:39432 T:39432 P:25279'},
[25278]={[0]='Cleaning House',[1]='B606 FA K0810 L080 A:39433 T:539433 P:25280'},
[25279]={[0]='The Shrine Reclaimed',[1]='B606 K0810 FH L080 A:39622 T:39432'},
[25280]={[0]='The Shrine Reclaimed',[1]='B606 K0810 FA L080 A:539627 T:539433 P:25273'},
[25281]={[0]='Pay It Forward',[1]='FA K0810 L080 A:36915 T:36915 P:24432'},
[25284]={[0]='Feeding the Fear',[1]='B607 K0300 FH L028 A:37153 T:37153'},
[25291]={[0]='Twilight Training',[1]='B606 K0810 L080 A:39442 T:39413 P:25223+25224+25330'}, -- guessed at, done in order: 25224,25223,25330.  appeared after last
[25292]={[0]='Next of Kin',[1]='B141 K0350 FH L032 A:39697 T:39144 B141'},
[25294]={[0]='Walking the Dog',[1]='B606 K0810 L080 A:39406 T:39406 P:25291'},
[25296]={[0]='Gather the Intelligence',[1]='B606 K0810 L080 A:1006093 T:1006093 P:25291'},
[25297]={[0]='From the Mouth of Madness',[1]='B606 K0810 L080 A:39434 T:1006098 P:25273'},
[25298]={[0]='Free Your Mind, the Rest Follows',[1]='B606 K0810 L080 A:1006098 T:39434 P:25297'},
[25299]={[0]='Mental Training: Speaking the Truth to Power',[1]='B606 K0810 L080 A:39413 T:39413 P:25499'},
[25300]={[0]='The Eye of Twilight',[1]='B606 K0810 L080 A:39435 T:1006089 P:25273'},
[25301]={[0]='Mastering Puppets',[1]='B606 K0810 L080 A:1006089 T:1006104 P:25300'},
[25303]={[0]='Elementary!',[1]='B606 K0810 L080 A:1006104 T:1006104 P:25301'},
[25304]={[0]='The Battle of Sardor',[1]='B121 K0370 FA L035 A:3936 T:39723 O:26402'},
[25308]={[0]='Seeds of Discord',[1]='B606 K0810 L080 A:1006093 T:1006093 P:25296'},
[25309]={[0]='Spiritual Training: Mercy is for the Weak',[1]='B606 K0810 L080 A:39413 T:39413 P:25299'},
[25310]={[0]='The Greater of Two Evils',[1]='B606 K0810 L080 A:39413 T:39413 P:25309+25496'},
[25311]={[0]='Twilight Territory',[1]='B606 K0810 L080 A:39413 T:39413 P:25309+25496'},
[25312]={[0]='Return to Duskwhisper',[1]='B606 K0810 L080 A:1006104 T:39435 P:25303'},
[25314]={[0]='Speech Writing for Dummies',[1]='B606 K0810 L080 A:1006093 T:1006093 P:25310+25311'}, -- guessed at, done in order: 25311,25310.  appeared after last
[25315]={[0]='Graduation Speech',[1]='B606 K0810 L080 A:39413 T:40619 P:25601'},
[25316]={[0]='As Hyjal Burns',[1]='B0 K0810 L080 A:39865 T:40289 P:27721,27726'},
[25317]={[0]='Protect the World Tree',[1]='B606 K0810 L080 A:40289 T:39857 TH:45312'},
[25319]={[0]="War on the Twilight's Hammer",[1]='B606 K0810 L080 A:39857 T:39857 P:25317'},
[25320]={[0]='The Captured Scout',[1]='B606 K0810 L080 A:38917 T:40096 P:25430'},
[25321]={[0]='Twilight Captivity',[1]='B606 K0810 L080 A:40096 T:40096 P:25320'},
[25323]={[0]='Flamebreaker',[1]='B606 K0810 L080 A:39857 T:39857 P:25472'},
[25324]={[0]='A Prisoner of Interest',[1]='B606 K0810 L080 A:38917 T:40139 P:25424'},
[25325]={[0]='Through the Dream',[1]='B606 K0810 L080 A:40139 T:40178 P:25324'},
[25328]={[0]="Gar'gol's Gotta Go",[1]='B606 K0810 L080 A:39640 T:39640'},
[25329]={[0]='Might of the Stonemaul',[1]='B121 K0370 FH L034 A:39656 T:39656'},
[25330]={[0]='Waste of Flesh',[1]='B606 K0810 L080 A:39451 T:39451 P:25276'},
[25332]={[0]='Get Me Outta Here!',[1]='B606 K08132 L080 A:39640 T:39435 P:25328'},
[25333]={[0]='Might of the Sentinels',[1]='B121 K0370 FA L035 A:39653 T:39653 P:25208+25406'},
[25334]={[0]='The Looming Threat',[1]='K0810 L080 A:39226 T:40398 P:25471'},
[25336]={[0]='Testing the Vessel',[1]='B121 K0380 FH L035 A:39894 T:39894'},
[25337]={[0]='Hippogryph Muisek',[1]='B121 K0380 FH L035 A:39894 T:39894 P:25336'},
[25338]={[0]='Treant Muisek',[1]='B121 K0370 FH L035 A:8115 T:8115 P:25641'},
[25339]={[0]='Vengeance on the Northspring',[1]='B121 K0360 FH L034 A:7776 T:7776'},
[25340]={[0]='Dark Heart',[1]='B121 K0360 FH L034 A:7776 T:7776'},
[25341]={[0]='The Gordunni Orb',[1]='B121 K0360 FH L034 A:39656 T:39656'},
[25342]={[0]="Talk to Swar'jan",[1]='B121 K0370 FH L035 A:39656 T:39840 P:25341'},
[25344]={[0]='Ogre Abduction',[1]='B121 K0370 FH L034 A:39840 T:39840 P:25342'},
[25345]={[0]='Faerie Dragon Muisek',[1]='B121 K0370 FH L035 A:8115 T:8115 P:25338'},
[25346]={[0]='Mountain Giant Muisek',[1]='B121 K0370 FH L035 A:8115 T:8115 P:25345'},
[25349]={[0]='Twisted Sisters',[1]='B121 K0400 FH L038 A:39847 T:39847'},
[25350]={[0]='The Lost Apprentice',[1]='B121 K0370 FA L035 A:40132 T:40129'},
[25352]={[0]='Sweeping the Shelf',[1]='B606 FA K0810 L080 A:539433 T:539433 P:25278'},
[25353]={[0]='Lightning in a Bottle',[1]='B606 FA K0810 L080 A:539433 T:500015 P:25278'},
[25354]={[0]='Sweeping the Shelf',[1]='B606 FH K0810 L080 A:39432 T:39432'},
[25355]={[0]='Lightning in a Bottle',[1]='B606 FH K0810 L080 A:39432 T:39622'}, -- needs P:
[25356]={[0]='To the Summit',[1]='B61 K0400 FH L038 A:39893 T:39895 P:28504 B61'},
[25357]={[0]='Buy Us Some Time',[1]='FA K0810 L080 A:39887 T:39887 P:25405'},
[25358]={[0]='Nerve Tonic',[1]='K0810 L080 A:40983 T:40983 P:25602'},
[25359]={[0]="Toshe's Vengeance",[1]='K0810 L080 A:39876 T:40221 P:25456'},
[25360]={[0]='Crabby Patrons',[1]='K0810 L080 A:40227 T:40227'},
[25361]={[0]="A New Cloak's Sheen",[1]='B121 K0380 FH L036 A:4544 T:4544'},
[25362]={[0]='A Grim Discovery',[1]='B121 K0380 FH L036 A:4544 T:4544 P:25361'},
[25363]={[0]='War on the Woodpaw',[1]='B121 K0380 FH L036 A:7875 T:7875'},
[25364]={[0]='Alpha Strike',[1]='B121 K0380 FH L036 A:7875 T:7875'},
[25365]={[0]='Woodpaw Investigation',[1]='B121 K0380 FH L036 A:7875 T:1142195'},
[25366]={[0]='The Battle Plans',[1]='B121 K0390 FH L037 A:1142195 T:7875 P:25365'},
[25367]={[0]="Zukk'ash Infestation",[1]='B121 K0380 FH L036 A:7875 T:7875'},
[25368]={[0]='Verinias the Twisted',[1]='B121 K0370 L035 A:40131 T:40131 P:25422+25423'},
[25369]={[0]='Stinglasher',[1]='B121 K0380 FH L036 A:7875 T:7875'},
[25370]={[0]='Inciting the Elements',[1]='B606 K0810 L080 A:40278 T:22016,40278'},
[25371]={[0]='The Abyssal Ride',[1]='K0810 L080 A:41248 T:41248 P:25477'},
[25372]={[0]="Aessina's Miracle",[1]='B606 K0810 L080 A:41381 T:539858 P:25842'},
[25373]={[0]='The Hilltop Threat',[1]='B121 K0390 FH L037 A:39847 T:39847'},
[25374]={[0]='Sasquatch Sighting',[1]='B121 K0390 FH L037 A:39847 T:39847'},
[25375]={[0]='Taming The Tamers',[1]='B121 K0390 FH L037 A:39847 T:39847'},
[25377]={[0]="The Horde's Hoard",[1]='K0810 L080 A:100053053 T:1202759 P:25598'},
[25378]={[0]="Ysondre's Call",[1]='B121 K0400 FH L038 A:39847 T:39407 P:25349'},
[25379]={[0]="Taerar's Fall",[1]='B121 K0400 L038 A:39407 T:39407 P:25378,25437'},
[25381]={[0]='Fighting Fire With ... Anything',[1]='B606 K0810 L080 A:39927 T:39927 P:25630'},
[25382]={[0]='Disrupting the Rituals',[1]='B606 K0810 L080 A:39927 T:39927'}, -- needs P code, coming in with 25630 in log has this available
[25383]={[0]="Ysondre's Farewell",[1]='B121 K0400 FH L038 A:39407 T:39847 P:25379'},
[25385]={[0]='Save the Wee Animals',[1]='B606 K0810 L080 A:39930 T:39930'}, -- needs P code, coming in with 25630 in log has this available
[25386]={[0]='To Stonemaul Hold',[1]='B121 K0360 FH L034 A:39377 T:39656 P:25250'},
[25387]={[0]='To Camp Mojache',[1]='B121 K0380 FH L036 A:39656 T:39847 P:25329'},
[25388]={[0]='A Case of Crabs',[1]='K0810 L080 A:1202871 T:39883 P:25598'},
[25389]={[0]='A Taste For Tail',[1]='K0810 L080 A:39883 T:39883 P:25598'},
[25390]={[0]="A Girl's Best Friend",[1]='K0810 L080 A:39883 T:39883 P:25598'},
[25391]={[0]='Weapons of Spirit',[1]='B121 K0370 FH L035 A:8115 T:8115 P:25346'},
[25392]={[0]='Oh, Deer!',[1]='B606 K0810 L080 A:39930 T:39930 P:25385'},
[25394]={[0]='More Than Illness',[1]='B121 K0360 FA L034 A:40032 T:40032 P:25447'},
[25395]={[0]='The Stolen Keg',[1]='B40 FA K0200 L018 A:41075 T:41075 O:26137,28565'},
[25396]={[0]='Tears of Stone',[1]='B121 K0360 FA L034 A:40032 T:40032 P:25394'},
[25397]={[0]='The Land, Corrupted',[1]='B121 K0360 FA L034 A:40032 T:40032 P:25396'},
[25398]={[0]='Sealing the Dream',[1]='B121 K0360 FA L034 A:40032 T:40032 P:25396+25397'},
[25399]={[0]='Hatecrest Forces',[1]='B121 K0370 FA L035 A:39723 T:3936'},
[25400]={[0]='The Gordunni Threat',[1]='B121 K0370 FA L035 A:39653 T:39653'},
[25401]={[0]='The Gordunni Orb',[1]='B121 K0370 FA L035 A:39653 T:39653'},
[25402]={[0]="Estulan's Examination",[1]='B121 K0370 FA L035 A:39653 T:40052 P:25401'},
[25403]={[0]='Ogre Abduction',[1]='B121 K0370 FA L034 A:40052 T:40052 P:25402'},
[25404]={[0]="If You're Not Against Us...",[1]='B606 K0810 L080 A:39928 T:39933'}, -- needs P code, coming in with 25630 in log has this available
[25405]={[0]='Rest For the Weary',[1]='FA K0810 L080 A:36915 T:39887 P:25281'},
[25406]={[0]='Gordok Guards',[1]='B121 K0370 FA L035 A:39653 T:39653 P:25400'},
[25407]={[0]='Forces of Nature: Wisps',[1]='B121 K0370 FA L035 A:40078 T:40078'},
[25408]={[0]='Seeds of Their Demise',[1]='B606 K0810 L080 A:39933 T:39933 P:25404'},
[25409]={[0]='Forces of Nature: Hippogryphs',[1]='B121 K0370 FA L035 A:40078 T:40078 P:25407'},
[25410]={[0]='Forces of Nature: Treants',[1]='B121 K0370 FA L035 A:40078 T:40078 P:25409'},
[25411]={[0]='A New Master',[1]='B606 K0810 L080 A:39933 T:40093 P:25408'},
[25412]={[0]='The Name Never Spoken',[1]='B606 K0810 L080 A:40093 T:39933 P:25411'},
[25419]={[0]="Lady La-La's Medallion",[1]='B0 K0810 SP L080 A:100055186 T:0'},
[25420]={[0]='Ancient Obstacles',[1]='B161 FA K0490 L047 A:40109 T:40109 O:28881'},
[25421]={[0]='The Grand Tablet',[1]='B161 FA K0490 L047 A:1202474 T:40109'},
[25422]={[0]='The Darkmist Legacy',[1]='B121 K0370 L035 A:40131 T:40131 P:25350'},
[25423]={[0]='Ancient Suffering',[1]='B121 K0370 L035 A:40131 T:40131 P:25350'},
[25424]={[0]='Return to Alysra',[1]='B606 K0810 L080 A:40096 T:38917 P:25321'},
[25426]={[0]='War on the Woodpaw',[1]='B121 FA K0390 L037 A:39725 T:39725'},
[25427]={[0]='Alpha Strike',[1]='B121 K0390 FA L037 A:39725 T:39725 P:25426'},
[25428]={[0]='Black Heart of Flame',[1]='B606 K0810 L080 A:39933 T:39933 P:25412'},
[25429]={[0]="Zukk'ash Infestation",[1]='B121 K0390 FA L037 A:39725 T:39725 P:25427'},
[25430]={[0]='Emerald Allies',[1]='B606 K0810 L080 A:39869 T:38917 P:25464'},
[25431]={[0]='Stinglasher',[1]='B121 K0390 FA L037 A:39725 T:39725 P:25427'},
[25432]={[0]="It's Not \"Ogre\" Yet",[1]='B121 FA K0390 L037 A:39725 T:39725'},
[25433]={[0]='Sasquatch Sighting',[1]='B121 K0390 FA L037 A:39725 T:39725 P:25432'},
[25434]={[0]='Taming The Tamers',[1]='B121 K0390 FA L037 A:39725 T:39725 P:25432'},
[25436]={[0]='Spiteful Sisters',[1]='B121 K0400 FA L038 A:39725 T:39725 P:25429'},
[25437]={[0]="Ysondre's Call",[1]='B121 K0400 FA L038 A:39725 T:39407 P:25436'},
[25438]={[0]="Ysondre's Farewell",[1]='B121 K0400 FA L038 A:39407 T:39725 P:25379'},
[25439]={[0]='Vengeful Heart',[1]='K0810 L080 A:40221 T:40221 P:25359'},
[25440]={[0]="Fathom-Lord Zin'jatar",[1]='K0810 L080 A:40221 T:40221 P:25439'},
[25441]={[0]='Vortex',[1]='K0810 L080 A:40221 T:40221'},
[25442]={[0]='A Pearl of Wisdom',[1]='K0810 L080 A:100054614 T:39875'},
--[25443]={[0]='The Name Never Spoken',[1]='B606 K0810 FH L080 A:39933 T:39933'},
[25447]={[0]='Signs of Change',[1]='B121 K0360 FA L034 A:40032 T:40032 O:14410,28511'},
[25448]={[0]='The Northspring Menace',[1]='B121 K0360 FA L034 A:40035 T:40035'},
[25449]={[0]='The Mark of Quality',[1]='B121 K0360 FA L034 A:40226 T:40226'},
[25450]={[0]='Improved Quality',[1]='B121 K0370 FA L034 A:40226 T:40226 P:25449'},
[25451]={[0]='Pristine Yeti Hide',[1]='B121 K0370 FA L035 A:100055166 T:40226 P:25449'}, -- TODO: Determine if this is in fact repeatable
[25452]={[0]='The Mark of Quality',[1]='B121 K0360 FH L034 A:7854 T:7854'},
[25453]={[0]='Improved Quality',[1]='B121 K0370 FH L034 A:7854 T:7854 P:25452'},
[25454]={[0]='Perfect Yeti Hide',[1]='B121 K0370 FH L034 A:100055167 T:7854 P:25452'},
[25456]={[0]='Back in One Piece',[1]='K0810 L080 A:39882 T:39876 P:25217'},
[25458]={[0]='General Skessesh',[1]='B121 K0370 FA L035 A:39723 T:3936'},
[25459]={[0]='Ophidophobia',[1]='K0810 L080 A:39883 T:39883 P:25602'},
[25460]={[0]='The Earth Rises',[1]='B606 K0810 L080 A:39925 T:39925'},
[25462]={[0]='The Bears Up There',[1]='B606 K0810 L080 A:39932 T:39932 O:25940'}, -- need to discover if there is a P:
[25463]={[0]='Report to Silvia',[1]='B121 K0370 FA L035 A:3936 T:39653 P:25458'},
[25464]={[0]='The Return of Baron Geddon',[1]='B606 K0810 L080 A:39857 T:39857 TH:45312 P:25323'},
[25465]={[0]='Still With The Zapped Giants',[1]='B121 K0370 L035 A:14637 T:14637'},
[25466]={[0]='Even More Fuel for the Zapping',[1]='B121 K0370 L035 A:14637 T:14637'},
[25467]={[0]="Kliklak's Craw",[1]='K0810 L080 A:100054345 T:1202859'},
[25468]={[0]='Forces of Nature: Faerie Dragons',[1]='B121 K0370 FA L035 A:40913 T:40913 P:25410'},
[25469]={[0]='Forces of Nature: Mountain Giants',[1]='B121 K0370 FA L035 A:40913 T:40913 P:25410'},
[25471]={[0]='Across the Great Divide',[1]='K0810 L080 A:41341 T:39226 P:27708 B615'},
[25472]={[0]="The Flameseer's Staff",[1]='B606 K0810 L080 A:39869 T:39857 P:25317'},
[25473]={[0]="Kaja'Cola",[1]='B0 K0020 FH RG A:34872 T:34668 P:14069+14075'},
[25475]={[0]='Find OOX-22/FE!',[1]='B121 K0370 L035 A:100008705 T:7807'},
[25476]={[0]='Rescue OOX-22/FE!',[1]='B121 K0370 L035 A:7807 T:7406 P:25475 B673'},
[25477]={[0]='Better Late Than Dead',[1]='K0810 L080 A:41248 T:41248 P:25558'},
[25478]={[0]='To the Summit',[1]='B61 K0400 FH L038 A:40344 T:39895 P:25356 B61'},
[25479]={[0]='To New Thalanaar',[1]='B121 K0400 FA L038 A:40345 T:39946 I:25481,25486,28503'},
[25481]={[0]='To New Thalanaar',[1]='B121 K0400 FA L038 A:40369 T:39946 I:25479,25486,28503'},
[25486]={[0]='The Grimtotem are Coming',[1]='B121 K0400 FA L038 A:39946 T:39992 O:25479,25481,28503'},
[25487]={[0]='The Grimtotem are Coming',[1]='B61 K0400 FH L038 A:39895 T:39963 P:25356,25478'},
[25488]={[0]='Two If By Boat',[1]='B61 K0400 FA L038 A:39992 T:40027 P:25486 B61'},
[25489]={[0]='Two If By Boat',[1]='B61 K0400 FH L038 A:39963 T:40028 P:25487'},
[25490]={[0]='Smashing Through Ashes',[1]='B606 K0810 L080 A:39932 T:39858 P:25462'},
[25491]={[0]='Durable Seeds',[1]='B606 K0810 L080 A:39858 T:39858 P:25490'},
[25492]={[0]='Firebreak',[1]='B606 K0810 L080 A:40331 T:40331 P:25490'},
[25493]={[0]='Fresh Bait',[1]='B606 K0810 L080 A:39858 T:39858 P:25490'},
[25494]={[0]="A Champion's Collar",[1]='B606 K0810 L078 A:39406 T:39406 P:25294'},
[25496]={[0]='Grudge Match',[1]='B606 K0810 L080 A:39406 T:39406 P:25494'},
[25499]={[0]='Agility Training: Run Like Hell!',[1]='B606 K0810 L080 A:39413 T:39413 P:25509'},
[25502]={[0]='Prepping the Soil',[1]='B606 K0810 L080 A:40331 T:40331 P:25492'},
[25503]={[0]="Blackfin's Booty",[1]='K0810 L080 A:100054639 T:1202916'},
[25504]={[0]='Do Me a Favor?',[1]='B61 FA K040 L038 A:40027 T:40475 P:25488'},
[25505]={[0]='Do Me a Favor?',[1]='B61 K0400 FH L038 A:40028 T:40487 P:25489'},
[25507]={[0]="Hell's Shells",[1]='B606 K0810 L080 A:39858 T:39858 P:25493'},
[25509]={[0]='Physical Training: Forced Labor',[1]='B606 K0810 L080 A:39413 T:39413 P:25291'},
[25510]={[0]='Tortolla Speaks',[1]='B606 K0810 L080 A:39858 T:40341 P:25507'},
[25513]={[0]='Thunderdrome: Grudge Match!',[1]='B161 FA K0490 L047 A:39034 T:19860 P:25095'},
[25514]={[0]='Breaking the Bonds',[1]='B606 K0810 L080 A:40341 T:40341 P:25510'},
[25515]={[0]='Down in the Deeps',[1]='B61 FA K040 L038 A:40475 T:40475 P:25504'},
[25516]={[0]='Down in the Deeps',[1]='B61 K0400 FH L038 A:40487 T:40487 P:25505'},
[25517]={[0]='Bar Fight!',[1]='B61 FA K040 L038 A:40554 T:40554 P:25488'},
[25518]={[0]='Bar Fight!',[1]='B61 K0400 FH L038 A:40556 T:40556 P:1'},
[25519]={[0]='Children of Tortolla',[1]='B606 K0810 L080 A:40341 T:40341 P:25510'},
[25520]={[0]='An Ancient Awakens',[1]='B606 K0810 L080 A:40341 T:39858 P:25514'},
[25521]={[0]="I'm With Scorpid",[1]='B161 K0460 L044 A:40580 T:40580'},
[25522]={[0]='Gargantapid',[1]='B161 K0460 L044 A:40580 T:40580 P:25521'},
[25523]={[0]='Flight in the Firelands',[1]='B606 K0810 L080 A:40578 T:40578 P:25810'},
[25524]={[0]='In the Outhouse',[1]='B61 FA K040 L038 A:1202975 T:1202975 P:25504'},
[25525]={[0]='Wave One',[1]='B606 K0810 L080 A:40578 T:40578 P:25523'},
[25526]={[0]='In the Outhouse',[1]='B61 K0400 FH L038 A:1202975 T:1202975'},
[25531]={[0]='Twilight Riot',[1]='B606 K0810 L080 A:40619 T:40772 P:25315'},
[25532]={[0]='Pirate Accuracy Increasing',[1]='B0 FA K0400 L038 A:40475 T:0 P:25515+25517+25524'},
[25533]={[0]='Pirate Accuracy Increasing',[1]='B0 K0400 FH L038 A:40487 T:0 P:25516+25518+25526'},
[25534]={[0]='Going Off-Task',[1]='B161 K0460 FH L044 A:38703 T:38703 P:24927+24949'},
[25535]={[0]='A Powerful Need To Eat',[1]='FA K0810 L080 A:39881 T:40641,49408 P:25922'},
[25536]={[0]='Cold Welcome',[1]='FA K0810 L080 A:40642 T:40642 P:25922'},
[25537]={[0]='Art of Attraction',[1]='FA K0810 L080 A:40639 T:40639 P:25535'},
[25538]={[0]='Odor Coater',[1]='FA K0810 L080 A:40639 T:40639 P:25537'},
[25539]={[0]='Clamming Up',[1]='FA K0810 L080 A:40641 T:40641 P:25535'},
[25540]={[0]='Bellies Await',[1]='FA K0810 L080 A:40641 T:39881 P:25538'},
[25541]={[0]='Filling Our Pockets',[1]='B161 K0460 FH L044 A:38703 T:38703 P:24927+24949'},
[25542]={[0]='Circle the Wagons... er, Boats',[1]='B61 K0400 FA L038 A:-61 T:40475 P:25532 I:25561,525542 OBC:525542'},
[25543]={[0]='Circle the Wagons... er, Boats',[1]='B61 K0400 FH L038 A:-61 T:40487 P:25533 I:25562,525543 OBC:525543'},
[25544]={[0]='Wave Two',[1]='B606 K0810 L080 A:40578 T:40578 P:25525'},
[25545]={[0]='To Arms!',[1]='FA K0810 L080 A:39887 T:39887 P:25357+25546'},
[25546]={[0]='Traveling on Our Stomachs',[1]='FA K0810 L080 A:39887 T:39887 P:25405'},
[25547]={[0]='On Our Own Terms',[1]='FA K0810 L080 A:39887 T:40690 P:25545+25564'},
[25548]={[0]='Might of the Firelord',[1]='B606 K0810 L080 A:540772 T:540772 P:25608'},
[25549]={[0]='The Sanctum of the Prophets',[1]='B0 K0810 L080 A:540772 T:540772 P:25548'},
[25550]={[0]='Magma Monarch',[1]='B606 K0820 L078 A:540772 T:540772 P:25549'},
[25551]={[0]='The Firelord',[1]='B0 K0820 L078 A:40773 T:540772 P:25550+25553'},
[25552]={[0]='Brood of Evil',[1]='B606 K0820 L078 A:40816 T:40816 P:25644'},
[25553]={[0]='Death to the Broodmother',[1]='B0 K0820 L078 A:40816 T:40816 P:25552'},
[25554]={[0]='Secrets of the Flame',[1]='B606 K0810 L080 A:40773 T:40773 P:25608'},
[25555]={[0]='The Gatekeeper',[1]='B606 K0820 L078 A:40773 T:40773 P:25554'},
[25556]={[0]="Into Zul'Farrak",[1]='B504956 K0470 L046 A:7804 T:40712 P:25032 I:27068'},
[25558]={[0]='All or Nothing',[1]='FA K0810 L080 A:40690 T:40105 P:25547'},
[25559]={[0]='Laying Claim',[1]='B161 FA K0490 L047 A:40109 T:40109'},
[25560]={[0]='Egg Wave',[1]='B606 K0810 L080 A:40578 T:40578 P:25544'},
[25561]={[0]='Circle the Wagons... er, Boats',[1]='B61 FA K0400 L038 A:40475 T:40475 P:25532+525542 I:25542'},
[25562]={[0]='Circle the Wagons... er, Boats',[1]='B61 K0400 FH L038 A:40487 T:40487 P:25533+525543 I:25543'},
[25564]={[0]='Stormwind Elite Aquatic and Land Forces',[1]='FA K0810 L080 A:39887 T:39887 P:25357+25546'},
[25565]={[0]='Fragments of Language',[1]='B161 FA K0490 L047 A:40109 T:40109'},
[25566]={[0]='The Secrets of Uldum',[1]='B161 FA K0490 L047 A:40109 T:1202474 P:25420'},
[25574]={[0]='Flames from Above',[1]='B606 K0810 L080 A:40278 T:40278 P:25370'},
[25575]={[0]='Forged of Shadow and Flame',[1]='B606 K0810 L080 A:40834 T:40834'},
[25576]={[0]='Rage of the Wolf Ancient',[1]='B606 K0810 L080 A:40837 T:40837'},
[25577]={[0]='Crushing the Cores',[1]='B606 K0810 L080 A:40834 T:40834'},
[25578]={[0]='Return to Nordrassil',[1]='B606 K0810 L080 A:40178 T:40289 P:25325'},
[25579]={[0]='Caught Off-Guard',[1]='FA K0810 L080 A:40643 T:40643 P:25536+25540'},
[25580]={[0]='Swift Approach',[1]='FA K0810 L080 A:40642 T:40642 P:25536+25540'},
[25581]={[0]='An Occupation of Time',[1]='FA K0810 L080 A:40644 T:40644 P:25536+25540'},
[25582]={[0]='A Better Vantage',[1]='FA K0810 L080 A:40643 T:40643 P:25536+25540'},
[25583]={[0]='Upon the Scene of Battle',[1]='FA K0810 L080 A:1202714 T:40643 P:27393'},
[25584]={[0]='The Return of the Ancients',[1]='B606 K0810 L080 A:40289 T:39429 P:25578'},
[25585]={[0]='Quiet the Cannons',[1]='B61 FA K041 L038 A:40475 T:40475 P:25542,25561'},
[25586]={[0]='Quiet the Cannons',[1]='B61 K0410 FH L038 A:40487 T:40487 P:25543,25562'},
[25587]={[0]='Gimme Shelter!',[1]='K0810 L080 A:39667 T:39883 P:27685'},
[25588]={[0]='A Little Payback',[1]='B61 FA K0410 L038 A:40591 T:40591 P:25542,25561'},
[25589]={[0]='A Little Payback',[1]='B61 K0410 FH L038 A:40595 T:40595 P:25543,25562'},
[25590]={[0]="Where's Wizzle?",[1]='B61 FA K0410 L038 A:40554 T:40885 P:25542,25561'},
[25591]={[0]='Thunderdrome: Grudge Match!',[1]='B161 K0490 FH L047 A:39034 T:19860'},
[25592]={[0]='Deep Attraction',[1]='FH K0810 L080 A:40917 T:40917'},
[25593]={[0]='Shelled Salvation',[1]='FH K0810 L080 A:40916 T:40916'},
[25594]={[0]='Crafty Crabs',[1]='FH K0810 L080 A:40918 T:40918'},
[25595]={[0]='Something Edible',[1]='FH K0810 L080 A:40919 T:40919'},
[25596]={[0]="Where's Synge?",[1]='B61 K0410 FH L038 A:40556 T:40888'},
[25597]={[0]='Commander Jarod Shadowsong',[1]='B606 K0810 L080 A:40289 T:39621 P:25653'},
[25598]={[0]="Ain't Too Proud to Beg",[1]='K0810 L080 A:39883 T:39883 P:25587'},
[25599]={[0]='Cindermaul, the Portal Master',[1]='B606 K0810 L080 A:40834 T:40834 P:25575+25576+25577'},
[25600]={[0]='Forgemaster Pyrendius',[1]='B606 K0810 L080 A:40834 T:40834 P:25599'},
[25601]={[0]='Head of the Class',[1]='B606 K0810 L080 A:1006093 T:39413 P:25314'},
[25602]={[0]="Can't Start a Fire Without a Spark",[1]='K0810 L080 A:39884 T:39884 P:25598'},
[25607]={[0]='Ze Gnomecorder',[1]='B43 K0250 FA L024 A:40895 T:40895'},
[25608]={[0]='Slash and Burn',[1]='B606 K0810 L080 A:40772 T:40772 P:25531'},
[25609]={[0]='Sunken Treasure',[1]='B61 FA K0410 L038 A:40885 T:40885 P:25590'},
[25610]={[0]='Sunken Treasure',[1]='B61 K0410 FH L038 A:40888 T:40888 P:25596'},
[25611]={[0]='Return from the Firelands',[1]='B606 FA K0810 L080 A:40834 T:539433 P:25600'},
[25612]={[0]='Return from the Firelands',[1]='B606 FH K0810 L080 A:40834 T:39432 P:25600'},
[25613]={[0]='Do Yourself a Favor',[1]='B81 K0250 FA L024 A:40894 T:39256 P:13913 B81'},
[25614]={[0]='The Only Way Down is in a Body Bag',[1]='B81 K0250 FA L024 A:39256 T:39256 P:25613'},
[25615]={[0]='Return to Stardust',[1]='B81 K0250 FA L024 A:39256 T:34354 P:25614'},
[25616]={[0]="Hellscream's Legacy",[1]='B81 K0260 FA L024 A:34354 T:40973 P:25615 B81'},
[25617]={[0]='Into the Maw!',[1]='B606 K0810 FH L080 A:39622 T:40834 P:25355 I:25624'},
[25618]={[0]='Into the Maw!',[1]='B606 K0810 FA L080 A:500015 T:40834 P:25353 I:25623'},
[25619]={[0]='Reoccupation',[1]='K0810 L080 A:40978 T:40978 PL:25760'},
[25620]={[0]='The Revered Lady',[1]='K0810 L080 A:40978 T:40640 P:25619'},
[25621]={[0]='Field Test: Gnomecorder',[1]='B81 K0260 FA L024 A:40895 T:40895 P:25615'},
[25622]={[0]='Burn, Baby, Burn!',[1]='B81 K0260 FA L024 A:-81,40895 T:40895 P:25621 B43'},
[25623]={[0]='Into the Maw!',[1]='B606 FA K0810 L080 A:39433 T:40834 I:25618'},
[25624]={[0]='Into the Maw!',[1]='B606 FH K0810 L080 A:39432 T:40834 I:25617'},
[25626]={[0]='Visions of the Past: Rise from the Deep',[1]='FA K0810 L080 A:39881 T:39881 P:25911'},
[25627]={[0]='Two-Tusk Takedown',[1]='B61 FA K0420 L038 A:40885 T:40885 P:25609'},
[25628]={[0]='Two-Tusk Takedown',[1]='B61 K0420 FH L038 A:40888 T:40888 P:25610'},
[25629]={[0]="Her Lady's Hand",[1]='K0810 L080 A:42077 T:42077 PL:26135'},
[25630]={[0]='The Fires of Mount Hyjal',[1]='B606 K0810 L080 A:39434 T:39927 P:25611'},
[25637]={[0]="To the Fathom-Lord's Call",[1]='K0810 L080 A:40640 T:41049 P:25620'},
[25638]={[0]='A Desperate Plea',[1]='K0810 L080 A:1203128 T:40105 P:25459'},
[25640]={[0]='Bombs Away: Windshear Mine!',[1]='B81 K0260 FA L024 A:40895 T:40879 P:25622 B81'},
[25641]={[0]='The Flow of Muisek',[1]='B121 K0370 FH L035 A:39894 T:8115 P:25337'},
[25642]={[0]="Don't Look Them in the Eyes",[1]='B81 K0260 FA L024 A:40879 T:40879 P:25640'},
[25643]={[0]='The Darkmist Ruins',[1]='B121 K0370 FH L035 A:5390 T:1203134'},
[25644]={[0]='The Twilight Egg',[1]='B606 K0820 L078 A:1010751 T:40816 P:25608'},
[25645]={[0]='Return to Sage Palerunner',[1]='B121 K0370 FH L035 A:1203134 T:5390'},
[25646]={[0]='Windshear Mine Cleanup',[1]='B81 K0260 FA L024 A:40973 T:40973 P:25640'},
[25647]={[0]='Illegible Orc Letter',[1]='B81 K0260 FA L024 A:100055181 T:40879 P:25640'},
[25648]={[0]='Beyond Durotar',[1]='B0 K0100 FH L008 A:39379 T:8576'},
[25649]={[0]="Minx'll Fix It",[1]='B81 K0260 FA L024 A:40879 T:40881 P:25647'},
[25650]={[0]='Orders from High Command',[1]='B81 K0260 FA L024 A:40881 T:40879 P:25649'},
[25651]={[0]='Oh, the Insanity!',[1]='K0810 L080 A:46338 T:46338 P:25602'},
[25652]={[0]='Commandeer That Balloon!',[1]='B81 K0260 FA L024 A:40879 T:40896 P:25650'},
[25653]={[0]='The Ancients are With Us',[1]='B606 K0810 L080 A:41504 T:40289 P:25928'},
[25654]={[0]='Dark Heart',[1]='B121 K0360 FA L034 A:40035 T:40035'},
[25655]={[0]='The Wormwing Problem',[1]='B606 K0810 L080 A:41006 T:41006'}, -- needs P code, probably returning from firelands
[25656]={[0]='Scrambling for Eggs',[1]='B606 K0810 L080 A:41006 T:41006'}, -- needs P code, probably returning from firelands
[25657]={[0]='Dah, Nunt... Dah, Nunt...',[1]='K0810 L080 A:46338 T:0 P:25651'},
[25658]={[0]='Built to Last',[1]='K0810 L080 A:41050 T:41050 P:25620'},
[25659]={[0]='Not Soon Forgotten',[1]='K0810 L080 A:41049 T:0 P:25637'},
[25660]={[0]='Haunted',[1]='B61 K0410 L038 A:41058 T:41060 P:25627,25628'},
[25661]={[0]='With a Little Help...',[1]='B61 K0420 L038 A:41060 T:41060 P:25660'},
[25662]={[0]='Free Our Sisters',[1]='B81 K0260 FA L025 A:40896 T:41071 P:25652'},
[25663]={[0]='An Offering for Aviana',[1]='B606 K0810 L080 A:41005 T:41068 O:25985,27874'},
[25664]={[0]='A Prayer and a Wing',[1]='B606 K0810 L080 A:41005 T:41005 P:25665'},
[25665]={[0]='A Plea From Beyond',[1]='B606 K0810 L080 A:41068 T:41005 P:25663'},
[25667]={[0]='Culling the Wendigos',[1]='B0 FA K0060 L005 A:40950 T:40950 P:25724'},
[25668]={[0]='Pilfered Supplies',[1]='B0 FA K0060 L005 A:40951 T:40951 P:25724'},
[25669]={[0]='Rumble in the Lumber... Mill',[1]='B81 K0270 FA L025 A:41071 T:40896 P:25662'},
[25670]={[0]='DUN-dun-DUN-dun-DUN-dun',[1]='K0810 L080 A:46338 T:46458 P:27699'},
[25671]={[0]='Thinning the Horde',[1]='B81 +D FA K0280 L025 M030 A:40896 T:40896 W0183999'},
[25672]={[0]='Carcass Collection',[1]='B61 K0420 L038 A:41060 T:41060 P:25661'},
[25673]={[0]='Just Ask Alice',[1]='B81 K0270 FA L025 A:40908 T:40908 P:25652'},
[25674]={[0]='Futile Pride',[1]='B19 K0550 FH L054 A:41124 T:41124 P:28553,28671,28858'},
[25675]={[0]='Ogre Combat',[1]='B19 K0550 FH L054 A:41125 T:41125'},
[25676]={[0]='Heartstrike',[1]='B19 K0550 FH L054 A:41124 T:41133 P:25674'},
[25677]={[0]="It's All Mine",[1]='B19 K0550 FH L054 A:41133 T:41133'},
[25678]={[0]='Pick Your Fate',[1]='B19 K0550 FH L054 A:41133 T:41133'},
[25679]={[0]='Into the Mountain',[1]='B19 K0550 FH L054 A:41133 T:41134'},
[25680]={[0]="That's Not Us",[1]='B19 K0550 FH L054 A:41134 T:41134 P:25679'},
[25681]={[0]='Some People Just Need Killing',[1]='B19 K0550 FH L054 A:41134 T:41134 P:25680'},
[25682]={[0]='Mission Complete',[1]='B19 K0550 FH L054 A:41134 T:41124 P:25681'},
[25683]={[0]='The Dreadmaul Furnace',[1]='B19 K0550 FH L054 A:41124 T:7506 P:25682'},
[25684]={[0]='Attune the Bloodstone',[1]='B19 K0550 FH L054 A:7506 T:7506 P:25683'},
[25685]={[0]='The First Step',[1]='B19 K0550 FH L054 A:7506 T:7506 P:25684'},
[25686]={[0]='Blood Ritual',[1]='B19 K0550 FH L054 A:7506 T:7506 P:25685'},
[25687]={[0]='Not Just Any Body',[1]='B19 K0550 FH L054 A:7506 T:7506 P:25686'},
[25688]={[0]='The Altar of Storms',[1]='B19 K0550 FH L054 A:7506 T:7783 P:25687'},
[25689]={[0]='Time is Short',[1]='B19 K0560 FH L054 A:7783 T:41159 P:25688'},
[25690]={[0]="A Bloodmage's Gotta Eat Too",[1]='B19 K0550 FH L054 A:7505 T:7505'},
[25691]={[0]='The Charred Granite of the Dark Portal',[1]='B19 K0560 FH L054 A:41159 T:41159'},
[25692]={[0]='The Vile Blood of Demons',[1]='B19 K0560 FH L054 A:41159 T:41159'},
[25693]={[0]='Enhancing the Stone',[1]='B19 K0560 FH L054 A:41159 T:7783'},
[25694]={[0]='Protecting Our Rear',[1]='B19 K0560 FH L054 A:19254 T:19254'},
[25695]={[0]='Watching Our Back',[1]='B19 K0560 FH L054 A:19254 T:19254 P:25694'},
[25696]={[0]='The Sunveil Excursion',[1]='B19 K0570 FH L055 A:19254 T:42344'},
[25697]={[0]='The Amulet of Allistarj',[1]='B19 K0560 FH L054 A:7783 T:7506'},
[25698]={[0]='The Amulet of Sevine',[1]='B19 K0560 FH L054 A:7783 T:7506'},
[25699]={[0]='The Amulet of Grol',[1]='B19 K0560 FH L054 A:7783 T:7506'},
[25700]={[0]='Loramus Thalipedes Awaits',[1]='B19 K0560 FH L054 A:7506 T:7783'},
[25701]={[0]="You Are Rakh'likh, Demon",[1]='B19 K0570 FH L054 A:7783 T:41159 P:25700'},
[25702]={[0]='Home... Gone... Naga...',[1]='B19 K0570 L055 A:41265 T:41354'},
[25703]={[0]='Atrocities',[1]='B19 K0570 L054 A:41354 T:41354 P:25702'},
[25704]={[0]='The Mad Magus',[1]='B61 K0420 L038 A:41060 T:41060 P:25672'},
[25705]={[0]='False Idols',[1]='B19 K0570 L054 A:41354 T:41354'},
[25706]={[0]="Neptool's Revenge",[1]='B19 K0570 L055 A:41354 T:41354'},
[25707]={[0]='The Future of the Rockpool',[1]='B0 K0570 L055 A:41402'},
[25708]={[0]='Our Fallen Friends',[1]='B19 FA K0550 L054 A:9540 T:9540'},
[25709]={[0]='Curtail the Darktail',[1]='B19 FA K0550 L054 A:9540 T:9540'},
[25710]={[0]='Minor Distractions',[1]='B19 K0550 FA L054 A:5393 T:5393 P:28673,28857'},
[25711]={[0]="Eliminate the Okril'lon",[1]='B19 FA K0550 L054 A:5393 T:5393 P:25710'},
[25712]={[0]='Nethergarde Reigns',[1]='B19 FA K0550 L054 A:42262 T:42262'},
[25713]={[0]='Remove Their Arms',[1]='B19 FA K0550 L054 A:42264 T:42264'},
[25714]={[0]='Watcher Mahar Ba',[1]='B19 FA K0550 L054 A:5393,9540 T:5385'},
[25715]={[0]='A Closer Look',[1]='B19 FA K0550 L054 A:9540 T:9540 P:27919'},
[25716]={[0]='Cultists at our Doorstep',[1]='B19 FA K0550 L054 A:5385 T:5385 P:25714'},
[25717]={[0]='The Demons and the Druid',[1]='B19 K0580 FH L055 A:42344 T:42344 P:25696'},
[25718]={[0]='How Best to Proceed',[1]='B19 K0580 FH L055 A:42344 T:42348 P:25717'},
[25719]={[0]='Demoniac Vessel',[1]='B19 K0580 FH L055 A:42348 T:42344 P:25718'},
[25720]={[0]='The Downfall of Marl Wormthorn',[1]='B19 K0590 FH L055 A:42344 T:42344 P:25719'},
[25721]={[0]='Fight the Flood',[1]='B40 FA K0200 L018 A:41086 T:41086 O:25770'},
[25722]={[0]='Sedimentary, My Dear',[1]='B40 FA K0200 L018 A:41129 T:41129'},
[25723]={[0]='Thresh Out of Luck',[1]='B40 FA K0200 L018 A:41128 T:41128'},
[25724]={[0]='Frostmane Aggression',[1]='B0 FA K0060 L005 A:40950 T:40950'},
[25725]={[0]='Fenbush Berries',[1]='B40 FA K0200 L018 A:41128 T:41128 P:25723'},
[25726]={[0]='A Dumpy Job',[1]='B40 FA K0200 L018 A:41129 T:41129 P:25722'},
[25727]={[0]='Drungeld Glowerglare',[1]='B40 FA K0200 L018 A:41086 T:41086 P:25721'},
[25728]={[0]="Mr. P's Wild Ride",[1]='B81 K0270 FA L025 A:40908 T:40896 P:25673'},
[25729]={[0]='Gerenzo the Traitor',[1]='B81 K0270 FA L025 A:4202,40895 T:40895 B43'},
[25730]={[0]='BEWARE OF CRAGJAW!',[1]='B81 K0270 FA L025 A:1203186 T:41054'},
[25731]={[0]='A Bird in Hand',[1]='B606 K0810 L080 A:41006 T:41006 P:25655+25656'},
[25732]={[0]='A Bone to Pick',[1]='K0810 L080 A:46458 T:46458 P:25670'},
[25733]={[0]='Get Out Of Here, Stalkers',[1]='B40 FA K0210 L018 A:41086 T:41086 P:25727'},
[25734]={[0]='Down In Thelgen Rock',[1]='B40 FA K0210 L018 A:41129 T:41129 P:25726'},
[25735]={[0]='Incendicite Ore',[1]='B40 FA K0210 L018 A:41128 T:41128 P:25725'},
[25736]={[0]='The Floodsurge Core',[1]='B40 FA K0200 L018 A:100055243 T:41086'}, -- is P:25734 really required here?  NPC 41167 drops this item
[25739]={[0]="If the Horde Don't Get You...",[1]='B81 K0270 FA L025 A:40897 T:40897 P:25669'},
[25740]={[0]='Fact-Finding Mission',[1]='B606 K0810 L080 A:40997 T:541006 P:25664'},
[25741]={[0]='Preparations for the Future',[1]='B81 K0270 FA L025 A:40898 T:40898 P:25669'},
[25743]={[0]='Decisions, Decisions',[1]='K0810 L080 A:46458 T:46463 P:25732'},
[25744]={[0]='Negotiations',[1]='B61 FA K0410 L038 A:40027 T:41190 P:25542,25561'},
[25745]={[0]='Negotiations',[1]='B61 K0410 FH L038 A:40028 T:41184 P:25543,25562'},
[25746]={[0]="Sethria's Brood",[1]='B606 K0810 L080 A:541006 T:541006 P:25740'},
[25747]={[0]='Looking Forward',[1]='FA K0810 L080 A:539881 T:540643 P:25760'},
[25748]={[0]='Clear Goals',[1]='FA K0810 L080 A:540643 T:540643 P:25747'},
[25749]={[0]='Not Entirely Unprepared',[1]='FA K0810 L080 A:540642 T:540642 P:25747'},
[25751]={[0]='Properly Inspired',[1]='FA K0810 L080 A:540639 T:540639 P:25747'},
[25752]={[0]='Swift Action',[1]='FA K0810 L080 A:540643 T:500001 P:25748+25749+25751'},
[25753]={[0]='Fallen But Not Forgotten',[1]='FA K0810 L080 A:500002 T:500002 P:25752 I:25964'},
[25754]={[0]='Gauging Success',[1]='FA K0810 L080 A:500001 T:500001 P:25752 I:25965'},
[25755]={[0]="Visions of the Past: The Slaughter of Biel'aran Ridge",[1]='FA K0810 L080 A:500004 T:500005 P:25753+25754 I:25966'},
[25756]={[0]='Get Zherin!',[1]='B61 FA K0410 L038 A:41190 T:41190 P:25744'},
[25757]={[0]='Get Koalbeard!',[1]='B61 K0410 FH L038 A:41184 T:41184 P:25745'},
[25758]={[0]='A Gap in Their Armor',[1]='B606 K0810 L080 A:541006 T:541006 P:25740'},
[25760]={[0]="Visions of the Past: The Invasion of Vashj'ir",[1]='FA K0810 L080 A:500003 T:539881 P:25583'},
[25761]={[0]='Disassembly',[1]='B606 K0810 L080 A:541006 T:541006 P:25758'},
[25762]={[0]='The Ancient Brazier',[1]='B61 K0420 L038 A:40082 T:40082 P:25744'},
[25763]={[0]='The Codex of Shadows',[1]='B606 K0810 L080 A:1006599 T:541006 P:25740'},
[25764]={[0]='Egg Hunt',[1]='B606 K0810 L080 A:541006 T:541006 P:25763'},
[25765]={[0]="Tell 'Em Koko Sent You",[1]='B81 K0280 FA L026 A:40897 T:41229 P:25739'},
[25766]={[0]='Arcane Legacy',[1]='B81 K0280 FA L025 A:40899 T:40899 P:25669'},
[25767]={[0]='Capturing Memories',[1]='B81 K0280 FA L025 A:40900 T:40900 P:25669'},
[25768]={[0]='Bombs Away: Mirkfallon Post!',[1]='B81 K0280 FA L026 A:40896 T:41233 P:25769'},
[25769]={[0]='Fallowmere Beckons',[1]='B81 K0280 FA L026 A:40899 T:40896 P:25766+25767'},
[25770]={[0]='Keg Run',[1]='B40 FA K0200 L018 A:41075 T:41086 P:25395 I:25721'},
[25771]={[0]="One Draenei's Junk...",[1]='B19 K0550 L054 A:100010593 T:7363'},
[25772]={[0]="Kum'isha's Endeavors",[1]='B19 K0550 L054 A:100008244 T:7363'},
--[25773]={[0]='A Natural Occurrence',[1]='+D FA A:40220 T:41210'},
[25774]={[0]="Fool's Gold",[1]='B61 FA K0420 L038 A:41190 T:41190 P:25756'},
[25775]={[0]="Fool's Gold",[1]='B61 K0420 FH L038 A:41184 T:41184 P:25757'},
[25776]={[0]="Sethria's Demise",[1]='B606 K0810 L080 A:541006 T:541006 P:25746'},
[25777]={[0]='Onwards to Menethil',[1]='B40 FA K0210 L018 A:41086 T:2104 P:25733+25734+25735+25736 I:25780'},
[25778]={[0]='Fake Gold for Black Gold',[1]='B61 FA K0410 L038 A:41190 T:41204 P:25774'},
[25779]={[0]='Fake Gold for Black Gold',[1]='B61 K0410 FH L038 A:41184 T:41205 P:25775'},
[25780]={[0]='Assault on Menethil Keep',[1]='B40 FA K0210 L019 A:2104 T:2104 O:25777'},
[25790]={[0]='Back to Crazzle',[1]='B61 FA K0410 L038 A:41204 T:41190 P:25778'},
[25791]={[0]='Back to Riznek',[1]='B61 K0410 FH L038 A:41205 T:41184 P:25779'},
[25792]={[0]='Pushing Forward',[1]='B0 FA K0070 L005 A:40950 T:40950 P:313+25667'},
[25793]={[0]='The Deep Reaches',[1]='B81 K0280 FA L026 A:41229 T:41276 P:25765'},
[25794]={[0]='Undersea Sanctuary',[1]='K0810 L080 A:40105 T:40105 P:25638'},
[25795]={[0]='Return to the Shrine',[1]='B606 K0810 L080 A:541006 T:41005 P:25776'},
[25796]={[0]='Eminent Domain',[1]='B61 FA K0410 L038 A:41190 T:41190 P:25790'},
[25797]={[0]='Eminent Domain',[1]='B61 K0410 FH L038 A:41184 T:41184 P:25791'},
[25798]={[0]='Defend the Drill',[1]='B61 FA K0410 L038 A:41190 T:41190 P:25790'},
[25799]={[0]='Defend the Drill',[1]='B61 K0410 FH L038 A:41184 T:41184 P:25791'},
[25800]={[0]='When Life Gives You Crabs',[1]='B40 FA K0220 L019 A:41297 T:41297'},
[25801]={[0]='Claws from the Deep',[1]='B40 FA K0220 L019 A:41297 T:41297 P:25800'},
[25802]={[0]='Reclaiming Goods',[1]='B40 FA K0220 L019 A:41297 T:1000261 P:25800'},
[25803]={[0]='The Search Continues',[1]='B40 FA K0220 L019 A:1000261 T:1142151 P:25802'},
[25804]={[0]='Search More Hovels',[1]='B40 FA K0220 L019 A:1142151 T:1000259 P:25803'},
[25805]={[0]='Return the Statuette',[1]='B40 FA K0220 L019 A:1000259 T:41297 P:25804'},
[25806]={[0]='They Put the Assass in... Never Mind',[1]='B81 K0280 FA L026 A:41277 T:41277 P:25793'},
[25807]={[0]='An Ancient Reborn',[1]='B606 K0810 L080 A:41005 T:41308 P:25795'},
[25808]={[0]='Is This Thing On?',[1]='B81 K0280 FA L026 A:41277 T:41277 P:25806'},
[25809]={[0]='Leave No Man Behind! ',[1]='B81 K0280 FA L026 A:41282 T:41282 P:25793'}, -- in 4.2 space at end
[25810]={[0]='The Hatchery Must Burn',[1]='B606 K0810 L078 A:41003 T:40578 P:25807'},
[25811]={[0]='Shuttin Her Down',[1]='B81 K0280 FA L026 A:41276 T:41276 P:25793'},
[25812]={[0]='Spelunking',[1]='FA K0810 L080 A:40105 T:41324 P:25794'},
[25813]={[0]='Go Blow that Horn',[1]='B61 FA K0420 L038 A:41190 T:41190 P:25796+25798'},
[25814]={[0]='Go Blow that Horn',[1]='B61 K0420 FH L038 A:41184 T:41184 P:25797+25799'},
[25815]={[0]='The Third Fleet',[1]='B40 FA K0220 L020 A:1239 T:1239'},
[25816]={[0]='Cursed to Roam',[1]='B40 FA K0220 L020 A:1239 T:41307 P:25815'},
[25817]={[0]='The Cursed Crew',[1]='B40 FA K0220 L020 A:41307 T:41307 P:25816'},
[25818]={[0]='Lifting the Curse',[1]='B40 FA K0230 L020 A:41307 T:1112948 P:25817'},
[25819]={[0]='The Eye of Paleth',[1]='B40 FA K0230 L020 A:1112948 T:1217 P:25818'},
[25820]={[0]="A Mother's Worries",[1]='B40 FA K0220 L020 A:1484 T:1484'},
[25821]={[0]='A Special Kind of Job',[1]='B81 K0280 FA L026 A:41277 T:41229 P:25808+25809+25811'},
[25822]={[0]='Armaments for War',[1]='B81 K0280 FA L026 A:41229 T:41229 P:25845'},
[25823]={[0]='The Unrelenting Horde',[1]='B81 K0280 FA L026 A:41229 T:41229 P:25845'},
[25824]={[0]='Debriefing',[1]='FA K0810 L080 A:41341 T:41341 P:25812'},
[25825]={[0]='Deliver the Goods',[1]='B61 FA K0420 L038 A:41190 T:40027 P:25813'},
[25826]={[0]='Deliver the Goods',[1]='B61 K0420 FH L038 A:41184 T:40028 P:25814'},
[25830]={[0]='The Last Living Lorekeeper',[1]='B606 K0810 L080 A:40289,46987,46998,47002 T:41381 P:25807'},
[25832]={[0]='Return to Aviana',[1]='B606 K0810 L080 A:40578 T:41308 P:25560'},
[25834]={[0]='Death by Proxy',[1]='B81 K0290 FA L026 A:41229 T:41278 P:25821'},
[25835]={[0]='Free Freewind Post',[1]='B61 FA K0420 L038 A:40027 T:41392 P:25704+25825'},
[25836]={[0]='Free Freewind Post',[1]='B61 K0420 FH L038 A:40028 T:41446 P:25704+25826'},
[25837]={[0]="A Proper Peace Offerin'",[1]='B81 K0280 FA L026 A:41278 T:41278 P:25834'},
[25838]={[0]="Help from Steelgrill's Depot",[1]='B0 FA K0080 L005 A:40950 T:41363 P:412+25792'},
[25839]={[0]='The Ultrasafe Personnel Launcher',[1]='B0 FA K0080 L005 A:41363 T:41298 P:25838'},
[25840]={[0]='Eliminate the Resistance',[1]='B0 FA K0080 L005 A:41298 T:41298 P:25839'},
[25841]={[0]='Strike From Above',[1]='B0 FA K0080 L005 A:41298 T:41298 P:25839'},
[25842]={[0]='Firefight',[1]='B606 K0810 L080 A:41381 T:41381 P:25830'},
[25843]={[0]="Tortolla's Revenge",[1]='B606 K0810 L080 A:539858 T:41504 P:25372'},
[25844]={[0]='Sating the Savage Beast',[1]='B81 K0290 FA L026 A:41278 T:41350 P:25837'},
[25845]={[0]='Terms of Service',[1]='B81 K0290 FA L026 A:41350 T:41229 P:25844'},
[25846]={[0]='Grundig Darkcloud, Chieftain of the Grimtotem',[1]='B81 K0290 FA L026 A:41229 T:11858 P:25822'},
[25847]={[0]='Grimtotem Supremacy',[1]='B81 K0300 L026 A:11858 T:11858 P:25846'},
[25848]={[0]='Downfall',[1]='B81 K0300 L026 A:11858 T:11858 P:25847'},
[25849]={[0]='When Archaeology Attacks',[1]='B40 FA K0230 L021 A:41411 T:41411 O:26981'},
[25850]={[0]='Strike the Earth!',[1]='B40 FA K0230 L021 A:41412 T:41412'},
[25851]={[0]='Dances with Grimtotem',[1]='B81 K0300 FA L026 A:11858 T:41229 P:25848'},
[25852]={[0]="All's Clear",[1]='B81 K0300 FA L026 A:41229 T:38378 P:25851 B607'},
[25853]={[0]='Tooling Around',[1]='B40 FA K0230 L021 A:41413 T:41413'},
[25854]={[0]="I'll Call Him Bitey",[1]='B40 FA K0230 L021 A:41435 T:41435'},
[25855]={[0]='Gizmos and Gadgets',[1]='B40 FA K0230 L021 A:41435 T:41435 P:25854'},
[25856]={[0]='Crocolisk Hides',[1]='B40 FA K0230 L021 A:41433 T:41433'},
[25857]={[0]='Hunting Horrorjaw',[1]='B40 FA K0230 L021 A:41433 T:41433 P:25856'},
[25858]={[0]="By Her Lady's Word",[1]='K0810 L080 A:42076 T:42074 PL:25755'},
[25859]={[0]='No Trespass Forgiven',[1]='K0810 L080 A:42074 T:42074 P:25858'},
[25860]={[0]='At All Costs',[1]='K0810 L080 A:41456 T:41456 P:25629+25896'},
[25861]={[0]='Setting An Example',[1]='K0810 L080 A:41457 T:41457 P:25858'},
[25862]={[0]='Stolen Property',[1]='K0810 L080 A:41476 T:1203305 P:25858'},
[25863]={[0]='Chosen Burden',[1]='K0810 L080 A:1203305 T:542076 P:25862'},
[25864]={[0]='Dinosaur Crisis',[1]='B40 FA K0230 L021 A:41415 T:41415 O:26980'},
[25865]={[0]='The Mosshide Job',[1]='B40 FA K0230 L021 A:41415 T:41415 P:25864'},
[25866]={[0]='Dark Iron Trappers',[1]='B40 FA K0230 L021 A:41415 T:41415 P:25865'},
[25867]={[0]='Gnoll Escape',[1]='B40 FA K0230 L021 A:41415 T:41415 P:25865'},
[25868]={[0]='Yorla Darksnare',[1]='B40 FA K0230 L021 A:41415 T:41415 P:25866+25867'},
[25869]={[0]='Grimtotem in the Post',[1]='B61 FA K0420 L038 A:41392 T:41392 P:25835'},
[25870]={[0]='Grimtotem in the Post',[1]='B61 K0420 FH L038 A:41446 T:41446 P:25836'},
[25871]={[0]='Save the Sentinel',[1]='B61 FA K0420 L038 A:41444 T:41444 P:25835'},
[25872]={[0]='The Brave and the Bold',[1]='B61 K0420 FH L038 A:41421 T:41421 P:25836'},
[25873]={[0]='Horn of the Traitor',[1]='B61 FA K0430 L038 A:45271 T:41392 P:25835'},
[25874]={[0]='Horn of the Traitor',[1]='B61 K0430 FH L038 A:45271 T:41446 P:25836'},
[25875]={[0]='Gnome on the Inside',[1]='B81 K0280 FA L026 A:41233 T:41434 P:25768'},
[25876]={[0]="It's Up There!",[1]='B81 K0280 FA L026 A:41434 T:41434 P:25875'},
[25877]={[0]='No Time for Goodbyes!',[1]='B81 K0280 FA L026 A:41434 T:41233 P:25876'},
[25878]={[0]="Schemin' That Sabotage",[1]='B81 K0280 FA L026 A:41441 T:41441 P:25768'},
[25879]={[0]='The Lumbering Oaf Problem',[1]='B81 K0280 FA L026 A:41441 T:41441 P:25768'},
[25880]={[0]="Warn Master Thal'darah",[1]='B81 K0290 FA L026 A:41233 T:41482 P:25877'},
[25881]={[0]='Lost Wardens',[1]='B606 K0810 L080 A:41507 T:41492 P:25372'},
[25882]={[0]='A Hand at the Ranch',[1]='B0 FA K0080 L005 A:41298 T:41578 P:25840+25841 I:25932'},
[25883]={[0]='How Disarming',[1]='K0810 L080 A:1203301 T:0'},
[25884]={[0]='Come Hell or High Water',[1]='K0810 L080 A:41344 T:0 P:25887'},
[25885]={[0]='What? What? In My Gut...?',[1]='FA K0810 L080 A:41340 T:41340 P:25887'},
[25886]={[0]='Pressing the Advantage',[1]='B606 K0810 L080 A:41492 T:41492 P:25881'},
[25887]={[0]='Wake of Destruction',[1]='K0810 L080 A:41341 T:41341 P:25824,26007'},
[25888]={[0]='Decompression',[1]='FA K0810 L080 A:41347 T:41347 P:25887'},
[25889]={[0]='Save the Children!',[1]='B81 K0290 FA L026 A:41482 T:41482 P:25880'},
[25890]={[0]='Nespirah',[1]='K0810 L080 A:39875 T:41531'},
[25891]={[0]='Last Ditch Effort',[1]='B81 K0290 FA L026 A:41482 T:41482 P:25889'},
[25892]={[0]='Losing Ground',[1]='FA K0810 L080 A:500005 T:40642 P:25755 I:25967'},
[25893]={[0]='Desperate Plan',[1]='FA K0810 L080 A:40642 T:41535 P:25892 I:25968'},
[25894]={[0]='Hostile Waters',[1]='FA K0810 L080 A:40645 T:41535 P:25893'},
[25895]={[0]='Come Prepared',[1]='FA K0810 L080 A:41535 T:41535 P:25893'},
[25896]={[0]='Devout Assembly',[1]='K0810 L080 A:41456 T:41456 PL:26135'},
[25897]={[0]='Unfurling Plan',[1]='FA K0810 L080 A:41535 T:41535 P:25893'},
[25898]={[0]='Honor and Privilege',[1]='FA K0810 L080 A:41535 T:540645 P:25894+25895+25897'},
[25899]={[0]='Breakthrough',[1]='B606 K0810 L080 A:41507 T:41492 P:25372'},
[25900]={[0]='Making Contact',[1]='K0810 L080 A:41531 T:41531 P:25890'},
[25901]={[0]='Hyjal Recycling Program',[1]='B606 K0810 L080 A:41497 T:41497'}, -- needs P code, is preset when Tortolle freed
[25904]={[0]='The Hammer and the Key',[1]='B606 K0810 L080 A:41504 T:41504 P:25843'},
[25905]={[0]='Rams on the Lam',[1]='B0 FA K0080 L005 A:1261 T:1261 P:25932'},
[25906]={[0]='The Third Flamegate',[1]='B606 K0810 L080 A:41504 T:41498 P:25904'},
[25907]={[0]='Slave Labor',[1]='K0810 L080 A:41531 T:41531 P:25900'},
[25908]={[0]='Stick it to Them',[1]='K0810 L080 A:41531 T:41531 P:25900'},
[25909]={[0]='Capture the Crab',[1]='FA K0810 L080 A:41531 T:41531 P:25907+25908'},
[25910]={[0]='The Time for Mercy has Passed',[1]='B606 K0810 L080 A:41498 T:41498 P:25906'},
[25911]={[0]='Welcome News',[1]='FA K0810 L080 A:540645 T:40642 P:25898'},
[25912]={[0]='Seen Better Days',[1]='B81 K0290 FA L026 A:41486 T:41486 P:25891'},
[25913]={[0]='Putting Them to Rest',[1]='B81 K0290 FA L026 A:41488 T:41488 P:25891'},
[25914]={[0]='Back to the Depths!',[1]='B81 K0290 FA L026 A:41488 T:41488 P:25891'},
[25915]={[0]='The Strength of Tortolla',[1]='B606 K0810 L080 A:41498 T:41498 P:25906'},
[25916]={[0]='Breaking Through',[1]='FA K0810 L080 A:41531 T:41531 P:25909'},
[25917]={[0]='We Are Not Alone',[1]='FA K0810 L080 A:41531 T:41540 P:25916'},
[25918]={[0]='Hopelessly Gearless',[1]='FA K0810 L080 A:41541 T:41541 P:25917'},
[25919]={[0]='Body Blows',[1]='FA K0810 L080 A:41540 T:41540 P:25917'},
[25920]={[0]='Still Valuable',[1]='FA K0810 L080 A:41802 T:41802 P:25917'},
[25921]={[0]="Overseer Idra'kess",[1]='FA K0810 L080 A:41540 T:41531 P:25918+25919+25920'},
[25922]={[0]='Waking the Beast',[1]='FA K0810 L080 A:41531 T:40642 P:25921'},
[25923]={[0]='Finish Nemesis',[1]='B606 K0810 L080 A:41498 T:41498 P:25915'},
[25924]={[0]='Call of Duty',[1]='B0 K0810 FH L080 A:41621 T:41618 P:27718,28816'},
[25925]={[0]="Thal'darah's Vengeance",[1]='B81 K0300 FA L026 A:41482 T:41487 P:25891'},
[25926]={[0]='Mired in Hatred',[1]='B40 FA K0250 L023 A:41503 T:41503'},
[25927]={[0]='The Threat of Flame',[1]='B40 FA K0250 L023 A:41503 T:41503 P:25926'},
[25928]={[0]="Tortolla's Triumph",[1]='B606 K0810 L080 A:41498 T:41504 P:25923'},
[25929]={[0]='Sea Legs',[1]='B0 FH K0810 L080 A:41618 T:41618 P:25924'},
[25930]={[0]='Ascending the Vale',[1]='B81 K0300 FA L026 A:41487 T:41487 P:25925'},
[25931]={[0]='Brood of Seldarria',[1]='B81 K0300 FA L026 A:41487 T:41487 P:25930'},
[25932]={[0]="It's Raid Night Every Night",[1]='B0 FA K0090 L006 A:41578 T:41578 O:25882'},
[25933]={[0]='Help for the Quarry',[1]='B0 FA K0090 L006 A:41578 T:1254 P:314+25905'},
[25934]={[0]='World First: Gnomegen',[1]='B81 K0300 FA L026 A:41664 T:41664 P:25925'},
[25935]={[0]='Hungry Pups',[1]='B81 K0300 FA L026 A:41638 T:41638 P:25925'},
[25936]={[0]='Pay It Forward',[1]='FH K0810 L080 A:41618 T:41618 P:25929'},
[25937]={[0]='Priceless Treasures',[1]='B0 FA K0100 L007 A:50631 T:50631'},
[25938]={[0]='Help for Desolace',[1]='B81 K0300 FA L027 A:41487 T:36410 I:14384,28531'},
[25939]={[0]="For Peat's Sake",[1]='B40 FA K0240 L022 A:41615 T:41615 P:25926'},
[25940]={[0]='Last Stand at Whistling Grove',[1]='B606 K0810 L080 A:39927,39928 T:39932 P:25428 I:25462'},
[25941]={[0]='Rest For the Weary',[1]='FH K0810 L080 A:41618 T:41711 P:25936'},
[25942]={[0]='Buy Us Some Time',[1]='FH K0810 L080 A:41711 T:41711 P:27668'},
[25943]={[0]='Traveling on Our Stomachs',[1]='FH K0810 L080 A:41711 T:41711 P:27668'},
[25944]={[0]='Girding Our Loins',[1]='FH K0810 L080 A:41711 T:41711 P:25942+25943+25946'},
[25945]={[0]="We're Here to Do One Thing, Maybe Two...",[1]='B81 K0260 FH L024 A:41678 T:34341 P:28532 B81'},
[25946]={[0]="Helm's Deep",[1]='FH K0810 L080 A:1203395 T:41711 P:27668'},
[25947]={[0]='Finders, Keepers',[1]='FH K0810 L080 A:41711 T:41711 P:25942+25943+25946'},
[25948]={[0]='Bring It On!',[1]='FH K0810 L080 A:41711 T:41750 P:25944+25947'},
[25949]={[0]='Blood and Thunder!',[1]='FH K0810 L080 A:41750,41769 T:40105 P:25948'},
[25950]={[0]="Sira'kess Slaying",[1]='FA K0820 L080 A:41667 T:41667 P:26080'},
[25951]={[0]='Final Judgement',[1]='K0810 L080 A:41456 T:542077 P:25860'},
[25952]={[0]='Caught Off-Guard',[1]='FH K0810 L080 A:40916 T:40916'},
[25953]={[0]='Swift Approach',[1]='FH K0810 L080 A:40917 T:40917'},
[25954]={[0]='An Occupation of Time',[1]='FH K0810 L080 A:40920 T:40920'},
[25955]={[0]='A Better Vantage',[1]='FH K0810 L080 A:40916 T:40916'},
[25956]={[0]='Upon the Scene of Battle',[1]='FH K0810 L080 A:1203140 T:40916 P:27394'},
[25957]={[0]="Visions of the Past: The Invasion of Vashj'ir",[1]='FH K0810 L080 A:40919 T:40919'},
[25958]={[0]='Looking Forward',[1]='FH K0810 L080 A:40919 T:40916 P:25957'},
[25959]={[0]='Clear Goals',[1]='FH K0810 L080 A:40916 T:40916 P:25958'},
[25960]={[0]='Not Entirely Unprepared',[1]='FH K0810 L080 A:40917 T:40917'},
[25962]={[0]='Properly Inspired',[1]='FH K0810 L080 A:40918 T:40918'},
[25963]={[0]='Swift Action',[1]='FH K0810 L080 A:40916 T:40916'},
[25964]={[0]='Fallen But Not Forgotten',[1]='FH K0810 L080 A:40917 T:40917 I:25753'},
[25965]={[0]='Gauging Success',[1]='FH K0810 L080 A:40916 T:40916 P:25963 I:25754'},
[25966]={[0]="Visions of the Past: The Slaughter of Biel'aran Ridge",[1]='FH K0810 L080 A:40919 T:40919 I:25755'},
[25967]={[0]='Losing Ground',[1]='FH K0810 L080 A:40919 T:40917 P:25966 I:25892'},
[25968]={[0]='Desperate Plan',[1]='FH K0810 L080 A:40917 T:41770 P:25967 I:25893'},
[25969]={[0]='Hostile Waters',[1]='FH K0810 L080 A:40921 T:41770'},
[25970]={[0]='Come Prepared',[1]='FH K0810 L080 A:41770'},
[25971]={[0]='Unfurling Plan',[1]='FH K0810 L080 A:41770 T:41770'},
[25972]={[0]='Honor and Privilege',[1]='FH K0810 L080 A:41770 T:40921'},
[25973]={[0]='Welcome News',[1]='FH K0810 L080 A:40921 T:40917 P:25972'},
[25974]={[0]="Sira'kess Slaying",[1]='FH K0820 L080 A:41670 T:41670'},
[25975]={[0]='Treasure Reclamation',[1]='FA K0820 L080 A:41665 T:41665 P:26080'},
[25976]={[0]='Treasure Reclamation',[1]='FH K0820 L080 A:41668 T:41668'},
[25977]={[0]='A Standard Day for Azrajar',[1]='FA K0820 L080 A:41667 T:41667 P:26080'},
[25978]={[0]='Entombed in Ice',[1]='B0 FA K0100 L007 A:41786 T:41786 O:25986'},
[25979]={[0]='Dealing with the Surge',[1]='B0 FA K0100 L007 A:41804 T:41804'},
[25980]={[0]='A Standard Day for Azrajar',[1]='FH K0820 L080 A:41670 T:41670'},
[25981]={[0]="Those Aren't Masks",[1]='FA K0820 L080 A:41666 T:41666 P:26080'},
[25982]={[0]="Those Aren't Masks",[1]='K0820 L080 A:41669 T:41669'},
[25983]={[0]='Promontory Point',[1]='FA K0820 L080 A:41666 T:41598 P:25987'},
[25984]={[0]='Promontory Point',[1]='FH K0820 L080 A:41669 T:41636,41984 P:25988'},
[25985]={[0]='Wings Over Mount Hyjal',[1]='B606 K0810 L080 A:40833 T:41005 P:25578 I:25663,27874'},
[25986]={[0]='Trouble at the Lake',[1]='B0 FA K0100 L006 A:1977 T:41786 P:432+433+25937 I:25978'},
[25987]={[0]='Put It On',[1]='FA K0820 L080 A:41666 T:41666 P:25981'},
[25988]={[0]='Put It On',[1]='FH K0820 L080 A:41669 T:41669 P:25982'},
[25989]={[0]='Capture the Crab',[1]='FH K0810 L080 A:41531 T:15104,41531 P:25907,25908'},
[25990]={[0]='Breaking Through',[1]='FH K0810 L080 A:41531 T:41531 P:25989'},
[25991]={[0]='We Are Not Alone',[1]='FH K0810 L080 A:41531 T:41810 P:25990'},
[25992]={[0]='Hopelessly Gearless',[1]='FH K0810 L080 A:41811 T:41811'},
[25993]={[0]='Body Blows',[1]='FH K0810 L080 A:41810 T:41810 P:25991'},
[25994]={[0]='Still Valuable',[1]='FH K0810 L080 A:41813 T:41813'},
[25995]={[0]="Overseer Idra'kess",[1]='FH K0810 L080 A:41810 T:41531'},
[25996]={[0]='Waking the Beast',[1]='FH K0810 L080 A:41531 T:40917 P:25995'},
[25997]={[0]='Dark Iron Scheming',[1]='B0 FA K0100 L007 A:41786 T:41786 P:25978+25979'},
[25998]={[0]='Get to the Airfield',[1]='B0 FA K0100 L007 A:41786 T:41853 P:25997'},
[25999]={[0]='Barrier to Entry',[1]='B81 K0260 FH L024 A:34341 T:34341 P:25945'},
[26000]={[0]='Spelunking',[1]='FH K0810 L080 A:40105 T:41863'},
[26001]={[0]='The Missing Blastgineer',[1]='B81 K0260 FH L024 A:34341 T:40901 P:25999'},
[26002]={[0]='Alliance Attack Plans',[1]='B81 K0260 FH L024 A:40901 T:34341 P:26001'},
[26003]={[0]='Lessons from the Lost Isles',[1]='B81 K0260 FH L024 A:40926 T:40926'},
[26004]={[0]="Krom'gar Fortress",[1]='B81 K0260 FH L024 A:34341 T:41023 P:26002'},
[26005]={[0]='A Breath of Fresh Air',[1]='FA K0810 L080 A:39881 T:42411 P:25626'},
[26006]={[0]='A Breath of Fresh Air',[1]='FH K0810 L080 A:40919 T:42410 P:26135'},
[26007]={[0]='Debriefing',[1]='FH K0810 L080 A:41341 T:41341 P:25824'},
[26008]={[0]='Decompression',[1]='FH K0810 L080 A:41347 T:33536,41347'},
[26009]={[0]='Seek and Destroy',[1]='B81 +D FH K0270 L024 A:41023 T:41023'},
[26010]={[0]='Ashes to Ashes',[1]='B81 K0270 FH L024 A:41023 T:41023'},
[26011]={[0]='Enemy of the Horde: Marshal Paltrow',[1]='B81 K0270 FH L024 A:40903 T:40903'},
[26012]={[0]='Trouble at Wyrmrest',[1]='B0 K0820 L080 A:16128 T:27990'},
[26013]={[0]='Assault on the Sanctum',[1]='B0 K0820 L080 A:27990 T:40429 P:26012'},
[26014]={[0]='The Brothers Digsong',[1]='FA K0810 L080 A:41662 T:41910 P:26105+26106'},
[26015]={[0]='Phosphora Hunting',[1]='K0810 L080 A:41910 T:46592,41910 P:26014'},
[26016]={[0]='Orders from Base Camp',[1]='B81 K0270 FH L024 A:100056474 T:41023'},
[26017]={[0]='A Lure',[1]='FA K0810 L080 A:41910 T:41910 P:26015'},
[26018]={[0]='Coldlights Out',[1]='FA K0810 L080 A:41910 T:41910 P:26015'},
[26019]={[0]='Enormous Eel Egg',[1]='FA K0810 L080 A:100056571 T:41910'},
[26020]={[0]='Report to Bombgutz',[1]='B81 K0270 FH L024 A:41023 T:40902 P:26010'},
[26021]={[0]='The Brothers Digsong 2: Eel-Egg-Trick Boogaloo',[1]='FA K0810 L080 A:41910 T:41910 P:26019'},
[26022]={[0]='First Blood',[1]='B16 K0270 FH L025 A:41949 T:41949 P:28572,28619'},
[26023]={[0]='The Forsaken Trollbane',[1]='B16 K0270 FH L025 A:41949 T:41944'},
[26024]={[0]='Wanted!  Marez Cowl',[1]='B16 FA K0280 L026 A:1002713 T:2700'},
[26025]={[0]='The Traitor Orc',[1]='B16 K0270 FH L025 A:41949 T:41949'},
[26026]={[0]='Dream of a Better Tomorrow',[1]='B81 K0270 FH L024 A:40907 T:40907'},
[26027]={[0]='Call to Arms',[1]='B16 K0270 FH L025 A:41966 T:41949 P:26053'},
[26028]={[0]="Mr. D's Wild Ride",[1]='B81 K0270 FH L024 A:40907 T:41023 P:26026'},
[26029]={[0]='The Real Threat',[1]='B16 K0270 FH L025 A:41966 T:41966'},
[26030]={[0]='Sigil of Strom',[1]='B16 K0270 FH L025 A:41944 T:41944 P:26023'},
[26031]={[0]='Sigil of Thoradin',[1]='B16 K0270 FH L025 A:41944 T:41944 P:26030'},
[26032]={[0]='Sigil of Arathor',[1]='B16 K0270 FH L025 A:41944 T:41944 P:26031'},
[26033]={[0]="Trol'kalar",[1]='B16 K0270 FH L025 A:41944 T:41944 P:26032'},
[26034]={[0]='The Twilight Destroyer',[1]='B0 K0820 L080 A:40429 T:27990 P:26013'},
[26035]={[0]='Worth Its Weight in Gold',[1]='B16 FA K0260 L024 A:2789 T:2789'},
[26036]={[0]='Wand over Fist',[1]='B16 FA K0260 L024 A:2789 T:2789 P:26035'},
[26037]={[0]="Trelane's Defenses",[1]='B16 FA K0270 L024 A:2789 T:41983 P:26036'},
[26038]={[0]='Attack on the Tower',[1]='B16 FA K0270 L024 A:41983 T:2789 P:26037'},
[26039]={[0]='The Princess Trapped',[1]='B16 K0290 L027 A:1138492 T:1002701 O:26341,26909'},
[26040]={[0]='What? What? In My Gut...?',[1]='FH K0810 L080 A:41863,41885 T:40192,41885'},
[26041]={[0]='Stones of Binding',[1]='B16 K0290 L027 A:1002701 T:1002702 P:26039'},
[26042]={[0]='Breaking the Keystone',[1]='B16 K0290 L024 A:1002702 T:1002688 P:26041'},
[26043]={[0]='BEWARE OF CRAGJAW!',[1]='B81 K0270 FH L024 A:1203186 T:40903'},
[26044]={[0]='Where Are the Parts?',[1]='B81 K0270 FH L024 A:40902 T:41991 P:26020'},
[26045]={[0]='I Got Your Parts Right Here...',[1]='B81 K0270 FH L024 A:41991 T:41991 P:26044'},
[26046]={[0]='Between a Rock and a Hard Place',[1]='B81 K0270 FH L024 A:41990 T:41990'},
[26047]={[0]="And That's Why They Call Them Peons...",[1]='B81 K0270 FH L024 A:41992 T:41992'},
[26048]={[0]='Spare Parts Up In Here!',[1]='B81 K0270 FH L024 A:41991 T:40902'},
[26049]={[0]='The Princess Unleashed',[1]='B16 FA K0280 L026 A:2789 T:1138492 P:26346'},
[26050]={[0]='Goggle Boggle',[1]='B16 K0280 L026 A:2768 T:2774'},
[26051]={[0]='Sunken Treasure',[1]='B16 K0280 L026 A:2774 T:2774 P:26050'},
[26052]={[0]='Speak to Shakes',[1]='B16 K0280 L026 A:2774 T:2610 P:26051'},
[26053]={[0]='Clearing the Highlands',[1]='B16 K0270 FH L025 A:41966 T:41966'},
[26054]={[0]='Water They Up To?',[1]='B0 K0800 FA L078 A:42443 T:466'},
[26055]={[0]='Drowned Sorrows',[1]='B16 K0280 L026 A:2769 T:2769'},
[26056]={[0]='The Wavespeaker',[1]='FA K0820 L080 A:41598 T:41640'},
[26057]={[0]='The Wavespeaker',[1]='FH K0820 L080 A:41636 T:41640'},
[26058]={[0]="In Defense of Krom'gar Fortress",[1]='B81 K0270 FH L024 A:40902 T:41023 P:26048'},
[26059]={[0]="Eyes and Ears: Malaka'jin",[1]='B81 K0280 FH L026 A:41023 T:3995'},
[26060]={[0]='Da Voodoo: Stormer Heart',[1]='B81 K0280 FH L026 A:3995 T:3995'},
[26061]={[0]='Da Voodoo: Ram Horns',[1]='B81 K0280 FH L026 A:3995 T:3995'},
[26062]={[0]='Da Voodoo: Resonite Crystal',[1]='B81 K0280 FH L026 A:3995 T:3995'},
[26063]={[0]='The Queen and Her Court',[1]='B81 K0270 FH L025 A:11821 T:11821'},
[26064]={[0]='Fight On Their Stomachs',[1]='B81 K0280 FH L026 A:3411 T:3411'},
[26065]={[0]="Free Wil'hai",[1]='K0820 L080 A:41640 T:41640 P:26056,26057'},
[26066]={[0]='Reinforcements...',[1]='B81 K0290 FH L026 A:42023 T:42023'},
[26067]={[0]="Jin'Zil's Blessing",[1]='B81 K0300 FH L026 A:3995 T:3995 P:26062'},
[26068]={[0]='Kobold Fury!',[1]='B81 K0300 FH L026 A:42023 T:42023 P:26066'},
[26069]={[0]='Nura Pathfinder',[1]='B81 K0300 FH L028 A:3995 T:37135 B607'},
[26070]={[0]='Clearing the Defiled',[1]='FA K0820 L080 A:41598 T:41598 P:25983'},
[26071]={[0]='Clearing the Defiled',[1]='FH K0820 L080 A:41636 T:41636 P:25984'},
[26072]={[0]='Into the Totem',[1]='K0820 L080 A:41600 T:41600'},
[26073]={[0]="All's Quiet on the Southern Front",[1]='B81 K0300 FH L026 A:3995 T:41023'},
[26074]={[0]='Beginning of the End',[1]='B81 K0300 FH L026 A:41023 T:42033 P:26073'},
[26075]={[0]='The Turd Problem',[1]='B81 K0300 FH L026 A:42033 T:42033 P:26074'},
[26076]={[0]='Spy Infestation',[1]='B81 K0300 FH L026 A:42033 T:42033 P:26075'},
[26077]={[0]='Final Delivery',[1]='B81 K0300 FH L026 A:42033 T:42050 P:26076'},
[26078]={[0]='Extinguish the Fires',[1]='B0 FA K0100 L007 A:41853 T:41853 P:25998'},
[26079]={[0]='Wanted!  Otto and Falconcrest',[1]='B16 FA K0280 L026 A:1002713 T:2700'},
[26080]={[0]='One Last Favor',[1]='FA K0810 L080 A:41910 T:41662 P:26017+26018'},
[26081]={[0]="Alina's Reward",[1]='B16 K0270 FH L025 A:41944 T:41949 P:26033'},
[26082]={[0]='To Battlescar!',[1]='B81 K0300 FH L026 A:42050 T:42050 P:26077'},
[26083]={[0]='Hello Lolo',[1]='B16 K0270 FH L025 A:42088 T:2766'},
[26084]={[0]='Hammerfall',[1]='B16 K0270 FH L025 A:41949 T:42130 P:26081'},
[26085]={[0]='Rallying the Defenders',[1]='B0 FA K0100 L007 A:41853 T:41853 P:26078'},
[26086]={[0]='Orako',[1]='FH K0810 L080 A:41663 T:41908'},
[26087]={[0]='"Glow-Juice"',[1]='FH K0810 L080 A:41908 T:41908 P:26086'},
[26088]={[0]='Here Fishie Fishie',[1]='FH K0810 L080 A:41908 T:41908'},
[26089]={[0]='Die Fishman Die',[1]='FH K0810 L080 A:41908 T:41908'},
[26090]={[0]='I Brought You This Egg',[1]='FH K0810 L080 A:100056812 T:41908'},
[26091]={[0]='Here Fishie Fishie 2: Eel-Egg-Trick Boogaloo',[1]='FH K0810 L080 A:41908 T:41908 P:26090'},
[26092]={[0]="Orako's Report",[1]='FH K0810 L080 A:41908 T:41663'},
[26093]={[0]='Northfold Manor',[1]='B16 FA K0260 L024 A:2700 T:2700 O:26139,28573'},
[26094]={[0]='Striking Back',[1]='B0 FA K0100 L007 A:41853 T:41853 P:26085'},
[26095]={[0]='Stromgarde Badges',[1]='B16 FA K0280 L026 A:2700 T:2700 P:26093'},
[26096]={[0]='Scalding Shrooms',[1]='K0820 L080 A:41639 T:41639'},
[26097]={[0]='Proof of Lies',[1]='B81 K0300 FH L026 A:42039 T:42091'},
[26098]={[0]='Betrayal at the Grove',[1]='B81 K0300 FH L026 A:42091 T:42039 P:26097'},
[26099]={[0]='Is This Justice?',[1]='B81 K0300 FH L026 A:42039 T:42047'},
[26100]={[0]='The General is Dead',[1]='B81 K0300 FH L026 A:42047 T:41023 P:26099'},
[26101]={[0]='Might Makes Right',[1]='B81 K0300 FH L026 A:41023 T:42106 P:26100'},
[26102]={[0]="Grimaxe's Demise",[1]='B0 FA K0100 L007 A:41853 T:41853 P:26094'},
[26103]={[0]='Bio-Fuel',[1]='FA K0810 L080 A:41666 T:41666 P:26219'},
[26105]={[0]="Claim Korthun's End",[1]='FA K0810 L080 AK:42115 T:41665'},
[26106]={[0]='Fuel-ology 101',[1]='FA K0810 L080 A:41666 T:41666 P:26103'},
[26107]={[0]='Raising Spirits',[1]='B16 K0280 FH L026 A:42130 T:42130'},
[26108]={[0]='Guile of the Raptor',[1]='B16 K0280 FH L026 A:42130 T:42130 P:26107'},
[26110]={[0]='Just Like Old Times',[1]='B16 FA K0280 L026 A:2712 T:2712 O:26113'},
[26111]={[0]='... It Will Come',[1]='K0820 L080 A:41600 T:41600 P:26072'},
[26112]={[0]='Demanding Answers',[1]='B0 FA K0100 L007 A:41853 T:42129 P:26102'},
[26113]={[0]='Quae and Kinelory',[1]='B16 FA K0280 L026 A:2608 T:2712 I:26110'},
[26114]={[0]='Quae Trusts You',[1]='B16 FA K0280 L026 A:2712 T:2713 P:26110'},
[26115]={[0]='To Be Horde...',[1]='B81 K0300 FH L026 A:42106 T:42039 P:26101'},
[26116]={[0]='Kinelory Strikes',[1]='B16 FA K02832 L026 A:2713 T:2712 P:26114'},
[26117]={[0]='For Southshore',[1]='B16 FA K0280 L026 A:2712 T:2608 P:26116'},
[26118]={[0]='Seize the Ambassador',[1]='B0 FA K0100 L007 A:42129 T:42129 P:26112'},
[26120]={[0]='The Crazed Dragonmaw',[1]='B40 FA K0250 L023 A:41612 T:41612'},
[26122]={[0]='Environmental Awareness',[1]='FH K0810 L080 A:41669 T:41669'},
[26125]={[0]='Secure Seabrush',[1]='FH K0810 L080 A:41663 T:41668'},
[26126]={[0]='The Perfect Fuel',[1]='FH K0810 L080 A:41669 T:41669 P:26122'},
[26127]={[0]="The Twilight's Hammer Revealed",[1]='B40 FA K0250 L023 A:42160 T:42160 O:26327'},
[26128]={[0]='The Battle of Thandol Span',[1]='B40 FA K0250 L023 A:42160 T:42160 P:26127'},
[26129]={[0]='Brothers In Arms',[1]='B0 FA RW K0030 A:35077 T:35112 P:14154'},
[26130]={[0]="Unplug L'ghorek",[1]='K0820 L080 A:41600 T:41600 P:26111'},
[26131]={[0]='Reinforcements for Loch Modan',[1]='B0 FA K010 L007 A:1959 T:1960 I:28567'},
[26132]={[0]='Fiends from the Netherworld',[1]='FA K0820 L080 A:41598 T:41598 P:26111'},
[26133]={[0]='Fiends from the Netherworld',[1]='FH K0820 L080 A:41636 T:41636'},
[26134]={[0]='Nothing Left for You Here',[1]='B81 K0300 FH L027 A:42039 T:35286 B121'},
[26135]={[0]='Visions of the Past: Rise from the Deep',[1]='FH K0810 L080 A:40919 T:40919'},
[26137]={[0]='Checking on the Boys',[1]='B40 FA K0200 L018 A:1343 T:41075 I:25395,28565,25235'}, -- It is reported that the I:25235 is currently an accident Blizzard may fix in the future.
[26139]={[0]='Into Arathi',[1]='B16 FA K0250 L023 A:42160 T:2700 P:26128 I:26093,28573 B16'},
[26140]={[0]='Communing with the Ancient',[1]='K0820 L080 A:41600 T:42197 P:26130'},
[26141]={[0]='Runestones of Binding',[1]='K0820 L080 A:42197 T:42197 P:26140'},
[26142]={[0]='Ascend No More!',[1]='K0820 L080 A:42197 T:42197 P:26140'},
[26143]={[0]='All that Rises',[1]='K0820 L080 A:-614 T:42197 P:26154'},
[26144]={[0]='Prisoners',[1]='B0 K0820 L080 A:100057102 T:0'},
[26145]={[0]='The Trogg Threat',[1]='B35 FA K0120 L010 A:1089 T:1089 P:13635'},
[26146]={[0]="In Defense of the King's Lands",[1]='B35 FA K0120 L010 A:1092 T:1092'},
[26147]={[0]='Bigger and Uglier',[1]='B35 FA K0120 L010 A:1090 T:1090 P:26146'},
[26148]={[0]='A Decisive Strike',[1]='B35 FA K0120 L010 A:1092 T:1092 P:26146'},
[26149]={[0]='Prisoners',[1]='B0 K0820 L080 A:100057118'},
[26150]={[0]='A Visit With Maybell',[1]='B0 K0060 FA L005 A:253 T:251 P:60 I:106'},
[26152]={[0]='Wanted: James Clark',[1]='B0 K0100 FA L007 A:1007125 T:42256'},
[26153]={[0]="Penny's Pumpkin Pancakes",[1]='B0 +D FA K0000 L010 A:42288 T:42288 I:26177,26183,26190,26192,29313,29314,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[26154]={[0]='Twilight Extermination',[1]='B0 K0820 L080 A:42197 T:0 P:26141,26142'},
[26157]={[0]='Kasim Sharim',[1]='B19 FA K0550 L054 A:5385 T:42298 P:25716'},
[26158]={[0]='Attune the Bloodstone',[1]='B19 FA K0550 L054 A:42298 T:42298 P:26157'},
[26159]={[0]='The First Step',[1]='B19 FA K0550 L054 A:42298 T:42298'},
[26160]={[0]='Blood Ritual',[1]='B19 FA K0550 L054 A:42298 T:42298 P:26159'},
[26161]={[0]='Not Just Any Body',[1]='B19 FA K0560 L054 A:42298 T:42298 P:26166'},
[26162]={[0]='The Altar of Storms',[1]='B19 FA K0560 L054 A:42298 T:7783 P:26161'},
[26163]={[0]='Time is Short',[1]='B19 FA K0560 L054 A:42298 T:42299'},
[26164]={[0]='The Charred Granite of the Dark Portal',[1]='B19 FA K0560 L054 A:42299 T:42299'},
[26165]={[0]='The Vile Blood of Demons',[1]='B19 FA K0560 L054 A:42299 T:42299'},
[26166]={[0]='Enhancing the Stone',[1]='B19 FA K0560 L054 A:42299 T:42298'},
[26167]={[0]='The Amulet of Allistarj',[1]='B19 FA K0550 L054 A:42298 T:42298'},
[26168]={[0]='The Amulet of Sevine',[1]='B19 FA K0550 L054 A:42298 T:42298'},
[26169]={[0]='The Amulet of Grol',[1]='B19 FA K0550 L054 A:42298 T:42298'},
[26170]={[0]='The Final Ritual',[1]='B19 FA K0560 L054 A:42298 T:7783'},
[26171]={[0]="You Are Rakh'likh, Demon",[1]='B19 FA K0570 L054 A:7783 T:42299 P:26170'},
[26172]={[0]="A Bloodmage's Gotta Eat Too",[1]='B19 FA K0550 L054 A:42298 T:42298'},
[26173]={[0]='Protecting Our Rear',[1]='B19 FA K0560 L054 A:16841 T:16841'},
[26174]={[0]='Watching Our Back',[1]='B19 FA K0560 L054 A:16841 T:16841 P:26173'},
[26175]={[0]='Surwich',[1]='B19 FA K0570 L055 A:16841 T:42349 P:26174'},
[26176]={[0]='Onward to Thelsamar',[1]='B35 FA K0120 L010 A:1092 T:1340 P:26148'}, -- TODO: Determine which I: needs to be added here
[26177]={[0]='Feeling Crabby?',[1]='B0 +D FA K0000 L010 A:42288 T:42288 I:26153,26183,26190,26192,29313,29314,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[26179]={[0]='The Venture Co.',[1]='B0 K0070 FH L005 A:2988 T:2988 P:751'},
[26180]={[0]='Supervisor Fizsprocket',[1]='B0 K0080 FH L006 A:2988 T:2988 P:751'},
[26181]={[0]='Back to Darkbreak Cove',[1]='B0 FA K0820 L080 A:42197 T:541600 P:26143'},
[26182]={[0]='Back to the Tenebrous Cavern',[1]='FH K0820 L080 A:42197 T:41600'},
[26183]={[0]="The King's Cider",[1]='B0 +D FA K0000 L010 A:42288 T:42288 I:26153,26177,26190,26192,29313,29314,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[26184]={[0]="Wormthorn's Dream",[1]='B19 FA K0580 L055 A:42349 T:42349 P:26175'},
[26185]={[0]='Advice from the Cenarion Circle',[1]='B19 FA K0580 L055 A:42349 T:42352 P:26184'},
[26186]={[0]='Demoniac Vessel',[1]='B19 FA K0580 L055 A:42352 T:42349 P:26185'},
[26187]={[0]='The Downfall of Marl Wormthorn',[1]='B19 FA K0590 L055 A:42349 T:42349 P:26186'},
[26188]={[0]='Mazzranache',[1]='B0 K0080 FH L006 A:3055 T:3055'},
[26189]={[0]='The Angerfang Menace',[1]='B40 FA K0240 L022 A:41411 T:41411 P:25849'},
[26190]={[0]="A Fisherman's Feast",[1]='B0 +D FA K0000 L010 A:42288 T:42288 I:26153,26177,26183,26192,29313,29314,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[26191]={[0]='The Culmination of Our Efforts',[1]='SP K0810 L080 A:542076 T:0 P:25859+25863'},
[26192]={[0]='Orphans Like Cookies Too!',[1]='B0 +D FA K0000 L010 A:42288 T:42288 I:26153,26177,26183,26190,29313,29314,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[26193]={[0]='Defending the Rift',[1]='FA K0820 L080 A:541600 T:44490 P:26181'},
[26194]={[0]='Defending the Rift',[1]='FH K0820 L080 A:41600 T:44540'},
[26195]={[0]='Who Wards The Greenwarden',[1]='B40 FA K0240 L022 A:41411 T:41615 P:25850+25853+26189'},
[26196]={[0]='Longbraid the Grim',[1]='B40 FA K0250 L023 A:41615 T:1071 P:25939'},
[26197]={[0]='The Future of Gnomeregan',[1]='B0 FA RN CM K0010 A:42396 T:42331'},
[26198]={[0]='The Arts of a Mage',[1]='B0 K0030 RN CM L003 A:42331 T:42331'},
[26199]={[0]='The Future of Gnomeregan',[1]='B0 FA RN CT K0010 A:42396 T:42323'},
[26200]={[0]='The Arts of a Priest',[1]='B0 K0030 RN CT L003 A:42323 T:42323'},
[26201]={[0]='The Power of a Warlock',[1]='B0 K0030 RN CL L003 A:460 T:460'},
[26202]={[0]='The Future of Gnomeregan',[1]='B0 FA RN CL K0010 A:42396 T:460'},
[26203]={[0]='The Future of Gnomeregan',[1]='B0 FA RN CW K0010 A:42396 T:42324'},
[26204]={[0]='The Arts of a Warrior',[1]='B0 K0030 RN CW CH L003 A:42324 T:42324'},
[26205]={[0]='A Job for the Multi-Bot',[1]='B0 K0020 RN L002 A:42553 T:42553 P:26222'},
[26206]={[0]='The Future of Gnomeregan',[1]='B0 FA RN CR K0010 A:42396 T:42366'},
[26207]={[0]='The Arts of a Rogue',[1]='B0 K0030 RN CR L003 A:42366 T:42366'},
[26208]={[0]='The Fight Continues',[1]='B0 FA RN K0020 L002 A:42317 T:42317 P:26421,26422,26423,26424,26425'},
[26209]={[0]='Murder Was The Case That They Gave Me',[1]='B39 FA K0110 L009 A:42308 T:42308 O:26378,28562'},
[26210]={[0]='Gammerita, Mon!',[1]='B26 K0310 FH L029 A:14740 T:14740'},
[26211]={[0]='Snapjaws, Mon!',[1]='B26 K0310 FH L029 A:14740 T:14740'},
[26212]={[0]='Lard Lost His Lunch',[1]='B26 K0310 FH L029 A:14731 T:14731'},
[26213]={[0]='Hot On the Trail: The Riverpaw Clan',[1]='B39 FA K0100 L009 A:42308 T:42308 P:26209'},
[26214]={[0]='Hot On the Trail: Murlocs',[1]='B39 FA K0110 L009 A:42308 T:42308 P:26209'},
[26215]={[0]='Meet Two-Shoed Lou',[1]='B39 FA K0110 L009 A:42308 T:42405 P:26213+26214'},
[26219]={[0]='Full Circle',[1]='FA K0810 L080 A:42411 T:41662 P:26005 B614'},
[26220]={[0]='Everything Is Better with Bacon',[1]='B0 +D FH K0000 L010 A:42506 T:42506 PC001  I:26226,26227,26233,26234,26235,29315,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[26221]={[0]='Full Circle',[1]='FH K0810 L080 A:42410 T:41663 B614'},
[26222]={[0]='Scrounging for Parts',[1]='B0 FA RN K0020 L002 A:42553 T:42553 P:26566'},
[26223]={[0]='Stalking the Stalkers',[1]='B26 K0320 FH L029 A:14741 T:14741'},
[26224]={[0]='Hunt the Savages',[1]='B26 K0320 FH L029 A:14741 T:14741 P:26223'},
[26225]={[0]='Pupellyverbos Port',[1]='B26 K0310 FH L029 A:42464 T:42464'},
[26226]={[0]='Crawfish Creole',[1]='B0 +D FH K0000 L010 A:42506 T:42506 PC001  I:26220,26227,26233,26234,26235,29315,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[26227]={[0]='Careful, This Fruit Bites Back',[1]='B0 +D FH K0000 L010 A:42506 T:42506 PC001  I:26220,26226,26233,26234,26235,29315,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[26228]={[0]="Livin' the Life",[1]='B39 FA K0110 L009 A:42405 T:42405 P:26215'},
[26229]={[0]='"I TAKE Candle!"',[1]='B39 FA K0110 L009 A:42498 T:42498 P:26215'},
[26230]={[0]='Feast or Famine',[1]='B39 FA K0120 L009 A:42497 T:42497 P:26215'},
[26232]={[0]="Lou's Parting Thoughts",[1]='B39 FA K0120 L009 A:42405 T:42558 P:26228'},
[26233]={[0]='Stealing From Our Own',[1]='B0 +D FH SL K0000 L010 A:42506 T:42506 PC001  I:26220,26226,26227,26234,26235,29315,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[26234]={[0]='Stealing From Our Own',[1]='B0 +D FH RL K0000 L010 A:42506 T:42506 PC001  I:26220,26226,26227,26233,26235,29315,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[26235]={[0]='Even Thieves Get Hungry',[1]='B0 +D FH K0000 L010 A:42506 T:42506 PC001  I:26220,26226,26227,26233,26234,29315,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[26236]={[0]="Shakedown at the Saldean's",[1]='B39 FA K0120 L010 A:42558 T:233 P:26232'},
[26237]={[0]='Times are Tough',[1]='B39 FA K0120 L010 A:233 T:233 P:26236'},
[26238]={[0]='The Savage Dwarves',[1]='B26 K0320 FH L030 A:42613 T:42613'},
[26240]={[0]='Stomp To My Beat',[1]='B26 K0320 FH L030 A:14739 T:14739'},
[26241]={[0]='Westfall Stew',[1]='B39 FA K0120 L010 A:235 T:235 P:26236'},
[26244]={[0]='The Earth Claims All',[1]='B640 K0820 L081 A:43397 T:43397'},
[26245]={[0]='Gunship Down',[1]='B640 K0820 L081 A:43065 T:43065 P:27123'},
[26246]={[0]="Captain's Log",[1]='B640 K0820 L081 A:1204274 T:43065 PL:26245'},
[26247]={[0]='Diplomacy First',[1]='B640 K0820 L081 A:43065 T:42684 P:26244+26246+27136'},
[26248]={[0]='All Our Friends Are Dead',[1]='B640 K0820 L081 A:42684 T:42684 P:26247'},
[26249]={[0]="The Admiral's Cabin",[1]='B640 K0820 L081 A:42684 T:43082 P:26247'},
[26250]={[0]='On Second Thought, Take One Prisoner',[1]='B640 K0820 L081 A:42684 T:42684 P:26248'},
[26251]={[0]='Take No Prisoners',[1]='B640 K0820 L081 A:42684 T:42684 P:26248'},
[26252]={[0]='Heart of the Watcher',[1]='B39 FA K0120 L010 A:100057935 T:233 P:26236'},
[26254]={[0]='Some Spraining to Do',[1]='B640 K0820 L081 A:42684 T:42684 P:26250'},
[26255]={[0]='Return to the Temple of Earth',[1]='B640 K0820 L081 A:42684 T:43065 P:26254'},
[26256]={[0]='Bleed the Bloodshaper',[1]='B640 K0820 L081 A:-640 T:0 P:26258'},
[26257]={[0]="It's Alive!",[1]='B39 FA K0130 L010 A:233 T:233 P:26252'},
[26258]={[0]="Deathwing's Fall",[1]='B640 K0820 L081 A:43065 T:0 P:26255'},
[26259]={[0]='Blood of the Earthwarder',[1]='B640 K0820 L081 A:43397 T:43397 P:26255'},
[26260]={[0]="The Forgemaster's Log",[1]='B640 K0820 L081 A:-640 T:1205134 P:26261'},
[26261]={[0]='Question the Slaves',[1]='B640 K0820 L081 A:-640 T:0 P:26256'},
[26263]={[0]='Thornar Thunderclash',[1]='B26 K0320 FH L030 A:42613 T:42613'},
[26264]={[0]="What's Left Behind",[1]='B0 FA RN K0020 L002 A:42611 T:42611'},
[26265]={[0]='Dealing with the Fallout',[1]='B0 FA RN K0020 L002 A:42630 T:42630'},
[26266]={[0]='Hope for the People',[1]='B39 FA K0130 L011 A:235 T:42575 P:26270'},
[26267]={[0]='Skulk Rock Clean-Up',[1]='B26 K0320 FH L030 A:42613 T:42613'},
[26268]={[0]='Skulk Rock Supplies',[1]='B26 K0320 FH L030 A:42613 T:42613 P:26267'},
[26269]={[0]='The Green Hills of Stranglethorn',[1]='B37 K0250 L024 A:716 T:716 P:583'},
[26270]={[0]='You Have Our Thanks',[1]='B39 FA K0130 L010 A:233 T:235 P:26237+26241'},
[26271]={[0]='Feeding the Hungry and the Hopeless',[1]='B39 FA K0130 L011 A:42575 T:42575 P:26266'},
[26272]={[0]='The Rise of the Darkspear',[1]='B0 K0020 FH CL A:37951 T:42618'},
[26273]={[0]='The Basics: Hitting Things',[1]='B0 K0020 CL A:42618 T:42618 P:26272'},
[26274]={[0]='The Arts of a Warlock',[1]='B0 K0030 CL A:42618 T:42618 P:26276'},
[26275]={[0]='A Rough Start',[1]='B0 K0030 FH CL A:42618 T:42618 P:26273'},
[26276]={[0]='Proving Pit',[1]='B0 K0030 CL A:42618 T:42618 P:26275'},
[26277]={[0]='More Than Expected',[1]='B0 K0030 FH CL A:42618 T:38966 P:26274'},
[26278]={[0]="The Defense of Grom'gol: Raptor Risk",[1]='B37 K0250 FH L024 A:2464 T:2464 O:26417,28688'},
[26279]={[0]="The Defense of Grom'gol: Ogre Oppression",[1]='B37 K0250 FH L024 A:2464 T:2464'},
[26280]={[0]="The Defense of Grom'gol: Murloc Menace",[1]='B37 K0250 FH L024 A:2464 T:2464'},
[26281]={[0]="The Defense of Grom'gol: Trollish Thievery",[1]='B37 K0250 FH L024 A:2464 T:2464 P:26280'},
[26283]={[0]='Prime Slime',[1]='B26 K0320 FH L030 A:42612 T:42612'},
[26284]={[0]='Missing in Action',[1]='B0 K0030 RN L002 AA:42645,42708 T:42708'},
[26285]={[0]='Get Me Explosives Back!',[1]='B0 FA RN K0030 L002 A:42708 T:42708 P:26284'},
[26286]={[0]='In Defense of Westfall',[1]='B39 FA K0130 L011 A:234 T:234 P:26266'},
[26287]={[0]='The Westfall Brigade',[1]='B39 FA K0130 L011 A:821 T:821 P:26266'},
[26288]={[0]='Jango Spothide',[1]='B39 FA K0140 L011 A:821 T:821 P:26287'},
[26289]={[0]='Find Agent Kearnen',[1]='B39 FA K0140 L011 A:234 T:7024 P:26286+26271'},
[26290]={[0]='Secrets of the Tower',[1]='B39 FA K0140 L011 A:7024 T:7024 P:26289'},
[26291]={[0]='Big Trouble in Moonbrook',[1]='B39 FA K0140 L011 A:7024 T:234 P:26290'},
[26292]={[0]='To Moonbrook!',[1]='B39 FA K0140 L012 A:234 T:42425 P:26291'},
[26293]={[0]='Machines of War',[1]='B0 K0840 FH L084 A:39605 T:42672 P:28717'},
[26294]={[0]='Weapons of Mass Dysfunction',[1]='B0 K0840 FH L084 A:42672 T:39605 P:26293'},
[26295]={[0]='Propaganda',[1]='B39 FA K0140 L012 A:42425 T:42425 P:26292'},
[26296]={[0]='Evidence Collection',[1]='B39 FA K0140 L012 A:100058117 T:42425 P:26292'},
[26297]={[0]='The Dawning of a New Day',[1]='B39 FA K0150 L012 A:42425 T:42425 P:26295'},
[26298]={[0]='Hunt for Yenniku',[1]='B37 K0260 FH L024 A:2497 T:2497'},
[26299]={[0]='Headhunting',[1]='B37 K0260 FH L024 A:2497 T:2497 P:26298'},
[26300]={[0]='Nezzliok Will Know',[1]='B37 K0270 FH L024 A:2497 T:1002076'},
[26301]={[0]='Speaking with Nezzliok',[1]='B37 K0270 FH L024 A:1002076 T:1002076'},
[26302]={[0]="Chasing Yenniku's Fate",[1]='B37 K0270 FH L024 A:1002076 T:2519 P:26301'},
[26303]={[0]="The Mind's Eye",[1]='B37 K0280 FH L024 A:2519 T:2519 P:26302'},
[26304]={[0]='Nighttime in the Jungle',[1]='B37 K0290 FH L027 A:42813 T:42813'},
[26305]={[0]='Saving Yenniku',[1]='B37 K0290 FH L024 A:2519 T:2497 P:26303'},
[26306]={[0]='Start Taking Back',[1]='B26 K0330 FH L031 A:42642 T:42642 P:26432,26496'},
[26307]={[0]='Death to the Vilebranch',[1]='B26 K0330 FH L031 A:42642 T:42642 P:26306,26497'},
[26308]={[0]="It's Ours Now",[1]='B26 K0330 FH L031 A:42642 T:42642 P:26307'},
[26309]={[0]='Dark Vessels',[1]='B26 K0330 FH L031 A:42622 T:42622 P:26310'},
[26310]={[0]='All That Skitters',[1]='B26 K0330 FH L031 A:42622 T:42622'},
[26311]={[0]='Unfamiliar Waters',[1]='B0 K0840 FH L084 A:42637 T:42637 P:28909'},
[26312]={[0]='Crumbling Defenses',[1]='B640 K0830 L081 A:42730 T:42730 P:26326'},
[26313]={[0]='Core of Our Troubles',[1]='B640 K0830 L081 A:42731 T:42731 P:26326'},
[26314]={[0]='On Even Ground',[1]='B640 K0830 L081 A:42730 T:42730 P:26326'},
[26315]={[0]='Imposing Confrontation',[1]='B640 K0830 L081 A:42731 T:42731 P:26312+26313+26314'},
[26316]={[0]="What's Keeping Jessup?",[1]='B0 FA RN K0030 L002 A:42489 T:42708'},
[26317]={[0]='A Lashtail Hatchling',[1]='B37 K0250 FH L024 A:2465 T:2465'},
[26318]={[0]="Finishin' the Job",[1]='B0 FA RN K0030 L002 A:42708 T:42708 P:26284,26285'},
[26319]={[0]='Secrets Revealed',[1]='B39 FA K0150 L012 A:42425 T:42651 P:26297'},
[26320]={[0]='A Vision of the Past',[1]='B39 FA K0150 L012 A:42651 T:234 P:26319'},
[26321]={[0]="I Think She's Hungry",[1]='B37 K0250 FH L024 A:2465 T:2465 P:26317'},
[26322]={[0]='Rise of the Brotherhood',[1]='B39 FA K0150 L012 A:234 T:29611 P:26320'},
[26323]={[0]='Favored Skull',[1]='B37 K0260 FH L024 A:42736 T:2497'},
[26324]={[0]='Where Is My Warfleet?',[1]='B0 K0840 FH L084 A:39605 T:42641 P:26294'},
[26325]={[0]='A Nose for This Sort of Thing',[1]='B37 K0260 FH L024 A:1002076 T:1002076'},
[26326]={[0]='The Very Earth Beneath Our Feet',[1]='B640 K0830 L081 A:43065 T:42730 P:27938'},
[26327]={[0]='Anvilmar the Hero',[1]='B40 FA K0250 L023 A:1071 T:42160 I:26127'},
[26328]={[0]='Rocky Relations',[1]='B640 K0830 L081 A:42731 T:42467 P:26315'},
[26329]={[0]='One More Thing',[1]='B0 FA RN K0030 L002 A:42708 T:42317 P:26318'},
[26330]={[0]="Who's a Big Troll?",[1]='B37 K0260 FH L024 A:1002076 T:1002076 P:26325'},
[26331]={[0]="Crushcog's Minions",[1]='B0 FA RN K0040 L002 A:42223,42317 T:42317 P:26329'},
[26332]={[0]='Skullsplitter Mojo',[1]='B37 K0260 FH L024 A:1002076 T:1002076 P:26330'},
[26333]={[0]='No Tanks!',[1]='B0 K0040 RN L003 A:42224 AA:42491 T:42491'},
[26334]={[0]='Bloodlord Mandokir',[1]='B37 K0260 FH L024 A:42790 T:42790'},
[26335]={[0]='Ready the Navy',[1]='B181 K0840 FH L084 A:42641 T:1204050'},
[26336]={[0]="Shakes O'Breen",[1]='B16 FA K0280 L026 A:2789 T:2610'},
[26337]={[0]='Beating the Market',[1]='B181 K0840 FH L084 A:1204050 T:42641 P:26335'},
[26338]={[0]='Population Con-Troll',[1]='B37 K0270 FH L025 A:2465 T:2465'},
[26339]={[0]='Staging in Brewnall',[1]='B0 FA RN K0050 L002 A:42366 T:42353'},
[26340]={[0]='The Hunt',[1]='B37 K0250 FH L024 A:17094 T:716'},
[26341]={[0]='The Stone Shards',[1]='B16 FA K0290 L027 A:2789 T:1138492'},
[26342]={[0]='Paint it Black',[1]='B0 FA RN K0050 L002 A:42353 T:42353 P:26339'},
[26343]={[0]='Supply and Demand',[1]='B37 K0260 L025 A:2495 T:2495'},
[26344]={[0]='Some Assembly Required',[1]='B37 K0270 L025 A:2495 T:2495 P:26343'},
[26345]={[0]='Excelsior',[1]='B37 K0280 L025 A:2495 T:2495 P:26344'},
[26346]={[0]="Myzrael's Tale",[1]='B16 FA K0270 L025 A:1002702 T:2789 P:26042'}, -- TODO: Determine how to conceptually put in P:26042 because the Rumbling Exile that spawns when it is turned in needs to die, allowing this quest to become available.
[26347]={[0]='Keeper of the Flame',[1]='B39 FA K0140 L012 A:392 T:392'},
[26348]={[0]="The Coast Isn't Clear",[1]='B39 FA K0150 L012 A:392 T:392 O:26371'},
[26349]={[0]='The Coastal Menace',[1]='B39 FA K0150 L012 A:392 T:392'},
[26350]={[0]="Priestess Hu'rala",[1]='B37 K0270 FH L024 A:2497 T:42812'},
[26351]={[0]='Mind Vision',[1]='B37 K0270 FH L024 A:42812 T:42812 P:26350'},
[26352]={[0]="Cozzle's Plan",[1]='B37 K0280 FH L026 A:42813 T:42813'},
[26353]={[0]="Captain Sanders' Hidden Treasure",[1]='B39 K0130 L009 A:100001357 T:1000035'},
[26354]={[0]="Captain Sanders' Hidden Treasure",[1]='B39 K0130 L009 A:1000035 T:1000036 P:26353'},
[26355]={[0]="Captain Sanders' Hidden Treasure",[1]='B39 K0130 L009 A:1000036 T:1000034 P:26354'},
[26356]={[0]="Captain Sanders' Hidden Treasure",[1]='B39 K0130 L009 A:1000034 T:1000033 P:26355'},
[26357]={[0]='Faces of Evil',[1]='B26 K0330 FH L031 A:42624 T:42624'},
[26358]={[0]='Ready the Air Force',[1]='B0 K0840 FH L084 A:42640 T:42643'},
[26359]={[0]='See Raptor',[1]='B37 K0270 FH L024 A:42812 T:42812 P:26351'},
[26360]={[0]='Mind Control',[1]='B37 K0290 FH L024 A:42812 T:42812 P:26359'},
[26361]={[0]="Smoot's Samophlange",[1]='B181 K0840 FH L084 A:42643 T:42643 P:26358'},
[26362]={[0]='Be Raptor',[1]='B37 K0290 FH L024 A:42812 T:42812 P:26360'},
[26363]={[0]='Summit of Fate',[1]='B26 K0330 FH L031 A:42642 T:42642 P:26367'},
[26364]={[0]='Down with Crushcog!',[1]='B0 K0050 RN L002 A:42353 T:42353 P:26342'},
[26365]={[0]="Hero's Call: Redridge Mountains!",[1]='B36 FA K0150 L014 A:821,29611 T:464 I:26503'},
[26366]={[0]='Heads Up',[1]='B26 K0330 FH L031 A:42642 T:42642'},
[26367]={[0]="Ongo'longo's Revenge",[1]='B26 K0330 FH L031 A:42642 T:42642'},
[26368]={[0]='Venomous Secrets',[1]='B26 K0330 FH L031 A:42622 T:42622 P:26524'},
[26369]={[0]='Hunt the Keeper',[1]='B26 K0330 FH L031 A:42642 T:42642 P:26363'},
[26370]={[0]='Return to Sentinel Hill',[1]='B39 FA K0150 L012 A:29611 T:234 P:26322 B39'},
[26371]={[0]='The Legend of Captain Grayson',[1]='B39 FA K0150 L012 A:878 T:392 I:26348'},
[26372]={[0]='Pre-Flight Checklist',[1]='B181 K0840 FH L084 A:42643 T:42640 P:26361'},
[26373]={[0]='On to Kharanos',[1]='B0 FA RN K0050 L002 A:42353 T:40950'},
[26374]={[0]='Ready the Ground Troops',[1]='B181 K0840 FH L084 A:42641 T:42641 P:26324'},
[26375]={[0]='Loose Stones',[1]='B640 K0830 L081 A:42899 T:42899 P:26328'},
[26376]={[0]='Hatred Runs Deep',[1]='B640 K0830 L081 A:42467 T:42467 P:26328'},
[26377]={[0]='Unsolid Ground',[1]='B640 K0830 L081 A:42467 T:42467 P:26328'},
[26378]={[0]="Hero's Call: Westfall!",[1]='B0 K0100 FA L009 A:240,261,294,963,42256 T:42308 I:26209,28562'},
[26380]={[0]='Bound for Kharanos',[1]='B0 FA K0050 L002 A:42933 T:1247'},
[26381]={[0]='The Eye of Shadra',[1]='B26 K0340 FH L032 A:42898 T:42898'},
[26382]={[0]="Can't Make An Omelette Without...",[1]='B26 K0340 FH L032 A:42896 T:42896'},
[26383]={[0]='Breaking Waves of Change',[1]='B0 FA SW K0100 L008 A:42936 T:32973 I:13518,26385,28490'},
[26384]={[0]='Darkcleric Marnal',[1]='B26 K0340 FH L031 A:42622 T:42898'},
[26385]={[0]='Breaking Waves of Change',[1]='B0 FA RW K0100 L008 A:48736 T:32973 P:28517 I:13518,26383,28490'},
[26386]={[0]='Surkhan',[1]='B37 K0290 FH L024 A:42812 T:42811 P:26362'},
[26387]={[0]='Starvation Diet',[1]='B26 K0340 FH L032 A:42896 T:42896 P:26382'},
[26388]={[0]='Twilight Skies',[1]='B181 K0840 FH L084 A:50367 T:42978 P:26372,28849'},
[26389]={[0]='Blackrock Invasion',[1]='B0 FA K0040 L002 A:197 T:197 P:28817,28818,28819,28820,28821,28822,28823,29083'},
[26390]={[0]='Ending the Invasion!',[1]='B0 K0050 L002 A:197 T:197 P:26389'},
[26391]={[0]='Extinguishing Hope',[1]='B0 FA K0040 L002 A:9296 T:9296 P:28817,28818,28819,28820,28821,28822,28823,29083'},
[26393]={[0]='A Swift Message',[1]='B0 K0070 FA RH L005 A:514 T:42983'},
[26394]={[0]='Continue to Stormwind',[1]='B0 K0070 FA L005 A:42983 T:1323 P:26393'},
[26395]={[0]='Dungar Longdrink',[1]='B0 FA K0070 L005 A:1323 T:352 P:26394'},
[26396]={[0]='Return to Argus',[1]='B0 FA K0070 L005 A:352 T:514 P:26395'},
[26397]={[0]='Walk With The Earth Mother',[1]='B0 K0120 FH RT L010 A:36648 T:39605 P:24540'}, -- also marks 26398 complete (which is another version it seems)
[26399]={[0]="The Mosh'Ogg Bounty",[1]='B37 K0280 FH L026 A:42814 T:42814'},
[26400]={[0]='The Universal Key',[1]='B37 K0280 FH L026 A:42814 T:42814 P:26399,26412'},
[26401]={[0]='Return to Vestia',[1]='B121 K0370 FA L035 A:1203134 T:40132 P:25368'},
[26402]={[0]='General Shandris Feathermoon',[1]='B121 K0360 FA L034 A:40032 T:3936 P:25398 I:25304'},
[26403]={[0]='Venture Company Mining',[1]='B37 K0280 FH L026 A:42814 T:42814'},
[26404]={[0]='Above My Pay Grade',[1]='B37 K0300 FH L029 A:42814 T:43095 P:26403 B673'},
[26405]={[0]="Zul'Mamwe Mambo",[1]='B37 K0290 FH L027 A:42811 T:42811'},
[26406]={[0]='The Fang of Shadra',[1]='B26 K0340 FH L032 A:42898 T:42898 P:26381'},
[26407]={[0]="Mosh'Ogg Handiwork",[1]='B37 K0250 FH L024 A:100058491 T:2465'},
[26408]={[0]='Ashes in Ashenvale',[1]='B43 K0200 FA L017 A:34402 T:33187 P:13897 I:28492 B43'},
[26409]={[0]="Where's Goldmine?",[1]='B640 K0820 L081 A:42573 T:42574'},
[26410]={[0]='Explosive Bonding Compound',[1]='B640 K0820 L081 A:42574 T:42574 P:26409'},
[26411]={[0]='Apply and Flash Dry',[1]='B640 K0820 L081 A:42574 T:42574 P:26410,27135'},
[26412]={[0]="The Mosh'Ogg Bounty",[1]='B0 K0280 FH L026 A:42814 T:42814'}, -- just a copy of 26399 because no idea what is live
[26413]={[0]='Take Him to the Earthcaller',[1]='B640 K0820 L081 A:42574 T:42573 P:26411'},
[26414]={[0]='Hitting a Walleye',[1]='B0 +D FA K0000 L010 A:5494 T:5494 I:29321,29323,29324,29325,29342,29343,29344,29347,29350,29359,26420,26442,26488,26536 PF001'},
[26416]={[0]='Well, Come to the Jungle',[1]='B37 K0250 FH L024 A:43063 T:43062'},
[26417]={[0]='Northern Stranglethorn: The Fallen Empire',[1]='B37 K0250 FH L024 A:43062 T:2464 P:26416 I:26278,28688'},
[26418]={[0]='The Shell of Shadra',[1]='B26 K0350 FH L032 A:42898 T:42898 P:26406'},
[26419]={[0]='Shadra the Venom Queen',[1]='B26 K0350 FH L032 A:43299 T:42898 P:26558'},
[26420]={[0]="Diggin' For Worms",[1]='B0 +D FA K0000 L010 A:5494 T:5494 I:29321,29323,29324,29325,29342,29343,29344,29347,29350,29359,26414,26442,26488,26536 PF001'},
[26421]={[0]='Meet the High Tinker',[1]='B0 FA RN CM K0020 L002 A:42331 T:42317 P:26197'},
[26422]={[0]='Meet the High Tinker',[1]='B0 FA RN CT K0020 L002 A:42323 T:42317 P:26199'},
[26423]={[0]='Meet the High Tinker',[1]='B0 FA RN CR K0020 L002 A:42366 T:42317 P:26206'},
[26424]={[0]='Meet the High Tinker',[1]='B0 FA RN CL K0020 L002 A:460 T:42317 P:26202'},
[26425]={[0]='Meet the High Tinker',[1]='B0 FA RN CW K0020 L002 A:42324 T:42317 P:26203'},
[26426]={[0]='Violent Gale',[1]='B640 K0830 L081 A:42467 T:0 P:26375+26376+26377'},
[26427]={[0]='Without a Captain or Crew',[1]='B640 K0820 L081 A:43082 T:43082 P:26249'},
[26428]={[0]='To Steal From Thieves',[1]='B16 K0270 FH L025 A:4486 T:4486'},
[26429]={[0]='Crush the Witherbark',[1]='B16 K0300 FH L028 A:2771 T:2771'},
[26430]={[0]='Revantusk Village',[1]='B26 K0310 FH L029 A:2771 T:42613 B26'},
[26432]={[0]="The Fall of Jintha'Alor",[1]='B26 K0330 FH L031 A:42613 T:42642 P:26267,26268,26491,26492'},
[26433]={[0]='The Holy Water of Clarity',[1]='B673 K0300 FH L026 A:43096 T:43096'},
[26434]={[0]='Primal Reagents of Power',[1]='B673 K0300 FH L026 A:43096 T:43096'},
[26435]={[0]="I'm A Huge Liar and a Fraud",[1]='B673 K0320 FH L026 A:43096 T:43849 P:26434,26592'},
[26436]={[0]='Entrenched',[1]='B640 FA K0830 L081 A:42467 T:42469 P:26871'},
[26437]={[0]='Making Things Crystal Clear',[1]='B640 FA K0830 L081 A:42469 T:42469 P:26436'},
[26438]={[0]='Intervention',[1]='B640 FA K0830 L081 A:42469 T:42469 P:26436'},
[26439]={[0]='Putting the Pieces Together',[1]='B640 K0830 L081 A:43344 T:43344 P:26436'},
[26440]={[0]='Clingy',[1]='B640 K0830 L081 A:43116 T:43116 O:28869'},
[26441]={[0]='So Big, So Round...',[1]='B640 K0830 FA L081 A:43116 T:42469 P:26440'},
[26442]={[0]='Rock Lobster',[1]='B0 +D FA K0000 L010 A:5494 T:5494 I:29321,29323,29324,29325,29342,29343,29344,29347,29350,29359,26414,26420,26488,26536 PF001'},
[26443]={[0]='Diabolical Plans',[1]='B43 K0210 FA L019 A:100023777 T:17303'},
[26444]={[0]='Destroy the Legion',[1]='B43 K0210 FA L019 A:17303 T:17303'},
[26445]={[0]='Never Again!',[1]='B43 K0220 FA L019 A:17303 T:17303 P:26443'},
[26446]={[0]='Reclaiming Felfire Hill',[1]='B43 K0210 FA L019 A:17310 T:17310'},
[26447]={[0]='Diabolical Plans',[1]='B43 K0210 FH L019 A:100023797 T:17355'},
[26448]={[0]='Destroy the Legion',[1]='B43 K0210 FH L019 A:17355 T:17355'},
[26449]={[0]='Never Again!',[1]='B43 K0220 FH L019 A:17355 T:17355 P:26447'},
[26450]={[0]="If They're Just Going to Leave Them Lying Around...",[1]='B673 K0300 FH L029 A:43095 T:43095'},
[26451]={[0]='Gurubashi Challenge: Free-For-All Arena Combat',[1]='B673 L030 A:43099 T:43099'},
[26452]={[0]='Gurubashi Challenge',[1]='B673 +D K001256 L030 A:43099 T:43099 P:26451'},
[26453]={[0]='A Helping Hand',[1]='B43 K0210 FA L019 A:17106 T:17291 I:26454'},
[26454]={[0]='A Shameful Waste',[1]='B43 K0210 FA L019 A:17291 T:17310 O:26453'},
[26455]={[0]='The Lost Chalice',[1]='B43 K0210 FA L019 A:3848 T:3848'},
[26456]={[0]='Report from the Northern Front',[1]='B43 K0250 FA L021 A:3880 T:14733 P:13935'},
[26457]={[0]='Agents of Destruction',[1]='B43 K0210 FA L019 A:17287 T:17287'},
[26462]={[0]='The Wicked Revantusk',[1]='B26 FA K0320 L029 A:43108 T:43108'},
[26463]={[0]='Finding Teronis',[1]='B43 K0210 FA L019 A:3847 T:3891 P:13623'},
[26464]={[0]='The Lost Gem',[1]='B43 K0210 FA L019 A:3891 T:3847 P:26463'},
[26465]={[0]='The Ancient Statuettes',[1]='B43 K0210 FA L019 A:3846 T:3846 O:13617'},
[26466]={[0]='Ruuzel',[1]='B43 K0220 FA L019 A:3846 T:3846 P:26465'},
[26467]={[0]='Vile Satyr! Dryads in Danger!',[1]='B43 K0210 FA L019 A:3901 T:3920'},
[26468]={[0]='The Branch of Cenarius',[1]='B43 K0220 FA L019 A:3920 T:3901 P:26467'},
[26469]={[0]='Satyr Slaying!',[1]='B43 K0210 FA L019 A:3901 T:3901 P:26468'},
[26470]={[0]='Retaking Mystral Lake',[1]='B43 K0260 FA L023 A:3885 T:3885 O:13964'},
[26472]={[0]='Insane Druids',[1]='B43 K0220 FA L019 A:33777 T:33777 P:13792'},
[26473]={[0]="Bathran's Hair",[1]='B43 K0210 FA L019 A:33204 T:33204'},
[26474]={[0]="Orendil's Cure",[1]='B43 K0230 FA L019 A:3847 T:3894 P:13642'},
[26475]={[0]="Elune's Tear",[1]='B43 K0230 FA L019 A:3894 T:3894 P:26474'}, -- after about 10 seconds
[26476]={[0]='Dryad Delivery',[1]='B43 K0230 FA L021 A:3691 T:3916 P:26475'},
[26477]={[0]='Search the Bole',[1]='B43 K0230 FA L021 A:3916 T:3916 P:26476'},
[26478]={[0]='Playing Possum',[1]='B43 K0230 FA L021 A:3916 T:3916 P:26477'},
[26479]={[0]='Return to Raene',[1]='B43 K0230 FA L019 A:3916 T:3691 P:26478'},
[26480]={[0]="Dartol's Rod",[1]='B43 K0250 FA L019 A:3691 T:3897 P:26479'},
[26481]={[0]='A New Adornment',[1]='B43 K0260 L019 A:3897 T:3897 P:13989'},
[26482]={[0]='True Power of the Rod',[1]='B43 K0250 FA L019 A:3897 T:3691 P:26481'},
[26483]={[0]="Gan'dranda",[1]='B26 FA K0320 L029 A:43108 T:43108'},
[26484]={[0]="To Stonehearth's Aid",[1]='B640 K0820 L081 A:42573 T:43071 P:26413'},
[26485]={[0]='Snapjaws, Lad!',[1]='B26 FA K0310 L029 A:43109 T:43109'},
[26486]={[0]='99 Bottles of Booze on the Beach',[1]='B26 FA K0310 L029 A:43109 T:43109'},
[26487]={[0]='Akiris by the Bundle',[1]='B673 K0300 FH L029 A:43095 T:43095'},
[26488]={[0]='Big Gulp',[1]='B0 +D FA K0000 L010 A:5494 T:5494 I:29321,29323,29324,29325,29342,29343,29344,29347,29350,29359,26414,26420,26442,26536 PF001'},
[26489]={[0]="It's You!!",[1]='B673 K0300 FH RG L029 A:43095 T:43095'},
[26490]={[0]='Prime Slime',[1]='B26 FA K0320 L029 A:43109 T:43109 P:26462+26483'},
[26491]={[0]='Skulk Rock Clean-Up',[1]='B26 FA K0320 L029 A:43108 T:43108 P:26462+26483'},
[26492]={[0]='Skulk Rock Supplies',[1]='B26 FA K0320 L029 A:43108 T:43108 P:26462+26483'},
[26493]={[0]="There's Somebody Out There Who Wants It",[1]='B673 K0300 FH L029 A:43095 T:43095'},
[26494]={[0]='Mixmaster Jasper',[1]='B673 K0310 FH L029 A:43095 T:43097'},
[26495]={[0]='Chabal',[1]='B673 K0310 FH L029 A:43095 T:43098'},
[26496]={[0]='Down with the Vilebranch',[1]='B26 FA K0330 L029 A:43108 T:43157 P:26491+26492 I:26496'},
[26497]={[0]='Vilebranch Scum',[1]='B26 FA K0330 L030 A:43157 T:43157 O:26496'},
[26498]={[0]='Death to the Vilebranch',[1]='B26 FA K0330 L030 A:43157 T:43157 P:26497'},
[26499]={[0]="Stonefather's Boon",[1]='B640 K0820 L081 A:43071 T:43071 P:27935,27936'},
[26500]={[0]="We're Surrounded",[1]='B640 K0820 L081 A:43160 T:43160 P:27935,27936'},
[26501]={[0]='Sealing the Way',[1]='B640 K0820 L081 A:43071 T:43168 P:26499'},
[26502]={[0]='Thunder Stones',[1]='B640 K0820 L081 A:43160 T:43169 P:26500'},
[26503]={[0]='Still Assessing the Threat',[1]='B36 K0150 FA L014 A:464 T:464 O:26365,28563'},
[26504]={[0]='Wanted: Redridge Gnolls',[1]='B36 K0150 FA L014 A:1204344 T:464'},
[26505]={[0]="Parker's Report",[1]='B36 K0160 FA L014 A:464 T:344 P:26503'},
[26506]={[0]='Franks and Beans',[1]='B36 K0160 FA L014 A:379 T:379'},
[26507]={[0]='Petrified Delicacies',[1]='B640 FA K0830 L081 A:42469 T:43116 P:26441'},
[26508]={[0]="Nida's Necklace",[1]='B36 K0160 FA L014 A:8965 T:8962'},
[26509]={[0]='An Unwelcome Guest',[1]='B36 K0160 FA L014 A:342 T:342'},
[26510]={[0]='We Must Prepare!',[1]='B36 K0160 FA L014 A:344 T:344'},
[26511]={[0]='Lake Everstill Clean Up',[1]='B36 K0160 FA L014 A:900 T:900'},
[26512]={[0]='Tuning the Gnomecorder',[1]='B36 K0160 FA L014 A:344 T:-100036,344 P:26510'},
[26513]={[0]='Like a Fart in the Wind',[1]='B36 K0160 FA L014 A:382 T:382 P:26510'}, -- or P:26511 or P:26510+26511 ... not sure currently
[26514]={[0]='Canyon Romp',[1]='B36 K0160 FA L014 A:-36,344 T:-36,344 P:26512'},
[26515]={[0]="Ongo'longo's Revenge",[1]='B26 FA K0330 L030 A:43157 T:43157 P:26518'},
[26516]={[0]="It's Ours Now",[1]='B26 FA K0330 L030 A:43157 T:43157 P:26498'},
[26517]={[0]='Summit of Fate',[1]='B26 FA K0330 L030 A:43156 T:43156 P:26515+26524'},
[26518]={[0]='Heads Up',[1]='B26 FA K0330 L030 A:43157 T:43157'},
[26519]={[0]='He Who Controls the Ettins',[1]='B36 K0160 FA L014 A:100058898 T:1204351 P:26512'}, -- There is a P: because hunting tons beforehand dropped none, while afterwards item drops tons of times.  Assumption is this P:, but it could be another.
[26520]={[0]='Saving Foreman Oslow',[1]='B36 K0160 FA L014 A:1204351 T:344 P:26519'},
[26521]={[0]='Faces of Evil',[1]='B26 FA K0330 L030 A:43156 T:43156'},
[26523]={[0]='All That Skitters',[1]='B26 FA K0330 L030 A:43156 T:43156 P:26521'},
[26524]={[0]='Dark Vessels',[1]='B26 FA K0330 L030 A:43156 T:43156 P:26521'},
[26525]={[0]='Venomous Secrets',[1]='B26 FA K0330 L030 A:43156 T:43156 P:26517'},
[26526]={[0]='Hunt the Keeper',[1]='B26 FA K0330 L030 A:43156 T:43156 P:26517'},
[26528]={[0]='The Eye of Shadra',[1]='B26 FA K0340 L032 A:43200 T:43200 P:27625+27626'},
[26529]={[0]='The Fang of Shadra',[1]='B26 FA K0340 L032 A:43200 T:43200 P:26528'},
[26530]={[0]='The Shell of Shadra',[1]='B26 FA K0350 L032 A:43200 T:43200 P:26529'},
[26531]={[0]='Summoning Shadra',[1]='B26 FA K0350 L032 A:43200 T:43298 P:26530'},
[26532]={[0]='Shadra the Venom Queen',[1]='B26 FA K0350 L032 A:43298 T:5636 P:26531'},
[26533]={[0]="Zanzil's Secret",[1]='B673 K0310 FH L029 A:43097 T:43097 P:26494'},
[26534]={[0]="Let's See What You've Got, Zanzil",[1]='B673 K0310 FH L029 A:43097 T:43097 P:26533'},
[26535]={[0]='Recipe for Disaster',[1]='B673 K0320 FH L029 A:43097 T:43097 P:26534'},
[26536]={[0]='Thunder Falls',[1]='B0 +D FA K0000 L010 A:5494 T:5494 I:29321,29323,29324,29325,29342,29343,29344,29347,29350,29359,26414,26420,26442,26488 PF001'},
[26537]={[0]='Shatter Them!',[1]='B640 K0820 L081 A:43168 T:43168 P:26501'},
[26538]={[0]='Emergency Aid',[1]='B700 FH K0840 L084 A:43193 T:43191'},
[26539]={[0]='Stalled Negotiations',[1]='B700 FH K0840 L084 A:42978 T:43187 P:26388'},
[26540]={[0]='Dangerous Compassion',[1]='B700 FH K0840 L084 A:43191 T:43193 P:26538'},
[26542]={[0]="Hero's Call: The Hinterlands!",[1]='B26 K0300 FA L029 M033 A:2700,1207320 T:5636'},
[26543]={[0]='Clammy Hands',[1]='B0 +D FH K0000 L010 A:43239 T:43239 I:26556,26557,26565,26572,26588,29317,29319,29320,29322,29345,29346,29348,29349,29354,29361 PF001'},
[26544]={[0]="They've Wised Up...",[1]='B36 K0160 FA L014 A:-36,344 T:-36,344 P:26514'},
[26545]={[0]='Yowler Must Die!',[1]='B36 K0160 L014 A:-36,344 T:344 P:26544'},
[26546]={[0]='Razorbeak Friends',[1]='B26 FA K0310 L029 A:5636 T:5636'},
[26547]={[0]='A Mangy Threat',[1]='B26 FA K0310 L029 A:5636 T:5636'},
[26548]={[0]='Out to the Front',[1]='B26 FA K0310 L029 A:5636 T:43108 P:26546+26547'},
[26549]={[0]='Madness',[1]='B700 FH K0840 L084 A:43187 T:43190 P:26539'},
[26550]={[0]='Backdoor Dealings',[1]='B673 K0310 FH L029 A:43098 T:43098 P:26495'},
[26551]={[0]='Eliminate the Outcast',[1]='B0 K0320 FH L029 A:43098 T:0 P:26550'},
[26552]={[0]='Through the Troll Hole',[1]='B0 K0320 L029 FH A:-673 T:0 P:26551'},
[26553]={[0]='High Priestess Jeklik',[1]='B0 K0320 L029 A:-100037 T:0 P:26552'},
[26554]={[0]="Plunging Into Zul'Gurub",[1]='B0 K0320 L029 A:-37 T:-37 P:26553'},
[26555]={[0]='High Priest Venoxis',[1]='B673 K0320 FH L029 A:-37 T:43098 P:26554 B673'},
[26556]={[0]='No Dumping Allowed',[1]='B0 +D FH K0000 L010 A:43239 T:43239 PF001 I:26543,26557,26565,26572,26588,29317,29319,29320,29322,29345,29346,29348,29349,29354,29361'},
[26557]={[0]='A Staggering Effort',[1]='B0 +D FH K0000 L010 A:43239 T:43239 PF001 I:26543,26556,26565,26572,26588,29317,29319,29320,29322,29345,29346,29348,29349,29354,29361'},
[26558]={[0]='Summoning Shadra',[1]='B26 K0350 FH L032 A:42898 T:43299 P:26418'},
[26560]={[0]='Jorgensen',[1]='B36 K0170 FA L015 A:43300 T:43272 P:26587'},
[26561]={[0]='Krakauer',[1]='B36 K0170 FA L015 A:43305 T:43274 P:26560'},
[26562]={[0]='And Last But Not Least... Danforth',[1]='B36 K0170 FA L015 A:43303 T:43275 P:26561'},
[26563]={[0]='Return of the Bravo Company',[1]='B36 K0170 FA L015 A:43302 T:43221 P:26562'},
[26564]={[0]='Fixer Upper',[1]='B640 K0820 L081 A:43169 T:43169 P:26502'},
[26565]={[0]='A Furious Catch (REMOVED)',[1]='B0 FH +D K0000 L010 PF001 I:26543,26556,26557,26572,26588,29317,29319,29320,29322,29345,29346,29348,29349,29354,29361'},
[26566]={[0]='A Triumph of Gnomish Ingenuity',[1]='B0 FA RN K0020 L002 A:42317 T:42553 P:26208'},
[26567]={[0]='John J. Keeshan',[1]='B36 K0170 FA L015 A:43221 T:43184 P:26545'},
[26568]={[0]="This Ain't My War",[1]='B0 K0170 FA L015 A:43184 T:43221 P:26567'},
[26569]={[0]='Surveying Equipment',[1]='B36 K0170 FA L015 A:43194 T:43194 P:1'},
[26570]={[0]="Render's Army",[1]='B36 K0170 FA L015 A:382 T:382 P:26568'},
[26571]={[0]='Weapons of War',[1]='B36 K0170 FA L015 A:43221 T:-36,43221 P:26568'},
[26572]={[0]='A Golden Opportunity',[1]='B0 +D FH K0000 L010 A:43239 T:43239 I:26543,26556,26557,26565,26588,29317,29319,29320,29322,29345,29346,29348,29349,29354,29361 PF001'},
[26573]={[0]='His Heart Must Be In It',[1]='B36 K0170 FA L015 A:-36,43221 T:43221 P:26571'},
[26574]={[0]="Adella's Covert Camp",[1]='B121 K0380 FA L036 A:39653 T:39725'},
[26575]={[0]='Rock Bottom',[1]='B640 FA K0830 L081 A:42469 T:42469 P:26441'},
[26576]={[0]='Steady Hand',[1]='B640 FA K0830 L081 A:42469 T:42466 P:26575'},
[26577]={[0]='Rocky Upheaval',[1]='B640 FA K0830 L081 A:42469 T:42472 P:26575'},
[26578]={[0]='Doomshrooms',[1]='B640 K0830 L081 A:42472 T:42472 P:26577'},
[26579]={[0]='Gone Soft',[1]='B640 K0830 L081 A:42472 T:42472 P:26577'},
[26580]={[0]='Familiar Intruders',[1]='B640 K0830 L081 A:42472 T:43395 P:26577'},
[26581]={[0]='A Head Full of Wind',[1]='B640 K0830 L081 A:43395 T:43395 P:26580'},
[26582]={[0]='Unnatural Causes',[1]='B640 K0830 L081 A:43395 T:42472 P:26581'},
[26583]={[0]='Wrath of the Fungalmancer',[1]='B640 K0830 L081 A:43442 T:43442'},
[26584]={[0]='Shaken and Stirred',[1]='B640 K0830 L081 A:42472 T:42472 P:26578+26582'},
[26585]={[0]='Corruption Destruction',[1]='B640 K0830 L081 A:42472 T:42472 P:26578+26582'},
[26586]={[0]='In Search of Bravo Company',[1]='B36 K0170 FA L015 A:43221 T:43270 P:26568'},
[26587]={[0]='Breaking Out is Hard to Do',[1]='B36 K0170 FA L015 A:43270 T:43270 P:26586'},
[26588]={[0]='A Furious Catch',[1]='B0 +D FH K0000 L010 A:43239 T:43239 I:26543,26556,26557,26565,26572,29317,29319,29320,29322,29345,29346,29348,29349,29354,29361 PF001'},
[26589]={[0]='The Wilds of Feralas',[1]='B0 K0350 FH L031 A:36487 T:39377 B121'},
[26590]={[0]='The Holy Water of Clarity',[1]='B673 K0300 FH L026 A:43096 T:43096'},
[26591]={[0]='Battlefront Triage',[1]='B640 K0820 L081 A:43319 T:43319 P:26502'},
[26592]={[0]='Diffractory Chromascope',[1]='B673 K0300 FH L026 A:43096 T:43096 P:26434'},
[26593]={[0]='Scaring Shaky',[1]='B673 K0320 L030 A:2501 T:2502'},
[26594]={[0]='Return to MacKinley',[1]='B673 K0320 L030 A:2502 T:2501 P:26593'},
[26595]={[0]='Kill-Collect',[1]='B673 K0320 L030 A:2501 T:2501 P:26594'},
[26596]={[0]='The Call of Kalimdor',[1]='B141 FA K0350 L034 A:48808 T:3391 B11'},
[26597]={[0]='Stranglethorn Fever',[1]='B673 K0330 L031 A:2486 T:2486'},
[26598]={[0]='The Heart of Mokk',[1]='B673 ++ K0330 L031 A:1449 T:1449 PL:26597'},
[26599]={[0]="The Captain's Chest",[1]='B673 K0330 L031 A:2500 T:2500'},
[26600]={[0]="A Giant's Feast",[1]='B673 K0330 L031 A:2500 T:2500 P:26599'},
[26601]={[0]="Mok'rash the Cleaver",[1]='B673 K0330 L031 A:2500 T:2500 P:26602'},
[26602]={[0]='A Dish Best Served Huge',[1]='B673 K0330 L031 A:2500 T:2500 P:26600'},
[26603]={[0]='Message in a Bottle',[1]='B673 K0320 L030 A:1204406 T:2634'},
[26604]={[0]='Protecting Her Royal Highness Poobah',[1]='B673 K0320 L030 A:2634 T:2634 P:26603'},
[26605]={[0]='Grubby Little Paws',[1]='B673 K0320 L030 A:2634 T:2634 P:26604'},
[26606]={[0]="Mukla's Demise",[1]='B673 K0330 L030 A:2634 T:2634 P:26605'},
[26607]={[0]='They Drew First Blood',[1]='B36 K0180 FA L016 A:43221 T:43184 P:26563+26573'},
[26608]={[0]='Negotiations Terminated',[1]='B700 FH K0840 L084 A:43190 T:42978 P:26549'},
[26609]={[0]='The Bloodsail Buccaneers',[1]='B673 K0320 L031 A:2490 T:1002083 P:26595,26601,26606'},
[26610]={[0]='Bloodsail Treachery',[1]='B673 K0320 L031 A:1002083 T:2490 P:26609'},
[26611]={[0]='The Baron Must Be Told',[1]='B673 K0320 L031 A:2490 T:2496 P:26610'},
[26612]={[0]='Details of the Attack',[1]='B673 K0330 L031 A:2496 T:2496 P:26611'},
[26613]={[0]='Up to Snuff',[1]='B673 K0330 L031 A:2488 T:2488 P:26611'},
[26614]={[0]='Keep An Eye Out',[1]='B673 K0330 L031 A:2493 T:2493 P:26611'},
[26616]={[0]="It's Never Over",[1]='B36 K0180 FA L016 A:43184 T:43458 P:26607'},
[26617]={[0]='An Old Sea Dog',[1]='B673 K0320 L030 A:100059143 T:2487'},
[26618]={[0]='Wolves at Our Heels',[1]='B34 FA K0210 L019 A:264 T:264 O:26728,28564'},
[26619]={[0]='You Say You Want a Revolution',[1]='B700 FH K0840 L084 A:43193 T:43581'},
[26620]={[0]='Seasoned Wolf Kabobs',[1]='B34 FA K0210 L018 A:272 T:272'},
[26621]={[0]='Insurrection',[1]='B700 FH K0840 L084 A:43581 T:43581 P:26619'},
[26622]={[0]="Death to Mor'ghor",[1]='B700 FH K0840 L084 A:43581 T:43943 P:26621'},
[26623]={[0]='Dusky Crab Cakes',[1]='B34 FA K0210 L018 A:272 T:272'},
[26624]={[0]='Getting In With the Bloodsail',[1]='B673 K0330 L031 A:2496 T:43504 P:26612'},
[26625]={[0]='Troggzor the Earthinator',[1]='B640 K0830 L081 A:43168 T:43168 P:26537'},
[26627]={[0]='The Hermit',[1]='B34 FA K0210 L019 A:264 T:289 P:26618 I:26653'},
[26628]={[0]='Death From Below',[1]='B16 K0280 L026 A:2610 T:2610 P:26052'},
[26629]={[0]='Seeing Where Your Loyalties Lie',[1]='B0 K0330 L031 A:43504 T:43504 P:26624'},
[26630]={[0]='Looks Like a Tauren Pirate to Me',[1]='B673 K0330 L031 A:2487 T:2487 PL:26629'},
[26631]={[0]='Your First Day as a Pirate',[1]='B673 K0330 L031 A:43504 T:2548 P:26629'},
[26632]={[0]='Close Escort',[1]='B640 K0830 L081 A:45043 T:43897 P:27126'},
[26633]={[0]='Swabbing Duty',[1]='B673 K0330 L031 A:2548 T:2548 P:26631'},
[26634]={[0]='The Bane of Many A Pirate',[1]='B673 K0330 L031 A:2549 T:2549 P:26631'},
[26635]={[0]='Cannonball Swim',[1]='B673 K0330 L031 A:2545 T:2545 P:26631'},
[26636]={[0]='Bravo Company Field Kit: Camouflage',[1]='B36 K0180 FA L016 A:43461 T:43461 P:26616'},
[26637]={[0]='Bravo Company Field Kit: Chloroform',[1]='B36 K0180 FA L016 A:43459 T:43459 P:26616'},
[26638]={[0]='Hunting the Hunters',[1]='B36 K0180 FA L016 A:43462 T:43462 P:26616'},
[26639]={[0]='Point of Contact: Brubaker',[1]='B36 K0180 FA L016 A:43458 T:43508 P:26616'},
[26640]={[0]='Unspeakable Atrocities',[1]='B36 K0180 FA L016 A:43508 T:43458 P:26639'},
[26641]={[0]="Can't Make An Omelette Without...",[1]='B26 FA K0340 L032 A:43200 T:43200  P:27625+27626'},
[26642]={[0]='Preserving the Barrens',[1]='B0 K0120 FH L009 A:35068 T:3337 I:840,28494'},
[26643]={[0]='Starvation Diet',[1]='B26 FA K0340 L032 A:43200 T:43200 P:26641'},
[26644]={[0]='Attracting Attention',[1]='B673 K0340 L031 A:2548 T:2546 P:26633+26634+26635'},
[26645]={[0]='The Night Watch',[1]='B34 FA K0210 L019 A:264 T:264 P:26618'},
[26646]={[0]='Prisoners of War',[1]='B36 K0180 FA L016 A:43458 T:-36,43458 P:26636+26637+26638+26640'},
[26647]={[0]="Ol' Blasty",[1]='B673 K0340 L031 A:2547 T:2547 P:26644'},
[26648]={[0]='Our Mortal Enemies',[1]='B673 K0340 L031 A:43556 T:-673 P:26644'},
[26649]={[0]='Drive-By Piracy',[1]='B673 K0340 L031 A:2547 T:2547 P:26647'},
[26650]={[0]="The Damsel's Luck",[1]='B673 K0350 L031 A:2546 T:1204450 P:26648'},
[26651]={[0]='To Win a War, You Gotta Become War',[1]='B36 K0180 L016 A:-36,43458 T:43611 P:26646'},
[26652]={[0]='Ghost Hair Thread',[1]='B34 FA K0210 L019 A:265 T:302 P:26653'},
[26653]={[0]='Supplies from Darkshire',[1]='B34 FA K0210 L019 A:289 T:265 O:26627'},
[26654]={[0]='Return the Comb',[1]='B34 FA K0210 L019 A:302 T:265 P:26652'},
[26655]={[0]='Deliver the Thread',[1]='B34 FA K0210 L019 A:265 T:289 P:26654'},
[26656]={[0]="Don't. Stop. Moving.",[1]='B640 K0830 L081 A:42466 T:42466 P:26576'},
[26657]={[0]='Hard Falls',[1]='B640 K0830 L081 A:42466 T:42466 P:26656'},
[26658]={[0]='Fragile Values',[1]='B640 K0830 L081 A:42466 T:42466 P:26656'},
[26659]={[0]='Resonating Blow',[1]='B640 K0830 L081 A:42466 T:542466 P:26657+26658'},
[26660]={[0]='Zombie Juice',[1]='B34 FA K0210 L019 A:289 T:273 P:26655'},
[26661]={[0]='Gather Rot Blossoms',[1]='B34 FA K0220 L019 A:273 T:273 P:26660'},
[26662]={[0]='The Brashtide Crew',[1]='B673 K0350 L031 A:1204450 T:-673,1204450 P:26650'},
[26663]={[0]='Sinking From Within',[1]='B673 K0350 L031 A:1204450 T:-673,1204450 P:26650'},
[26664]={[0]='Making Mutiny',[1]='B673 K0350 L031 A:1204450 T:-673,1204450 P:26650'},
[26665]={[0]='Call of Booty',[1]='B673 K0350 L031 A:-673,1204450 T:2496 P:26662+26663+26664'},
[26666]={[0]='The Legend of Stalvan',[1]='B34 FA K0230 L021 A:43453 T:267'},
[26667]={[0]='The Stolen Letters',[1]='B34 FA K0230 L021 A:267 T:267 P:26666'},
[26668]={[0]='Detonation',[1]='B36 K0180 FA L016 A:43611 T:43611 P:26651'},
[26669]={[0]='In A Dark Corner',[1]='B34 FA K0230 L021 A:267 T:267 P:26667'},
[26670]={[0]="Roland's Doom",[1]='B34 FA K0230 L021 A:267 T:267 P:26669'},
[26671]={[0]='The Fate of Stalvan Mistmantle',[1]='B34 FA K0230 L021 A:267 T:43453 P:26670'},
[26672]={[0]='Clawing at the Truth',[1]='B34 FA K0230 L021 A:43453 T:265 P:26671'},
[26673]={[0]='REUSE - BREADCRUMB',[1]='B0 '}, -- this has a tooltip that shows that it does the same as 26672, but what triggers its completion?
[26674]={[0]="Mistmantle's Revenge",[1]='B34 FA K0230 L021 A:265 T:43453 P:26672'},
[26676]={[0]='Juice Delivery',[1]='B34 FA K0220 L019 A:273 T:289 P:26661'},
[26677]={[0]='Ghoulish Effigy',[1]='B34 FA K0220 L019 A:289 T:289 P:26680'},
[26678]={[0]='Doublerum',[1]='B673 K0350 L031 A:2496 T:1204578 P:26665'},
[26679]={[0]='Return to Revilgaz',[1]='B673 K0350 L031 A:1204578 T:2496 P:26678'},
[26680]={[0]='Ogre Thieves',[1]='B34 FA K0220 L019 A:289 T:289 P:26676'},
[26681]={[0]='Note to the Mayor',[1]='B34 FA K0220 L019 A:289 T:263 P:26677'},
[26682]={[0]='A Shambling Threat',[1]='B141 K0360 FH L034 A:4926 T:4926 P:26701'},
[26683]={[0]='Look To The Stars',[1]='B34 FA K0210 L019 A:276 T:302 P:26618'},
[26684]={[0]='The Insane Ghoul',[1]='B34 FA K0210 L019 A:302 T:276 P:26683'},
[26685]={[0]='Classy Glass',[1]='B34 FA K0220 L019 A:276 T:276 P:26684'},
[26686]={[0]='Bones That Walk',[1]='B34 FA K0210 L018 A:264 T:264 P:26645'},
[26687]={[0]='Reinforcements From Theramore',[1]='B141 K0350 FA L032 A:39118 T:4944 P:25182 B141'},
[26688]={[0]='Worgen in the Woods',[1]='B34 FA K0230 L021 A:663 T:663'},
[26689]={[0]='The Rotting Orchard',[1]='B34 FA K0230 L021 A:663 T:663 P:26688'},
[26690]={[0]='Vile and Tainted',[1]='B34 FA K0230 L021 A:663 T:663 P:26689'},
[26691]={[0]='Worgen in the Woods',[1]='B34 FA K0240 L021 A:663 T:661 P:26690'},
[26692]={[0]='Shadowhide Extinction',[1]='B36 K0190 FA L017 A:43607 T:-36,43607 P:26668'},
[26693]={[0]='The Dark Tower',[1]='B36 K0190 FA L017 A:43611 T:-36,43611 P:26668'},
[26694]={[0]='The Grand Magus Doane',[1]='B36 K0190 L017 A:-36,43611 T:43611 P:26693'},
[26695]={[0]='Prepare for Takeoff',[1]='B673 K0350 L031 A:2496 T:2496 P:26679'},
[26696]={[0]='The Call of Kalimdor',[1]='B141 K0350 FH L034 A:48797 T:3391'},
[26697]={[0]='The Final Voyage of the Brashtide',[1]='B673 K0350 L031 A:2496 T:2496 P:26695'},
[26698]={[0]='Seeking Seahorn',[1]='B673 K0350 L031 A:2496 T:502487 P:26679'},
[26699]={[0]='Turning the Brashtide',[1]='B673 K0350 L031 A:502487 T:2496 P:26698'},
[26700]={[0]="The Damsel's (Bad) Luck",[1]='B673 K0350 L031 A:502487 T:2496 P:26698'},
[26701]={[0]='Flight to Brackenwall',[1]='B141 K0350 FH L034 A:3391 T:4926 P:26696'},
[26702]={[0]='Flight to Theramore',[1]='B141 FA K0350 L034 A:3391 T:23566 P:26596 I:27210,28552'},
[26703]={[0]="Bloodsail's End",[1]='B673 K0350 L031 A:2496 T:2496 P:26697+26699+26700'},
[26706]={[0]='Endgame',[1]='B0 K0120 FA RW L012 A:43727 T:43727 P:24681'},
[26707]={[0]='A Deadly Vine',[1]='B34 FA K0240 L022 A:43738 T:43738'},
[26708]={[0]='AHHHHHHHHHHHH! AHHHHHHHHH!!!',[1]='B36 K0200 FA L017 A:43733 T:543733 P:26694'},
[26709]={[0]='The Stone Throne',[1]='B640 K0830 L081 A:43792 T:42465 P:26971'},
[26710]={[0]='Lost In The Deeps',[1]='B0 +D K0830 L081 A:44945 T:44945 P:26709 I:27048,28488'},
[26711]={[0]='Off to the Bank',[1]='B0 K0030 FH RG GF A:35054 T:35120,535120 P:14071'},
[26712]={[0]='Off to the Bank',[1]='B0 K0030 FH RG GM A:35053 T:35120,535120 P:14071'},
[26713]={[0]='Showdown at Stonewatch',[1]='B36 K0200 FA L017 A:543733 T:-36,543733 P:26708'},
[26714]={[0]='Darkblaze, Brood of the Worldbreaker',[1]='B36 K0200 L017 A:-36,543733 T:543733 P:26713'},
[26717]={[0]='The Yorgen Worgen',[1]='B34 FA K0240 L022 A:43738 T:43738 O:26785'},
[26719]={[0]='Delivery to Master Harris',[1]='B34 FA K0240 L022 A:43738 T:43730 P:26717'},
[26720]={[0]='A Curse We Cannot Lift',[1]='B34 FA K0240 L022 A:43730 T:43730 P:26719'},
[26721]={[0]='The Jitters-Bugs',[1]='B34 FA K0240 L022 A:288 T:288'},
[26722]={[0]='Buried Below',[1]='B34 FA K0250 L022 A:1204824 T:1204825 P:26753'},
[26723]={[0]='The Fate of Morbent Fel',[1]='B34 FA K0240 L022 A:43861 T:43861 PC:26760'},
[26724]={[0]='The Lurking Lich',[1]='B34 FA K0250 L022 A:43861 T:43731 P:26723'},
[26725]={[0]='Guided by the Light',[1]='B34 FA K0250 L022 A:43731 T:1204817 P:26724'},
[26726]={[0]='Triumphant Return',[1]='B36 K0200 FA L017 A:543733 T:344 P:26714'},
[26727]={[0]="The Embalmer's Revenge",[1]='B34 FA K0220 L019 A:263 T:263 P:26681'},
[26728]={[0]="Hero's Call: Duskwood!",[1]='B34 K0200 FA L019 A:900 T:264 I:26618,28564'},
[26729]={[0]='Water Elementals',[1]='B37 K0260 FA L024 A:43885 T:543885 P:26736'}, -- not PC code, but P code and required to leave the area before they appear
[26730]={[0]='You Can Take the Murloc Out of the Ocean...',[1]='B37 K0260 FA L024 A:543885 T:543885 P:26729'},
[26731]={[0]='The Altar of Naias',[1]='B37 K0260 FA L024 A:543885 T:543885 P:26730'},
[26732]={[0]='Bad Medicine',[1]='B37 K0250 FA L024 A:739 T:739 OCC:28855'},
[26733]={[0]='Control Sample',[1]='B37 K0250 FA L024 A:739 T:739 P:26732'},
[26734]={[0]='The Source of the Madness',[1]='B37 K0250 FA L024 A:739 T:739 P:26733'},
[26735]={[0]='The Fate of Kurzen',[1]='B37 K0250 FA L024 A:469 T:469 O:26838,28699'},
[26736]={[0]='Spared from Madness',[1]='B37 K0250 FA L024 A:469 T:469 P:26735'},
[26737]={[0]="Stopping Kurzen's Legacy",[1]='B37 K0250 FA L024 A:469 T:469 P:26736'},
[26738]={[0]='Just Hatched',[1]='B37 K0250 FA L024 A:-37 T:1422 P:28855 I:526738'},
[26739]={[0]="I Think She's Hungry",[1]='B37 K0250 FA L024 A:1422 T:1422 P:26738'},
[26740]={[0]="Krazek's Cookery",[1]='B37 K0280 FA L026 A:770 T:773'},
[26742]={[0]='Bloodscalp Insight',[1]='B37 K0260 FA L024 A:43886 T:43886 P:26736'},
[26743]={[0]='Sacred to the Bloodscalp',[1]='B37 K0260 FA L024 A:43886 T:43886 P:26742'},
[26744]={[0]='Deep Roots',[1]='B37 K0260 FA L024 A:1422 T:1422 P:26739'},
[26745]={[0]='Favored Skull',[1]='B37 K0260 FA L024 A:42736 T:43884 P:26736+26739'},
[26746]={[0]='A Nose for This Sort of Thing',[1]='B37 K0260 FA L024 A:43884 T:43884 P:26745'},
[26747]={[0]='A Physical Specimen',[1]='B37 K0260 FA L024 A:43884 T:43884 P:26746'},
[26748]={[0]='Bloodlord Mandokir',[1]='B37 K0260 FA L024 A:42790 T:42790 P:26747'},
[26749]={[0]='Priestess Thaalia',[1]='B37 K0270 FA L024 A:43884 T:44017 P:26748'},
[26750]={[0]="At the Stonemother's Call",[1]='B640 K0830 L081 A:42472 T:42465 P:26584+26585'},
[26751]={[0]='Population Con-Troll',[1]='B37 K0270 FA L025 A:733 T:733 P:26746'},
[26752]={[0]='Audience with the Stonemother',[1]='B640 K0830 L081 A:42465 T:43809 P:26750'},
[26753]={[0]='The Halls of the Dead',[1]='B34 FA K0250 L022 A:1204817 T:1204824 P:26725'},
[26754]={[0]="Morbent's Bane",[1]='B34 FA K0250 L022 A:1204825 T:43861 P:26722'},
[26755]={[0]='Keep Them off the Front',[1]='B640 K0830 L081 A:43897 T:43897 P:26632'},
[26760]={[0]='Cry For The Moon',[1]='B34 FA K0240 L021 A:43730 T:43730 P:26720'},
[26761]={[0]='Threat to the Kingdom',[1]='B36 FA K0150 L012 A:234 T:344 P:26370 B36'},
[26762]={[0]='Reactivate the Constructs',[1]='B640 K0830 L081 A:43897 T:43897 P:26755'},
[26763]={[0]='Venture Company Mining',[1]='B37 K0280 FA L026 A:773 T:773 P:26740'},
[26765]={[0]='Return to Corporal Kaleb',[1]='B37 K0280 FA L026 A:773 T:770 P:26763'},
[26766]={[0]='Big Game, Big Bait',[1]='B640 K0820 L081 A:44010 T:44010 P:27061'},
[26768]={[0]='To Catch a Dragon',[1]='B640 K0820 L081 A:44010 T:44010 P:27061'},
[26769]={[0]='Raging River Ride',[1]='B11 K0160 FH L014 A:3391 T:34698 P:14050'},
[26770]={[0]='Mystic Masters',[1]='B640 K0830 L081 A:43898 T:43898 P:26755'},
[26771]={[0]='Testing the Trap',[1]='B640 K0820 L081 A:44010 T:44010 P:26766+26768'},
[26772]={[0]='Mind Vision',[1]='B37 K0270 FA L024 A:44017 T:44017 P:26749'},
[26773]={[0]='See Raptor',[1]='B37 K0270 FA L024 A:44017 T:44017 P:26772'},
[26774]={[0]='Mind Control',[1]='B37 K0290 FA L024 A:44017 T:44017 P:26773'},
[26775]={[0]='Be Raptor',[1]='B37 K0290 FA L024 A:44017 T:44017 P:26774'},
[26776]={[0]='Ghaliri',[1]='B37 K0290 FA L024 A:44017 T:44021 P:26775'},
[26777]={[0]='Soothing Spirits',[1]='B34 FA K0240 L022 A:43731 T:43731'},
[26778]={[0]='The Cries of the Dead',[1]='B34 FA K0240 L022 A:43731 T:43731 P:26760'},
[26779]={[0]="Zul'Mamwe Mambo",[1]='B37 K0290 FA L027 A:44021 T:44021 P:26773'},
[26780]={[0]='Nighttime in the Jungle',[1]='B37 K0290 FA L027 A:44043 T:44043 P:26773'},
[26781]={[0]="The Mind's Eye",[1]='B37 K0280 FA L026 A:44019 T:44019'},
[26782]={[0]="The Mosh'Ogg Bounty",[1]='B37 K0280 FA L026 A:44018 T:44018 I:26783'}, -- L85 elf hunter got this one
[26783]={[0]="The Mosh'Ogg Bounty",[1]='B37 K0280 FA L026 A:44018 T:44018 I:26782'}, -- not sure why this exists with 26782 there...draenei hunter got 26782
[26784]={[0]='Muddied Waters',[1]='B700 FH K0840 L084 A:44024 T:44024 P:26786'},
[26785]={[0]='Part of the Pack',[1]='B34 FA K0240 L021 A:43453 T:43738 P:26674 I:26717'},
[26786]={[0]='Securing the Beach Head',[1]='B700 FH K0840 L084 A:43943 T:44024 P:26622'},
[26787]={[0]='Bear In Mind',[1]='B34 FA K0240 L022 A:288 T:288 P:26721'},
[26788]={[0]='Cementing Our Victory',[1]='B700 FH K0840 L084 A:44042 T:44042'},
[26791]={[0]='Sprout No More',[1]='B640 K0830 L081 A:44143 T:44143 P:26834'},
[26792]={[0]='Fungal Monstrosities',[1]='B640 K0830 L081 A:44143 T:44143 P:26834'},
[26793]={[0]='The Weathered Grave',[1]='B34 FA K0250 L023 A:1000061 T:268'},
[26794]={[0]='Morgan Ladimore',[1]='B34 FA K0250 L023 A:268 T:264 P:26793'},
[26795]={[0]="Mor'Ladim",[1]='B34 FA K0250 L023 A:264 T:264 P:26794'},
[26796]={[0]='The Daughter Who Lived',[1]='B34 FA K0250 L023 A:264 T:576 P:26795'},
[26797]={[0]="A Daughter's Love",[1]='B34 FA K0250 L023 A:576 T:1000061 P:26796'},
[26798]={[0]='The Warchief Will be Pleased',[1]='B700 FH K0840 L084 A:44024 T:39605 P:26784'},
[26799]={[0]="Those That Couldn't Be Saved",[1]='B0 K0010 RU A:1568 T:1568 P:28608'},
[26800]={[0]='Recruitment',[1]='B0 K0020 FH RU A:1740,49340 T:1740 P:25089'},
[26801]={[0]='Scourge on our Perimeter',[1]='B0 K0030 FH A:1569 T:1569 O:28653'},
[26802]={[0]='The Damned',[1]='B0 K0030 FH L003 A:1570 T:1570 P:28672'},
[26803]={[0]='Missing Reports',[1]='B0 K0100 FH RG L005 A:3144 T:3310'},
[26804]={[0]='Flight to Razor Hill',[1]='B0 K0100 FH RG L005 A:3310 T:3139 P:26803'},
[26805]={[0]='To the Cape!',[1]='B673 K0300 FA L029 A:44018 T:44082 I:28702 B673'},
[26806]={[0]='Reports to Orgrimmar',[1]='B0 K0100 FH RG L005 A:3139 T:41140 P:26804'},
[26807]={[0]='Return to Eitrigg',[1]='B0 K0100 FH RG L005 A:41140 T:3144 P:26806'},
[26808]={[0]='Maywiki',[1]='B673 FA K0310 L029 A:44083 T:44084 P:26819'},
[26809]={[0]='Backdoor Dealings',[1]='B673 FA K0310 L029 A:44084 T:44084 P:26808'},
[26810]={[0]='Eliminate the Outcast',[1]='B0 FA K0320 L029 A:44084 T:-100673 P:26809'},
[26811]={[0]='Through the Troll Hole',[1]='B0 FA K0320 L029 A:-673 T:-100037 P:26810'},
[26812]={[0]='High Priestess Jeklik',[1]='B0 K0320 L029 A:-100037 T:-37 P:26811'},
[26813]={[0]="Plunging Into Zul'Gurub",[1]='B0 K0320 L029 A:-37 T:-37 P:26812'},
[26814]={[0]='High Priest Venoxis',[1]='B673 K0320 FA L029 A:-37 T:44084 P:26813 B673'},
[26815]={[0]="Zanzil's Secret",[1]='B673 FA K0310 L029 A:44099 T:44099 P:26817'},
[26816]={[0]='Recipe for Disaster',[1]='B673 FA K0320 L029 A:44099 T:44099 P:26815'},
[26817]={[0]='Perfectly Pure',[1]='B673 FA K0300 L026 A:44099 T:44099 P:26823'},
[26818]={[0]='Plush Pelts',[1]='B673 FA K0300 L026 A:44083 T:44083 P:26823'},
[26819]={[0]='Akiris by the Bundle',[1]='B673 FA K0300 L029 A:44083 T:44083 P:26823'},
[26820]={[0]="If They're Just Going to Leave Them Lying Around...",[1]='B673 FA K0300 L029 A:44083 T:44083 P:26823'},
[26821]={[0]='Airwyn Bantamflax',[1]='B673 FA K0320 L026 A:44082 T:44112 P:26824'},
[26822]={[0]="Good-Fer-Nothin' Slither-Dogs",[1]='B673 FA K0300 L029 A:44100 T:44100'},
[26823]={[0]='Too Big For His Britches',[1]='B673 FA K0300 L029 A:44099 T:44099 P:26825,26826'},
[26824]={[0]='Results: Inconclusive',[1]='B673 FA K0320 L029 A:44099 T:44082 P:26815'},
[26825]={[0]='Dask "The Flask" Gobfizzle',[1]='B673 FA K0300 L029 A:44082 T:44099 O:28702 I:26826'}, -- L85 elf hunter got this one
[26826]={[0]='Dask "The Flask" Gobfizzle',[1]='B673 FA K0300 L029 A:44082 T:44099 I:26825'},
[26827]={[0]='Rallying the Earthen Ring',[1]='B640 K0830 L081 A:43809 T:43065 P:26752'},
[26828]={[0]='Our Part of the Bargain',[1]='B640 K0830 L081 A:43065 T:44025 P:26827'},
[26829]={[0]='The Stone March',[1]='B640 K0830 L081 A:44025 T:44025 P:26828'},
[26830]={[0]="Traitor's Bait",[1]='B0 K0840 FH L084 A:39605 T:39605 P:26798'},
[26831]={[0]='The Twilight Flight',[1]='B640 K0830 L081 A:44080 T:44080,42614 P:26828'},	-- yes, can be turned into either!
[26832]={[0]="Therazane's Mercy",[1]='B640 K0830 L081 A:44025 T:44025 P:26828'},
[26833]={[0]='Word In Stone',[1]='B640 K0830 L081 A:44025 T:43818 P:26829+26832'}, -- does this need 26831 as well?
[26834]={[0]='Down Into the Chasm',[1]='B640 K0830 L081 A:43897 T:44143 P:26762'},
[26835]={[0]='A Slight Problem',[1]='B640 K0830 L081 A:44143 T:43897 P:26791+26792'},
[26836]={[0]='Rescue the Stonefather... and Flint',[1]='B640 K0830 L081 A:43897 T:43897 P:26835'},
[26838]={[0]='Rebels Without a Clue',[1]='B37 FA K0250 L024 A:3885,43731 T:469 I:28699,26735'},
[26840]={[0]='Return to the Highlands',[1]='B0 K0840 FH L084 A:39605 T:44169 P:26830'},
[26841]={[0]='Forbidden Sigil',[1]='B0 FA RE CM K0030 L003 A:2077,502079 T:43006 P:28714+28715'},
[26842]={[0]='Out of Gnoll-where',[1]='B35 FA K0120 L010 A:1340 T:1340 P:26176'},
[26843]={[0]='A Tiny, Clever Commander',[1]='B35 FA K0130 L011 A:1343 T:1343 O:13636'},
[26844]={[0]='Kobold and Kobolder',[1]='B35 FA K0130 L011 A:1343 T:1343 P:26843'},
[26845]={[0]="Who's In Charge Here?",[1]='B35 FA K0130 L011 A:1343 T:1343 P:26844'},
[26846]={[0]='A Nasty Exploit',[1]='B35 FA K0130 L011 A:44200 T:44200 P:26844'},
[26847]={[0]='The Quaking Fields',[1]='B0 K0830 '},
[26848]={[0]='X Marks the Spot',[1]='B0 K0830 '},
[26849]={[0]='The Axe of Earthly Sundering',[1]='B0 K0830 '},
[26850]={[0]='Elemental Ore',[1]='B0 K0830 '},
[26851]={[0]='One With the Ground',[1]='B0 K0830 '},
[26852]={[0]="The Fragment's Inside",[1]='B0 K0830 '},
[26853]={[0]='The Middle Fragment',[1]='B0 K0830 '},
[26854]={[0]='The Lost Pilot',[1]='B0 FA K0110 L010 A:1960 T:1002059'},
[26855]={[0]="A Pilot's Revenge",[1]='B0 FA K0110 L010 A:1002059 T:1960 P:26854'},
[26856]={[0]='Repel the Invasion',[1]='B0 K0150 FH L010 A:44217 T:44217 P:26865,26866,26867,28003'},
[26857]={[0]="Abyssion's Minions",[1]='B640 K0820 L081 A:44010 T:44010 P:26771'},
[26858]={[0]='Taragaman the Hungerer',[1]='B0 K0160 FH L010 A:44217 T:44217'},
[26860]={[0]='Thelsamar Blood Sausages',[1]='B35 FA K0120 L010 A:1963 T:1963'},
[26861]={[0]='Block the Gates',[1]='B640 K0820 L081 A:44222 T:44222 P:26771'},
[26862]={[0]='Elemental Tampering',[1]='B0 K0150 FH L010 A:44216 T:44216'},
[26863]={[0]='Filthy Paws',[1]='B35 FA K0130 L011 A:1343 T:1343 P:26844'},
[26864]={[0]='The Bearer of Gnoll-edge',[1]='B35 FA K0130 L011 A:1343 T:1340 P:26845'},
[26865]={[0]='Enemies Below',[1]='B504956 K01564 FH L015 A:39605 T:44217 I:26866,26867,28003'},
[26866]={[0]='Enemies Below',[1]='B504956 K01564 FH L015 A:36648 T:44217 I:26865,26867,28003'},
[26867]={[0]='Enemies Below',[1]='B504956 K01564 FH L015 A:10181 T:44217 I:26865,26866,28003'},
[26868]={[0]='Axis of Awful',[1]='B35 FA K0150 L012 A:44345 T:44345 P:26928'},
[26869]={[0]='Depth of the Depths',[1]='B640 K0830 L081 A:-640 T:1204959 P:26426'},
[26870]={[0]='Cleansing the Caverns',[1]='B0 K0210 L016 A:5768 T:5768'},
[26871]={[0]='A Rock Amongst Many',[1]='B640 K0830 L081 A:1204959 T:42467 P:26869'},
[26872]={[0]='Deviate Hides',[1]='B0 K0180 L016 A:5767 T:5767'},
[26873]={[0]='Preemptive Methods',[1]='B0 K0180 L016 A:5767 T:5767'},
[26875]={[0]='Undying Twilight',[1]='B640 K0830 L081 A:43818 T:0 P:26833'},
[26876]={[0]='The World Pillar Fragment',[1]='B640 K0830 L081 A:44010 T:43065 P:26857+26861'},
[26877]={[0]="The Fragment's Inside",[1]='B0 K0830 '},
[26878]={[0]='Disciples of Naralex',[1]='B504956 K0160 FH L015 A:3448 T:5767'},
[26879]={[0]='Disciples of Naralex',[1]='B0 K0160 '},
[26881]={[0]='In Search of Thaelrid',[1]='B0 K0250 FA L022 A:33256 T:4787'},
[26882]={[0]='Blackfathom Villainy',[1]='B0 K0280 FA L022 A:4787 T:33256 P:26881'},
[26883]={[0]='Twilight Falls',[1]='B0 K0280 FA L022 A:33260 T:33260'},
[26884]={[0]='Researching the Corruption',[1]='B0 K0260 FA L022 A:33258 T:33258'},
[26885]={[0]='Knowledge in the Deeps',[1]='B0 K0250 FA L022 A:33261 T:33261'},
[26886]={[0]='Going Off-Task',[1]='B161 FA K0460 L044 A:38704 T:38704 P:25052'},
[26887]={[0]='Filling Our Pockets',[1]='B161 FA K0460 L044 A:38704 T:38704 P:25054'},
[26888]={[0]='Nightmare of the Deeps',[1]='B0 K0270 FH L021 A:12736 T:12736'},
[26889]={[0]='All Cheered Out',[1]='B161 FA K0460 L044 A:38704 T:38706 P:25166'},
[26890]={[0]="The Essence of Aku'Mai",[1]='B43 K0220 FH L017 A:34303 T:34303'},
[26891]={[0]='Amongst the Ruins',[1]='B0 K0260 FH L020 A:12736 T:12736'},
[26892]={[0]='Deep in the Deeps',[1]='B0 K0260 FH L021 A:44375 T:44375'},
[26893]={[0]='Blackfathom Deeps',[1]='B0 K0230 '},
[26894]={[0]='Blackfathom Deeps',[1]='B504956 K0240 FH L022 A:34122 T:12736'},
[26895]={[0]='The Thunderdrome!',[1]='B161 FA K0490 L047 A:38578 T:39034 I:25067'},
[26896]={[0]='The Thunderdrome!',[1]='B161 K0490 FH L047 A:44374 T:39034 I:25067'},
[26897]={[0]='Blackfathom Deeps',[1]='B504956 K0240 FA L022 A:3845 T:33260 I:26898'},
[26898]={[0]='Blackfathom Deeps',[1]='B504956 K0240 FA L022 A:3691 T:33260 I:26897'},
[26899]={[0]='The Enemy of My Enemy',[1]='B0 K0280 FH L021 A:44387 T:44387'},
[26901]={[0]='Going, Going, Guano!',[1]='B0 K0350 L032 A:44402 T:44402'},
[26903]={[0]='Willix the Importer',[1]='B0 K0350 L032 A:4508 T:4508'},
[26904]={[0]='Harnessing the Flames',[1]='B0 FA RF CW CS CL K0030 L003 A:43455 T:43455'},
[26905]={[0]="Agamaggan's Charge",[1]='B0 K0350 L032 A:44415 T:44415 P:26906'},
[26906]={[0]='Agamaggan',[1]='B504956 K0350 L032 A:44402 T:44415'},
[26907]={[0]='Take Them Down!',[1]='B0 K0350 L032 A:44402 T:44402'},
[26908]={[0]='Feeling Thorny',[1]='B504956 K0330 L032 A:37812 T:44402'},
[26909]={[0]='The Stone Shards',[1]='B16 K0290 FH L027 A:2787 T:1138492 P:26341'},
[26910]={[0]='Etched Letter',[1]='B0 FA CH K0030 L003 A:197 T:43278 P:28759'},
[26911]={[0]="Myzrael's Tale",[1]='B16 K0270 FH L025 A:1002702 T:2787'}, -- see comment in quest 26346
[26912]={[0]='The Princess Unleashed',[1]='B16 K0280 FH L026 A:2787 T:1138492 P:26911'},
[26913]={[0]='Charging into Battle',[1]='B0 K0030 L003 CW A:911 T:911 P:3100'},
[26914]={[0]='Immolation',[1]='B0 K0030 L003 A:459 T:459 P:3105'},
[26915]={[0]='The Deepest Cut',[1]='B0 FA CR K0030 L003 A:915 T:915 P:3102'},
[26916]={[0]='Mastering the Arcane',[1]='B0 K0030 L003 A:198 T:198 P:3104'},
[26917]={[0]="The Hunter's Path",[1]='B0 FA CH K0030 L003 A:43278 T:43278 P:26910'},
[26918]={[0]='The Power of the Light',[1]='B0 FA CP K0030 L003 A:925 T:925 P:3101'},
[26919]={[0]='Healing the Wounded',[1]='B0 K0030 L003 A:375 T:375 P:3103'},
[26920]={[0]='The Battle for Andorhal',[1]='B22 K0350 FH L034 A:10837 T:44452 I:28508,28575,28750'},
[26921]={[0]='Scourge First... Alliance Later',[1]='B22 K0350 FH L034 A:44452 T:44452 P:26920,28508,28575,28750'},
[26922]={[0]='The Endless Flow',[1]='B22 K0350 FH L034 A:44462 T:44462'},
[26923]={[0]='War Machines',[1]='B22 K0350 FH L034 A:44466 T:44466'},
[26924]={[0]='Scholomancer',[1]='B22 K0350 FH L034 A:44452 T:44452 P:26922'},
[26925]={[0]='Araj the Summoner',[1]='B22 K0350 FH L034 A:44462 T:44452 P:26922'},
[26926]={[0]='Victory, For Now',[1]='B22 K0350 FH L034 A:44452 T:10837 P:26924+26925+27117'},
[26927]={[0]='Suddenly, Murlocs!',[1]='B35 FA K0140 L012 A:1340 T:44345 P:26864'},
[26928]={[0]='Smells Like A Plan',[1]='B35 FA K0150 L012 A:44345 T:44345 P:26927'},
[26929]={[0]='A Load of Croc',[1]='B35 FA K0150 L012 A:44345 T:44345 P:26927'},
[26930]={[0]='After the Crusade',[1]='B22 K0360 FH L034 A:10837 T:10837 P:26926'},
[26931]={[0]='Foxes and Hounds',[1]='B22 K0360 FH L034 A:11055 T:11055'},
[26932]={[0]='Buzz Off',[1]='B35 FA K0150 L013 A:1340 T:1340 P:26927'},
[26933]={[0]='Foes Before Hoes',[1]='B22 K0360 FH L034 A:11055 T:11055 P:26931'},
[26934]={[0]='Latent Disease',[1]='B22 K0360 FH L034 A:11057 T:11057'},
[26935]={[0]='Northridge Lumber Mill',[1]='B22 K0370 L034 A:44454 T:11616 P:26999 I:27000'},
[26936]={[0]='Lower the Boom',[1]='B22 K0360 FH L034 A:10837 T:10837'},
[26937]={[0]='When Death is Not Enough',[1]='B22 K0360 FH L034 A:44466 T:44466 P:26979'},
[26938]={[0]='Combat Training',[1]='B22 K0370 L034 A:45098 AH:44466 T:44466 P:26937'},
[26939]={[0]='The G-Team',[1]='B0 K0270 FA L026 A:44556 T:44560 P:26943,26944'},
[26940]={[0]='Arcane Missiles',[1]='B0 RE CM K0030 L003 A:43006 T:43006 P:26841'},
[26941]={[0]='The G-Team',[1]='B0 K0280 FA L026 A:44560 T:44561 P:26939'},
[26942]={[0]='The G-Team',[1]='B0 K0290 FA L026 A:44561 T:44563 P:26941'},
[26943]={[0]='Home Sweet Gnome',[1]='B504956 FA K02664 L026 A:2789 T:44556 I:26944'},
[26944]={[0]='Exploring Gnomeregan',[1]='B504956 K0260 FA L026 A:44018 T:44556 I:26943'},
[26945]={[0]='Learning New Techniques',[1]='B0 RE CW K0030 L003 A:3593 T:3593 P:3116'},
[26946]={[0]="A Rogue's Advantage",[1]='B0 K0030 RE CR L003 A:3594 T:3594 P:3118'},
[26947]={[0]="A Woodsman's Training",[1]='B0 RE CH K0030 L003 A:3596 T:3596 P:3117'},
[26948]={[0]="Rejuvenating Touch",[1]='B0 RE CD K0030 L003 A:3597 T:3597 P:3120'},
[26949]={[0]='Healing for the Wounded',[1]='B0 K0030 RE CT L003 A:3595 T:3595 P:3119'},
[26950]={[0]='The Dark Side of the Light',[1]='B504956 K0300 FH L028 A:44637 T:44637'},
[26951]={[0]='Cleanup on Isle E.',[1]='B0 K0100 FH L004 A:3188 T:3188'},
[26952]={[0]="The Menders' Stead",[1]='B22 K0370 FH L035 A:10839 T:44454 I:27150'},
[26953]={[0]="Zen'Kiki, the Druid",[1]='B22 K0370 L035 A:44456 T:44456'},
[26954]={[0]='A Different Approach',[1]='B22 K0370 L035 A:44456 T:44456 P:26953'},
[26955]={[0]="Zen'Kiki and the Cultists",[1]='B22 K0380 L035 A:44456 T:44456 P:27057'},
[26956]={[0]="I Ain't Sayin' You a Gourd-Digger...",[1]='B22 K0370 L035 A:44457 T:44457'},
[26957]={[0]='The Long Trip Home',[1]='B22 K0380 L036 A:44905 T:44458'},
[26958]={[0]='Your First Lesson',[1]='B0 K0030 FA RD CW L003 A:16503 T:16503 P:9289'},
[26959]={[0]='Stripping Their Defenses',[1]='B0 K0330 FH L031 A:44660 T:44660'},
[26960]={[0]='My Son, the Prince',[1]='B0 FA K0840 L084 A:29611 T:29611 O:28716'},
[26961]={[0]='Gathering Idols',[1]='B35 FA K0160 L014 A:1345 T:1345'},
[26962]={[0]='Stripping Their Offense',[1]='B0 K0360 FH L034 A:44690 T:44690'},
[26963]={[0]='Steadying Your Shot',[1]='B0 K0030 FA RD CH L003 A:16499 T:16499 P:9288'},
[26964]={[0]="Warchief's Command: Silverpine Forest!",[1]='B21 K0100 FH L009 M013 A:1515 T:44615 I:26965,28568'},
[26965]={[0]='The Warchief Cometh',[1]='B21 K0110 FH L009 A:44615 T:44615 O:26964,28568'},
[26966]={[0]="The Light's Power",[1]='B0 K0030 FA RD CP L003 A:16501 T:16501 P:9287'},
[26967]={[0]='Battle for the Scarlet Monastery',[1]='B0 K0390 FH L037 A:44706 T:44706'},
[26968]={[0]='Arcane Missiles',[1]='B0 K0030 FA RD CM L003 A:16500 T:16500 P:9290'},
[26969]={[0]='Primal Strike',[1]='B0 K0030 FA RD CS L003 A:17089 T:17089 P:9421'},
[26970]={[0]='Aiding the Injured',[1]='B0 K0030 FA RD CT L003 A:16502 T:16502 P:9291'},
[26971]={[0]='The Binding',[1]='B640 K0830 L081 A:-640 T:43835 P:26875'},
[26972]={[0]='The Dark Side of the Light',[1]='B504956 K0300 FA L028 A:44728 T:44728'},
[26973]={[0]='The Only True Path',[1]='B0 K0330 FA L031 A:44738 T:44738'},
[26974]={[0]='The False Champion',[1]='B0 FA K0360 L034 A:44741 T:44741'},
[26975]={[0]='Rallying the Fleet',[1]='B0 FA K0840 L084 A:29611 T:44749 P:26960'},
[26976]={[0]='Battle for the Scarlet Monastery',[1]='B0 K0390 FA L037 A:44746 T:44746'},
[26977]={[0]='Twilight Investigation',[1]='B0 FA K0840 L084 A:29611 T:2439 P:26960'},
[26978]={[0]='Who Needs Cauldrons?',[1]='B22 K0360 FH L034 A:11057 T:11057 P:26934'},
[26979]={[0]='Strange New Faces',[1]='B22 K0360 FH L034 A:10837 T:44466 B22'},
[26980]={[0]='Swiftgear Station',[1]='B40 FA K0230 L021 A:2104 T:41415 P:25801+25805+25819+25820 I:25864'},
[26981]={[0]="Whelgar's Retreat",[1]='B40 FA K0230 L021 A:41415 T:41411 P:25868 I:25849'},
[26982]={[0]='The Scarlet Monastery',[1]='B504956 FA K03064 L028 A:2700 T:44728'},
[26983]={[0]='Just Close Enough',[1]='B0 K0330 FA L031 A:39084 T:44738'},
[26984]={[0]='An Old, Crazed Friend',[1]='B0 K0350 FA L034 A:44019 T:44741'},
[26985]={[0]='Pitting Madness Against Madness',[1]='B0 K0380 FA L037 A:3936 T:44746'},
[26986]={[0]='Into the Scarlet Monastery',[1]='B504956 K0300 FH L028 A:12920 T:44637'},
[26987]={[0]='The Right Way',[1]='B0 K0330 FH L031 A:14741 T:44660'},
[26988]={[0]='Moving Things Along',[1]='B0 K0350 FH L034 A:14739 T:44690'},
[26989]={[0]='The Gilneas Liberation Front',[1]='B21 K0110 FH L009 A:44615 T:44615 P:26965'},
[26990]={[0]='Water They Up To?',[1]='B0 K0800 FH L078 A:42600 T:5769'},
[26991]={[0]='Enemies Abroad',[1]='B0 K0380 FH L037 A:4791 T:44706'},
[26992]={[0]='Agony Abounds',[1]='B21 K0110 FH L009 A:44778 T:44778 P:26965'},
[26993]={[0]='Compendium of the Fallen',[1]='B0 K0330 L031 A:44800 T:44800'},
[26994]={[0]='Without Rhyme or Reason',[1]='B0 K0360 L034 A:44804 T:44804'},
[26995]={[0]='Guts and Gore',[1]='B21 K0110 FH L009 A:44784 T:44784 P:26965'},
[26996]={[0]='Right Under Their Noses',[1]='B0 K0390 L037 A:44805 T:44805'},
[26997]={[0]='The Usual Suspects',[1]='B0 FA K0840 L084 A:2439 T:44293 P:26977'},
[26998]={[0]='Iterating Upon Success',[1]='B21 K0110 FH L009 A:44784 T:44784 P:26992+26995'},
[26999]={[0]='A New Era for the Plaguelands',[1]='B22 K0370 L034 A:44454 T:44454 O:26952,27150,27175,27233'},
[27000]={[0]='Learning the Ropes',[1]='B22 K0370 L034 A:11616 T:11616 O:26935'},
[27001]={[0]='This Means WAR (Wild Arachnid Roundup)',[1]='B22 K0370 L034 A:11616 T:11616 P:27000'},
[27002]={[0]='An Audience with the Highlord',[1]='B22 K0370 L034 A:11616 T:44441 P:27001'},
[27003]={[0]='Easy Money',[1]='B0 K0830 L083 A:44833 T:46873 P:28295,28296,28557,28558'},
[27004]={[0]='The Twilight Plot',[1]='B640 FA K0830 L083 A:44799 T:44799 O:27952'},
[27005]={[0]='The Twilight Plot',[1]='B640 FH K0830 L083 A:44823 T:44823 P:27953'},
[27006]={[0]='Fly Over',[1]='B640 FA K0830 L083 A:44802 T:44802'},
[27007]={[0]='Silvermarsh Rendezvous',[1]='B640 K0820 L081 A:-640 T:0 P:26260'},
[27008]={[0]='Fly Over',[1]='B640 FH K0830 L083 A:44818 T:44818'},
[27009]={[0]='The Coldbringer',[1]='B0 K0460 L042 A:44837 T:44837 P:27062,27063'},
[27010]={[0]='Quicksilver Submersion',[1]='B640 K0820 L081 A:-640 T:0 P:27007'},
[27011]={[0]='Redpine Thievery',[1]='B22 K0370 L035 A:44472 T:44472 P:27013'},
[27012]={[0]="A Gnoll's Resolve",[1]='B22 K0370 L035 A:44472 T:44472 P:27013'},
[27013]={[0]='Too Close for Comfort',[1]='B22 K0370 L035 A:44472 T:44472'},
[27014]={[0]='Hallowed Note',[1]='B0 K0030 FH RT RL RB CT L003 A:44927 T:37724'},
[27015]={[0]='Consecrated Note',[1]='B0 K0030 FH RT RB CP L003 A:44927 T:37737'},
[27016]={[0]='The Joy of Boar Hunting',[1]='B35 FA K0160 L014 A:1187 T:1187'},
[27017]={[0]='Memories from a Lost Past',[1]='B22 K0380 L036 A:44458 T:44458 P:26957'},
[27019]={[0]='Scourge of the Downs',[1]='B0 K0440 L042 A:8516 T:8516'},
[27020]={[0]='The First Lesson',[1]='B0 K0030 FH RT CW L003 A:3059 T:3059 P:3091'},
[27021]={[0]="The Hunter's Path",[1]='B0 K0030 FH RT RL CH L003 A:3061 T:3061 P:3092'},
[27022]={[0]='Extinguishing the Idol',[1]='B0 K0450 L042 A:8516 T:1152097 P:27019'},
[27023]={[0]='The Way of the Sunwalkers',[1]='B0 K0030 FH RT RB CP L003 A:37737 T:37737 P:27015'},
[27024]={[0]='Partners in Crime',[1]='B0 K0440 L042 A:44837 T:44837'},
[27025]={[0]='Thistle While You Work',[1]='B35 FA K0160 L014 A:44859 T:44859'},
[27026]={[0]='Defcon: Bobcat',[1]='B35 FA K0160 L014 A:44859 T:44859 P:27025'},
[27027]={[0]='Primal Strike',[1]='B0 K0030 FH RT CS L003 A:3062 T:3062 P:3093'},
[27028]={[0]='Hornet Hunting',[1]='B35 FA K0160 L014 A:1154 T:1154'},
[27029]={[0]='Cure the Scourge',[1]='B0 K0440 L042 A:44837 T:44837'},
[27030]={[0]='Foxtails By The Handful',[1]='B35 FA K0160 L014 A:1154 T:1154'},
[27031]={[0]='Wing Nut',[1]='B35 FA K0170 L015 A:6577 T:6577'},
[27032]={[0]='Bird is the Word',[1]='B35 FA K0180 L015 A:6577 T:44618 P:27031'},
[27033]={[0]="Skystrider's Heart",[1]='B35 FA K0180 L015 A:44618 T:6577 P:27032'},
[27034]={[0]="He's That Age",[1]='B35 FA K0180 L015 A:6577 T:44870 P:27033'},
[27035]={[0]='Standing Up',[1]='B35 FA K0180 L014 A:44870 T:44870 P:27034'},
[27036]={[0]="Vyrin's Revenge",[1]='B35 FA K0170 L014 A:1156 T:1187 P:27016'},
[27037]={[0]="Vyrin's Revenge",[1]='B35 FA K0160 L014 A:1187 T:1156 P:27036'},
[27038]={[0]='Missing Parts',[1]='B0 FA K0840 L084 A:44749 T:44806 P:26975'},
[27039]={[0]='Dangerous Intentions',[1]='B21 K0110 FH L009 A:44789 T:1205143 P:26989+26998'},
[27040]={[0]='Decryption Made Easy',[1]='B0 FA K0830 L083 A:44799 T:0 P:27004+27006'},
[27041]={[0]='Decryption Made Easy',[1]='B0 FH K0830 L083 A:44823 T:0 P:27005+27008'},
[27042]={[0]='Fight Fire and Water and Air with...',[1]='B640 FA K0830 L083 A:44802 T:44802 P:27004+27006'},
[27043]={[0]='Fight Fire and Water and Air with...',[1]='B640 FH K0830 L083 A:44818 T:44818 P:27005+27008'},
[27044]={[0]='Peasant Problems',[1]='B0 FA K0840 L084 A:44293 T:44807 P:26975'},
[27045]={[0]='Waiting to Exsanguinate',[1]='B21 K0110 FH L009 A:1205143 T:44789 P:27039'},
[27046]={[0]='Fear of Boring',[1]='B0 +D K0830 L081 A:43805 T:43805 P:26709'},
[27047]={[0]='Motes',[1]='B0 +D K0830 L081 A:43805 T:43805 P:26709'},
[27048]={[0]='Underground Economy',[1]='B0 +D K0830 L081 A:44968 T:44968 P:26709 I:26710,28488'},
[27049]={[0]='Soft Rock',[1]='B0 +D K0830 L081 A:43804 T:43804 P:26709'},
[27050]={[0]='Fungal Fury',[1]='B0 +D K0830 L081 A:43804 T:43804 P:26709'},
[27051]={[0]='Through Persistence',[1]='B0 +D K0830 L081 A:44973 T:44973 P:26709'},
[27053]={[0]="Gahrron's Withering Cauldron",[1]='B22 K0380 L036 A:44454 T:1176392 P:27002'},
[27054]={[0]='Desperate Acts',[1]='B22 K0380 L036 A:44454 T:-22,44454 P:27057'},
[27055]={[0]='Students of Krastinov',[1]='B22 K0390 L036 A:-22,44454 T:44454 P:27054'},
[27056]={[0]="Belmont's Report",[1]='B21 K0110 FH L009 A:44789 T:44365 P:27045'},
[27057]={[0]='Return to the Stead',[1]='B22 K0380 L035 A:1176392 T:44454 P:27053'},
[27058]={[0]='The Wrong Sequence',[1]='B640 FA K0830 L083 A:-640 T:44799 P:27040'},
[27059]={[0]='The Wrong Sequence',[1]='B640 FH K0830 L083 A:-640 T:44823 P:27041'},
[27060]={[0]='Unholy Cow',[1]='B0 FA K0840 L084 A:44807 T:44293 P:27044'},
[27061]={[0]='The Twilight Overlook',[1]='B640 K0820 L081 A:-640 T:44010 P:27010'},
[27062]={[0]='Looming Threat',[1]='B504956 K0430 FH L042 A:39895 T:44837'},
[27063]={[0]='Looming Threat',[1]='B0 K0430 FA L042 A:40032 T:44837'},
[27064]={[0]="He's Holding Out on Us",[1]='B0 FA K0840 L084 A:1747,44293 T:544293 P:27038'},
[27065]={[0]="The Warchief's Fleet",[1]='B21 K0120 FH L010 A:44365 T:44916 P:27056'},
[27066]={[0]='Healing in a Flash',[1]='B0 K0030 FH RT RL RB CT L003 A:37724 T:37724 P:27014'},
[27067]={[0]="Rejuvenating Touch",[1]='B0 K0030 FH RT RL CD L003 A:3060 T:3060 P:3094'},
[27068]={[0]='Chief Ukorz Sandscalp',[1]='B0 K0490 L046 A:40712 T:40712 O:25556'},
[27069]={[0]='Steel Thunder',[1]='B21 K0120 FH L010 A:44916 T:44916 P:27065'},
[27070]={[0]="A Fool's Errand",[1]='B0 K0480 L046 A:7407 T:7407'},
[27071]={[0]='Wrath of the Sandfury',[1]='B0 K0480 L046 A:40712 T:40712'},
[27072]={[0]='The Old Barracks',[1]='B0 FA K0840 L084 A:332 T:50049 P:28807'},
[27073]={[0]="Give 'em Hell!",[1]='B21 K0120 FH L010 A:44917 T:44917 P:27065'},
[27074]={[0]='Fight the Hammer',[1]='B35 FA K0180 L014 A:44870 T:1073 P:27035'},
[27075]={[0]="Servants of Cho'gall",[1]='B35 FA K0180 L014 A:1073 T:1073 P:27074'},
[27076]={[0]='Breaking and Entering',[1]='B0 K0480 L046 A:44929 T:44929'},
[27077]={[0]='Clutching at Chaos',[1]='B35 FA K0180 L014 A:1073 T:1073 P:27074'},
[27078]={[0]="Gor'kresh",[1]='B35 FA K0190 L014 A:1073 T:1073 P:27075+27077'},
[27082]={[0]='Playing Dirty',[1]='B21 K0120 FH L010 A:44912 T:44912 P:27065'},
[27083]={[0]='The Battle Resumes!',[1]='B22 K0400 FH L038 A:10837,45013 T:44452'},
[27084]={[0]="The Farmers' Militia",[1]='B22 K0400 FH L038 A:44452 T:44452'},
[27085]={[0]='Supporting the Troops',[1]='B22 K0400 FH L038 A:44462 T:44462'},
[27086]={[0]='Ashes to Ashes',[1]='B22 K0400 FH L038 A:44452 T:44452 P:27084'},
[27087]={[0]='Lindsay Ravensun, Revealed',[1]='B22 K0400 FH L038 A:44452 T:44466 P:27084,27086'},
[27088]={[0]="It's Only Poisonous if You Ingest It",[1]='B21 K0120 FH L010 A:44912 T:44912 P:27082'},
[27089]={[0]='Ace in the Hole',[1]='B22 K0400 FH L038 A:44451 T:45129'},
[27090]={[0]='Andorhal, Once and For All',[1]='B22 K0400 FH L038 A:45129 T:44451 P:27089'},
[27091]={[0]='Charge!',[1]='B0 K0030 RB CW L003 A:43010 T:43010 P:8329'},
[27092]={[0]='Cataclysm in the Catacombs',[1]='B0 FA K0840 L084 A:50049 T:1008590 P:27072'},
[27093]={[0]='Lost in the Darkness',[1]='B21 K0120 FH L010 A:44916 T:44916 P:27069+27073'},
[27094]={[0]='Deeper into Darkness',[1]='B21 K0130 L010 A:-21,44917 T:44917 P:27095'},
[27095]={[0]='Skitterweb Menace',[1]='B21 K0120 FH L010 A:44917 T:-21,44917 P:27069+27073'},
[27096]={[0]='Orcs are in Order',[1]='B21 K0130 FH L010 A:44916 T:44365 P:27088+27093+27094'},
[27097]={[0]='Rise, Forsaken',[1]='B21 K0130 FH L011 A:44365 T:-21,44365 P:27096'},
[27098]={[0]='Lordaeron',[1]='B21 K0130 FH L011 A:44365 T:544365 P:27099'},
[27099]={[0]='No Escape',[1]='B21 K0130 L011 A:-21,44365 T:44365 P:27097'},
[27100]={[0]='Twilight Research',[1]='B640 K0820 L081 A:100060816 T:0'},
[27101]={[0]="Maziel's Revelation",[1]='B640 K0820 L081 A:-640 T:1008599 P:27100'},
[27102]={[0]="Maziel's Ascendancy",[1]='B640 K0820 L081 A:1008599 T:0 P:27101'},
[27103]={[0]='Shards of the Felvine',[1]='B0 K0410 L038 A:44969 T:44969'},
[27104]={[0]='Alzzin the Wildshaper',[1]='B0 K0410 L038 A:44969 T:44969'},
[27105]={[0]='An Unwelcome Guest',[1]='B0 K0400 L038 A:44969 T:44969'},
[27106]={[0]='A Villain Unmasked',[1]='B0 FA K0840 L084 A:1008590 T:29611 P:27092'},
[27107]={[0]='Pusillin The Thief',[1]='B0 K0400 L038 A:44971 T:44971'},
[27108]={[0]="Lethtendris's Web",[1]='B0 K0400 L038 A:44971 T:44971'},
[27109]={[0]='The Warped Defender',[1]='B0 K0430 L041 A:44999 T:44999'},
[27110]={[0]='The Madness Within',[1]='B0 K0440 L041 A:14358 T:14358'},
[27111]={[0]="The Treasure of the Shen'dralar",[1]='B0 K0440 L041 A:14358 T:1179517'},
[27112]={[0]='The Cursed Remains',[1]='B0 K0430 L041 A:44991 T:44991'},
[27113]={[0]="The Shen'dralar Ancient",[1]='B0 K0430 L041 A:44991 T:14358'},
[27114]={[0]='The Gordok Taste Test',[1]='B0 K0460 FH L044 A:14322 T:14322'},
[27115]={[0]="Ando's Call",[1]='B35 FA K0180 L015 A:1073 T:44870 P:27078'},
[27116]={[0]='The Winds of Loch Modan',[1]='B35 FA K0180 L015 A:44870 T:1343 P:27115'},
[27117]={[0]='Brute Strength',[1]='B22 K0350 FH L034 A:44452 T:44452 P:26922'},
[27118]={[0]='A Broken Trap',[1]='B0 K0460 L042 A:1179485 T:1179485'},
[27119]={[0]='The Gordok Ogre Suit',[1]='B0 K0460 L042 A:14338 T:14338'},
[27120]={[0]='The Gordok Ogre Suit',[1]='B0 K0460 L042 A:14338 T:14338'},
--[27122]={[0]='Fired Up and Not So Good To Go.',[1]='K0800 FA L078 A:45009 T:42805'},
[27123]={[0]='Deepholm, Realm of Earth',[1]='B640 K0820 L081 A:45042 T:43065 P:27203 B640'},
[27124]={[0]='Unfinished Gordok Business',[1]='B0 K0470 L044 A:14325 T:14326'},
[27125]={[0]='King of the Gordok',[1]='B0 K0470 FA L044 A:45040 T:45040'},
[27126]={[0]='Rush Delivery',[1]='B640 K0830 L081 A:43169 T:45043 P:26625'},
--[27127]={[0]='Fired Up and Not So Good To Go.',[1]='K0800 FH L078 A:45046 T:45320'},
[27128]={[0]='King of the Gordok',[1]='B0 K0470 FH L044 A:45052 T:45052'},
[27129]={[0]='Saving Warpwood',[1]='B0 K0400 FA L038 A:40032 T:44969'},
[27130]={[0]='Saving Warpwood',[1]='B0 K0400 FH L038 A:7875 T:44969'},
[27131]={[0]='The Highborne',[1]='B0 K0420 FA L041 A:40032 T:44991'},
[27132]={[0]='The Highborne',[1]='B0 K0420 FH L041 A:7875 T:44991'},
[27133]={[0]='Eyes in the Sky',[1]='B0 K0460 FA L044 A:3936 T:45040'},
[27134]={[0]='Ogre in the Field',[1]='B0 K0460 FH L044 A:39656 T:45052'},
[27135]={[0]='Something that Burns',[1]='B640 K0820 L081 A:42574 T:42574 P:26409'},
[27136]={[0]='Elemental Energy',[1]='B640 K0820 L081 A:43397 T:43397'},
--[27137]={[0]="Earth Girls Aren't So Easy",[1]='K0800 FA L078 A:45009 T:42805'},
--[27138]={[0]="Earth Girls Aren't So Easy",[1]='K0800 FH L078 A:45046 T:45320'},
[27139]={[0]='Hobart Needs You',[1]='B0 K0070 FH RG A:36471 T:38120'},
[27140]={[0]="Alexi's Gambit",[1]='B0 K04364 L040 A:45110 T:45110'},
[27141]={[0]='Premature Explosionation',[1]='B720 K0830 L083 A:44860 T:45180 P:27993'},
[27142]={[0]='The Lich, Ras Frostwhisper',[1]='B0 K04364 L040 A:45110 T:45110'},
[27143]={[0]='Barov Family Fortune',[1]='B0 K04364 L040 A:45109 T:45109'},
[27144]={[0]='The Reckoning',[1]='B22 K0400 FH L038 A:44451 T:44451'},
[27145]={[0]='Plagued Hatchlings...For Now',[1]='B0 K04264 L040 A:45109 T:45109'},
[27146]={[0]='Doctor Theolen Krastinov, the Butcher',[1]='B0 K04364 L040 A:45107 T:45107'},
[27147]={[0]='Kirtonos the Herald',[1]='B0 K04364 L040 A:45107 T:45107'},
[27148]={[0]="School's Out Forever",[1]='B0 K04464 L040 A:45108 T:45108'},
[27150]={[0]="The Menders' Stead",[1]='B0 FH K0370 L035 T:44454 I:26952'}, -- TODO: Need the A: for this
[27151]={[0]="Taelan Fordring's Legacy",[1]='B22 K0370 L035 A:45147 T:-22,45147 P:27002'},
[27152]={[0]='Unusual Behavior... Even For Gnolls',[1]='B22 K0370 L035 A:-22,45147 T:-22,45147 P:27151'},
[27153]={[0]='The Good People of Hearthglen',[1]='B22 K0370 L035 A:-22,45147 T:-22,45147 P:27152'},
[27154]={[0]='Bagging Bisp',[1]='B22 K0370 L035 A:-22,45147 T:-22,45147 P:27153'},
[27155]={[0]='Turning Yourself In',[1]='B22 K0370 L035 A:-22,45147 T:44441 P:27154'},
[27156]={[0]="It's About Time!",[1]='B22 K0370 L035 A:45157 T:45157'},
[27157]={[0]='Drudges... <Sigh>',[1]='B22 K0370 L035 A:45157 T:45157 P:27156'},
[27158]={[0]='The Battle for Andorhal',[1]='B22 FA K0350 L034 A:10838 T:44453 I:27159,28505,28576,28749'},
[27159]={[0]='Scourge First... Horde Later',[1]='B22 FA K0350 L034 A:44453 T:44453 O:27158,28505,28576,28749'},
[27160]={[0]='War Machines',[1]='B22 FA K0350 L034 A:44471 T:44471'},
[27161]={[0]='The Endless Flow',[1]='B22 FA K0350 L034 A:44467 T:44467'},
[27162]={[0]='Scholomancer',[1]='B22 FA K0350 L034 A:44453 T:44453 P:27159+27160'},
[27163]={[0]='Brute Strength',[1]='B22 FA K0350 L034 A:44453 T:44453 P:27159+27160'},
[27164]={[0]='Araj the Summoner',[1]='B22 FA K0350 L034 A:44467 T:44453 P:27161'},
[27165]={[0]='Victory, For Now',[1]='B22 FA K0350 L034 A:44453 T:10838 P:27162+27163+27164'},
[27166]={[0]='Go Fletch!',[1]='B22 FA K0360 L034 A:10838 T:10838'},
[27167]={[0]='A Mighty Hunger',[1]='B22 FA K0360 L034 A:45165 T:45165'},
[27168]={[0]="Those That Couldn't Let Go",[1]='B22 FA K0360 L034 A:11053 T:11053 P:27166+27167'},
[27169]={[0]="Uther's Blessing",[1]='B22 FA K0360 L034 A:10838 T:1854 P:27166+27167'},
[27170]={[0]='The Abandoned Crypt',[1]='B22 FA K0360 L034 A:1854 T:1205258 P:27169'},
[27171]={[0]='Ambushed!',[1]='B22 FA K0360 L034 A:1205258 T:10838 P:27170'},
[27172]={[0]='The Writhing Haunt',[1]='B22 FA K0360 L034 A:10838 T:545165 P:27171'},
[27173]={[0]='This Is Our Army',[1]='B22 FA K0360 L034 A:545165 T:545165 P:27172'},
[27174]={[0]='Combat Training',[1]='B22 FA K0370 L034 A:545165 T:545165 P:27173'},
[27175]={[0]="The Menders' Stead",[1]='B22 FA K0370 L035 A:10840 T:44454 I:27233 P:27168'},
[27176]={[0]='Just the Tip',[1]='B720 K0830 L083 A:1205266 T:45180 P:27141'},
[27177]={[0]='Salvage Operation',[1]='B700 FA K0840 L084 A:45170 T:45170 P:28599'},
[27178]={[0]='Naga Reinforcements',[1]='B700 FA K0840 L084 A:45170 T:45170 P:28599'},
[27179]={[0]='Field Work',[1]='B720 K0830 L083 A:45186 T:45180 P:27141'},
[27180]={[0]='Honor the Dead',[1]='B21 K0130 FH L011 A:544365 T:544365 P:27098'},
[27181]={[0]='Excising the Taint',[1]='B21 FH K0130 L011 AK:45195 T:-21,544365 PL:27180'},
[27182]={[0]='The Hermit of Witch Hill',[1]='B141 K0360 FH L034 A:4501 T:4792'},
[27183]={[0]='Marsh Frog Legs',[1]='B141 K0360 L034 A:4792 T:4792 O:27215'}, -- P:27182 was totally wrong
[27184]={[0]='Jarl Needs Eyes',[1]='B141 K0360 L034 A:4792 T:4792 P:27183'},
[27185]={[0]='Cutting the Competition',[1]='B0 K0460 L044 A:45201 T:45201'},
[27186]={[0]='Jarl Needs a Blade',[1]='B141 K0360 L034 A:4792 T:4792 P:27184'},
[27187]={[0]='Do the World a Favor',[1]='B0 K0830 L083 AK:45202 T:0'},
[27188]={[0]="What's Haunting Witch Hill?",[1]='B141 K0360 L034 A:23843 T:23843'},
[27189]={[0]="The Witch's Bane",[1]='B141 K0360 L034 A:23843 T:23843 P:27188'},
[27190]={[0]='Cleansing Witch Hill',[1]='B141 K0360 L034 A:23843 T:23843 P:27189'},
[27191]={[0]='Hungry as an Ogre!',[1]='B141 K0360 L034 A:4792 T:4792 P:27184'},
[27192]={[0]='The Great Fras Siabi',[1]='B0 K0460 L044 A:45323 T:45323'},
[27193]={[0]='Seek and Destroy',[1]='B21 K0130 FH L011 A:-21,544365 T:-21,544365 P:27181'},
[27194]={[0]='Cornered and Crushed!',[1]='B21 K0130 FH L011 A:-21,544365 T:45228 P:27193'},
[27195]={[0]='Nowhere to Run',[1]='B21 K0130 FH L011 A:45228 T:544365 P:27194'},
[27196]={[0]='On to Something',[1]='B720 K0830 L083 A:45180 T:45296 P:27176+27179'},
[27197]={[0]='The Battle Resumes!',[1]='B22 FA K0400 L038 A:45012 T:544453 P:27175,27233'},
[27198]={[0]='Supporting the Troops',[1]='B22 FA K0400 L038 A:544467 T:544467 P:27197'},
[27199]={[0]='Ashes to Ashes',[1]='B22 FA K0400 L038 A:544453 T:544453 P:27197'},
[27200]={[0]="Siren's Song",[1]='B700 FA K0840 L084 A:45171 T:45171'},
[27201]={[0]="Val'kyr Incursion",[1]='B22 FA K0400 L038 A:544453 T:544453 P:27205'},
[27202]={[0]='Brother Against Brother',[1]='B22 FA K0400 L038 A:500020 T:500020 P:27205'},
[27203]={[0]='The Maelstrom',[1]='B0 K0820 L082 AA:45226 AH:45244 T:45042 P:27722,27727'},
[27204]={[0]='Aradne',[1]='B22 FA K0400 L038 A:544453 T:544453 P:27201+27202'},
[27205]={[0]='The Depravity of the Forsaken',[1]='B22 FA K0400 L038 A:544453 T:544453 P:27198+27199'},
[27206]={[0]='Alas, Andorhal',[1]='B22 FA K0400 L038 A:544453 T:10838 P:27204'},
[27207]={[0]='This Blows',[1]='B0 K0800 FA L078 A:42443 T:466'},
[27208]={[0]='The Dreadlord Balnazzar',[1]='B0 K0470 L044 A:45200 T:45200'},
[27209]={[0]='This Blows',[1]='B0 K0800 FH L078 A:42600 T:5769'},
[27210]={[0]='Traitors Among Us',[1]='B141 K0360 FA L034 A:23566 T:23566 O:26702,28552'},
[27211]={[0]='Propaganda War',[1]='B141 K0360 FA L034 A:23566 T:23566 P:27210'},
[27212]={[0]='Discrediting the Deserters',[1]='B141 K0360 FA L034 A:23566 T:23566 P:27211'},
[27213]={[0]='The End of the Deserters',[1]='B141 K0360 FA L034 A:23566 T:23566 P:27212'},
[27214]={[0]='A Disturbing Development',[1]='B141 K0360 FA L034 A:23951 T:5086 P:27213'},
[27215]={[0]='The Hermit of Swamplight Manor',[1]='B141 K0360 FA L034 A:23835 T:4792 P:27213 I:27183'},
[27216]={[0]='This Old Lighthouse',[1]='B141 K0360 FA L034 A:23835 T:23892'},
[27217]={[0]='Thresher Oil',[1]='B141 K0360 FA L034 A:23892 T:23892 P:27216'},
[27218]={[0]='Dastardly Denizens of the Deep',[1]='B141 K0360 FA L034 A:23892 T:23896 P:27217'},
[27219]={[0]='Is it Real?',[1]='B141 K0360 FA L034 A:23896 T:12919 P:27218'},
[27220]={[0]="Nat's Bargain",[1]='B141 K0370 FA L034 A:12919 T:12919 P:27219'},
[27221]={[0]="Oh, It's Real",[1]='B141 K0370 FA L034 A:12919 T:23905 P:27220'},
[27222]={[0]='Take Down Tethyr!',[1]='B141 K0370 FA L034 A:23905 T:23905 P:27221'},
[27223]={[0]='Retribution',[1]='B0 K0470 L044 A:45200 T:45200'},
[27225]={[0]='A Summons from Ander Germaine',[1]='B0 FA CW K0200 L020 A:4087,17120 T:914 I:27337'},
[27226]={[0]='Hair of the Dog',[1]='B21 K0130 FH L011 A:544917 T:544917 P:27098'},
[27227]={[0]='Lord Aurius Rivendare',[1]='B0 K0510 L048 A:45329 T:45329'},
[27228]={[0]='Man Against Abomination',[1]='B0 K0500 L048 A:45206 T:45206'},
[27229]={[0]='SMASH BROODQUEEN',[1]='B141 K0360 FH L034 A:1205332 T:4926'},
[27230]={[0]='Weapons for War',[1]='B0 K0500 L048 A:45331 T:45331'},
[27231]={[0]='Reinforcements from Fenris',[1]='B21 K0130 FH L011 A:544916 T:1205350 P:27098'},
[27232]={[0]='The Waters Run Red...',[1]='B21 K0130 FH L011 A:1205350 T:544916 P:27231'},
[27233]={[0]="The Menders' Stead",[1]='B22 FA K0370 L035 A:45165 T:44454 I:27175 P:27174'},
[27234]={[0]='Defias in Dustwallow?',[1]='B141 K0370 FA L034 A:5086 T:5086 O:27214'},
[27235]={[0]='Renn McGill',[1]='B141 K0370 FA L032 A:5086 T:23569 P:27234'},
[27236]={[0]='Secondhand Diving Gear',[1]='B141 K0370 FA L032 A:23569 T:23569 P:27235'},
[27237]={[0]='Recover the Cargo!',[1]='B141 K0370 FA L032 A:23569 T:23569 P:27236'},
[27238]={[0]='Jaina Must Know',[1]='B141 K0370 FA L034 A:23569 T:4968 P:27237'},
[27239]={[0]='Survey Alcaz Island',[1]='B141 K0370 FA L034 A:4968 T:4968 P:27238'},
[27240]={[0]='Proof of Treachery',[1]='B141 K0370 FA L034 A:4968 T:29611 P:27239'}, -- appears 40 seconds after completion of 27239
[27241]={[0]='Return to Jaina',[1]='B141 FA K0370 L032 A:29611 T:4968 P:27240 B141'},
[27242]={[0]='Raptor Captor',[1]='B141 K0370 FA L035 A:23723 T:23723'},
[27243]={[0]='Unleash the Raptors',[1]='B141 K0370 FA L035 A:23723 T:23723 P:27242'},
[27244]={[0]='The Lost Report',[1]='B141 K0360 FH L034 A:1020985 T:4791'},
[27245]={[0]='Prisoners of the Grimtotems',[1]='B141 K0370 FA L035 A:23723 T:23723 P:27242'},
[27246]={[0]='The Orc Report',[1]='B141 K0360 FA L034 A:1020985 T:23951'},
[27247]={[0]='Captain Vimes',[1]='B141 K0360 FA L034 A:23951 T:4944 P:27246'},
[27248]={[0]='Mission to Mudsprocket',[1]='B141 K0390 FA L037 A:23951 T:23572'},
[27249]={[0]='Inspecting the Ruins',[1]='B141 K0370 FA L035 A:4944 T:23567 O:27251'},
[27251]={[0]='They Call Him Smiling Jim',[1]='B141 K0370 FA L035 A:4921 T:4944 I:27249'},
[27252]={[0]='The Black Shield',[1]='B141 K0370 FA L035 A:1020992 T:4944 P:27249'},
[27253]={[0]='Inspecting the Ruins',[1]='B141 K0370 FH L035 A:4926 T:23567'},
[27254]={[0]='The Black Shield',[1]='B141 K0350 FH L030 A:1020992 T:4926'},
[27255]={[0]='The Black Shield',[1]='B141 K0370 FH L035 A:4926 T:5087 P:27254'},
[27256]={[0]='The Black Shield',[1]='B141 K0370 FH L035 A:5087 T:5087 P:27255'},
[27257]={[0]='The Black Shield',[1]='B141 K0370 FH L035 A:5087 T:4926 P:27256'},
[27258]={[0]='The Black Shield',[1]='B141 K0370 FH L035 A:4926 T:4943'},
[27259]={[0]='Suspicious Hoofprints',[1]='B141 K0370 FH L035 A:1187273 T:4926'},
[27260]={[0]='Lieutenant Paval Reethe',[1]='B141 K0370 FH L035 A:1021042 T:4926'},
[27261]={[0]='Questioning Reethe',[1]='B141 K0370 FH L035 A:4983 T:4926 P:27306'},
[27262]={[0]='Suspicious Hoofprints',[1]='B141 K0370 FA L035 A:1187273 T:4944 P:27249'},
[27263]={[0]='Lieutenant Paval Reethe',[1]='B141 K0370 FA L035 A:1021042 T:4944 P:27249'},
[27264]={[0]='Lieutenant Paval Reethe',[1]='B141 K0370 FA L035 A:4944 T:4948 P:27263'},
[27265]={[0]='Lord Grayson Shadowbreaker',[1]='B0 FA RF RD RH CP K020 L020 A:5147,16761,35281 T:928 I:27343'},
[27266]={[0]='Wulf Calls',[1]='B0 FA CH K0200 L020 A:4138,5115,17122 T:44247 I:27344'},
[27267]={[0]='Make Contact with SI:7',[1]='B0 FA CR K0200 L020 A:4214,5165 T:918 I:27351'},
[27268]={[0]='Make Haste to the Cathedral',[1]='B0 FA CT RH RF RD RW K0200 L020 A:11401,11406,16756 T:376 I:27361'},
[27269]={[0]='The Temple of the Moon',[1]='B0 FA RE CT K0200 L020 A:11401,11406 T:7999 I:27362'},
[27270]={[0]='An Audience with the Farseer',[1]='B0 FA RF RD CS K0200 L020 A:23127 T:20407 I:27353'},
[27271]={[0]="Journey to the Wizard's Sanctum",[1]='B0 FA CM K020 L020 A:5146,16749,50690 T:331 I:27354'},
[27272]={[0]='Demisette Sends Word',[1]='B0 FA CL K0200 L020 A:5173 T:461 I:27355'},
[27273]={[0]='An Invitation from Moonglade',[1]='B0 FA RE RW CD K0200 L020 A:4217,5504,16721,44395 T:12042 I:27356'},
[27274]={[0]='The Chief Surgeon',[1]='B0 FA RN CT K0200 L020 A:11406 T:45306 I:27363'},
[27275]={[0]='Together Again',[1]='B61 FA K0420 L038 A:41444 T:45277 P:25871'},
[27276]={[0]='Together Again',[1]='B61 K0420 FH L038 A:41421 T:45278 P:25872'},
[27277]={[0]='An Audience with Ureda',[1]='B0 K0200 FH CM L020 A:3047,4566,16653 T:47246 I:27400'},
[27278]={[0]="Grimshot's Call",[1]='B0 K0200 FH CH L020 A:3039,16674,39116 T:3352 I:27395'},
[27279]={[0]='The Shattered Hand',[1]='B0 K0200 FH CR L020 A:4584,16684 T:47233 I:27396'},
[27280]={[0]='The Dreamseeker Calls',[1]='B0 K0200 FH CS L020 A:3032 T:3344 I:27397'},
[27281]={[0]='Grezz Ragefist',[1]='B0 K0200 FH CW L020 A:3042,4593,43009 T:3353 I:27365'},
[27282]={[0]="Zevrost's Behest",[1]='B0 K0200 FH CL L020 A:4563,16648,43881 T:3326 I:27402'},
[27283]={[0]='A Journey to Moonglade',[1]='B0 K0200 FH RT RL CD L020 A:3034,44726,44978 T:12042 I:27404'},
[27284]={[0]='The Black Shield',[1]='B141 K0370 FA L035 A:4944 T:4941 P:27252'},
[27285]={[0]='The Black Shield',[1]='B141 K0370 FA L035 A:4941 T:4944 P:27284'},
[27286]={[0]="Daelin's Men",[1]='B141 K0370 FA L035 A:4948 T:4944 P:27264'},
[27287]={[0]='The Deserters',[1]='B141 K0370 FA L035 A:4944 T:5089 P:27286'},
[27288]={[0]='The Deserters',[1]='B141 K0370 FA L035 A:5089 T:4944 P:27287'},
[27290]={[0]='To Forsaken Forward Command',[1]='B21 K0140 FH L012 A:544365 T:45312 P:23732+27180+27195+27226'},
[27291]={[0]='Peace at Last',[1]='B141 K0390 FA L030 A:4944 T:4944 P:27430'},
[27292]={[0]='Return to Krog',[1]='B141 K0370 FH L034 A:4943 T:4926 P:27258'},
[27293]={[0]='The Grimtotem Plot',[1]='B141 K0380 FH L035 A:4926 T:4926'},
[27294]={[0]='More than Coincidence',[1]='B141 K0370 FH L035 A:4926 T:4926'},
[27295]={[0]='Seek Out Tabetha',[1]='B141 K0380 FH L036 A:4926 T:6546'},
[27296]={[0]='Raze Direhorn Post!',[1]='B141 K0380 FH L036 A:6546 T:6546 P:27295'},
[27297]={[0]='Justice Dispensed',[1]='B141 K0380 FH L036 A:6546 T:4926 P:27296'},
[27298]={[0]='Seek Out Master Pyreanor',[1]='B0 K0200 FH RB CP L020 A:16681,20406,43795 T:23128 I:27434'},
[27299]={[0]='Torn Ground',[1]='B700 K0840 L084 A:45332 T:45332 P:27374,27375'},
[27300]={[0]='Pushing Back',[1]='B700 K0840 L084 A:45332 T:45332 P:27299'},
[27301]={[0]='Unbroken',[1]='B700 K0840 L084 A:45391 T:45362 P:27299'},
[27302]={[0]='Simple Solutions',[1]='B700 K0840 L084 A:45432 T:45432 P:27299'},
[27303]={[0]='Mercy for the Bound',[1]='B700 K0840 L084 A:45362 T:45386 P:27301'},
[27304]={[0]='Follow the Sun',[1]='B0 K0200 FH RT CP L020 A:20406,43795 T:44725 I:27403'},
[27305]={[0]='Of Love and Family',[1]='B0 K0460 L044 A:45200 T:45200'},
[27306]={[0]='Talk to Ogron',[1]='B141 K0370 FH L035 A:4926 T:4983'},
--[27307]={[0]='The Elements Cry Out',[1]='FA A:45341,45946 T:45702'},
--[27308]={[0]='The Elements Cry Out',[1]='FH A:45343 T:39283'},
[27310]={[0]='No Weapons For You!',[1]='B61 FA K0420 L038 A:45277 T:545277 P:27275'},
[27311]={[0]='No Weapons For You!',[1]='B61 K0420 FH L038 A:45278 T:545278 P:27276'},
[27312]={[0]='Darkcloud Grimtotem',[1]='B61 FA K0420 L038 A:45277 T:545277 P:27275'},
[27313]={[0]='Darkcloud Grimtotem',[1]='B61 K0420 FH L038 A:45278 T:545278 P:27276'},
[27314]={[0]='Grimtotem Chiefs: Isha Gloomaxe',[1]='B61 FA K0420 L038 A:45277 T:545277 P:27275'},
[27315]={[0]='Grimtotem Chiefs: Isha Gloomaxe',[1]='B61 K0420 FH L038 A:45278 T:545278 P:27276'},
[27316]={[0]='The Rattle of Bones',[1]='B61 FA K0420 L038 A:48208 T:545277 O:28283 P:27275'},
[27317]={[0]='The Rattle of Bones',[1]='B61 K0420 FH L038 A:48208 T:545278 O:28284 P:27276'},
[27318]={[0]='Grimtotem Chiefs: Elder Stormhoof',[1]='B61 FA K0420 L038 A:545277 T:545277 P:27314'},
[27319]={[0]='Grimtotem Chiefs: Elder Stormhoof',[1]='B61 K0420 FH L038 A:545278 T:545278 P:27315'},
[27320]={[0]='The Writ of History',[1]='B61 FA K0420 L038 A:545277 T:545277 P:27316'},
[27321]={[0]='The Writ of History',[1]='B61 K0420 FH L038 A:545278 T:545278 P:27317'},
[27322]={[0]='Korok the Colossus',[1]='B21 K0150 FH L012 A:100060956 T:45315'},
[27323]={[0]='Grimtotem Chiefs: Grundig Darkcloud',[1]='B61 FA K0420 L038 A:545277 T:545277 P:27318'},
[27324]={[0]='Grimtotem Chiefs: Grundig Darkcloud',[1]='B61 K0420 FH L038 A:545278 T:545278 P:27319'},
[27325]={[0]='The Drums of War',[1]='B61 FA K0420 L038 A:545277 T:545277 P:27316'},
[27326]={[0]='The Drums of War',[1]='B61 K0420 FH L038 A:545278 T:545278 P:27317'},
[27327]={[0]='Grimtotem Chiefs: The Chief of Chiefs',[1]='B61 FA K0430 L038 A:545277 T:545277 P:27323'},
[27328]={[0]='Grimtotem Chiefs: The Chief of Chiefs',[1]='B61 K0430 FH L038 A:545278 T:545278 P:27324'},
[27329]={[0]='Invoking the Serpent',[1]='B61 FA K0430 L038 A:45442 T:45442 P:27357'},
[27330]={[0]='Invoking the Serpent',[1]='B61 K0430 FH L038 A:45442 T:45442 P:27358'},
[27331]={[0]="The Seer's Call",[1]='B0 K0200 FH CT RT L020 A:4606,43870 T:44735 I:27435'},
[27332]={[0]='Seek the Shadow-Walker',[1]='B0 K0200 FH CT RL L020 A:3045,4606,16658 T:45137 I:27436'},
[27333]={[0]='Losing Ground',[1]='B21 K0140 FH L012 A:45315 T:45315 P:27290'},
[27334]={[0]='Dark Cleric Cecille',[1]='B0 K0200 FH RU CT L020 A:3045,4606,16658 T:45339 I:27437'},
[27335]={[0]='Journey to Orgrimmar',[1]='B0 K0200 FH RB CT L020 A:16658,43870 T:45337 I:27439'},
[27336]={[0]='The Grimtotem Weapon',[1]='B141 K0380 L036 A:23601 T:23601'},
[27337]={[0]='A Fitting Weapon',[1]='B0 FA CW K02064 L020 A:914 T:5511 O:27225'},
[27338]={[0]='Our Boys on the Shore',[1]='B700 FA K0840 L084 A:45167 T:45169 P:28599'},
[27339]={[0]='The Reagent Thief',[1]='B141 K0380 L036 A:23601 T:23601'},
[27340]={[0]='Direhorn Raiders',[1]='B141 K0380 L036 A:23600 T:23600'},
[27341]={[0]='Scouting the Shore',[1]='B700 FA K0840 L084 A:45169 T:45169 P:27338'},
[27342]={[0]='In Time, All Will Be Revealed',[1]='B21 K0140 FH L012 A:45312 T:45312 P:27290'},
[27343]={[0]='The Hand of the Light',[1]='B0 FA RF RD RH CP K02064 L020 A:928 T:5511 O:27265'},
[27344]={[0]='A Well-Earned Reward',[1]='B0 FA CH K02064 L020 A:44247 T:1298 O:27266'},
[27345]={[0]='The F.C.D.',[1]='B21 K0140 FH L012 A:45315 T:45315 P:27290'},
[27346]={[0]='The Zeppelin Crash',[1]='B141 K0380 L036 A:23600 T:23797'},
[27347]={[0]='Corrosion Prevention',[1]='B141 K0380 L036 A:23797 T:23797'},
[27348]={[0]='Secure the Cargo!',[1]='B141 K0380 L036 A:23797 T:23797'},
[27349]={[0]='Break in Communications: Dreadwatch Outpost',[1]='B21 K0140 FH L012 A:45315 T:45315 P:27333+27345'},
[27350]={[0]="Break in Communications: Rutsak's Guard",[1]='B21 K0140 FH L012 A:-21,45315 T:45389 P:27349'},
[27351]={[0]='A Royal Reward',[1]='B0 FA CR K02064 L020 A:13283 T:5511 O:27267'},
[27352]={[0]='Liquid Gold',[1]='B0 K0500 L048 A:45328 T:45328'},
[27353]={[0]='Blessings of the Elements',[1]='B0 FA RF RD CS K02064 L020 A:20407 T:5511 O:27270'},
[27354]={[0]='Mastering the Arcane',[1]='B0 FA CM K02064 L020 A:331 T:1317 O:27271'},
[27355]={[0]='A Boon for the Powerful',[1]='B0 FA RN RW CL K02064 L020 A:461 T:1317 O:27272'},
[27356]={[0]="The Circle's Future",[1]='B0 FA RE RW CD K02064 L020 A:12042 T:12029 O:27273'},
[27357]={[0]='The Captive Bride',[1]='B61 FA K0430 L038 A:545277 T:45442 P:27327+27325+27320'},
[27358]={[0]='The Captive Bride',[1]='B61 K0430 FH L038 A:545278 T:45442 P:27328+27326+27321'},
[27359]={[0]='Argent Reinforcements',[1]='B0 K0500 L048 A:45330 T:45330'},
[27360]={[0]='Vengeance for Our Soldiers',[1]='B21 K0150 FH L012 A:45389 T:45389 P:27350'},
[27361]={[0]='Favored of the Light',[1]='B0 FA CT RH RF RD RW K02064 L020 A:376 T:1317 O:27268'},
[27362]={[0]='Favored of Elune',[1]='B0 FA CT RE K02064 L020 A:7999 T:1317 O:27269'},
[27363]={[0]='A Budding Young Surgeon',[1]='B0 FA CT RN K02064 L020 A:45306 T:1317 O:27274'},
[27364]={[0]='On Whose Orders?',[1]='B21 FH K0150 L012 A:-21,45315 T:-21,45315'},
[27365]={[0]='A Fitting Weapon',[1]='B0 K0200 FH CW L020 A:3353 T:3355 O:27281'},
[27366]={[0]='Landgrab',[1]='B700 FA K0840 L084 A:45169 T:45169 P:27341 P:27338'},
[27367]={[0]='Gidwin Goldbraids',[1]='B23 K0400 L039 A:45417 T:45428'},
[27368]={[0]='Just Encased',[1]='B23 K0400 L039 A:45428 T:45428 P:27367'},
[27369]={[0]='Greasing the Wheel',[1]='B23 K0400 L039 A:45431 T:45417 P:27368'},
[27370]={[0]='Tarenar Sunstrike',[1]='B23 K0400 L039 A:45417 T:45429'},
[27371]={[0]='What I Do Best',[1]='B23 K0400 L039 A:45429 T:45429 P:27370'},
[27372]={[0]='A Gift For Fiona',[1]='B23 K0400 L039 A:45429 T:45417'},
[27373]={[0]="Onward, to Light's Hope Chapel",[1]='B0 K0400 L039 A:45417 T:45417 P:27369+27372'},
[27374]={[0]='The Maw of Madness',[1]='B700 FA K0840 L084 A:49374 T:45332 P:28655'},
[27375]={[0]='The Weeping Wound',[1]='B700 FH K0840 L084 A:46324 T:45332 P:27374'},
[27376]={[0]="The Maw of Iso'rath",[1]='B700 K0840 L084 A:45332 T:47991 P:27300+27302+27303'},
[27377]={[0]='Devoured',[1]='B700 K0840 L084 A:47991 T:48051 P:27376'},
[27378]={[0]='The Worldbreaker',[1]='B700 K0840 L084 A:48051 T:48059 P:27377'},
[27379]={[0]="The Terrors of Iso'rath",[1]='B700 K0840 L084 A:48059 T:48059 P:27378'},
[27380]={[0]='Nightmare',[1]='B700 K0850 L084 A:48059 T:45332 P:27379'},
[27381]={[0]='Traveling Companions',[1]='B23 K0410 L039 A:45429 T:45429 P:27383'},
[27382]={[0]='Rough Roads',[1]='B23 K0410 L039 A:45451 T:45451 PL:27381'},
[27383]={[0]='Little Pamela',[1]='B23 K0410 L039 A:11063 T:10926'},
[27384]={[0]="Pamela's Doll",[1]='B23 K0410 L039 A:10926 T:10926 O:27383'},
[27385]={[0]='Uncle Carlin',[1]='B23 K0410 L039 A:10926 T:11063 P:27384+27392'},
[27386]={[0]='A Strange Historian',[1]='B23 K0410 L039 A:11063 T:10667 P:27385'},
[27387]={[0]='Villains of Darrowshire',[1]='B23 K0410 L039 A:10667 T:10667 P:27386'},
[27388]={[0]='Heroes of Darrowshire',[1]='B23 K0410 L039 A:10667 T:10667 P:27386'},
[27389]={[0]='Marauders of Darrowshire',[1]='B23 K0410 L039 A:10667 T:10667 P:27386'},
[27390]={[0]='The Battle of Darrowshire',[1]='B23 K0410 L039 A:10667 T:10926 P:27387+27388+27389'},
[27391]={[0]='Hidden Treasures',[1]='B23 K0410 L039 A:10926 T:1177544 P:27390'},
[27392]={[0]="I'm Not Supposed to Tell You This",[1]='B23 K0410 L039 A:10926 T:10926 O:27383'},
[27393]={[0]='The Call of the Blade',[1]='FA K0810 L080 A:39881 T:1202714 P:25580'},
[27394]={[0]='The Call of the Blade',[1]='FH K0810 L080 A:40919 T:1203140'},
[27395]={[0]="A Marksman's Weapon",[1]='B0 K0200 FH CH L020 A:3352 T:3355 O:27278'},
[27396]={[0]='Blade of the Shattered Hand',[1]='B0 K0200 FH CR L020 A:47233 T:3355 O:27279'},
[27397]={[0]="Dreamseeker's Task",[1]='B0 K0200 FH CS L020 A:3344 T:3355 O:27280'},
[27398]={[0]='The Battle Is Won, The War Goes On',[1]='B0 FA K0820 L082 A:540772 T:45226 P:25551'},
[27399]={[0]='The Battle Is Won, The War Goes On',[1]='B0 FH K0820 L082 A:540772 T:45244 P:25551'},
[27400]={[0]='Mastering the Arcane',[1]='B0 K0200 FH CM L020 A:47246 T:3345 O:27277'},
[27401]={[0]='What Tomorrow Brings',[1]='B21 K0150 L012 FH A:-21,45315 T:-21,45315 P:27364'},
[27402]={[0]='Token of Power',[1]='B0 K0200 FH CL L020 A:3326 T:3345 O:27282'},
[27403]={[0]='A True Sunwalker',[1]='B0 K0200 FH RT CP L020 A:44725 T:3355 O:27304'},
[27404]={[0]="The Circle's Future",[1]='B0 K0200 FH RT RL CD L020 A:12042 T:12029 O:27283'},
[27405]={[0]='Fall Back!',[1]='B21 K0150 FH L012 A:-21,45315 T:545312 P:27401'},
[27406]={[0]='A Man Named Godfrey',[1]='B21 K0160 FH L013 A:545312 T:545474 P:27405'},
[27407]={[0]='Bloodfen Feathers',[1]='B141 K0390 L036 A:23579 T:23579'},
[27408]={[0]='Banner of the Stonemaul',[1]='B141 K0390 L036 A:23579 T:23579 P:27407'},
[27409]={[0]='The Essence of Enmity',[1]='B141 K0390 L036 A:23579 T:23579 P:27407'},
[27410]={[0]='Spirits of Stonemaul Hold',[1]='B141 K0390 L036 A:23579 T:23579 P:27408+27409'},
[27411]={[0]='Challenge to the Black Flight',[1]='B141 K0390 L036 A:23579 T:23579 P:27410'},
[27412]={[0]='WANTED: Goreclaw the Ravenous',[1]='B141 K0390 L036 A:1186426 T:23572'},
[27413]={[0]='Catch a Dragon by the Tail',[1]='B141 K0390 L036 A:23570 T:23570'},
[27414]={[0]='Identifying the Brood',[1]='B141 K0390 FH L036 A:4501 T:4501'},
[27415]={[0]='The Brood of Onyxia',[1]='B141 K0390 FH L036 A:4501 T:4501 P:27417'},
[27416]={[0]='The Brood of Onyxia',[1]='B141 K0390 FH L036 A:4501 T:4500'},
[27417]={[0]='The Brood of Onyxia',[1]='B141 K0390 FH L037 A:4500 T:4501'},
[27418]={[0]="Challenge Overlord Mok'Morokk",[1]='B141 K0390 FH L037 A:4500 T:4501'},
[27420]={[0]='Postponing the Inevitable',[1]='B23 K0410 L039 A:16135 T:16135 O:27544'},
[27421]={[0]='Amidst Death, Life',[1]='B23 K0410 L039 A:16135 T:16135'},
[27422]={[0]='A City Under Siege',[1]='B504956 K0450 L044 A:45482 T:45323'},
[27423]={[0]='Resistance is Futile',[1]='B0 FH K0160 L013 A:-21 T:45474 PL:27406'},
[27424]={[0]="Overlord Mok'Morokk's Concern",[1]='B141 K0390 FH L037 A:4500 T:4500'},
[27425]={[0]='A Grim Connection',[1]='B141 K0380 FA L035 A:4944 T:23568 P:27262+27285+27288'},
[27426]={[0]='Confirming the Suspicion',[1]='B141 K0380 FA L035 A:23568 T:23568 P:27425'},
[27427]={[0]='Arms of the Grimtotems',[1]='B141 K0380 FA L035 A:23568 T:23568 P:27425'},
[27428]={[0]="Tabetha's Assistance",[1]='B141 K0380 FA L036 A:23568 T:6546 P:27426+27427'},
[27429]={[0]='Raze Direhorn Post!',[1]='B141 K0380 FA L036 A:6546 T:6546 P:27428'},
[27430]={[0]='Justice for the Hyals',[1]='B141 K0380 FA L036 A:6546 T:4944 P:27429'},
[27431]={[0]='Tipping the Balance',[1]='B720 K0830 L083 A:45296 T:45296 P:27549'},
[27432]={[0]='Zaeldarr the Outcast',[1]='B23 K0410 L039 A:45500 T:45500'},
[27433]={[0]='Shredderectomy',[1]='B700 FA K0840 L084 A:45168 T:45168 P:27338'},
[27434]={[0]="The Adept's Path",[1]='B0 K0200 FH RB CP L020 A:23128 T:3355 O:27298'},
[27435]={[0]="A Seer's Staff",[1]='B0 K0200 FH CT RT L020 A:44735 T:3345 O:27331'},
[27436]={[0]="The Shadow-Walker's Task",[1]='B0 K0200 FH RL CT L020 A:45137 T:3345 O:27332'},
[27437]={[0]="The Dark Cleric's Bidding",[1]='B0 K0200 FH RU CT L020 A:45339 T:3345 O:27334'},
[27438]={[0]='The Great Escape',[1]='B21 K0160 FH L013 A:500026 T:45525 P:27406'},
[27439]={[0]='Staff of the Light',[1]='B0 K0200 FH RB CT L020 A:45337 T:3345 O:27335'},
[27440]={[0]='Trolls, Ogres, and Orcs, Oh My!',[1]='B0 K0590 L057 A:10299 T:10299'},
[27441]={[0]="A Seer's Staff",[1]='B0 K0200 FH RG CT L020 A:45347 T:3345 O:28164'},
[27442]={[0]='The War Has Many Fronts',[1]='B0 FH K0820 L082 A:45460 T:45244'},
[27443]={[0]='The War Has Many Fronts',[1]='B0 FA K0820 L082 A:45462 T:45226'},
[27444]={[0]='The False Warchief',[1]='B0 K0590 L057 A:10299 T:10299'},
[27445]={[0]='General Drakkisath, Hand of Nefarian',[1]='B0 K0600 L057 A:10299 T:10299'},
[27446]={[0]='Tanaris is Calling',[1]='B161 FA K0430 L043 A:40027 T:38535 I:25048,28507 B161'},
[27447]={[0]='Tanaris is Calling',[1]='B161 K0430 FH L043 A:40028 T:38534 B161'},
[27448]={[0]='The Trek Continues',[1]='B23 K0420 L039 A:45417 T:45417 P:27382'},
[27449]={[0]='Honor and Strength',[1]='B23 K0420 L039 A:45574 T:45574 P:27432'},
[27450]={[0]="Frederick's Fish Fancy",[1]='B23 K0420 L039 A:45575 T:45575'},
[27451]={[0]='To Kill With Purpose',[1]='B23 K0420 L039 A:11035 T:11035'},
[27452]={[0]='Dark Garb',[1]='B23 K0420 L039 A:11035 T:11035'},
[27453]={[0]='Catalysm',[1]='B23 K0420 L039 A:11035 T:11035 P:27451+27452'},
[27454]={[0]='Just a Drop in the Bucket',[1]='B23 K0420 L039 A:11035 T:11035 P:27453'},
[27455]={[0]='Boys Will Be Boys',[1]='B23 K0420 L039 A:45417 T:45431 P:27448'},
[27456]={[0]='Gathering Some Grub(s)',[1]='B23 K0420 L039 A:16134 T:16134'},
[27457]={[0]='An Opportune Alliance',[1]='B23 K0420 L039 A:16134 T:45417 P:27456+27465+27467'},
[27458]={[0]='Smokey and the Bandage',[1]='B23 K0420 L039 A:11033 T:11033'},
[27459]={[0]='The Brotherhood of Light',[1]='B23 K0420 L039 A:11036 T:16116'},
[27460]={[0]='Soft Landing',[1]='B23 K0420 L039 A:16116 T:1205875 P:27459'},
[27461]={[0]='To Take the Abbey',[1]='B23 K0420 L039 A:1205875 T:16115 P:27460'},
[27462]={[0]='To Take the Barracks',[1]='B23 K0420 L039 A:1205875 T:16112 P:27460'},
[27463]={[0]='A Boyhood Dream',[1]='B23 K0420 L039 A:45431 T:11034 P:27455'},
[27464]={[0]='Argent Call: The Trial of the Crypt',[1]='B23 K0420 L039 A:11034 T:11034 P:27463'},
[27465]={[0]='Argent Call: The Noxious Glade',[1]='B23 K0420 L039 A:11034 T:11034 P:27464'},
[27466]={[0]='Argent Call: Northdale',[1]='B23 K0430 L039 A:45729 T:45417 P:27465+27467'},
[27467]={[0]='Buried Blades',[1]='B23 K0420 L039 A:16365 T:16365 P:27464'},
[27468]={[0]='Siege Tank Rescue',[1]='B700 FA K0840 L084 A:45168 T:45168 P:27433'},
[27469]={[0]='Friends on The Other Side',[1]='B0 K0580 L057 A:9563 T:10299'},
[27470]={[0]='A Potential Ally',[1]='B504956 K0580 L057 A:14625,514625 T:10299'},
[27471]={[0]='Blackrock Anomaly',[1]='B0 FA K05864 L057 A:9562 T:10299'},
[27472]={[0]='Rise, Godfrey',[1]='B21 K0160 FH L013 A:45525 T:45617 P:27438'},
--[27473]={[0]="What's Shaking in Ironforge",[1]='FA K0800 A:45341,45945 T:45712'},
[27474]={[0]='Breaking the Barrier',[1]='B21 K0170 FH L014 A:45617 T:45617 P:27472'},
[27475]={[0]='Unyielding Servitors',[1]='B21 K0170 FH L014 A:45626 T:45626 P:27472'},
[27476]={[0]='Dalar Dawnweaver',[1]='B21 K0180 FH L014 A:45617 T:1938 P:27474+27475'},
[27477]={[0]='The Corpulent One',[1]='B23 K0430 L039 A:45735 T:45735'},
[27478]={[0]='Relios the Relic Keeper',[1]='B0 K0180 FH L014 A:1938 T:1938 P:27476'},
[27479]={[0]='Righteous Indignation',[1]='B23 K0430 L039 A:45736 T:45736'},
[27480]={[0]='Ley Energies',[1]='B0 K0180 FH L014 A:100061310 T:1938 PLT:27483'},
[27481]={[0]='Out of the Ziggurat',[1]='B23 K0430 L039 A:45574 T:45574 P:27449'},
[27482]={[0]='Into the Flames',[1]='B0 K0430 L039 A:-23,45574 P:27465+27481'},
[27483]={[0]='Practical Vengeance',[1]='B0 K0180 FH L014 A:1938 T:1938 P:27476'},
[27484]={[0]='Only One May Enter',[1]='B0 K0180 FH L014 A:1938 T:45617 P:27478'},
[27485]={[0]='Warm Welcome',[1]='B700 FA K0850 L084 A:48265 T:45528 P:27380'},
[27486]={[0]='Warm Welcome',[1]='B700 FH K0850 L084 A:48264 T:45528 P:27485'},
[27487]={[0]="Ix'lar the Underlord",[1]='B23 K0430 L039 A:45729 T:45417 P:27466'},
[27488]={[0]='Impatience',[1]='B23 K0430 L039 A:45729 T:45729 P:27487'},
[27489]={[0]='Nobody to Blame but Myself',[1]='B23 K0430 L039 A:45729 T:45729 P:27488'},
[27490]={[0]='SI:7 Drop',[1]='B700 FA K0850 L084 A:45669 T:45669 P:28248'},
[27491]={[0]="Kor'kron Drop",[1]='B700 FH K0850 L084 A:45665 T:45665'},
[27492]={[0]='Ogres & Ettins',[1]='B700 FA K0850 L084 A:45668 T:45668 P:28248'},
[27493]={[0]='Ogres & Ettins',[1]='B700 FH K0850 L084 A:45658 T:45658 P:28249'},
[27494]={[0]='Move the Mountain',[1]='B0 FA K0850 L084 A:45668 T:0 P:27490+27492+27496'},
[27495]={[0]='Move the Mountain',[1]='B0 FH K0850 L084 A:45658 T:0 P:27491+27493+27497'},
[27496]={[0]='Call in the Artillery',[1]='B700 FA K0850 L084 A:45669 T:45669 P:28248'},
[27497]={[0]='Call in the Artillery',[1]='B700 FH K0850 L084 A:45665 T:45665'},
[27498]={[0]='Signal the Attack',[1]='B0 FA K0850 L084 A:-700 T:0 P:27494'},
[27499]={[0]='Signal the Attack',[1]='B0 FH K0850 L084 A:-700 T:0 P:27495'},
[27500]={[0]='Four Heads are Better than None',[1]='B700 FA K0850 L084 A:-700 T:45669 P:27498'},
[27501]={[0]='Four Heads are Better than None',[1]='B700 FH K0850 L084 A:-700 P:27499'},
[27502]={[0]='Up to the Citadel',[1]='B0 FA K0850 L084 A:45669 T:0 P:27500'},
[27503]={[0]='Up to the Citadel',[1]='B0 FH K0850 L084 A:45665 P:27501'},
[27504]={[0]='Even Dragons Bleed',[1]='B700 K0850 L084 A:45528 T:45522 P:27485,27486'},
[27505]={[0]='Draconic Mending',[1]='B700 K0850 L084 A:45522 T:45522 P:27504'},
[27506]={[0]='Life from Death',[1]='B700 K0850 L084 A:45562 T:45562 P:27504'},
[27507]={[0]='Encroaching Twilight',[1]='B700 K0850 L084 A:45528 T:45528 P:27564'},
[27508]={[0]='Far from the Nest',[1]='B700 K0850 L084 A:45518 T:45518 P:27564'},
[27509]={[0]='Breach in the Defenses',[1]='B700 K0850 L084 A:45528 T:45528 P:27564'},
[27510]={[0]="A Wolf in Bear's Clothing",[1]='B21 K0180 FH L014 A:45631 T:45631,46125 P:27542'},
[27511]={[0]='The Thrill of Discovery',[1]='B720 K0830 L083 A:45296 T:0 P:27196'},
[27512]={[0]='Transdimensional Warfare: Chapter I',[1]='B21 K0180 FH L014 A:45617 T:45752 P:27484'},
[27513]={[0]='Transdimensional Warfare: Chapter II',[1]='B21 K0180 L014 A:-21,45752 T:-21,45617 P:27512'},
[27514]={[0]='Bird Down! Bird Down!',[1]='B700 FA K0840 L084 A:45169 T:45172 P:27341,27366'},
[27515]={[0]="Roots'll Do 'Er",[1]='B700 FA K0840 L084 A:45172 T:45172 P:27514'},
[27516]={[0]='Wings Over Highbank',[1]='B700 FA K0840 L084 A:45172 T:45167 P:27515'},
[27517]={[0]='Be Prepared',[1]='B720 K0830 L083 A:1205540 T:45296'},
[27518]={[0]='Transdimensional Warfare: Chapter III',[1]='B21 FH K0190 L014 A:-21,45617 T:45617 P:27513'},
[27519]={[0]='Under the Choking Sands',[1]='B720 K0830 L083 A:45772 T:45772 P:28135'},
[27520]={[0]="Minions of Al'Akir",[1]='B720 K0830 L083 A:45799 T:45799 P:28135'},
[27521]={[0]='Wretched Hive of Scum and Villainy',[1]='B23 K0440 L039 A:45826 T:45826'},
[27522]={[0]='Beat it Out of Them',[1]='B23 K0440 L039 A:45729 T:45417 P:27489'},
[27523]={[0]='Duskwing, Oh How I Hate Thee...',[1]='B23 K0440 L039 A:45816 T:45816'},
[27524]={[0]='Blind Fury',[1]='B23 K0440 L039 A:45417 T:45729 P:27522'},
[27525]={[0]='Guardians of Stratholme',[1]='B23 K0450 L039 A:45729 T:45729 P:27524'},
[27526]={[0]="Gidwin's Fate Revealed",[1]='B23 K0450 L039 A:45729 T:45730 P:27551'},
[27527]={[0]="Journey's End",[1]='B23 K0450 L039 A:45730 T:45417 P:27526'},
[27528]={[0]='Scourged Mass',[1]='B23 K0440 L039 A:45831 T:45831'},
[27529]={[0]='Defenders of Darrowshire',[1]='B23 K0440 L039 A:45831 T:45831'},
[27530]={[0]='The Corpsebeasts',[1]='B23 K0450 L039 A:45831 T:45831 P:27528+27529+27539'},
[27531]={[0]='Counter-Plague Research',[1]='B23 K0440 L041 A:45828 T:45828 O:27532'},
[27532]={[0]='The Plaguewood Tower',[1]='B23 K0440 L041 A:45451 T:45828 P:27522 I:27531'},
[27533]={[0]='A Fate Worse Than Butchery',[1]='B23 K0440 L041 A:12384 T:12384 O:27535'},
[27534]={[0]="Augustus' Receipt Book",[1]='B23 K0440 L041 A:12384 T:12384'},
[27535]={[0]='Just a Little Touched',[1]='B23 K0440 L041 A:45828 T:12384 I:27533'},
[27536]={[0]='Mostly Harmless',[1]='B38 K0520 L051 A:45786 T:45786 P:27587'},
[27537]={[0]='Any Portal in a Storm',[1]='B700 FA K0840 L084 A:45167 T:45173 P:27516'},
[27538]={[0]='The Perfect Poultice',[1]='B700 FA K0840 L084 A:545172 T:45173 P:27516'},
[27539]={[0]="Add 'em to the Pile",[1]='B23 K0440 L039 A:45831 T:45831'},
--[27540]={[0]='The Wildhammer',[1]='FA A:45702 T:39055 P:27307'},
[27541]={[0]='Lessons From the Past',[1]='B720 K0830 L083 A:45874 T:45296'},
[27542]={[0]='Taking the Battlefront',[1]='B21 K0190 FH L015 A:45617 T:45617 P:27518'},
[27544]={[0]='Cenarion Tenacity',[1]='B23 K0410 L039 A:45500 T:16135 P:27386'},
[27545]={[0]='The Way is Open',[1]='B700 FA K0840 L084 A:45173 T:45167 P:27537'},
--[27546]={[0]='Speak with Captain Anton',[1]='FA A:45702 T:39508'},
[27547]={[0]='Of No Consequence',[1]='B21 K0190 FH L015 A:45880 T:45880 P:27542'},
[27548]={[0]='Lessons in Fear',[1]='B21 K0190 FH L015 A:45879 T:45879 P:27542'},
[27549]={[0]='By the Light of the Stars',[1]='B720 K0830 L083 A:45296 T:45296 P:27541'},
[27550]={[0]="Pyrewood's Fall",[1]='B21 K0190 FH L015 A:45878 T:45878 P:27542'},
[27551]={[0]="The Baroness' Missive",[1]='B23 K0450 L039 A:100061378 T:45729 PL:27525'},
[27555]={[0]="Fiona's Lucky Charm",[1]='B23 ++ L039 A:45400 T:45400 P:27369'},
[27556]={[0]="Gidwin's Weapon Oil",[1]='B0 ++ L039 A:45400 T:45400 P:27369'},
[27557]={[0]="Tarenar's Talisman",[1]='B0 ++ L039 A:45400 T:45400 P:27369'},
[27558]={[0]="Pamela's Doll",[1]='B23 ++ L039 A:45400 T:45400 P:27382'},
[27559]={[0]="Vex'tul's Armbands",[1]='B0 ++ L039 A:45400 T:45400 P:27382'},
[27560]={[0]="Argus' Journal",[1]='B23 ++ L039 A:45400 T:45400 P:27466'},
[27561]={[0]="Rimblat's Stone",[1]='B0 ++ L039 A:45400 T:45400 P:27527'},
[27562]={[0]="Beezil's Cog",[1]='B23 ++ L039 A:45400 T:45400'},
[27564]={[0]='In Defense of the Redoubt',[1]='B700 K0850 L084 A:45522 T:45528 P:27505+27506'},
[27565]={[0]='Into the Prison',[1]='B0 K0520 FA L047 A:45892 T:45898'},
--[27566]={[0]='A Gathering in Outland',[1]='FA L060 A:45341,45945,45946 T:41263'},
[27567]={[0]='Twilight?! No!',[1]='B0 K0550 FA L047 A:45898 T:45898 P:27565'},
[27568]={[0]='Infiltrating Shadowforge City',[1]='B0 K0540 FA L051 A:45891 T:45894'},
[27569]={[0]='Dark Iron Tacticians',[1]='B0 K0550 FA L051 A:45894 T:45888 P:27568'},
--[27570]={[0]='The Situation So Far',[1]='FH A:39283 T:35068 P:27308'},
[27571]={[0]='The Grim Guzzler',[1]='B0 K0560 FA L051 A:45888 T:45899 P:27569'},
--[27572]={[0]='A Gathering in Outland',[1]='FH L060 A:39283 T:41239'},
[27573]={[0]='The Dark Iron Pact',[1]='B0 K0570 FA L051 A:45899 T:45890 P:27571'},
[27574]={[0]='I Never Forget a Face',[1]='B0 K0190 FH L015 A:100061505 T:-21,45878 P:27547+27548+27550'},
[27575]={[0]='From the Belly of the Beast',[1]='B0 K0190 FH L015 A:-21,45878 T:45878 P:27574'},
[27576]={[0]='Patchwork Command',[1]='B700 FH K0850 L084 A:45528 T:47492'},
[27577]={[0]='7th Legion Battle Plans',[1]='B21 K0190 FH L015 A:45879 T:45879 P:27548'},
[27578]={[0]="Morgan's Fruition",[1]='B0 K0580 FA L051 A:45890 T:45890 P:27573'},
[27579]={[0]='Into the Prison',[1]='B0 K0520 FH L047 A:45821 T:45818'},
[27580]={[0]='Sowing Discord',[1]='B21 K0200 FH L015 A:45878 T:45878 P:27550'},
[27581]={[0]='Twilight?! No!',[1]='B0 K0550 FH L047 A:45818 T:45818 P:27579'},
[27582]={[0]='Infiltrating Shadowforge City',[1]='B0 K0540 FH L051 A:45839 T:45820'},
[27583]={[0]='The Northern Flank',[1]='B700 FH K0840 L084 A:44169 T:45982'},
[27584]={[0]='Blood in the Surf',[1]='B700 FH K0840 L084 A:45982 T:45982 P:27583'},
[27585]={[0]='The 109th Division',[1]='B0 K0550 FH L051 A:45820 T:45817 P:27582'},
[27586]={[0]='Shells on the Sea Shore',[1]='B700 FH K0840 L084 A:45983 T:45983'},
[27587]={[0]='Maliciously Delicious',[1]='B38 K0520 L051 A:45786 T:45786 O:28569,28570,28675,28677'},
[27589]={[0]='The Grim Guzzler',[1]='B0 K0560 FH L051 A:45817 T:45824 P:27585'},
[27591]={[0]='The Dark Iron Pact',[1]='B0 K0570 FH L051 A:45824 T:45840 P:27589'},
[27592]={[0]='Drinks on the Rocks',[1]='B38 K0520 L051 A:46010 T:46010'},
[27593]={[0]='Rebirth of the K.E.F.',[1]='B0 K0580 FH L051 A:45840 T:45840 P:27591'},
[27594]={[0]="On Her Majesty's Secret Service",[1]='B0 K0200 FH L015 A:45878 T:45617 P:27580'},
[27595]={[0]='The Prophet Hadassi',[1]='B720 K0830 L083 A:45772 T:46003 P:28135'},
[27596]={[0]='The Heart of the Mountain',[1]='B0 K0550 L051 A:45850 T:45850'},
[27597]={[0]='Crazy Larry',[1]='B38 K0520 L051 A:45786 T:45948 P:27536+27656'},
[27598]={[0]='Kill Gil',[1]='B38 K0520 L051 A:45948 T:45948 P:27597'},
[27599]={[0]="Can't Take It With Them",[1]='B38 K0520 L051 A:45948 T:45948 P:27597'},
[27600]={[0]='In With a Bang',[1]='B38 K0520 L051 A:45948 T:45948 P:27598+27599'},
[27601]={[0]='Cities in Dust',[1]='B0 K0200 FH L015 A:45617 T:46124 P:27594'},
[27602]={[0]="The Prophet's Dying Words",[1]='B720 K0830 L083 A:46003 T:1205874 P:27595'},
[27603]={[0]='The Sealed Gate',[1]='B0 K0520 L047 A:45849 T:45849'},
[27604]={[0]="Jammal'an the Prophet",[1]='B0 K0540 L052 A:46077 T:46077 O:27915'},
[27605]={[0]='Eranikus',[1]='B0 K0540 L052 A:46077 T:46077 O:27915'},
[27606]={[0]='Blast Him!',[1]='B700 FH K0840 L084 A:45983 T:45983'},
[27607]={[0]='The Southern Flank',[1]='B700 FH K0840 L084 A:44169 T:46089'},
[27610]={[0]='Scouting the Shore',[1]='B700 FH K0840 L084 A:46089 T:46089'},
[27611]={[0]='Blood on the Sand',[1]='B700 FH K0840 L084 A:46089 T:46089'},
[27612]={[0]='Victory From Within',[1]='B23 K0420 L039 A:16115 T:16115 P:27461'},
[27613]={[0]='The Assassin',[1]='B23 K0420 L039 A:16115 T:16115 P:27461'},
[27614]={[0]='Scarlet Salvage',[1]='B23 K0420 L039 A:16112 T:16112 P:27462'},
[27615]={[0]='The Wrathcaster',[1]='B23 K0420 L039 A:16112 T:16112 P:27462'},
[27616]={[0]='The Huntsman',[1]='B23 K0420 L039 A:16112 T:16112 P:27462'},
[27617]={[0]='Befouled No More',[1]='B23 K0420 L039 A:16115 T:16116 P:27612+27613'},
[27618]={[0]='Argent Upheaval',[1]='B23 K0420 L039 A:16112 T:16116 P:27614+27615+27616+27619'},
[27619]={[0]='The Commander',[1]='B23 K0420 L039 A:16112 T:16112 P:27462'},
[27620]={[0]='Like Rats',[1]='B23 K0430 L039 A:16116 T:11036 P:27617+27618'},
[27621]={[0]="Firebeard's Patrol",[1]='B700 FA K0840 L084 A:545172 T:46804 P:27545'},
[27622]={[0]="Mo' Better Shredder",[1]='B700 FH K0840 L084 A:46090 T:46090'},
[27623]={[0]='Colossal Guardians',[1]='B720 K0830 L083 A:1205874 T:1205874 P:27602'},
[27624]={[0]='After the Fall',[1]='B720 K0830 L083 A:45296 T:45296 P:27431'},
[27625]={[0]="In Defense of Quel'Danil",[1]='B26 FA K0350 L030 A:46475 T:46475 P:27725'},
[27626]={[0]='The Highvale Documents',[1]='B26 FA K0350 L030 A:46475 T:46475 P:27725'},
[27627]={[0]='Just a Fancy Cockroach',[1]='B0 K0830 AK:46126,46127,46128,46129 T:0'},
[27628]={[0]='Send Word to Phaoris',[1]='B720 K0830 L083 A:45799 T:47684 P:27706'},
[27629]={[0]="The Vizier's Vote",[1]='B720 K0840 L083 A:47959 T:46136 P:27628'},
[27630]={[0]="The High Priest's Vote",[1]='B720 K0830 L083 A:47959 T:46135 P:27628'},
[27631]={[0]="The High Commander's Vote",[1]='B720 K0830 L083 A:47959 T:46134 P:27628'},
[27632]={[0]="Tanotep's Son",[1]='B720 K0830 L083 A:46136 T:0 P:27629'},
[27633]={[0]='The Blood God Hakkar',[1]='B0 K0540 L052 A:46077 T:46077 O:27915'},
[27635]={[0]='Decontamination',[1]='B0 FA RN K0020 A:46274 T:46255'},
[27636]={[0]='Just You and Mathias',[1]='B700 FA K0850 L084 A:-700 T:45796 P:27502'},
[27640]={[0]="Dunwalds Don't Die",[1]='B700 FA K0840 L084 A:546804 T:46177 P:27817'},
[27641]={[0]='While Meeting The Family',[1]='B700 FA K0840 L084 A:46143 T:46143,46628 P:27640'}, -- TODO: Verify T:46143 as well
[27642]={[0]='Sifting Through The Wreckage',[1]='B700 FA K0840 L084 A:46143 T:46143,46628 P:27640'}, -- TODO: Verify T:46143 as well
[27643]={[0]='Donnelly Dunwald',[1]='B700 FA K0840 L084 A:46177 T:46176 P:27640'},
[27644]={[0]='Eoin Dunwald',[1]='B700 FA K0840 L084 A:46177 T:46175 P:27640'},
[27645]={[0]='Cayden Dunwald',[1]='B700 FA K0840 L084 A:46177 T:46174 P:27640'},
[27646]={[0]='Finding Beak',[1]='B700 FA K0840 L084 A:46176 T:46176 P:27643'},
[27647]={[0]='Anything But Water',[1]='B700 FA K0840 L084 A:46175 T:46583 P:27644'},
[27648]={[0]='Once More Into The Fire',[1]='B700 FA K08432 L084 A:46174 T:46174 P:27645'},
[27649]={[0]='A Steady Supply',[1]='B700 FA K0840 L084 A:46583 T:46585,46627 P:27647'},
[27650]={[0]='Home Again',[1]='B700 FA K0840 L084 A:46176,46626,46627 T:46177 P:27646'},
[27651]={[0]='Doing It Like a Dunwald',[1]='B700 FA K0840 L084 A:46177 T:46177,46628 P:27650'}, -- TODO: Verify T:46177 as well
[27652]={[0]='Dark Assassins',[1]='B700 FA K0850 L084 A:45796 T:45796 P:27636'},
[27653]={[0]='Dark Assassins',[1]='B700 FH K0850 L084 A:45675 T:45675'},
[27654]={[0]='Bring the Hammer Down',[1]='B700 FA K0850 L084 A:45796 T:45796 P:27636'},
[27655]={[0]='Bring the Hammer Down',[1]='B700 FH K0850 L084 A:45675 T:45675'},
[27656]={[0]='Croc-Out',[1]='B38 K0520 L051 A:45786 T:45786 P:27587'},
[27657]={[0]='Help from the Earthcaller',[1]='B700 FA K0850 L084 A:45796 T:46242 P:27636'},
[27658]={[0]='Help from the Earthcaller',[1]='B700 FH K0850 L084 A:45675 T:46242'},
[27659]={[0]='Portal Overload',[1]='B700 K0850 L084 A:46242 T:46242 P:27657'},
[27660]={[0]='Spirit of the Loch',[1]='B700 K0850 L084 A:46242 T:46413 P:27657'},
[27661]={[0]='Fire the Cannon',[1]='B700 K0850 L084 A:46413 T:46413 P:27660'},
[27662]={[0]='Unbinding',[1]='B700 K0850 L084 A:46243 T:46243 P:27657'},
[27663]={[0]='Tastes Like Strider',[1]='B38 K0520 L051 A:46182 T:46182 P:27587'},
[27664]={[0]='Darkmoon Volcanic Deck',[1]='B0 K0850 A:100062021 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[27665]={[0]='Darkmoon Hurricane Deck',[1]='B0 K0850 A:100062045 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[27666]={[0]='Darkmoon Tsunami Deck',[1]='B0 K0850 A:100062044 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[27667]={[0]='Darkmoon Earthquake Deck',[1]='B0 K0850 A:100062046 T:14847'},	-- does this need to be tagged HF or can it be turned it with summoning at any time of the year?
[27668]={[0]='Pay Attention!',[1]='FH K0810 L080 A:41711 T:1203395'},
[27669]={[0]='Do the Honors',[1]='B720 K0830 L083 A:45296 T:48034 P:27624'},
[27670]={[0]='Pinned Down',[1]='B0 K0010 RN A:46363 AA:45966 T:45966'},
[27671]={[0]='See to the Survivors',[1]='B0 FA RN K0010 A:46268,47250 T:47250 P:28167'},
[27672]={[0]="The Chamber of Khaz'mul",[1]='B0 K0390 FA L037 A:46234 T:46234'},
[27673]={[0]="It's What's Inside That Counts",[1]='B0 K0390 FA L037 A:46247 T:46247'},
[27674]={[0]='To the Surface',[1]='B0 FA RN K0020 A:46255 T:42396'},
[27675]={[0]='Forged Documents',[1]='B0 FA A:100062056 T:332,3518,8670,14721,29142,43693'},
[27676]={[0]='Behind Closed Doors',[1]='B0 K0390 FA L037 A:46233 T:46233'},
[27677]={[0]='Archaedas, The Ancient Stone Watcher',[1]='B0 K0400 FA L037 A:2748,46234 T:46234 P:27672'},
[27679]={[0]="The Chamber of Khaz'mul",[1]='B0 K0390 FH L037 A:46236 T:46236'},
[27680]={[0]='Archaedas, The Ancient Stone Watcher',[1]='B0 K0400 FH L037 A:2748,46236 T:46236 P:27679'},
[27681]={[0]='Behind Closed Doors',[1]='B0 K0390 FH L037 A:46235 T:46235'},
[27682]={[0]='We Require More Minerals',[1]='B0 K0390 FH L037 A:46241 T:46241'},
[27683]={[0]='Into the Woods',[1]='B23 K0400 L039 A:44456,10840 T:45417 I:27684 B23'},
[27684]={[0]='Visitors',[1]='B23 K0400 L039 A:11034 T:45417 I:27683'},
[27685]={[0]='Good Deed Left Undone',[1]='K0810 L080 A:41252 T:39667 P:25371'},
[27686]={[0]='Forged Documents',[1]='B0 FH A:100063276 T:14375,17098,44853,44871,46708'},
[27687]={[0]='An Opened Can of Whoop Gnash',[1]='K0810 L080 A:100062138 T:39884'},
[27688]={[0]='Distract Them for Me',[1]='B700 FA K0850 L084 A:45796 T:45796 P:27654'}, -- TODO: Determine if also need 27652
[27689]={[0]='Distract Them for Me',[1]='B700 FH K0850 L084 A:45675 T:45675'},
[27690]={[0]='Narkrall, the Drake-Tamer',[1]='B700 FH K0840 L084 A:45982 T:46313'},
[27691]={[0]='Marshfin Madness',[1]='B38 K0530 L051 A:46172 T:46172'},
[27692]={[0]='Princess Theradras',[1]='B504956 K0390 L036 A:12201 T:12238'},
[27693]={[0]="The Warden's Game",[1]='B0 K0460 L044 A:1206335 T:-17 P:27796'},
[27694]={[0]='Pool of Tears',[1]='B38 K0530 L051 A:46071 T:46071 O:27869'},
[27695]={[0]='The Elementium Axe',[1]='B0 FA K0850 L084 A:45796 T:45796 P:27654'}, -- TODO: Determine if also need 27652
[27696]={[0]='The Elementium Axe',[1]='B700 FH K0850 L084 A:45675 T:45675'},
[27697]={[0]='Corruption in Maraudon',[1]='B0 K0340 FH L032 A:12236 T:12238'},
[27698]={[0]='Servants of Theradras',[1]='B504956 K0360 L034 A:12258,13282 T:12238'},
[27699]={[0]='Shark Weak',[1]='K0810 L080 A:-610 T:46338 P:25657'},
[27700]={[0]='Dragon, Unchained',[1]='B0 FA K0850 L084 A:45796 T:45796 P:27688+27695'},
[27701]={[0]='Dragon, Unchained',[1]='B700 FH K0850 L084 A:45675 T:45675 P:27689+27696'},
[27702]={[0]='Coup de Grace',[1]='B0 FA K0850 L084 A:45796 T:45796 P:27700'},
[27703]={[0]='Coup de Grace',[1]='B700 FH K0850 L084 A:45675 T:45675 P:27701'},
[27704]={[0]='Legends of the Sunken Temple',[1]='B38 K0530 L051 A:46071 T:-38 P:27694'},
[27705]={[0]='Step One: The Priestess',[1]='B38 K0530 L051 A:-38 T:-100038 P:27704'},
[27706]={[0]='The Scepter of Orsis',[1]='B720 K0830 L083 A:1205874 T:45772 P:27623'},
[27707]={[0]='Neferset Prison',[1]='B0 K0830 L083 A:-720 T:0 P:27632'},
[27708]={[0]="The Warden's Time",[1]='K0810 L080 A:-610 T:41341 P:25884'},
[27709]={[0]="The Sentinel's Game",[1]='B0 K0460 L044 A:1206336 T:-17 P:27797'},
[27711]={[0]='Back to the Elementium Depths',[1]='B0 FA K0850 L084 A:45796 T:46243 P:27702+27719'},
[27712]={[0]='Back to the Elementium Depths',[1]='B0 FH K0850 L084 A:45675 T:46243 P:27703+27798'},
[27713]={[0]='The Day that Deathwing Came',[1]='B17 K0470 L044 A:2785 T:2785 O:27927'},
[27714]={[0]='The Day that Deathwing Came: The Real Story',[1]='B17 K0470 L044 A:2920 T:2920 P:27713'},
[27715]={[0]='The Day that Deathwing Came: What Really Happened',[1]='B17 K0470 L044 A:4618 T:4618 P:27714'},
[27716]={[0]='Piece of the Past',[1]='FA K0810 L080 A:100062281 T:40644'},
[27717]={[0]='Piece of the Past',[1]='FH K0810 L080 A:100062282 T:40920'},
[27718]={[0]="Warchief's Command: Vashj'ir!",[1]='B0 K0800 FH L080 M084 A:1206109,1206116,1207323,1207324 T:41621 P:28805'},
[27719]={[0]='Water of Life',[1]='B0 FA K0850 L084 A:46413 T:45796 P:27661'},
[27720]={[0]="Mr. Goldmine's Wild Ride",[1]='B0 FA K0850 L084 A:46243 T:46513 P:27711'},
[27721]={[0]="Warchief's Command: Mount Hyjal!",[1]='B0 K0800 FH L080 M084 A:1206109,1206116,1207323,1207324 T:39865'},
[27722]={[0]="Warchief's Command: Deepholm!",[1]='B0 K0820 FH L082 M086 A:1206109,1206116,1207323,1207324 T:45244'},
[27724]={[0]="Hero's Call: Vashj'ir!",[1]='B0 FA K0800 L080 M084 A:1009686,1009503,1207320,1207321,1207322 T:36799 I:14481,28827'},
[27725]={[0]="Quel'Danil Lodge",[1]='B26 FA K0340 L030 A:46476 T:46475 P:26526'},
[27726]={[0]="Hero's Call: Mount Hyjal!",[1]='B0 FA K0800 L080 M084 A:1009503,1009686,1010712,1010713,1010714 T:39865'},
[27727]={[0]="Hero's Call: Deepholm!",[1]='B0 FA K0820 L082 M086 A:1009686,1009503,1207320,1207321 T:45226'},
[27729]={[0]='Once More, With Eeling',[1]='B0 K0810 L080 AK:40855 T:0'},
[27733]={[0]="The Good Ol' Switcheroo",[1]='B0 K0230 FA L022 A:46417 T:46417'},
[27737]={[0]='By Fire Be Saved!',[1]='B0 K0240 FA L022 A:46410 T:46410'},
[27738]={[0]='The Pit of Scales',[1]='B720 K0830 L083 A:-720 T:46136 P:27707'},
[27739]={[0]='The Gnoll King',[1]='B0 K0250 FA L022 A:46409 T:46409'},
[27740]={[0]='Baba Bogbrew',[1]='B38 K0530 L051 A:45948 T:46172 P:27600'},
[27742]={[0]='A Little on the Side',[1]='B0 K0850 L084 A:46513 T:46513 P:27720'},
[27743]={[0]="While We're Here",[1]='B0 K0850 L084 A:46513 T:46513 P:27720'},
[27744]={[0]='Rune Ruination',[1]='B0 K0850 L084 A:46671 T:46513 P:27742+27743'}, -- TODO: really determine if these are needed or if it will be there at the end of the ride
[27745]={[0]='A Fiery Reunion',[1]='B0 K0850 L084 A:46513 T:46243 P:27742+27743+27744'},
[27746]={[0]='Empire of Dirt',[1]='B0 K0200 FH L019 A:46124 T:2215 P:27601'},
[27747]={[0]='Total War',[1]='B700 FH K0840 L084 A:46318 T:46318'},
[27748]={[0]='Fortune and Glory',[1]='B0 K0830 L083 A:47158 T:49151 P:28613'},
[27750]={[0]='War Forage',[1]='B700 FH K0840 L084 A:46319 T:46319'},
[27751]={[0]='Crushing the Wildhammer',[1]='B700 FH K0840 L084 A:46313 T:46313'},
[27752]={[0]='Fight Like a Wildhammer',[1]='B700 FA K0840 L084 A:48010 T:48010'},
[27753]={[0]='Never Leave a Dinner Behind',[1]='B700 FA K0840 L084 A:48013 T:48013 O:28369'},
[27754]={[0]='Dragonmaw Takedown',[1]='B700 FA K0840 L084 A:46591 T:46591'},
[27755]={[0]='The Curse of the Tombs',[1]='B720 K0830 L083 A:48501 T:48501 P:28501'},
[27756]={[0]='The Foreman',[1]='B504956 K0160 FA L015 A:46612 T:-756,46612'},
[27757]={[0]='The Darkest Depths',[1]='B38 K0530 L051 A:46172 T:46172 P:27691'},
[27758]={[0]='The Carpenter',[1]='B0 K0160 FA L015 A:46612 T:-756,46612 P:27756'},
[27760]={[0]='Artificial Intelligence',[1]='B720 K0830 L083 A:100062483 T:1206293'},
[27761]={[0]='A Disarming Distraction',[1]='B720 K0830 L083 A:1206293 T:1206293 P:27760'},
[27762]={[0]='Fuselight, Ho!',[1]='B17 K0450 L044 A:48704 T:46650 O:28579,28580 I:27763 B17'},
[27763]={[0]='To Fuselight Proper',[1]='B17 K0450 L044 A:46650 T:46652 O:27762 I:27774'},
[27764]={[0]='A Strange Request',[1]='B17 K0450 L044 A:46652 T:46654 P:27774'},
[27765]={[0]='First Sample: Wild Eggs',[1]='B17 K0450 L044 A:46654 T:46654 P:27764'},
[27766]={[0]='Second Sample: Whelps',[1]='B17 K0450 L044 A:46654 T:46654 P:27764'},
[27768]={[0]='Step Two: The Bloodletter',[1]='B0 K0540 L051 A:-100038 T:-110038 P:27705'},
[27769]={[0]='Rhea Revealed',[1]='B17 K0450 L044 A:46654 T:46655 P:27771'},
[27770]={[0]='Lifting the Veil',[1]='B17 K0450 L044 A:46654 T:46654 P:27765+27766'},
[27771]={[0]='Third Sample: Implanted Eggs',[1]='B17 K0450 L044 A:46654 T:46654 P:27770'},
[27772]={[0]='The Venerable Doctor Blam',[1]='B17 K0450 L044 A:46655 T:46664 P:27769'},
[27773]={[0]='Step Three: Prophet',[1]='B0 K0540 L051 A:-110038 T:-120038 P:27768'},
[27774]={[0]='Easily Swayed',[1]='B17 K0450 L044 A:46652 T:46652 O:27763'},
[27775]={[0]='When the Going Gets Tough, Cheat',[1]='B17 K0450 L044 A:46653 T:46653'},
[27776]={[0]="It's Goat Time, Baby",[1]='B17 K0450 L044 A:46653 T:46653 P:27775'},
[27777]={[0]='Core Access Codes',[1]='B720 K0830 L083 A:1206293 T:1206293 P:27760'},
[27778]={[0]='Hacking the Wibson',[1]='B720 K0830 L083 A:1206293 T:46750 P:27761,27777'},
[27779]={[0]='Gnomebliteration',[1]='B720 K0830 L083 A:46750 T:46750 P:27778'},
[27781]={[0]='The Machination',[1]='B0 K0160 FA L015 A:46612 T:-756,46612 P:27758'},
[27782]={[0]='Mathias Needs You',[1]='B0 FA K0850 L084 A:46243 T:45796 P:27745'},
[27783]={[0]='Garona Needs You',[1]='B0 FH K0850 L084 A:46243 T:45675'},
[27784]={[0]='The Hammer of Twilight',[1]='B0 FA K0850 L084 A:45796 T:46717 P:27782'},
[27785]={[0]='The Admiral',[1]='B0 K0160 FA L015 A:46612 T:-756,46612 P:27781'},
[27786]={[0]='The Hammer of Twilight',[1]='B0 FH K0850 L084 A:45675 T:46717 P:27783'},
[27787]={[0]='Skullcrusher the Mountain',[1]='B0 FA K0850 L084 A:46717 T:45668 P:27784'},
[27788]={[0]='Skullcrusher the Mountain',[1]='B0 FH K0850 L084 A:46717 T:45658 P:27786'},
[27789]={[0]='Troggish Troubles',[1]='B17 K0460 L044 A:46664 T:46664 P:27772'},
[27790]={[0]='The Defias Kingpin',[1]='B504956 K0170 FA L015 A:-756,46612 T:546612 P:27785'},
[27791]={[0]='Dustwind Dig',[1]='B17 FA K0460 L044 A:46664 T:46760 P:27789'},
[27792]={[0]="All's Fair in Love, War, and Archaeology",[1]='B17 FA K0460 L044 A:46760 T:46760 P:27791'},
[27793]={[0]='Ancient Protectors',[1]='B0 K0460 L044 A:-17 T:-17 P:27693+27709'},
[27794]={[0]='Return to Blam',[1]='B17 FA K0460 L044 A:1206374 T:46664 P:27912'},
[27795]={[0]='Tides of Darkness',[1]='B38 FA K0540 L052 A:46676 T:46676 P:27821+27822'},
[27796]={[0]="The Warden's Pawn",[1]='B17 FA K0460 L044 A:46760 T:1206335 P:27792'},
[27797]={[0]="The Sentinel's Pawn",[1]='B17 FA K0460 L044 A:46760 T:1206336 P:27792'},
[27798]={[0]='Water of Life',[1]='B700 FH K0850 L084 A:46413 T:45675 P:27703'},
[27803]={[0]='Welcome Relief',[1]='B700 FA K0840 L084 A:46804 T:46804 P:27621'},
[27804]={[0]='The Only Homes We Have',[1]='B700 FA K0840 L084 A:46804 T:46804 P:27621'},
[27805]={[0]='Small Comforts',[1]='B700 FA K0840 L084 A:46814 T:46814 P:27803'},
[27806]={[0]='Honorable Bearing',[1]='B700 FA K0840 L084 A:46804 T:46805 P:27803+27804'},
[27807]={[0]='Clan Mullan',[1]='B700 FA K0840 L084 A:46805 T:46811 P:27806'},
[27808]={[0]='Stubborn as a Doyle',[1]='B700 FA K0840 L084 A:46805 T:47317 P:27806'},
[27809]={[0]='Firebeard Bellows',[1]='B700 FA K0840 L084 A:46805 T:46850 P:27806'},
[27810]={[0]='The Fighting Spirit',[1]='B700 FA K0840 L084 A:46811 T:46811 P:27807'},
[27811]={[0]='The Scent of Battle',[1]='B700 FA K0840 L084 A:46812 T:46812 P:27807'},
[27812]={[0]='The Loyalty of Clan Mullan',[1]='B700 FA K0840 L084 A:46811 T:46805 P:27810+27811'},
[27813]={[0]='Death Worthy of a Dragonmaw',[1]='B700 FA K0840 L084 A:46850 T:46850 P:27809'},
[27814]={[0]='Anything We Can Get',[1]='B700 FA K0840 L084 A:46806 T:46806 P:27809'},
[27815]={[0]="Somethin' for the Boys",[1]='B700 FA K0840 L084 A:46850 T:46805 P:27813+28234'},
[27816]={[0]='Personal Request',[1]='B700 FA K0840 L084 A:46805 T:546804 P:27812+27815'},
[27817]={[0]='Dropping the Hammer',[1]='B700 FA K0840 L084 A:546804 T:546804 P:27816'},
[27818]={[0]='Slithering Signs',[1]='B38 K0530 L051 A:46172 T:46172 P:27757'},
[27821]={[0]='Orcs and Humans',[1]='B38 FA K0540 L052 A:46676 T:46676 O:27870'},
[27822]={[0]='Lumbering Oafs',[1]='B38 FA K0540 L052 A:46676 T:46676 O:27870'},
[27823]={[0]="A Dwarf's Got Needs",[1]='B17 FA K0460 L044 A:2860 T:2860'},
[27824]={[0]='The Good Stuff',[1]='B17 FA K0460 L044 A:2860 T:2860 P:27823'},
[27825]={[0]='Survival of the Fattest',[1]='B17 FA K0470 L044 A:46930 T:46930'},
[27826]={[0]="Into the Dragon's Mouth",[1]='B17 FA K0470 L044 A:46664 T:546654 P:27794'},
[27827]={[0]='The Swift, the Fierce, and the Stout',[1]='B17 FA K0470 L044 A:546654 T:46852 P:27826'},
[27828]={[0]='Eric, the Utility Dwarf',[1]='B17 FA K0470 L044 A:46852,46855 T:46855 P:27827'},
[27829]={[0]='The Wrath of a Dragonflight',[1]='B17 FA K0470 L044 A:-17 T:-17,46654 P:27828+27834+27835'},
[27830]={[0]='Their Hunt Continues',[1]='B17 FA K0470 L044 A:-17 T:-17,46654 P:27829'},
[27831]={[0]='The Sorrow and the Fury',[1]='B17 FA K0470 L044 A:-17 T:46654 P:27830'},
[27832]={[0]='The Hidden Clutch',[1]='B17 FA K0470 L044 A:-17 T:500021 P:27831'},
[27833]={[0]='Half-Ton Holdouts',[1]='B17 FA K0470 L044 A:46972 T:46972'},
[27834]={[0]='Baelog, the Glass Cannon',[1]='B17 FA K0470 L044 A:46853,46856 T:46856 P:27827'},
[27835]={[0]="Olaf, the Big Fella'",[1]='B17 FA K0470 L044 A:46854,46857 T:46857 P:27827'},
[27836]={[0]='Stopping the Spread',[1]='B720 K0830 L083 A:46135 T:46135 P:27630'},
[27837]={[0]='Trespassers in the Water',[1]='B720 K0830 L083 A:46135 T:46135 P:27630'},
[27838]={[0]='The Root of the Corruption',[1]='B720 K0830 L083 A:46135 T:46135 P:28611'},
[27839]={[0]='Ancient Weapons',[1]='B720 K0830 L083 A:46134 T:46134 P:28201'},
[27840]={[0]='Draenethyst Crystals',[1]='B38 FA K0540 L052 A:18221 T:18221'},
[27842]={[0]='Only the Beginning',[1]='B0 K0160 FH L015 A:46889 T:46889'},
[27841]={[0]='The Grateful Dead',[1]='B0 HD K00016 FH RG A:46901 T:46901 I:13952,14166,14167,14168,14169,14170,14171,14172,14173,14174,14175,14176,14177,27846'},
[27843]={[0]='Reinforcements Denied',[1]='B38 FA K0540 L052 A:46676 T:46676 P:27821+27822'},
[27844]={[0]='Traitors!!!',[1]='B0 K0160 FH L015 A:46906 T:46906'},
[27845]={[0]='Marking the Fallen',[1]='B38 FA K0540 L052 A:46676 T:46676 P:27821+27822'},
[27846]={[0]='The Grateful Dead',[1]='B0 HD K00016 FA RW A:46908 T:46908 I:13952,14166,14167,14168,14169,14170,14171,14172,14173,14174,14175,14176,14177,27841'},
[27847]={[0]='Not Quite There',[1]='B0 K0160 FH L015 A:46902 T:46902'},
[27848]={[0]='Good Intentions...Poor Execution',[1]='B0 K0160 FH L015 A:46889 T:46889 P:27842'},
[27849]={[0]='Assault on Stonard',[1]='B38 FA K0540 L052 A:46676 T:46676 P:27795+27843+27845'},
[27850]={[0]='The Defias Kingpin',[1]='B0 K0170 FH L015 A:46889 T:46889 P:27848'},
[27851]={[0]='Cutting Supply',[1]='B38 FA K0540 L052 A:46676 T:46676 P:27795+27843+27845'},
[27852]={[0]='Orcs and Humans',[1]='B38 K0540 FH L052 A:7623 T:7623'},
[27853]={[0]='Lumbering Oafs',[1]='B38 K0540 FH L052 A:7623 T:7623'},
[27854]={[0]='Tides of Darkness',[1]='B38 K0540 FH L052 A:7623 T:7623'},
[27855]={[0]='Reinforcements Denied',[1]='B38 K0540 FH L052 A:7623 T:7623'},
[27856]={[0]='Marking the Fallen',[1]='B38 K0540 FH L052 A:7623 T:7623'},
[27857]={[0]="We're Under Attack!",[1]='B38 K0540 FH L052 A:7623 T:7623'},
[27858]={[0]="Rheastrasza's Gift",[1]='B0 FA K0470 L044 A:500021 T:-17 P:27832'},
[27859]={[0]='The Egg Lives On',[1]='B17 SP K0470 L044 A:546664 T:546664 P:27930'},
[27860]={[0]='The Lost Ones',[1]='B38 FA K0540 L052 A:18221 T:18221'},
[27863]={[0]='The Crucible of Carnage: The Bloodeye Bruiser!',[1]='B700 K0850 L084 A:46935 T:0'},
[27864]={[0]='The Crucible of Carnage: The Deadly Dragonmaw!',[1]='B700 FA K0850 L084 A:46935 T:0 P:27863'},
[27865]={[0]='The Crucible of Carnage: The Wayward Wildhammer!',[1]='B700 FH K0850 L084 A:46935 T:0 P:27863'},
[27866]={[0]="The Crucible of Carnage: Calder's Creation!",[1]='B0 K0850 L084 A:46935 T:0 P:27865,27864'},
[27867]={[0]='The Crucible of Carnage: The Earl of Evisceration!',[1]='B700 K0850 L084 A:46935 T:0 P:27866'},
[27868]={[0]='The Crucible of Carnage: The Twilight Terror!',[1]='B700 K0850 L084 A:46935 T:0 P:27867'},
[27869]={[0]='The Dragon and the Temple',[1]='B38 K0530 L051 A:46172 T:46071 P:27818 I:27694'},
[27870]={[0]='To Marshtide Watch',[1]='B38 K0540 FA L051 A:46071 T:46676 P:27914 I:27821'},
[27871]={[0]='To Stonard',[1]='B38 K0540 FH L051 A:46071 T:7623'},
[27874]={[0]="Aviana's Legacy",[1]='B606 K0810 L080 A:40289,46987,46998 T:41005 P:25611 I:25663,25985'},
[27875]={[0]='Prayerblossom',[1]='B38 FA K0550 L053 A:17127 T:17127'},
[27876]={[0]='Secrets of the Mire',[1]='B38 FA K0550 L053 A:17127 T:17127'},
[27877]={[0]="The Morons' League",[1]='B17 K0460 FH L044 A:46759 T:46759'},
[27878]={[0]='Forcible Acquisition',[1]='B17 K0460 FH L044 A:46758 T:46758'},
[27879]={[0]='Survival of the Fattest',[1]='B17 K0470 FH L044 A:46660 T:46660'},
[27880]={[0]='Half-Ton Holdouts',[1]='B17 K0470 FH L044 A:1068 T:1068'},
[27881]={[0]='Bloodwatcher Point',[1]='B17 K0460 FH L044 A:46664 T:46757'},
[27882]={[0]="It's Not About History, It's About Power",[1]='B17 K0460 FH L044 A:46757 T:46757 P:27881'},
[27883]={[0]="The Warden's Pawn",[1]='B17 K0460 FH L044 A:46757 T:1206335'},
[27884]={[0]="The Sentinel's Pawn",[1]='B17 K0460 FH L044 A:46757 T:1206336'},
[27885]={[0]="The Warden's Game",[1]='B0 K0460 L044 A:1206335 T:-17 P:27883'},
[27886]={[0]="The Sentinel's Game",[1]='B0 K0460 L044 A:1206336 T:-17 P:27884'},
[27887]={[0]='Ancient Protectors',[1]='B0 K0460 FH L044 A:-17 T:-17 P:27885+27886'},
[27888]={[0]='Return to Blam',[1]='B17 K0460 FH L044 A:1206374 T:46664 P:27913'},
[27889]={[0]='New Kargath',[1]='B17 K0470 FH L044 A:46664 T:46654'},
[27890]={[0]='The Bad Dogs',[1]='B17 K0470 FH L044 A:46654 T:47011 P:27889'},
[27891]={[0]='Amakkar, Jack of All Trades',[1]='B17 K0470 FH L044 A:47011,47021 T:47021'},
[27892]={[0]='Jurrix the Striker',[1]='B17 K0470 FH L044 A:47018,47024 T:47024'},
[27893]={[0]='Gargal, the Behemoth',[1]='B17 K0470 FH L044 A:47013,47022 T:47022'},
[27894]={[0]='The Wrath of a Dragonflight',[1]='B17 K0470 FH L044 A:47021,47022,47024 T:46654 P:27891+27892+27893'},
[27895]={[0]='Their Hunt Continues',[1]='B17 K0470 FH L044 A:46654,46860,46917,46938 T:46654 P:27894'},
[27896]={[0]='The Sorrow and the Fury',[1]='B17 K0470 FH L044 A:46654,46861,46916 T:46654 P:27895'},
[27897]={[0]='The Hidden Clutch',[1]='B17 K0470 FH L044 A:46654 T:500021 P:27896'},
[27898]={[0]="Rheastrasza's Gift",[1]='B0 K0470 FH L044 A:500021 P:27897'},
[27899]={[0]='That Gleam in his Eye',[1]='B720 K0830 L083 A:47005 T:46978 P:27669'},
[27900]={[0]="I've Got This Guy",[1]='B720 K0830 L083 A:46978 T:46978 P:27899'},
[27901]={[0]="They Don't Know What They've Got Here",[1]='B720 K0830 L083 A:46978 T:46978 P:27899'},
[27902]={[0]='The Purespring',[1]='B38 FA K0550 L053 A:17127 T:17127 P:27875+27876'},
[27903]={[0]='Ignition',[1]='B720 K0830 L083 A:46978 T:50401 P:27900+27901'},
[27904]={[0]='Breath of Mist',[1]='B38 FA K0550 L053 A:17127 T:17127 P:27875+27876'},
[27905]={[0]='Tailgunner!',[1]='B720 K0830 L083 A:46978 T:48082 P:27903'},
[27906]={[0]='Neeka Bloodscar',[1]='B38 K0550 FH L053 A:7623 T:47041'},
[27907]={[0]='Prayerblossom',[1]='B38 K0550 FH L053 A:47041 T:47041'},
[27908]={[0]='Secrets of the Mire',[1]='B38 K0550 FH L053 A:47041 T:47041'},
[27909]={[0]='The Purespring',[1]='B38 K0550 FH L053 A:47041 T:47041'},
[27910]={[0]='Last Regrets',[1]='B38 K0550 FH L053 A:47041 T:47041'},
[27911]={[0]='With Dying Breath',[1]='B38 K0550 FH L053 A:47041 T:47041'},
[27912]={[0]="The Titans' Trove",[1]='B17 FA K0460 L044 A:-17 T:1206374 P:27793'},
[27913]={[0]="The Titans' Trove",[1]='B17 FH K0460 L044 A:-17 T:1206374 P:27887'},
[27914]={[0]='Blessing of the Green Dragonflight',[1]='B38 K0540 L052 A:-120038 T:46071 P:27773'},
[27915]={[0]='The Heart of the Temple',[1]='B504956 K0540 L052 A:46071 T:46077 P:27914'},
[27916]={[0]="Ruag's Report",[1]='B38 K0550 FH L053 A:47041 T:7623 P:27911'},
[27917]={[0]='Sniffing Them Out',[1]='B504956 K0180 FA L018 A:47006 T:47006'},
[27918]={[0]='The Harborage',[1]='B38 FA K0550 L053 A:18221 T:17127 P:27840+27860'},
[27919]={[0]='Onward to the Blasted Lands',[1]='B19 FA K0550 L054 A:17127 T:9540 B19'},
[27920]={[0]='Armored to the Teeth',[1]='B0 K0190 FA L018 A:47006 T:47006 P:27917'},
[27921]={[0]='Fighting Tooth and Claw',[1]='B0 K0200 FA L018 A:47006 T:47006 P:27920'},
[27922]={[0]='Traitors!',[1]='B720 K0830 L083 A:46872 T:46872 P:27003'},
[27923]={[0]='Smoke in Their Eyes',[1]='B720 K0830 L083 A:46872 T:46872 P:27922'},
[27924]={[0]="Budd's Plan",[1]='B720 K0830 L083 A:46875 T:46875 P:27922'},
[27925]={[0]='Efficient Excavations',[1]='B0 K0830 L083 A:100062768 T:47670'}, -- TODO: Does this exist?  Is is Horde only?
[27926]={[0]='Eastern Hospitality',[1]='B720 K0830 L083 A:47670 T:47670 P:27925,28132'},
[27927]={[0]='Down to the Scar',[1]='B17 K0470 L044 AA:46930 AH:46660 T:2785 I:27713'},
[27928]={[0]='A Favor for the Furrier',[1]='B720 K0830 L083 A:47670 T:47670 P:27926'},
[27929]={[0]="Drag 'em Down",[1]='B700 FH K0840 L084 A:46313 T:46313'},
[27930]={[0]='Devastation',[1]='B17 K0470 L044 A:-17 T:1206504 P:27858,27898'},
[27931]={[0]='The Quaking Fields',[1]='B640 K0820 L081 A:43071 T:47195 P:26484'},
[27932]={[0]='The Axe of Earthly Sundering',[1]='B640 K0820 L081 A:47195 T:47195 P:27931'},
[27933]={[0]='Elemental Ore',[1]='B640 K0820 L081 A:47195 T:47195 P:27931'},
[27934]={[0]='One With the Ground',[1]='B0 K0820 L081 A:47195 T:0 P:27932+27933'},
[27935]={[0]='Bring Down the Avalanche',[1]='B640 K0820 L081 A:-640 T:43071 P:27934'},
[27936]={[0]='Bring Down the Avalanche',[1]='B640 K0820 L081 A:-640 T:43071 P:27934'},
[27937]={[0]='The Hero Returns',[1]='B640 K0830 L081 A:43897 T:44204 P:26836'},
[27938]={[0]='The Middle Fragment',[1]='B640 K0830 L081 A:44204 T:42573 P:27937'},
[27939]={[0]='The Desert Fox',[1]='B720 K0830 L083 A:47159 T:47159 P:27926'},
[27940]={[0]='Dirty Birds',[1]='B0 K0830 L083 AK:47202 T:0'},
[27941]={[0]='Fashionism',[1]='B720 K0830 L083 A:47670 T:47670 P:27928'},
[27942]={[0]='Idolatry',[1]='B720 K0830 L083 A:47159 T:47159 P:27939'},
[27943]={[0]='Angered Spirits',[1]='B720 K0830 L083 A:47159 T:47159 P:27939'},
[27944]={[0]='Thinning the Brood',[1]='B0 +D FA K0850 L085 A:48255 T:48255'},
[27945]={[0]='Paint it Black',[1]='B700 FH K0840 L084 A:46324 T:46324'},
[27947]={[0]='A Vision of Twilight',[1]='B700 FH K0840 L084 A:46323 T:1009961'},
[27948]={[0]='A Sticky Task',[1]='B0 +D FA K0850 L085 A:48255 T:48255'},
[27949]={[0]='The Forgotten',[1]='B0 +D FA K0850 L085 A:48250 T:48250'},
[27950]={[0]='Gobbles!',[1]='B0 K0830 L083 A:47159 T:0 P:27941+27942+27943'},
[27951]={[0]='We All Must Sacrifice',[1]='B700 FH K0840 L084 A:1009961 T:1009961 P:27947'},
[27952]={[0]='The Explorers',[1]='B640 FA K0830 L083 A:42573 T:44799 I:27004'},
[27953]={[0]='The Reliquary',[1]='B640 FH K0830 L083 A:42573 T:44823'},
[27954]={[0]='The Eyes Have It',[1]='B700 FH K0840 L084 A:1009961 T:46323 P:27951'},
[27955]={[0]='Eye Spy',[1]='B700 FH K0840 L084 A:46323 T:46323 P:27954'},
[27956]={[0]="Lunk's Task",[1]='B28 K0470 L046 A:47269 T:47269'},
[27957]={[0]='Lunk No Kill',[1]='B28 SP K0470 L046 A:47269 T:47269 P:27956'},
[27958]={[0]='A Proper Antivenom',[1]='B28 K0470 L046 A:47268 T:47268 P:27957'},
[27959]={[0]="Lunk's Adventure: Spider Rider",[1]='B0 K0470 L046 A:47280 T:-28 PL:27958'},
[27960]={[0]='The Fewer, the Better',[1]='B28 K0470 L046 A:47267 T:47267'},
[27961]={[0]='Out of Place',[1]='B28 K0470 L046 A:47267 T:47267 P:27960'},
[27962]={[0]='A Lumbering Relic',[1]='B28 K0470 L046 A:47267 T:47267 P:27960'},
[27963]={[0]='A New Master... But Who?',[1]='B28 K0470 L046 A:47266 T:47266 O:28512,28581,28582'},
[27964]={[0]='Dig-Boss Dinwhisker',[1]='B28 K0470 L046 A:47266 T:47266 P:27963'},
[27965]={[0]='Thorium Point: The Seat of the Brotherhood',[1]='B28 K0480 L046 A:47266 T:14625 P:27957+27958+27961+27962+27964'},
[27966]={[0]='Salvaging the Remains',[1]='B0 +D FA K0850 L085 A:48250 T:48250'},
[27967]={[0]='First Lieutenant Connor',[1]='B0 +D FA K0850 L085 A:48250 T:48250'},
[27968]={[0]='Fury of the Pack',[1]='B0 K0210 FA L018 A:47006 T:47006 P:27921'},
[27969]={[0]='Make Yourself Useful',[1]='B720 K0830 L083 A:47159 T:47159 P:27950'},
[27970]={[0]='Captain P. Harris',[1]='B0 +D FA K0850 L085 A:48255 T:48255'},
[27971]={[0]='Rattling Their Cages',[1]='B0 +D FA K0850 L085 A:48255 T:48255'},
[27972]={[0]='Boosting Morale',[1]='B0 +D FA K0850 L085 A:48255 T:48255'},
[27973]={[0]='Watch Out For Splinters!',[1]='B0 +D FA K0850 L085 A:48254 T:48254'},
[27974]={[0]='This Land is Our Land',[1]='B504956 K0180 FH L018 A:47293 T:47293'},
[27975]={[0]='WANTED: Foreman Wellson',[1]='B0 +D FA K0850 L085 A:48254 T:48254'},
[27976]={[0]='Curse These Fat Fingers',[1]='B28 K0480 L046 A:14627 T:14627 P:27965'},
[27977]={[0]='Recon Essentials',[1]='B28 K0480 L046 A:14626 T:14626 P:27965'},
[27978]={[0]='Ghostbuster',[1]='B0 +D FA K0850 L085 A:48254 T:48254'},
[27979]={[0]='Dark Ministry',[1]='B28 K0480 L046 A:14627 T:14627 P:27976'},
[27980]={[0]='The Spiders Have to Go',[1]='B28 K0480 L046 A:14634 T:14634'},
[27981]={[0]="Heat That Just Don't Quit",[1]='B28 K0480 L046 A:14627 T:14627 P:27965'},
[27982]={[0]='Twilight Collars',[1]='B28 K0480 L046 A:14626 T:14624 P:27977+28099'},
[27983]={[0]="Lunk's Adventure: Cranky Little Dwarfs",[1]='B0 K0480 L046 A:47332 T:-28 PL:27977'},
[27984]={[0]="Lunthistle's Tale",[1]='B28 K0480 L046 A:8436 T:8436'}, -- there is a P: of somesort or maybe Thorium rep
[27985]={[0]='Prayer to Elune',[1]='B0 K0480 L046 A:8436 T:-100028 P:27984'},
[27986]={[0]='In the Hall of the Mountain-Lord',[1]='B28 K0490 L046 A:14627 T:47393 P:27979'},
[27987]={[0]='Cannonball!',[1]='B0 +D FA K0850 L085 A:48254 T:48254'},
[27988]={[0]='Plague...Plague Everywhere!',[1]='B0 K0190 FH L018 A:47293 T:47293 P:27974'},
[27989]={[0]='Ruumbo Demands Honey',[1]='B182 K0450 L044 A:1206585 T:1206585'},
[27990]={[0]='Battlezone',[1]='B720 K0830 L083 A:47159 T:47940 P:28002'},
[27991]={[0]='Taking the Overlook Back',[1]='B0 +D FA K0850 L085 A:48254 T:48254'},
[27992]={[0]='Magnets, How Do They Work?',[1]='B0 +D FA K0850 L085 A:48250 T:48250'},
[27993]={[0]="Take it to 'Em!",[1]='B720 K0830 L083 A:47318 T:44860'},
[27994]={[0]='Ruumbo Demands Justice',[1]='B182 K0450 L044 A:1206585 T:1206585'},
[27995]={[0]='Dance for Ruumbo!',[1]='B182 K0460 L044 A:1206585 T:11554'},
[27996]={[0]='Orders Are For the Living',[1]='B0 K0200 FH L018 A:47293 T:47293 P:27988'},
[27997]={[0]='The Corruption of the Jadefire',[1]='B182 K0450 L044 A:10923 T:10923 P:28542,28543'},
[27998]={[0]='Sweet, Merciless Revenge',[1]='B0 K0210 FH L018 A:47293 T:47293 P:27996'},
[27999]={[0]='The Fate of the Doyles',[1]='B700 FA K0840 L084 A:47317 T:46805 P:27808'},
[28000]={[0]='Do the Imp-Possible',[1]='B182 K0450 L044 A:47341 T:47341 P:28150'},
[28001]={[0]="A Coward's Due",[1]='B700 FA K0840 L084 A:546804 T:46591 P:27817'},
[28002]={[0]='Crisis Management',[1]='B720 K0830 L083 A:47670 T:47670 P:27969'},
[28003]={[0]='Adventurers Wanted: Ragefire Chasm',[1]='B0 FH K01564 L015 I:26865,26866,26867'},
[28028]={[0]='Siege!',[1]='B28 K0490 L046 A:47393 T:47393 P:27986'},
[28029]={[0]='Set Them Ablaze!',[1]='B28 K0490 L046 A:47393 T:47393 P:27986'},
[28030]={[0]='They Build a Better Bullet',[1]='B28 K0490 L046 A:47393 T:47393 P:27986'},
[28031]={[0]='Special Delivery for Brivelthwerp',[1]='B61 FA K0410 L038 A:40726 T:47383 P:25542,25561'},
[28032]={[0]='The Mysteries of the Fire-Gizzard',[1]='B28 K0490 L046 A:47440 T:47440 P:27986'},
[28033]={[0]='Deceit',[1]='B28 K0490 L046 A:47393 T:47429 P:28028+28029+28030'},
[28034]={[0]="Lunk's Adventure: Rendan's Weakness",[1]='B28 K0490 L046 A:47429 T:47393 P:28033'},
[28035]={[0]="The Mountain-Lord's Support",[1]='B28 K0490 L046 A:47393 T:14625 P:28034'},
[28038]={[0]='Blood in the Highlands',[1]='B700 FH K0850 L084 A:46318 T:46936'},
[28041]={[0]='Bait and Throttle',[1]='B700 FH K0840 L084 A:46313 T:46313'},
[28042]={[0]='Special Delivery for Brivelthwerp',[1]='B61 K0410 FH L038 A:40727 T:47383 P:25543,25562'},
[28043]={[0]='How to Maim Your Dragon',[1]='B700 FH K0840 L084 A:46313 T:47417 P:28041'},
[28044]={[0]='Touch the Untouchable',[1]='B182 K0460 L044 A:47366 T:47341 P:28049'},
[28045]={[0]='The Greatest Flavor in the World!',[1]='B61 K0410 L038 A:47383 T:47383 P:28031,28042'},
[28046]={[0]='Finish The Job',[1]='B0 +D FA K0850 L085 A:48250 T:48250'},
[28047]={[0]='Freezing the Pipes',[1]='B61 K0410 L038 A:47383 T:47383 P:28045+28051'},
[28048]={[0]="That Smart One's Gotta Go",[1]='B61 K0420 L038 A:47383 T:47383 P:28045+28051'},
[28049]={[0]='See the Invisible',[1]='B182 K0460 L044 A:47366 T:47366'},
[28050]={[0]='Shark Tank',[1]='B0 +D FA K0850 L085 A:48255 T:48255'},
[28051]={[0]='We All Scream for Ice Cream... and then Die!',[1]='B61 K0410 L038 A:47383 T:47383 P:28031,28042'},
[28052]={[0]='Operation: Stir the Cauldron',[1]='B28 K0490 L046 A:14625 T:547393 P:28035'},
[28053]={[0]='Lunk Like Your Style',[1]='B28 SP K0500 L046 A:547429 T:547429 PL:28064'},
[28054]={[0]='Slavery is Bad',[1]='B28 K0490 L046 A:547393 T:14628 P:28052'},
[28055]={[0]='Sweet, Horrible Freedom',[1]='B28 K0490 L046 A:547393 T:14628 P:28052'},
[28056]={[0]='Rise, Obsidion',[1]='B28 K0490 L046 A:547393 T:14628 P:28052'},
[28057]={[0]="Kill 'em With Sleep Deprivation",[1]='B28 K0500 L046 A:14628 T:514626 P:28054+28055+28056'},
[28058]={[0]='Look at the Size of It!',[1]='B28 K0500 L046 A:100062933 T:14628'}, -- seems to be triggered by someone doing 28057
[28059]={[0]='Claiming The Keep',[1]='B0 +D FA K0850 L085 A:47240 T:47240'},
[28060]={[0]='Twisted Twilight Ties',[1]='B28 K0500 L046 A:514626 T:514625 P:28057'},
[28061]={[0]='Minions of Calcinder',[1]='B0 K0500 L046 A:514625 T:-28 P:28060'},
[28062]={[0]='From Whence He Came',[1]='B0 K0500 L046 A:514625 T:-28 P:28060'},
[28063]={[0]='Leave No Weapon Behind',[1]='B0 +D FA K0850 L085 A:47240 T:47240'},
[28064]={[0]='Welcome to the Brotherhood',[1]='B28 K0500 L046 A:-28 T:14625 P:28061+28062'},
[28065]={[0]='Walk A Mile In Their Shoes',[1]='B0 +D FA K0850 L085 A:47240 T:47240'},
[28068]={[0]='Adventurers Wanted: Blackrock Depths',[1]='B504956 FA K04964 L049 A:1207304 T:45903'},
[28069]={[0]='Adventurers Wanted: Blackrock Depths',[1]='B504956 K0490 FH L049 A:1207303 T:45823'},
[28084]={[0]="Might of the Krom'gar",[1]='B81 K0250 FH L024 A:42028 T:42028'},
[28085]={[0]='Trouble at Highperch',[1]='B61 K0440 L038 A:45442 T:47471 P:27329,27330'},
[28086]={[0]='Free the Pridelings',[1]='B61 K0440 L038 A:47471 T:47471 P:28085'},
[28087]={[0]='Death to all Trappers!',[1]='B61 K0440 L038 A:47471 T:47471 P:28085'},
[28088]={[0]='Release Heartrazor',[1]='B61 K0440 L038 A:47471 T:47471 P:28086+28087'},
[28089]={[0]="Warchief's Command: Hillsbrad Foothills!",[1]='B0 K0200 FH L019 M023 A:44640 T:2215 PLT:26965 I:27098,27601,28096,28571'},
[28090]={[0]='Precious Goods',[1]='B700 FH K0850 L084 A:47492 T:47492'},
[28091]={[0]='Easy Pickings',[1]='B700 FH K0850 L084 A:47492 T:47492 P:28090'},
[28092]={[0]='If The Key Fits',[1]='B700 FH K0850 L084 A:47493 T:47374 P:28097'},
[28093]={[0]='Pressing Forward',[1]='B700 K0850 FH L084 A:47374 T:47605 P:28092'},
[28094]={[0]='Paving the Way',[1]='B700 K0850 FH L084 A:47374 T:47374'},
[28096]={[0]='Welcome to the Machine',[1]='B24 K0200 FH L019 A:2215 T:2215 O:28089,28571'},
[28097]={[0]='The Gates of Grim Batol',[1]='B700 FH K0850 L084 A:47492 T:47493 P:28090,28091'},
[28098]={[0]='The Twilight Skymaster',[1]='B61 K0440 L038 A:47471 T:47471 P:28088'},
[28099]={[0]="Rasha'krak",[1]='B28 K0480 L046 A:14625 T:14625 P:27965'},
[28100]={[0]='A Talking Totem',[1]='B182 K0460 L044 A:11554 T:1206585'},
[28101]={[0]="Mathias' Command",[1]='B700 FA K0850 L084 A:45528 T:47592 P:27507+27508+27509'},
[28102]={[0]='Fight the Power',[1]='B182 K0460 L044 A:9116 T:9116'},
[28103]={[0]='Easy Pickings',[1]='B700 FA K0850 L084 A:47592 T:47592 P:28101'},
[28104]={[0]='Precious Goods',[1]='B700 FA K0850 L084 A:47592 T:47592 P:28101'},
[28105]={[0]='Kavem the Callous',[1]='B720 K0830 L083 A:46872 T:46872 P:27922'},
[28107]={[0]='Paving the Way',[1]='B700 FA K0850 L084 A:47611 T:47611 PL:28108'},
[28108]={[0]='If The Key Fits',[1]='B700 FA K0850 L084 A:47592 T:47611 P:28103+28104'},
[28109]={[0]='Pressing Forward',[1]='B700 FA K0850 L084 A:47611 T:47605 P:28108'},
[28111]={[0]='Trouble at Azurelode',[1]='B24 K0200 FH L019 A:2215 T:47554 P:28096'},
[28112]={[0]='Escape From the Lost City',[1]='B720 K0830 L083 A:46872 T:47684 P:27923+27924+28105'},
[28113]={[0]='Break the Unbreakable',[1]='B182 K0460 L044 A:47341 T:47341'},
[28114]={[0]='Glorious Harvest',[1]='B24 K0200 FH L019 A:47432 T:47551'},
[28115]={[0]='Past Their Prime',[1]='B24 K0200 FH L019 A:47432 T:47551'},
[28116]={[0]='Crying Violet',[1]='B182 K0460 L044 A:10922 T:10922 P:28152'},
[28117]={[0]='Clearing the Depths',[1]='B0 +D FA K0850 L085 A:48039 T:48039'},
[28118]={[0]='The Imprisoned Archmage',[1]='B0 +D FA K0850 L085 A:48039 T:48039'},
[28119]={[0]='Purity From Corruption',[1]='B182 K0460 L044 A:10922 T:10922'},
[28120]={[0]='Learning From The Past',[1]='B0 +D FA K0850 L085 A:48039 T:48039'},
[28121]={[0]='Forces of Jaedenar',[1]='B182 K0460 L044 A:11019 T:11019'},
[28122]={[0]='A Huge Problem',[1]='B0 +D FA K0850 L085 A:48066 T:48066'},
[28123]={[0]='The Demon Chain',[1]='B700 FH K0840 L084 A:47417 T:47417 P:28043'},
[28124]={[0]='On to the Bulwark',[1]='B61 K0450 L038 A:47471 T:47580 P:28098'},
[28125]={[0]='Something to Wear',[1]='B61 K0450 L038 A:47580 T:47580 P:28124'},
[28126]={[0]='Dousing the Flames of Protection',[1]='B182 K0460 L044 A:10922 T:10922 P:28119'},
[28127]={[0]='Break Them Out',[1]='B61 K0450 L038 A:47580 T:47580 P:28124'},
[28128]={[0]='The Inner Circle',[1]='B182 K0460 L044 A:7114,7118,7120,9862,11019 T:11019 P:28121'},
[28129]={[0]='The Demon Prince',[1]='B182 K0460 L044 A:47617 T:47617'},
[28130]={[0]='Not The Friendliest Town',[1]='B0 +D FA K0850 L085 A:47240 T:47240'},
[28131]={[0]='Twin Temptresses',[1]='B182 K0460 L044 A:9860,9861,47617 T:47617 P:28129'},
[28132]={[0]='Efficient Excavations',[1]='B720 K0830 L083 A:100062768 T:47670'},
[28133]={[0]='Fury Unbound',[1]='B700 FH K0840 L084 A:47417 T:47671 P:28123'},
[28134]={[0]='Impending Retribution',[1]='B720 K0830 L083 A:47684 T:47684 P:28112'},
[28135]={[0]="Al'Akir's Vengeance",[1]='B720 K0830 L083 A:47684 T:45799 P:28134'},
[28136]={[0]='Behind You!',[1]='B61 K0450 L038 A:47580 T:47580 P:28125+28127'},
[28137]={[0]='Teach A Man To Fish.... Or Steal',[1]='B0 +D FA K0850 L085 A:47240 T:47240'},
[28138]={[0]='Human Infestation',[1]='B24 K0200 FH L019 A:47554 T:47554 P:28111'},
[28139]={[0]="Codemaster's Code",[1]='B61 K0450 L038 A:47580 T:47580 P:28125+28127'},
[28140]={[0]='The Elder Crone',[1]='B0 K0450 L038 A:47580 T:-61 P:28136+28139'},
[28141]={[0]='Relics of the Sun King',[1]='B720 K0830 L083 A:47715 T:47715'},
[28142]={[0]='To the Withering',[1]='B61 K0450 L038 A:-61 T:47745 P:28140'},
[28144]={[0]='Thieving Little Monsters!',[1]='B24 K0200 FH L019 A:47554 T:47554'},
[28145]={[0]='Venomblood Antidote',[1]='B720 K0830 L083 A:47715 T:47715'},
[28146]={[0]='Coastal Delicacies!',[1]='B24 K0200 FH L019 A:47551 T:47551'},
[28147]={[0]='Purple is Your Color',[1]='B700 FH K0850 L084 A:47723 T:47723'},
[28148]={[0]='Culling the Corrupted',[1]='B182 K0450 L044 A:10921 T:10921'},
[28149]={[0]='Whispers in the Wind',[1]='B700 FH K0850 L084 A:47751 T:47751'},
[28150]={[0]='An Arcane Ally',[1]='B182 K0460 L044 A:10923 T:47341'},
[28151]={[0]='Dressed to Kill',[1]='B700 FH K0850 L084 A:47723 T:47723 P:28147'},
[28152]={[0]='Jaedenar Awaits',[1]='B182 K0460 L044 A:9116 T:10922'},
[28153]={[0]="Shadow Lord Fel'dan",[1]='B182 K0460 L044 A:9517,47617 T:47617 P:28131'},
[28154]={[0]="Muckgill's Flipper or Something...",[1]='B24 K0200 FH L019 A:100063090 T:47554'},
[28155]={[0]='Lord Banehollow',[1]='B182 K0460 L044 A:47617 T:47617 P:28153'},
[28156]={[0]='Deep Mine Rescue',[1]='B24 K0200 FH L019 A:47681 T:47554'},
[28157]={[0]='Four Twilight Elements',[1]='B61 K0450 L038 A:47745 T:47745 P:28142'},
[28158]={[0]='Unbound',[1]='B61 K0450 L038 A:47745 T:47745 P:28142'},
[28159]={[0]='The Doomstone',[1]='B61 K0450 L038 A:47745 T:47745 P:28157+28158'},
[28160]={[0]='Spread the Word',[1]='B61 FA K0450 L038 A:47745 T:40027 P:28159'},
[28161]={[0]='Spread the Word',[1]='B61 K0450 FH L038 A:47745 T:40028 P:28159'},
[28162]={[0]='Swamp Bait',[1]='B0 +D FA K0850 L085 A:48066 T:48066'},
[28163]={[0]='The Leftovers',[1]='B0 +D FA K0850 L085 A:48066 T:48066'},
[28164]={[0]='Seek Brother Silverhallow',[1]='B0 FH CT RG K0200 L020 A:43870 T:45347 I:27441'},
[28165]={[0]='D-Block',[1]='B0 +D FA K0850 L085 A:48061 T:48061'},
[28166]={[0]="Thog's Nightlight",[1]='B700 FH K0850 L084 A:47751 T:47751 P:28149'},
[28167]={[0]='Report to Carvo Blastbolt',[1]='B0 FA RN K0010 A:45966 T:47250'},
[28168]={[0]='Trouble at the Sludge Fields',[1]='B24 K0210 FH L019 A:47554 T:47781 P:28144'},
[28169]={[0]='Withdraw to the Loading Room!',[1]='B0 FA RN K0010 A:47250 T:46274'},
[28170]={[0]='Night Terrors',[1]='B700 FH K0850 L084 A:47751 T:47751 P:28166'},
[28171]={[0]='And the Sky Streaked Red',[1]='B700 K0850 L084 A:47605 T:47902 P:28758'},
[28172]={[0]='Done Nothing Wrong',[1]='B29 FA K0500 L049 A:47779 T:47779'},
[28173]={[0]='Blackout',[1]='B700 K0850 L084 A:47902 T:47902 P:28171'},
[28174]={[0]='Burning Vengeance',[1]='B29 FA K0500 L049 A:47811 T:47811 I:28416,26726'},
[28175]={[0]='Shining Through the Dark',[1]='B700 K0850 L084 A:47904 T:47904 P:28171'},
[28176]={[0]='Following the Young Home',[1]='B700 K0850 L084 A:47902 T:47905 P:28173+28175+28191'},
[28177]={[0]='Stocking Up',[1]='B29 FA K0500 L049 A:47811 T:47811 P:28174,28416'},
[28178]={[0]='A Future Project',[1]='B29 FA K0500 L049 A:47811 T:47811 P:28174,28416'},
[28179]={[0]='Mud Hunter',[1]='B29 FA K0500 L049 A:47811 T:47811 P:28174,28416'},
[28180]={[0]='The Sand, the Cider, and the Orb',[1]='B29 FA K0500 L049 A:47811 T:14437 P:28177+28178+28179'},
[28181]={[0]='Warlocks Have the Neatest Stuff',[1]='B29 FA K0500 L049 A:14437 T:14437 P:28180'},
[28182]={[0]='Shadow Boxing',[1]='B29 FA K0500 L049 A:14437 T:14437 P:28180'},
[28183]={[0]='Return to Keeshan',[1]='B29 FA K0500 L049 A:14437 T:47811 P:28181+28182'},
[28184]={[0]='Chiselgrip, the Heart of the Steppes',[1]='B29 FA K0500 L049 A:47811 T:48033 P:28172+28183'},
[28185]={[0]='Svarnos',[1]='B0 +D FA K0850 L085 A:48061 T:48061'},
[28186]={[0]='Cursed Shackles',[1]='B0 +D FA K0850 L085 A:48061 T:48061'},
[28187]={[0]='Missed Me By Zhat Much!',[1]='B720 K0830 L083 A:47940 T:47972 P:27990'},
[28188]={[0]='Prison Revolt',[1]='B0 +D FA K0850 L085 A:48074 T:48074'},
[28189]={[0]='Do the Right Thing',[1]='B0 K0200 FH L019 A:1206944'},
[28190]={[0]='The Tainted Ooze',[1]='B182 K0470 L045 A:47692 T:47692'},
[28191]={[0]='A Fitting End',[1]='B700 K0850 L084 A:47902 T:47902 P:28171'},
[28192]={[0]='No One Here Gets Out Alive',[1]='B24 K0210 FH L019 A:47781 T:47781 P:28168'},
[28193]={[0]='Lockdown!',[1]='B720 K0830 L083 A:47972 T:47972 P:28187'},
[28194]={[0]='The Great Escape',[1]='B720 K0830 L083 A:47967 T:47967 P:28187'},
[28195]={[0]='Sending a Message',[1]='B720 K0830 L083 A:47972 T:47972 P:28193'},
[28196]={[0]='The Battle for Hillsbrad',[1]='B24 K0210 FH L019 A:100063250 T:47781 P:28192'},
[28197]={[0]='Discretion is Key',[1]='B24 K0210 FH L019 A:47781 T:47781 P:28196'},
[28198]={[0]='The Weakest Link',[1]='B720 K0830 L083 A:46134 T:46883 P:27631'},
[28199]={[0]='For Science!',[1]='B24 K0210 FH L019 A:47899 T:47899'},
[28200]={[0]='The Element of Supplies',[1]='B720 K0830 L083 A:48012 T:48012 P:27631'},
[28201]={[0]='Ploughshares to Swords',[1]='B720 K0830 L083 A:46134 T:46134 P:27631'},
[28202]={[0]='A Perfect Costume',[1]='B29 FA RF RH K0500 L049 A:48001 T:48109 P:28254'},
[28203]={[0]='A Perfect Costume',[1]='B29 FA RD RW K0500 L049 A:48001 T:48109 P:28254'},
[28204]={[0]='A Perfect Costume',[1]='B29 FA RN K0500 L049 A:48001 T:48109 P:28254'},
[28205]={[0]='A Perfect Costume',[1]='B29 FA RE K0500 L049 A:48001 T:48109 P:28254'},
[28206]={[0]='Little Girl Lost',[1]='B24 K0210 FH L019 A:47781 T:47869 P:28196,28197'},
[28207]={[0]='A Slimy Situation',[1]='B182 K0470 L045 A:47696 T:47696'},
[28208]={[0]="Winna's Kitten",[1]='B182 K0470 L045 A:47696 T:47696'},
[28209]={[0]='Freedom for Lydon',[1]='B24 K0210 FH L019 A:47900 T:47900'},
[28210]={[0]='Shaping Up',[1]='B720 K0830 L083 A:46883 T:48022 P:28198'},
[28211]={[0]='Tempered in Elemental Flame',[1]='B700 FA K0840 L084 A:48014 T:48014'}, -- TODO: Same req: methinks 27752 and maybe 27753 and/or 27754
[28212]={[0]='Hot Stuff',[1]='B700 FA K0840 L084 A:48014 T:48014'}, -- TODO: Same req: methinks 27752 and maybe 27753 and/or 27754
[28213]={[0]='Hazzard Disposal',[1]='B182 K0470 L045 A:47696 T:47696 P:28208'},
[28214]={[0]='Cleanup at Bloodvenom Post',[1]='B182 K0470 L045 A:47692 T:47692'},
[28215]={[0]='Potential Energy',[1]='B700 FA K0840 L084 A:48014 T:48014'}, -- TODO: Same req: methinks 27752 and maybe 27753 and/or 27754
[28216]={[0]='Magmalord Falthazar',[1]='B700 FA K0840 L084 A:46591 T:46591,48173 P:27754'}, -- TODO: Determine which of 27752 and/or 27753 needed too
[28217]={[0]='Wanted: The Demon Hunter',[1]='B182 K0480 L046 A:47843 T:47923'},
[28218]={[0]='A Destiny of Flame and Sorrow',[1]='B182 K0480 L046 A:47923 T:47923'},
[28219]={[0]='Buzzers for Baby',[1]='B182 K0480 L046 A:48032,48038 T:48032 P:28229'},
[28220]={[0]='Seeking Soil',[1]='B182 K0480 L046 A:48032 T:48032 P:28219'},
[28221]={[0]="These Roots Were Made For Stompin'",[1]='B182 K0480 L046 A:7139,48042 T:48042 P:28219,28220'},
[28222]={[0]="Singin' in the Sun",[1]='B182 K0480 L046 A:48032 T:48042 P:28221'},
[28223]={[0]='The Warden',[1]='B0 +D FA K0850 L085 A:48074 T:48074'},
[28224]={[0]='The Last Protector',[1]='B182 K0480 L046 A:7149,48042 T:48044 P:28221,28222'},
[28225]={[0]='Prove Yer Allegiance',[1]='B29 K0500 L049 A:48033 T:48033 P:28184'},
[28226]={[0]='Scrapped Golems',[1]='B29 K0500 L049 A:48033 T:48033 P:28184'},
[28227]={[0]='Golem Training',[1]='B29 L049 A:48033 T:48033 P:28225+28226'},
[28228]={[0]='Rejoining the Forest',[1]='B0 K0480 L046 A:48044 P:28224'},
[28229]={[0]='Nature and Nurture',[1]='B0 K0480 L046 A:48126'},
[28230]={[0]='Protocol',[1]='B24 K0210 FH L019 A:47900,48020 T:48020'},
[28231]={[0]='Do it for Twinkles',[1]='B24 K0210 FH L019 A:47869,48021 T:48021'},
[28232]={[0]='Food From Below',[1]='B0 +D FA K0850 L085 A:48074 T:48074'},
[28233]={[0]='The Lost Brother',[1]='B700 FA K0840 L084 A:48046 T:48053 P:27809'},
[28234]={[0]='They Took Me Pants!',[1]='B700 FA K0840 L084 A:48053 T:48053 P:28233'},
[28235]={[0]='Burnside Must Fall',[1]='B24 K0210 FH L019 A:48020 T:48020 P:28230'},
[28237]={[0]='A Blight Upon the Land',[1]='B24 K0210 FH L019 A:48020 T:47900 P:28235'},
[28238]={[0]='Twilight Shores',[1]='B0 FA K0840 L084 A:29611 T:544806 P:27106'},
[28239]={[0]='Into the Black Tooth Hovel',[1]='B29 FA K0500 L049 A:48109 T:48085 P:28202,28203,28204,28205'},
[28241]={[0]='A Vision of Twilight',[1]='B700 FA K0840 L084 A:48010 T:1009961 P:27752+27753'},
[28242]={[0]='We All Must Sacrifice',[1]='B700 FA K0840 L084 A:1009961 T:1009961 P:28241'},
[28243]={[0]='The Eyes Have It',[1]='B700 FA K0840 L084 A:1009961 T:48010 P:28242'},
[28244]={[0]='Eye Spy',[1]='B700 FA K0840 L084 A:48010,48175 T:48010,48175 P:28243'}, -- TODO: Can 48175 really do this?  what phase?
[28245]={[0]='Grunt Work',[1]='B29 K0500 L049 A:48085 T:48085 P:28239'},
[28246]={[0]='Strategic Cuts',[1]='B29 K0500 L049 A:9176,48099,48100 AA:48110 T:48110 P:28245'},
[28247]={[0]='Last of Her Kind',[1]='B700 K0850 L084 A:47905 T:47902 P:28176'},
[28248]={[0]="Victors' Point",[1]='B700 FA K0850 L084 A:47902 T:45668 P:28247'},
[28249]={[0]='Crushblow',[1]='B700 FH K0850 L084 A:47902 T:45658'},
[28250]={[0]='Thieving Little Pluckers',[1]='B720 +D K0830 L083 A:46603 T:46603'},
[28251]={[0]='Trouble at Southshore',[1]='B24 K0220 FH L020 A:47900 T:2391 P:28237'},
[28252]={[0]="The Kodocaller's Horn",[1]='B0 K0500 L049 A:48085 P:28246'},
[28253]={[0]='Taking the Horn For Ourselves',[1]='B29 FA K0500 L049 A:48110 T:48110 P:28246,28252'},
[28254]={[0]='A Needle in a Hellhole',[1]='B29 FA K0500 L049 A:48109 T:48001 PC:28225+28226'},
[28256]={[0]="The Skull of Gul'dan",[1]='B182 K0480 L046 A:47923 T:47923'},
[28257]={[0]='The Fall of Tichondrius',[1]='B182 K0480 L046 A:47923 T:47923'},
[28258]={[0]='Meet with Ander Germaine',[1]='B0 FA CW K0500 L050 A:4087,17120 T:914 I:28393'},
[28259]={[0]='Meet with Demisette Cloyce',[1]='B0 FA CL K0500 L050 A:5173 T:461 I:28399'},
[28260]={[0]='Meet with Wulf Hansreim',[1]='B0 FA CH K0500 L050 A:4138,5115,17122 T:44247 I:28394'},
[28261]={[0]='Deceivers In Our Midst',[1]='B182 K0480 L046 A:47923 T:47923'},
[28262]={[0]='Meet with Lord Tony Romano',[1]='B0 FA CR K0500 L050 A:4214,5165 T:13283 I:28406'},
[28263]={[0]='Meet with Maginor Dumas',[1]='B0 FA CW CM K0500 L050 A:5146,16749,50690 T:331 I:28398'},
[28264]={[0]="Navarax's Gambit",[1]='B182 K0480 L046 A:47923 T:47843 P:28261'},
[28265]={[0]="General Thorg'izog",[1]='B29 FA K0510 L049 A:48109 T:48133 P:28227+28253'},
[28266]={[0]='Trial by Magma',[1]='B29 FA K0510 L049 A:48133 T:48133 P:28265'},
[28267]={[0]='Firing Squad',[1]='B720 K0830 L083 A:47972 T:48162 P:28194+28195'},
[28268]={[0]='Meet with Lord Grayson Shadowbreaker',[1]='B0 FA RF RD RH CP K050 L050 A:5147,16761,35281 T:928 I:28405'},
[28269]={[0]="Meet Me In Vir'sar",[1]='B720 K0830 L083 A:48162 T:48186 P:28267'},
[28271]={[0]='Reduced Productivity',[1]='B720 K0830 L083 A:48186 T:48186 P:28353'},
[28272]={[0]='Missing Pieces',[1]='B720 K0830 L083 A:48186 T:48186 P:28274'},
[28273]={[0]='Friend of a Friend',[1]='B720 K0830 L083 A:48186 T:48203 P:28269'},
[28274]={[0]='Two Tents',[1]='B720 K0830 L083 A:48203 T:48431 P:28273'},
[28275]={[0]="Bombs Away!",[1]='B0 K0850 +D FA L085 A:48254 T:48254'},
[28276]={[0]="Salhet's Secret",[1]='B720 K0830 L083 A:48022 T:48237 P:28210'},
[28277]={[0]='Salhet the Tactician',[1]='B720 K0830 L083 A:48237 T:48237 P:28276'},
[28278]={[0]='I Am the Law and I Am the Lash',[1]='B29 FA K0510 L049 A:48133 T:48133 P:28266'},
[28279]={[0]='Abuse of Power',[1]='B29 FA K0510 L049 A:48110 T:48110 P:28266'},
[28280]={[0]='Tear Them From the Sky!',[1]='B700 FA K0840 L084 A:48174 T:48174 P:28215'},
[28281]={[0]='Last Stand at Thundermar',[1]='B700 FA K0840 L084 A:48173 T:48173 P:28280'},
[28282]={[0]='Narkrall, The Drake-Tamer',[1]='B700 FA K0840 L084 A:48173 T:48173 P:28281'},
[28283]={[0]="What's that Rattle?",[1]='B61 K0420 FA L038 A:545277 T:48208 P:27314 I:27316'},
[28284]={[0]="What's that Rattle?",[1]='B61 K0420 FH L038 A:545278 T:48208 P:27315 I:27317'},
[28285]={[0]='Meet with High Priestess Laurena',[1]='B0 FA CT K0500 L050 A:11401,11406,16756 T:376 I:28328'},
[28286]={[0]='Enough Damage For One Day',[1]='B29 FA K0510 L049 A:48110 T:48110 P:28279'},
[28287]={[0]='Meet with Farseer Umbrua',[1]='B0 FA RF RD CS K0500 L050 A:23127 T:20407 I:28401'},
[28288]={[0]='Open Their Eyes',[1]='B182 K0460 L044 A:47341 T:47341'},
[28289]={[0]='Moonglade Calls',[1]='B0 K0500 CD L050 AA:4217,44395 AH:3034,44726,44978 T:12042 I:28343'},
[28290]={[0]='Meet with Grezz Ragefist',[1]='B0 K0500 FH CW L050 A:3042,4593,43009 T:3353 I:28457'},
[28291]={[0]='Return to Camp',[1]='B720 K0830 L083 A:48237 T:46134 P:28277'},
[28292]={[0]="That's No Pyramid!",[1]='B0 FA K0830 L083 A:44799 T:44238 P:27058'},
[28293]={[0]="That's No Pyramid!",[1]='B0 FH K0830 L083 A:44823 T:47571 P:27059'},
[28294]={[0]='The Kirthaven Summit',[1]='B700 FA K0840 L084 A:48173 T:48367 P:28282'},
[28295]={[0]='Meetup with the Caravan',[1]='B0 FA K0830 L083 A:44238 T:44833 P:28292 I:28558'},	-- TODO: Discover the other I:...probably the one where you take the caravan itself
[28296]={[0]='Meetup with the Caravan',[1]='B0 K0830 FH L083 A:47571 T:44833 P:28293 I:28557'},
[28297]={[0]='Meet with Ormak Grimshot',[1]='B0 K0500 FH CH L050 A:3039,16674,39116 T:3352 I:28461'},
[28298]={[0]='Meet with Gordul',[1]='B0 K0500 FH CR L050 A:4584,16684 T:47233 I:28463'},
[28299]={[0]='Meet with Zevrost',[1]='B0 K0500 FH CL L050 A:4563,16648,43881 T:3326 I:28459'},
[28300]={[0]='Meet with Ureda',[1]='B0 K0500 FH CM L050 A:3047,4566,16653 T:47246 I:28458'},
[28301]={[0]='Meet with Kardris Dreamseeker',[1]='B0 K0500 FH CS L050 A:3032 T:3344 I:28465'},
[28302]={[0]='Meet with Sunwalker Atohmo',[1]='B0 K0500 FH RT CP L050 A:20406,43795 T:44725 I:28466'},
[28303]={[0]='Meet with Master Pyreanor',[1]='B0 K0500 FH RB CP L050 A:16681,20406,43795 T:23128 I:28473'},
[28304]={[0]='Meet with Dark Cleric Cecille',[1]='B0 K0500 FH RU CT L050 A:3045,4606,16658 T:45339 I:28474'},
[28305]={[0]='The Fate of Bloodvenom Post',[1]='B182 K0480 L046 A:47617 T:47696'},
[28306]={[0]='Whisperwind Grove',[1]='B182 K0470 L045 A:47696 T:48459'},
[28307]={[0]='Meet with Tyelis',[1]='B0 K0500 FH RB CT L050 A:4606,16658,43870 T:45337 I:28475'},
[28309]={[0]='Meet with Shadow-Walker Zuru',[1]='B0 K0500 FH RL CT L050 A:3045,16658 T:45137 I:28477'},
[28310]={[0]="Morgan's Vigil",[1]='B29 FA K0510 L049 A:48110 T:9177 P:28286'},
[28311]={[0]='Blackened Ashes',[1]='B29 FA K0510 L049 A:48307 T:48307 P:28310'},
[28312]={[0]='Latent Demons of the Land',[1]='B29 FA K0510 L049 A:48307 T:48307 P:28310'},
[28313]={[0]='A Heap of Delicious Worg',[1]='B29 FA K0510 L049 A:48307 T:48307 P:28310'},
[28314]={[0]='Blood Tour',[1]='B29 FA K0510 L049 A:48306,48346 T:48346 P:28311+28312+28313'},
[28315]={[0]='Draconic Vanguard',[1]='B29 FA K0510 L049 A:48306,48346 T:48346 P:28311+28312+28313'},
[28316]={[0]='A Deal With a Dragon',[1]='B29 FA K0510 L049 A:48306,48346 T:48292 P:28311+28312+28313'},
[28317]={[0]="A Delivery for Thorg'izog",[1]='B29 FA K0510 L049 A:48307 T:48316 P:28326'},
[28318]={[0]='A Delivery for Neeralak',[1]='B29 FA K0510 L049 A:48307 T:48314 P:28326'},
[28319]={[0]="A Delivery for Xi'lun",[1]='B29 FA K0510 L049 A:48307 T:48312 P:28326'},
[28320]={[0]='Assault on Dreadmaul Rock',[1]='B29 FA K0520 L049 A:48306 T:48307 P:28327'},
[28321]={[0]='Glory Amidst Chaos',[1]='B29 FA K0520 L049 A:48307 T:48307 P:28320'},
[28322]={[0]='The Spoils of War',[1]='B29 FA K0520 L049 A:48307 T:1207125 P:28321'},
[28323]={[0]='Meet with Brother Silverhallow',[1]='B0 FH RG CT K0500 L050 A:43870 T:45347 I:28478'},
[28324]={[0]='Studies in Lethality',[1]='B24 K0220 FH L020 A:2391 T:2391 P:28251'},
[28325]={[0]='Green Living',[1]='B24 K0220 FH L020 A:2391 T:2391'},
[28326]={[0]='Placing the Pawns',[1]='B29 FA K0510 L049 A:-29 T:48307 P:28314+28315+28316'},
[28327]={[0]='Locked and Loaded',[1]='B29 FA K0520 L049 A:-29 T:48307 P:28317+28318+28319'},
[28328]={[0]='Twilight Scheming',[1]='B0 FA CT K05064 L050 A:376 T:376 O:28285'},
[28329]={[0]='Angry Scrubbing Bubbles',[1]='B24 K0220 FH L020 A:48319 T:2391'},
[28330]={[0]='Trail of Filth',[1]='B24 K0220 FH L020 A:2391,48322 T:2391 P:28329'},
[28331]={[0]="Helcular's Rod Giveth...",[1]='B24 K0220 FH L020 A:48129 T:48129'},
[28332]={[0]="Helcular's Command",[1]='B24 K0220 FH L020 A:48129 T:48129 P:28331'},
[28333]={[0]="It's Time to Oil Up",[1]='B182 K0490 FH L047 A:48127 T:48127'},
[28334]={[0]='A Flare Fight',[1]='B182 K0490 FH L047 A:48127 T:48127'},
[28335]={[0]='Turn It Off! Turn It Off!',[1]='B182 K0490 FH L047 A:48333 T:1207104'},
[28336]={[0]='Slap and Cap',[1]='B182 K0490 FH L047 A:48127 T:48127'},
[28337]={[0]='The Shredders of Irontree',[1]='B182 FA K0480 L046 A:48493 T:48493 P:28384'},
[28338]={[0]='Deadwood of the North',[1]='B182 K0490 L047 A:15395 T:15395 P:28373,28392'},
[28339]={[0]='Is Your Oil Running?',[1]='B182 K0490 FH L047 A:48127 T:48127'},
[28340]={[0]='A Bomb Deal',[1]='B182 K0490 FH L047 A:48333 T:48333'},
[28341]={[0]='Collecting Corruption',[1]='B182 K0480 L046 A:48339 T:48339'},
[28342]={[0]='Fel To Pieces',[1]='B182 K0480 L046 A:48339 T:48339'},
[28343]={[0]='The Breath of Cenarius',[1]='B0 K0500 CD L050 A:12042 T:12042 O:28289'},
[28344]={[0]="Can You Smell What the Lok'tar is Cooking?",[1]='B24 K0220 FH L020 A:48129 T:48218 P:28331,28332'},
[28345]={[0]='*Gurgle* HELP! *Gurgle*',[1]='B24 K0220 FH L020 A:48218 T:48218 P:28344'},
[28346]={[0]='The Bachelor',[1]='B700 FA K0840 L084 A:48365 T:48364 P:28294'},
[28348]={[0]='Stormpike Rendezvous',[1]='B24 K0220 FH L020 A:48218 T:48218 P:28345'},
[28349]={[0]='Megs in Marketing',[1]='B0 K0030 FH RG A:34668 T:34874 P:25473'},
[28350]={[0]='Master Trapper',[1]='B720 K0830 L083 A:48431 T:48431 P:28274'},
[28351]={[0]='Unlimited Potential',[1]='B720 K0830 L083 A:48431 T:48431 P:28274'},
[28352]={[0]='Camel Tow',[1]='B720 K0830 L083 A:48431 T:48431 P:28274'},
[28353]={[0]='Jonesy Sent For You',[1]='B720 K0830 L083 A:48431 T:48186 P:28350+28351+28352'},
[28354]={[0]='Kasha Will Fly Again',[1]='B24 K0220 FH L020 A:48218 T:48218 P:28348'},
[28355]={[0]='Terrible Little Creatures',[1]='B0 K0220 FH L020 AK:2372,2373 T:0'},
[28356]={[0]='Preemptive Strike',[1]='B24 K0220 FH L020 A:100063686 T:48129'},
[28357]={[0]='Take it to the Tree',[1]='B182 K0490 FH L047 A:48127 T:48127'},
[28358]={[0]='Hunting the Damned',[1]='B182 K0480 L046 A:48349 T:48349'},
[28359]={[0]='The Core of Kroshius',[1]='B182 K0480 L046 A:48349 T:48349'},
[28360]={[0]='Running Their Course',[1]='B182 K0480 L046 A:48459 T:48459'},
[28361]={[0]='Squirrely Clean',[1]='B182 K0480 L046 A:48459 T:48459 P:28360'},
[28362]={[0]='Stupid Drizle!',[1]='B182 K0490 L047 A:48461 T:47556'},
[28363]={[0]="Stirred the Hornet's Nest",[1]='B720 K0830 L083 A:48186 T:48431 P:28271+28272'},
[28364]={[0]="The Chieftain's Key",[1]='B182 K0490 L047 A:47556 T:47556 P:28362'},
[28366]={[0]='Disarming Bears',[1]='B182 K0490 L047 A:15395 T:15395'},
[28367]={[0]='Shroud of the Makers',[1]='B720 K0830 L083 A:48431 T:48186 P:28363'},
[28368]={[0]='Fire in the Hole!',[1]='B182 K0490 FH L047 A:1207104 T:48127 P:28335'},
[28369]={[0]='My Sister, Fanny',[1]='B700 FA K0840 L084 A:46591 T:48013 I:27753'},
[28370]={[0]='Wisp-napping',[1]='B182 K0490 FH L047 A:48127 T:48127 P:28357'},
[28372]={[0]='Back to Business',[1]='B182 K0490 FH L047 A:48469 T:48127'},
[28373]={[0]='Timbermaw Hold',[1]='B182 K0490 FH L047 A:48127 T:15395 P:28368'},
[28374]={[0]='Weeding the Lawn',[1]='B182 K0480 L046 A:48459 T:48459 P:28360,28361'},
[28375]={[0]='The Road to Purgation',[1]='B24 K0230 FH L020 A:48218 T:48470'},
[28376]={[0]="Myzerian's Head",[1]='B720 K0830 L083 A:100063700 T:48431'},
[28377]={[0]="Rescue at Glopgut's Hollow",[1]='B700 FA K0850 L084 A:48364 T:48472 P:28346'},
[28378]={[0]='Find Fanny',[1]='B700 FA K0850 L084 A:48472 T:48472 P:28377'},
[28379]={[0]="Ogre Bashin'",[1]='B700 FA K0850 L084 A:48472 T:48472 P:28377'},
[28380]={[0]='Pikwik in Peril',[1]='B182 K0490 FH L047 A:48127 T:48333 P:28357,28370'},
[28381]={[0]='The Denmother',[1]='B182 FA K0490 L047 A:48491 T:47931'},
[28382]={[0]='Enemy at our Roots',[1]='B182 FA K0490 L047 A:47931 T:47931 P:28381'},
[28383]={[0]='Wisps of the Woods',[1]='B182 FA K0490 L047 A:48492 T:48492'},
[28384]={[0]='Into the Clearing',[1]='B182 FA K0490 L047 A:47931 T:48493 P:28382'},
[28385]={[0]='Oil and Irony',[1]='B182 FA K0490 L047 A:48493 T:1207104'},
[28386]={[0]='Borrowed Bombs',[1]='B182 FA K0490 L047 A:48493 T:48493'},
[28387]={[0]='Burnout',[1]='B182 FA K0490 L047 A:48493 T:48493'},
[28388]={[0]='Bloody Wages',[1]='B182 FA K0490 L047 A:48493 T:48493 P:28387'},
[28389]={[0]='Report to the Denmother',[1]='B182 FA K0490 L047 A:48493 T:47931 P:28387,28388'},
[28390]={[0]='Glop, Son of Glop',[1]='B0 +D K0830 L081 A:44973 T:44973 V5862999 P:26709'},
[28391]={[0]='The Restless Brood',[1]='B0 +D K0830 L081 A:43806 T:42466,43806 V5862999 P:26709'},
[28392]={[0]='The Timbermaw Tribe',[1]='B182 FA K0490 L048 A:47931 T:15395 P:28373'},
[28393]={[0]='A Dangerous Alliance',[1]='B0 FA CW K05064 L050 A:914 T:914 O:28258'},
[28394]={[0]="The Golem Lord's Creations",[1]='B0 FA CH K05064 L050 A:44247 T:44247 O:28260'},
[28395]={[0]='Feathers for Nafien',[1]='B0 K0500 ++ L047 A:15395 T:15395'},
[28396]={[0]='Feathers for Grazle',[1]='B0 K0500 ++ L044 A:11554 T:11554'},
[28397]={[0]='They Will Never Expect This...',[1]='B24 K0230 FH L020 A:48470 T:48470 P:28375'},
[28398]={[0]="The Pyromancer's Grimoire",[1]='B0 FA CM K05064 L050 A:331 T:331 O:28263'},
[28399]={[0]='Stones of Binding',[1]='B0 FA RN CL K05064 L050 A:461 T:461 O:28259'},
[28400]={[0]='Heroes of the Horde!',[1]='B24 K0230 FH L020 A:48503 T:48545'},
[28401]={[0]='Slaves of the Firelord',[1]='B0 FA RF RD CS K05064 L050 A:20407 T:20407 O:28287'},
[28402]={[0]='Schnottz So Fast',[1]='B720 K0830 L083 A:48186 T:48528 P:28367'},
[28403]={[0]='Bad Datas',[1]='B720 K0830 L083 A:48528 T:48558 P:28402'},
[28404]={[0]="I'll Do It By Hand",[1]='B720 K0830 L083 A:48558 T:48558 P:28403'},
[28405]={[0]='Weapons of Darkness',[1]='B0 FA RF RD RH CP K05064 L050 A:928 T:928 O:28268'},
[28406]={[0]='The Dark Iron Army',[1]='B0 FA CR K05064 L050 A:13283 T:13283 O:28262'},
[28407]={[0]='The Bachelorette',[1]='B700 FA K0840 L084 A:48472 T:48530 P:28378+28379'},
[28408]={[0]='Something Bold',[1]='B700 FA K0840 L084 A:48367 T:48367 P:28407'},
[28409]={[0]='Something Brewed',[1]='B700 FA K08432 L084 A:48367 T:48367 P:28407'},
[28410]={[0]='Something Stolen',[1]='B700 FA K0840 L084 A:48367 T:48367 P:28407'},
[28411]={[0]='Something Stewed',[1]='B700 FA K0840 L084 A:48367 T:48367 P:28407'},
[28413]={[0]='Words and Music By...',[1]='B700 FA K0840 L084 A:48366 T:48366 P:28407'},
[28414]={[0]='Fourth and Goal',[1]='B0 K0030 RB A:37106 T:37106 P:24502'},	-- TODO: Determine who gets this quest vice 24503
[28415]={[0]='SEVEN! YUP!',[1]='B29 FA K0510 L049 A:9177 T:9177 P:28310'},
[28416]={[0]='Burning Vengeance',[1]='B29 FA K0500 L049 A:47811 T:47811 I:28174 P:26726'},
[28417]={[0]='Done Nothing Wrong',[1]='B29 K0500 FH L049 A:47779 T:47779 P:28515'},
[28418]={[0]='Burning Vengeance',[1]='B29 K0500 FH L049 A:48559 T:48559 P:28667'},
[28419]={[0]='Stocking Up',[1]='B29 K0500 FH L049 A:48559 T:48559'},
[28420]={[0]='A Future Project',[1]='B29 K0500 FH L049 A:48559 T:48559'},
[28421]={[0]='Mud Hunter',[1]='B29 K0500 FH L049 A:48559 T:48559'},
[28422]={[0]='The Sand, the Cider, and the Orb',[1]='B29 K0500 FH L049 A:48559 T:14437 P:28419+28420+28421'},
[28423]={[0]='Warlocks Have the Neatest Stuff',[1]='B29 K0500 FH L049 A:14437 T:14437'},
[28424]={[0]='Shadow Boxing',[1]='B29 K0500 FH L049 A:14437 T:14437 P:28423'},
[28425]={[0]='Return to Ariok',[1]='B29 K0500 FH L049 A:14437 T:48559 P:28423,28424'},
[28426]={[0]='Chiselgrip, the Heart of the Steppes',[1]='B29 K0500 FH L049 A:48559 T:48033 P:28425'},
[28427]={[0]='A Needle in a Hellhole',[1]='B29 K0500 FH L049 A:48568 T:48001'},
[28428]={[0]='A Perfect Costume',[1]='B29 K0500 FH RO RU L049 A:48001 T:48568'},
[28429]={[0]='A Perfect Costume',[1]='B29 K0500 FH RT RB L049 A:48001 T:48568'},
[28430]={[0]='A Perfect Costume',[1]='B29 K0500 FH L049 A:48001 T:48568'},
[28431]={[0]='A Perfect Costume',[1]='B29 K0500 FH RT RL RB L049 A:48001 T:48568'},
[28432]={[0]='Into the Black Tooth Hovel',[1]='B29 K0500 FH L049 A:48568 T:48085 P:28428,28429,28430,28431'},
[28433]={[0]='Grunt Work',[1]='B29 K0500 FH L049 A:48085 T:48085 P:28432'},
[28434]={[0]='Strategic Cuts',[1]='B29 K0500 L049 A:9176,48099,48100 AH:48568 T:48568 P:28433'},
[28435]={[0]="The Kodocaller's Horn",[1]='B0 K0500 FH L049 A:48085 P:28434'},
[28436]={[0]='Taking the Horn For Ourselves',[1]='B29 K0500 FH L049 A:48568 T:48568 P:28434,28435'},
[28437]={[0]="General Thorg'izog",[1]='B29 K0510 FH L049 A:48568 T:48133 P:28436'},
[28438]={[0]='Trial by Magma',[1]='B29 K0510 FH L049 A:48133 T:48133 P:28437'},
[28439]={[0]='I Am the Law and I Am the Lash',[1]='B29 K0510 FH L049 A:48133 T:48133 P:28438'},
[28440]={[0]='Abuse of Power',[1]='B29 FH K0510 L049 A:48568 T:48568'},
[28441]={[0]='Enough Damage For One Day',[1]='B29 K0510 FH L049 A:48568 T:48568 P:28440'},
[28442]={[0]='Flame Crest',[1]='B29 K0510 FH L049 A:48568 T:10260 P:28441'},
[28443]={[0]='Blackened Ashes',[1]='B29 K0510 FH L049 A:48569 T:48569'},
[28444]={[0]='Latent Demons of the Land',[1]='B29 K0510 FH L049 A:48569 T:48569'},
[28445]={[0]='A Heap of Delicious Worg',[1]='B29 K0510 FH L049 A:48569 T:48569'},
[28446]={[0]='Blood Tour',[1]='B29 K0510 FH L049 A:48565,48567 T:48567'},
[28447]={[0]='Draconic Vanguard',[1]='B29 K0510 FH L049 A:48565,48567 T:48567'},
[28448]={[0]='A Deal With a Dragon',[1]='B29 K0510 FH L049 A:48565,48567 T:48292'},
[28450]={[0]="A Delivery for Thorg'izog",[1]='B29 K0510 FH L049 A:48569 T:48316'},
[28451]={[0]='A Delivery for Neeralak',[1]='B29 K0510 FH L049 A:48569 T:48314'},
[28452]={[0]="A Delivery for Xi'lun",[1]='B29 K0510 FH L049 A:48569 T:48312'},
[28454]={[0]='Assault on Dreadmaul Rock',[1]='B29 K0520 FH L049 A:48565 T:48569'},
[28455]={[0]='Glory Amidst Chaos',[1]='B29 K0520 FH L049 A:48569 T:48569 P:28454'},
[28456]={[0]='The Spoils of War',[1]='B29 K0520 FH L049 A:48569 T:1207125 P:28455'},
[28457]={[0]='A Dangerous Alliance',[1]='B0 K0500 FH CW L050 A:3353 T:3353 O:28290'},
[28458]={[0]="The Pyromancer's Grimoire",[1]='B0 K0500 FH CM L050 A:47246 T:47246 O:28300'},
[28459]={[0]='Stones of Binding',[1]='B0 K0500 FH CL L050 A:3326 T:3326 O:28299'},
[28460]={[0]='Threat of the Winterfall',[1]='B281 K0500 L049 A:9298 T:9298 P:28524,28544,28545,28768'},
[28461]={[0]="The Golem Lord's Creations",[1]='B0 K0500 FH CH L050 A:3352 T:3352 O:28297'},
[28462]={[0]='Winterfall Firewater',[1]='B0 K0500 L049 A:100064353 T:9298'},
[28463]={[0]='The Dark Iron Army',[1]='B0 K0500 FH CR L050 A:47233 T:47233 O:28298'},
[28464]={[0]='Falling to Corruption',[1]='B281 K0500 L049 A:9298 T:1207179 P:28462'},
[28465]={[0]='Slaves of the Firelord',[1]='B0 K0500 FH CS L050 A:3344 T:3344 O:28301'},
[28466]={[0]='Weapons of Darkness',[1]='B0 K0500 FH RT CP L050 A:44725 T:44725 O:28302'},
[28467]={[0]='Mystery Goo',[1]='B281 K0500 L049 A:1176091,1207179 T:9298 P:28464'},
[28469]={[0]='Winterfall Runners',[1]='B281 K0500 L049 A:9298 T:9298 P:28467'},
[28470]={[0]='High Chief Winterfall',[1]='B281 K0500 L049 A:9298 T:9298 P:28469'},
[28471]={[0]='The Final Piece',[1]='B281 K0500 L049 A:100012842 T:9298'},
[28472]={[0]='Words of the High Chief',[1]='B281 K0500 L049 A:9298 T:10920 P:28471'},
[28473]={[0]='Weapons of Darkness',[1]='B0 K0500 FH RB CP L050 A:23128 T:23128 O:28303'},
[28474]={[0]='Twilight Scheming',[1]='B0 K0500 FH RU CT L050 A:45339 T:45339 O:28304'},
[28475]={[0]='Twilight Scheming',[1]='B0 K0500 FH RB CT L050 A:45337 T:45337 O:28307'},
[28477]={[0]='Twilight Scheming',[1]='B0 K0500 FH RL CT L050 A:45137 T:45137 O:28309'},
[28478]={[0]='Twilight Scheming',[1]='B0 K0500 FH RG CT L050 A:45347 T:45347 O:28323'},
[28479]={[0]="The Ruins of Kel'Theril",[1]='B281 K0510 L049 A:10920 T:48658 P:28472'},
[28480]={[0]='Lieutenants of Darkness',[1]='B720 K0840 L083 A:48564 T:48564 P:28623'},
[28482]={[0]="Sullah's Gift",[1]='B720 K0830 L083 A:48621 T:48698 P:28404'},
[28483]={[0]='Bleeding the Enemy',[1]='B720 K0840 L083 A:48564 T:48564 P:28623'},
[28484]={[0]='The Heart of the Matter',[1]='B24 K0230 FH L021 A:2437 T:2437'},
[28485]={[0]='Yetimus the Yeti Lord',[1]='B24 K0250 FH L021 A:2418 T:2418'},
[28486]={[0]="Salhet's Gambit",[1]='B720 K0840 L083 A:49345 T:49345 P:28623'},
[28487]={[0]="Humbert's Personal Problems",[1]='B24 K0230 FH L021 A:2419 T:2419'},
[28488]={[0]='Beneath the Surface',[1]='B0 +D K0830 L081 A:43805 T:43805 P:26709 I:26710,27048'},
[28489]={[0]='Stagwiches',[1]='B24 K0230 FH L021 A:2397 T:2397'},
[28490]={[0]="Hero's Call: Darkshore!",[1]='B0 FA RE RW K0100 L009 M013 A:1207321 T:32973 I:13518,26383,26385'},
[28491]={[0]='Not Fireflies, Flameflies',[1]='B29 K0510 FH L049 A:10260 T:10260 P:28442'},
[28492]={[0]="Hero's Call: Ashenvale!",[1]='B43 FA K0200 L019 M023 A:1207321,1207322 T:33187 I:26408'},
[28493]={[0]="Warchief's Command: Ashenvale!",[1]='B43 K0200 FH L019 M023 A:1206109,1206116,1207323 T:8582'},
[28494]={[0]="Warchief's Command: Northern Barrens!",[1]='B0 K0100 FH L009 M013 A:1206109,1206116,1207323 T:3337 I:26642'}, -- removed I:840 because I proved it to be wrong
[28495]={[0]='A Fighting Chance',[1]='B24 K0230 FH L021 A:17092 T:17092'},
[28496]={[0]="Warchief's Command: Azshara!",[1]='B0 K0100 FH L009 M013 A:1206109,1206116,1207323 T:35086'}, -- P:25275 is wrong
[28497]={[0]='Fire From the Sky',[1]='B720 K0830 L083 A:48698 T:48698 P:28482'},
[28498]={[0]='The Secret of Nahom',[1]='B720 K0840 L083 A:48761 T:48761 P:28561'},
[28499]={[0]='Punish the Trespassers',[1]='B720 K0840 L083 A:48501 T:48501 P:28561'},
[28500]={[0]='The Cypher of Keset',[1]='B720 K0840 L083 A:48761 T:48761 P:28498+28499'},
[28501]={[0]='The Defense of Nahom',[1]='B720 K0840 L083 A:48761 T:48761 P:28500'},
[28502]={[0]='The Bandit Warlord',[1]='B720 K0840 L083 A:47715 T:47715 P:28141+28145'},
[28503]={[0]="Hero's Call: Thousand Needles!",[1]='B61 FA K0400 L039 M043 A:1207321,1207322 T:39946 I:25479,25481,25486'},
[28504]={[0]="Warchief's Command: Thousand Needles!",[1]='B61 K0400 FH L039 M043 A:1206109,1206116,1207323 T:40344'},
[28505]={[0]='The Battle for Andorhal',[1]='B22 FA K0350 L034 A:5636 T:44453 I:27158,27159,28576,28749'},
[28506]={[0]='March of the Stormpike',[1]='B24 K0230 FH L021 A:48545 T:48545 P:28600'},
[28507]={[0]="Hero's Call: Tanaris!",[1]='B161 FA K0450 L044 M048 A:1207321,1207322 T:38535 I:27446'},
[28508]={[0]='The Battle for Andorhal',[1]='B22 K0350 FH L034 A:42898 T:44452 I:26920,28575,28750'},
[28509]={[0]="Warchief's Command: Tanaris!",[1]='B161 K0450 FH L044 M048 A:1206109,1206116,1207323 T:38534'},
[28510]={[0]="Warchief's Command: Feralas!",[1]='B121 K0350 FH L034 M038 A:1206109,1206116,1207323 T:39377'},
[28511]={[0]="Hero's Call: Feralas!",[1]='B0 FA K0350 L034 M038 A:1207321,1207322 T:40032 I:14410,25447'},
[28512]={[0]='To the Aid of the Thorium Brotherhood',[1]='B28 K0470 L046 AA:46930 AH:46660 T:47266 I:27963,28581,28582'},
[28513]={[0]='Pride of the Highborne',[1]='B281 K0510 L049 A:48658 T:48658 P:28479'},
[28514]={[0]='Mouton Flamestar',[1]='B29 FA K0500 L049 A:14625 T:47779 I:28666 B29'},
[28515]={[0]='Mouton Flamestar',[1]='B29 K0500 FH L049 A:14625 T:47779 B29'},
[28517]={[0]='The Howling Oak',[1]='B0 FA RE RW K0100 L008 A:42968 T:48736'},
[28518]={[0]='Legacy of the High Elves',[1]='B281 K0510 L049 A:48659 T:48659 P:28534'},
[28519]={[0]='Pain of the Blood Elves',[1]='B281 K0510 L049 A:48660 T:48660 P:28535'},
[28520]={[0]='The Fall of Neferset City',[1]='B720 K0840 L083 A:48564 T:47684 P:28480+28483+28486'},
[28521]={[0]='Speak to Salfa',[1]='B281 K0500 L049 A:15395 T:11556 B281'},
[28522]={[0]='Winterfall Activity',[1]='B281 K0500 L049 A:11556 T:11556'},
[28523]={[0]='More Beads for Salfa',[1]='B0 K0520 ++ L049 A:11556 T:11556'},
[28524]={[0]='Delivery for Donova',[1]='B281 K0500 L049 A:11556 T:9298 I:28544,28545,28768'},
[28525]={[0]="Hero's Call: Un'Goro Crater!",[1]='B201 FA K0500 L049 M053 A:1207321,1207322 T:9270 I:24911'},
[28526]={[0]="Warchief's Command: Un'Goro Crater!",[1]='B201 K0500 FH L049 M053 A:1206109,1206116,1207323 T:9270 I:24911'},
[28527]={[0]="Warchief's Command: Silithus!",[1]='B261 K0550 FH L054 M058 A:1206109,1206116,1207323 T:15191 I:28528,28856,28859'},
[28528]={[0]="Hero's Call: Silithus!",[1]='B261 FA K0550 L054 M058 A:1207321,1207322 T:15191 I:28527,28856,28859'},
[28529]={[0]='Writings of the Void',[1]='B42 K0120 FA L010 A:100064450 T:32971'},
[28530]={[0]='Scalding Signs',[1]='B281 K0500 L049 A:9298 T:9298'},
[28531]={[0]="Hero's Call: Desolace!",[1]='B101 FA K0300 L029 M033 A:1207321,1207322 T:36410 I:14384,25938'},
[28532]={[0]="Warchief's Command: Stonetalon Mountains!",[1]='B81 K0250 FH L024 M028 A:1206109,1206116,1207323 T:41678'},
[28533]={[0]="The High Council's Decision",[1]='B720 K0840 L083 A:46134,46135,46136 T:47684 P:27738'},
[28534]={[0]='Descendants of the Highborne',[1]='B281 K0510 L049 A:48658 T:48659 P:28513'},
[28535]={[0]='Descendants of the High Elves',[1]='B281 K0510 L049 A:48659 T:48660 P:28518'},
[28536]={[0]='The Curse of Zin-Malor',[1]='B281 K0510 L049 A:48660 T:10920 P:28519'},
[28537]={[0]='In Pursuit of Shades',[1]='B281 K0510 L049 A:10920 T:10920 P:28536'},
[28538]={[0]='Cry of the Banshee',[1]='B24 K0240 FH L021 A:2278 T:2278'},
[28539]={[0]="Hero's Call: Stonetalon Mountains!",[1]='B81 FA K0250 L024 M028 A:1207321,1207322 T:34354'},
[28540]={[0]="Doin' De E'ko Magic",[1]='B281 K0510 L049 A:10307 T:10307'},
[28542]={[0]="Warchief's Command: Felwood!",[1]='B182 K0450 FH L044 M048 A:1206109,1206116,1207323 T:10923'},
[28543]={[0]="Hero's Call: Felwood!",[1]='B182 FA K0450 L044 M048 A:1207321,1207322 T:10923 P:28542'},
[28544]={[0]="Hero's Call: Winterspring!",[1]='B281 FA K0500 L049 M053 A:1207321,1207322 T:9298 I:28524,28545,28768'},
[28545]={[0]="Warchief's Command: Winterspring!",[1]='B281 K0500 FH L049 M053 A:1206109,1206116,1207323 T:9298 I:28524,28544,28768'},
[28548]={[0]="Warchief's Command: Desolace!",[1]='B101 K0300 FH L029 M033 A:1206109,1206116,1207323 T:35286'},
[28549]={[0]="Warchief's Command: Southern Barrens!",[1]='B607 K0300 FH L029 M033 A:1206109,1206116,1207323 T:37135'},
[28550]={[0]="Hero's Call: Southern Barrens!",[1]='B607 FA K0300 L029 M033 A:1207321,1207322 T:38378 I:24862'}, -- note that you can have both this and 28551
[28551]={[0]="Hero's Call: Southern Barrens!",[1]='B607 FA K0300 L029 M033 A:1009686,1009503 T:38623 I:24921'}, -- note that you can have both this and 28550
[28552]={[0]="Hero's Call: Dustwallow Marsh!",[1]='B607 FA K0350 L034 M038 A:1009686,1009503,1207321,1207322 T:23566 I:26702,27210'},
[28553]={[0]='Okrilla and the Blasted Lands',[1]='B19 K0550 FH L054 A:7623 T:41124 P:27196 I:28671,28858'},
[28554]={[0]="Warchief's Command: Dustwallow Marsh!",[1]='B141 K0350 FH L034 M038 A:1206109,1206116,1207323 T:4926'},
[28556]={[0]='Breaking the Hand',[1]='B24 K0240 FH L021 A:48545 T:48545 P:28506'},
[28557]={[0]="Warchief's Command: Uldum!",[1]='B0 K0840 FH L083 M087 A:1206109,1206116,1207323,1207324 T:44833 I:28296'},
[28558]={[0]="Hero's Call: Uldum!",[1]='B0 FA K0840 L083 M087 A:1009686,1009503,1207320,1207321 T:44833 I:28295'},
[28559]={[0]="Hero's Call: Bloodmyst Isle!",[1]='B0 FA K0100 L009 M013 A:1207322 T:17586 I:9625,9634'},
[28560]={[0]="Warchief's Command: Ghostlands!",[1]='B463 K0100 FH L009 M013 A:1207325 T:16197 I:9144'},
[28561]={[0]='Nahom Must Hold',[1]='B720 K0840 L083 A:47684 T:48761 P:28533'},
[28562]={[0]="Hero's Call: Westfall!",[1]='B39 FA K0100 L009 M014 A:1009686,1009503 T:42308 I:26378,26209'},
[28563]={[0]="Hero's Call: Redridge Mountains!",[1]='B36 FA K0150 L014 M018 A:1009686,1009503 T:464 I:26503'},
[28564]={[0]="Hero's Call: Duskwood!",[1]='B34 FA K0200 L019 M023 A:1009686,1009503 T:264 I:26618,26728'},
[28565]={[0]="Hero's Call: Wetlands!",[1]='B40 FA K020 L019 M023 A:1207320 T:41075 I:25395,26137'},
[28566]={[0]='Decimation',[1]='B24 K0240 FH L021 A:48878,48880,2278 T:2278 P:28538'},
[28567]={[0]="Hero's Call: Loch Modan!",[1]='B0 FA K0100 L009 M013 A:1207320 T:1960 I:26131'},
[28568]={[0]="Warchief's Command: Silverpine Forest!",[1]='B21 K0100 FH L009 M013 A:1207324 T:44615 I:26964,26965'},
[28569]={[0]='The Bogpaddle Bullet',[1]='B38 FA K0520 L051 A:9177 T:45786 I:27587,28675'},
[28570]={[0]='The Bogpaddle Bullet',[1]='B38 K0520 FH L051 A:10260 T:45786 I:28677'},
[28571]={[0]="Warchief's Command: Hillsbrad Foothills!",[1]='B24 K0200 FH L019 M023 A:1207324,1207325 T:2215 I:28089,28096'},
[28572]={[0]="Warchief's Command: Arathi Highlands!",[1]='B16 K0250 FH L024 M028 A:1207324,1207325 T:41949'},
[28573]={[0]="Hero's Call: Arathi Highlands!",[1]='B0 FA K0250 L024 M028 A:1207320 T:2700 I:26093,26139'},
[28574]={[0]="Warchief's Command: The Hinterlands!",[1]='B26 K0300 FH L029 M033 A:1207324 T:42613'},
[28575]={[0]="Warchief's Command: Western Plaguelands!",[1]='B22 K0350 FH L034 M038 A:1207324 T:44452 I:26920,28508,28750'},
[28576]={[0]="Hero's Call: Western Plaguelands!",[1]='B22 FA K0350 L034 M038 A:1009686,1009503,1207320 T:44453 I:27158,27159,28505,28749'},
[28577]={[0]="Warchief's Command: Eastern Plaguelands!",[1]='B23 K0400 FH L039 M043 A:1207324 T:45417'},
[28578]={[0]="Hero's Call: Eastern Plaguelands!",[1]='B23 FA K040 L039 M043 A:1009686,1009503,1207320 T:45417'},
[28579]={[0]="Hero's Call: Badlands!",[1]='B17 FA K0450 L044 M048 A:1009686,1009503,1207320 T:48704 I:27762'},
[28580]={[0]="Warchief's Command: Badlands!",[1]='B17 K0450 FH L044 M048 A:1207324 T:48704 I:27762'},
[28581]={[0]="Warchief's Command: Searing Gorge!",[1]='B28 K0480 FH L047 M051 A:1207324,1207325 T:47266 I:27963,28512,28582'},
[28582]={[0]="Hero's Call: Searing Gorge!",[1]='B28 FA K0480 L047 M053 A:1009686,1009503,1207320 T:47266 I:27963,28512,28581'}, -- needs some other I: because level 52 hunter not available
[28583]={[0]='Krazzworks',[1]='B700 FH K0840 L084 A:46090 T:48993 P:27622'},
[28584]={[0]='Quality Construction',[1]='B700 FH K0840 L084 A:49439 T:49439'},
[28586]={[0]='Pool Pony Rescue',[1]='B700 FH K0840 L084 A:49441 T:49441'},
[28587]={[0]='Aid of the Frostwolf',[1]='B24 K0240 FH L021 A:48545 T:13817'},
[28588]={[0]='Wildhammer Infestation',[1]='B700 FH K0840 L084 A:48993 T:48993 P:28583'},
[28589]={[0]='Everything But the Kitchen Sink',[1]='B700 FH K0840 L084 A:48993 T:48993 P:28588'},
[28590]={[0]='Reprisal',[1]='B700 FH K0840 L084 A:48993 T:49378'},
[28591]={[0]='Off The Wall',[1]='B700 FH K0840 L084 A:49378 T:49378 P:28590'},
[28592]={[0]='Parting Packages',[1]='B700 FH K0840 L084 A:49002,49379 T:49002'},
[28593]={[0]='Of Utmost Importance',[1]='B700 FH K0840 L084 A:49378 T:49000'},
[28594]={[0]='Highbank, Crybank',[1]='B700 FH K0840 L084 A:49378 T:49000 P:28593'},
[28595]={[0]='Krazz Works!',[1]='B700 FH K0840 L084 A:49000 T:48993 P:28593,28594'},
[28596]={[0]='Welcome to Highbank!',[1]='B700 FA K0840 L084 A:49022 T:49022 P:28832'},
[28597]={[0]="Burnin' at Both Ends",[1]='B700 FA K0840 L084 A:49020,49252 T:49020 P:28596'}, -- yes, can accept at either, but only turn in at one.
[28598]={[0]='Aiming High',[1]='B700 FA K0840 L084 A:49020 T:549020 P:28597'},
[28599]={[0]="Kurdran's Waitin'",[1]='B700 FA K0840 L084 A:549020 T:45167 P:28598'},
[28600]={[0]='Matters of Loyalty',[1]='B24 K0240 FH L021 A:13817 T:48545 P:28587'},
[28602]={[0]='Be Prepared',[1]='B720 K0830 L083 A:45296 T:45296 P:27517'},
[28603]={[0]='Infiltration',[1]='B24 K0240 FH L021 A:48922,48923,48924,2278 T:2278 P:28566'},
[28604]={[0]='Deception and Trickery',[1]='B24 K0240 FH L021 A:49035 T:49035 P:28603'},
[28605]={[0]='Domination',[1]='B24 K0240 FH L021 A:49116,49035 T:2278 P:28603,28604'},
[28607]={[0]='The Keys to the Hot Rod',[1]='B0 K0050 FH A:34874 T:34874'},
[28608]={[0]='The Shadow Grave',[1]='B0 K0010 FH RU A:1568 T:1568 P:24959'},
[28609]={[0]='Hammer Time',[1]='B281 K0520 L050 A:11191 T:48965'},
[28610]={[0]='Rubble Trouble',[1]='B281 K0520 L050 A:48965 T:48965 P:28609'},
[28611]={[0]="The Defilers' Ritual",[1]='B720 K0840 L083 A:46135 T:46135 P:27836+27837'},
[28612]={[0]='Harrison Jones and the Temple of Uldum',[1]='B720 K0830 L083 A:49151 T:49204 P:27748'},
[28613]={[0]='See You on the Other Side!',[1]='B720 K0830 L083 A:48698 T:47158 P:28497'},
[28614]={[0]='Bearzerker',[1]='B281 K0520 L050 A:48722 T:48722'},
[28615]={[0]='Turning the Earth',[1]='B281 K0520 L050 A:48723 T:48723'},
[28616]={[0]='Stormpike Apocalypse',[1]='B24 K0240 FH L021 A:48545 T:48545'},
[28617]={[0]='Flower Power',[1]='B0 K0200 L020 A:49687 T:49687 P:28733'},
[28618]={[0]='Boulder Delivery',[1]='B281 K0520 L050 A:48965 T:11191 P:28610'},
[28619]={[0]="Warchief's Command: Arathi Highlands!",[1]='B16 K0250 FH L024 M028 A:1207279 T:41949 P:28572'},
[28620]={[0]='Eastpoint Tower',[1]='B24 K0250 FH L023 A:2229 T:49201'},
[28621]={[0]='Put That Baby in the Cradle!',[1]='B0 K0830 L083 A:49204 T:49203 P:28612'},
[28622]={[0]='Three if by Air',[1]='B720 K0830 L083 A:49203 T:49248 P:28621'},
[28623]={[0]='The Push Westward',[1]='B720 K0840 L083 A:48761 T:48564 P:28501'},
[28624]={[0]="Kilram's Boast",[1]='B281 K0520 L050 A:11192 T:48965'},
[28625]={[0]='Chop Chop',[1]='B281 K0520 L050 A:48965 T:48965 P:28624'},
[28626]={[0]='Tree Delivery',[1]='B281 K0520 L050 A:48965 T:11192 P:28625'},
[28627]={[0]="Seril's Boast",[1]='B281 K0520 L050 A:11193 T:48965'},
[28628]={[0]='Ice Delivery',[1]='B281 K0520 L050 A:48965 T:11193 P:28632'},
[28629]={[0]='Are We There, Yeti?',[1]='B281 K0520 L050 A:10305 T:10305'},
[28630]={[0]='Echo Three',[1]='B281 K0520 L050 A:10305 T:1207291'},
[28631]={[0]='The Perfect Horns',[1]='B281 K0520 L050 A:10305 T:10305 P:28629'},
[28632]={[0]='Fresh From The Hills',[1]='B281 K0520 L050 A:48965 T:48965 P:28627'},
[28633]={[0]='The Coffer of Promise',[1]='B720 K0830 L083 A:49248 T:49351 P:28622'},
[28634]={[0]='Extinction',[1]='B24 K0250 FH L023 A:49201 T:49201 P:28620'},
[28635]={[0]='A Haunting in Hillsbrad',[1]='B24 K0250 FH L023 A:49243 T:49240'},
[28636]={[0]='Silence of the Dwarves',[1]='B24 K0250 FH L023 A:49240 T:49243 P:28635'},
[28637]={[0]='A Taste for Bear',[1]='B281 K0530 L051 A:49436 T:49436'},
[28638]={[0]='The Owls Have It',[1]='B0 K0530 L051 A:49537'},
[28639]={[0]='Ursius',[1]='B281 K0530 L050 A:10806,49436 T:49436 P:28719'},
[28640]={[0]='Fresh Frostsabers',[1]='B281 K0530 L051 A:49396 T:49396 P:28718'},
[28641]={[0]='Pride of the Dinner Table',[1]='B281 K0530 L051 A:7434,49396 T:49396 P:28640'},
[28643]={[0]='The Durnholde Challenge: Zephyrus',[1]='B24 K0250 FH L023 A:49243 T:49243'},
[28644]={[0]='The Durnholde Challenge: Teracula',[1]='B24 K0250 FH L023 A:49243,49265 T:49243 P:28643'},
[28645]={[0]='The Durnholde Challenge: Bloodvenom',[1]='B24 K0250 FH L023 A:49243,49264 T:49243 P:28644'},
[28646]={[0]='The Durnholde Challenge: Infernus',[1]='B24 K0250 FH L023 A:49243,49266 T:49243 P:28645'},
[28647]={[0]='The Durnholde Challenge: D-1000',[1]='B24 K0250 FH L023 A:49243,49268 T:49243 P:28646'},
[28649]={[0]='A Special Surprise',[1]='B0 K0550 RW CK L055 A:29053 T:29053'},
[28650]={[0]='A Special Surprise',[1]='B0 K0550 RG CK L055 A:29053 T:29053'},
[28651]={[0]='Novice Elreth',[1]='B0 K0030 FH RU L002 A:2119,2122,2123,2124,2126,38911 T:1661 P:24964,24965,24966,24967,24968,24969 I:24961'},
[28652]={[0]='Caretaker Caice',[1]='B0 K0010 FH RU A:1568 T:2307 P:26799 I:24960'},
[28653]={[0]='Shadow Priest Sarvis',[1]='B0 K0020 FH RU A:1740 T:1569 I:26801'},
[28654]={[0]='The Heart of the Matter',[1]='B504956 K08364 L083 A:49351 T:39908 P:28633'},
[28655]={[0]='Wild, Wild, Wildhammer Wedding',[1]='B700 FA K0840 L084 A:48368 T:49358 P:28408+28409+28410+28411'},
[28657]={[0]='A Huge Problem',[1]='B0 +D FH K0850 L085 A:48069 T:48069'},
[28658]={[0]='Swamp Bait',[1]='B0 +D FH K0850 L085 A:48069 T:48069'},
[28659]={[0]='The Leftovers',[1]='B0 +D FH K0850 L085 A:48069 T:48069'},
[28660]={[0]='Clearing the Depths',[1]='B0 +D FH K0850 L085 A:48071 T:48071'},
[28661]={[0]='The Imprisoned Archmage',[1]='B0 +D FH K0850 L085 A:48071 T:48071'},
[28662]={[0]='Learning From The Past',[1]='B0 +D FH K0850 L085 A:48071 T:48071'},
[28663]={[0]='D-Block',[1]='B0 +D FH K0850 L085 A:48070 T:48070'},
[28664]={[0]='Svarnos',[1]='B0 +D FH K0850 L085 A:48070 T:48070'},
[28665]={[0]='Cursed Shackles',[1]='B0 +D FH K0850 L085 A:48070 T:48070'},
[28666]={[0]="Hero's Call: Burning Steppes!",[1]='B29 FA K050 L049 M053 A:1009686,1009503,1207320 T:47811 I:28514'}, -- needs some other I: because level 52 hunter not available
[28667]={[0]="Warchief's Command: Burning Steppes!",[1]='B29 K0500 FH L049 M053 A:1207324 T:48559'},
[28668]={[0]='Prison Revolt',[1]='B0 +D FH K0850 L085 A:48062 T:48062'},
[28669]={[0]='The Warden',[1]='B0 +D FH K0850 L085 A:48062 T:48062'},
[28670]={[0]='Food From Below',[1]='B0 +D FH K0850 L085 A:48062 T:48062'},
[28671]={[0]="Warchief's Command: Blasted Lands!",[1]='B19 K0550 FH L054 M058 A:1207324 T:41124 I:28553,28858'},
[28672]={[0]='The Executor In the Field',[1]='B0 K0030 FH L003 A:1661 T:1570 P:24961'},
[28673]={[0]="Hero's Call: Blasted Lands!",[1]='B19 FA K0550 L054 M058 A:1009686,1009503,1207320 T:5393'},
[28674]={[0]='Starfall Village',[1]='B281 K0530 L051 A:48965 T:11079'},
[28675]={[0]="Hero's Call: Swamp of Sorrows!",[1]='B38 FA K0520 L051 M058 A:1009686,1009503,1207320 T:45786 I:27587,28569'},
[28676]={[0]='Exterminators at Work',[1]='B281 K0530 L051 A:11079 T:49407'},
[28677]={[0]="Warchief's Command: Swamp of Sorrows!",[1]='B38 K0520 FH L051 M055 A:1207324 T:45786 I:28570'},
[28678]={[0]='Captain P. Harris',[1]='B0 +D FH K0850 L085 A:48360 T:48360'},
[28679]={[0]='Rattling Their Cages',[1]='B0 +D FH K0850 L085 A:48360 T:48360'},
[28680]={[0]='Boosting Morale',[1]='B0 +D FH K0850 L085 A:48360 T:48360'},
[28681]={[0]='Shark Tank',[1]='B0 +D FH K0850 L085 A:48360 T:48360'},
[28682]={[0]='Claiming The Keep',[1]='B0 +D FH K0850 L085 A:48358 T:48358'},
[28683]={[0]='Thinning the Brood',[1]='B0 +D FH K0850 L085 A:48360 T:48360'},
[28684]={[0]='A Sticky Task',[1]='B0 +D FH K0850 L085 A:48360 T:48360'},
[28685]={[0]='Leave No Weapon Behind',[1]='B0 +D FH K0850 L085 A:48358 T:48358'},
[28686]={[0]='Not The Friendliest Town',[1]='B0 +D FH K0850 L085 A:48358 T:48358'},
[28687]={[0]='Teach A Man To Fish.... Or Steal',[1]='B0 +D FH K0850 L085 A:48358 T:48358'},
[28688]={[0]="Warchief's Command: Northern Stranglethorn Vale!",[1]='B37 K0250 FH L024 M028 A:1207324,1207325 T:2464 I:26278,26417'},
[28689]={[0]='The Forgotten',[1]='B0 +D FH K0850 L085 A:48363 T:48363'},
[28690]={[0]='Salvaging the Remains',[1]='B0 +D FH K0850 L085 A:48363 T:48363'},
[28691]={[0]='First Lieutenant Connor',[1]='B0 +D FH K0850 L085 A:48363 T:48363'},
[28692]={[0]='Magnets, How Do They Work?',[1]='B0 +D FH K0850 L085 A:48363 T:48363'},
[28693]={[0]='Finish The Job',[1]='B0 +D FH K0850 L085 A:48363 T:48363'},
[28694]={[0]='Watch Out For Splinters!',[1]='B0 +D K0850 FH L085 A:48361 T:48361'},
[28695]={[0]='WANTED: Foreman Wellson',[1]='B0 +D FH K0850 L085 A:48361 T:48361'},
[28696]={[0]="Bombs Away!",[1]='B0 +D FH K0850 L085 A:48361 T:48361'},
[28697]={[0]='Ghostbuster',[1]='B0 +D FH K0850 L085 A:48361 T:48361'},
[28698]={[0]='Cannonball!',[1]='B0 +D FH K0850 L085 A:48361 T:48361'},
[28699]={[0]="Hero's Call: Northern Stranglethorn Vale!",[1]='B37 FA K0250 L024 M028 A:1009686,1009503 T:469 I:26735,26838'},
[28700]={[0]='Taking the Overlook Back',[1]='B0 +D FH K0850 L085 A:48361 T:48361'},
[28701]={[0]="Out of Harm's Way",[1]='B281 K0530 L051 A:11079 T:11079'},
[28702]={[0]="Hero's Call: The Cape of Stranglethorn!",[1]='B673 FA K0300 L029 M033 A:1009686,1009503 T:44082 I:26805'},
[28703]={[0]='Step Into My Barrow',[1]='B281 K0530 L051 A:49407 T:49407'},
[28704]={[0]="Warchief's Command: The Cape of Stranglethorn!",[1]='B673 K0300 FH L029 M033 A:1207324 T:43095'},
[28705]={[0]="Warchief's Command: Outland!",[1]='B19 K0600 FH L058 M062 A:1206109,1206116,1207323,1207324 T:19253 P:9407'},
[28706]={[0]='Spray it Forward',[1]='B281 K0530 L051 A:49407 T:49399'},
[28707]={[0]='Spray it Again',[1]='B281 K0530 L051 A:49399 T:49400 P:28706'},
[28708]={[0]="Hero's Call: Outland!",[1]='B465 FA K0600 L058 M068 A:1009686,1009503,1207320,1207321 T:19229'},
[28709]={[0]="Hero's Call: Northrend!",[1]='B486 FA K0700 L068 M078 A:1009686,1009503,1207320,1207321 T:25307'},
[28710]={[0]='Spray it One More Time',[1]='B281 K0530 L051 A:49400 T:49402 P:28707'},
[28711]={[0]="Warchief's Command: Northrend!",[1]='B486 K0700 FH L068 M072 A:1206109,1206116,1207323,1207324 T:25273'},
[28712]={[0]='Enter the Dragon Queen',[1]='B700 K0850 L084 A:47603 T:49417 P:28109'},
[28713]={[0]='The Balance of Nature',[1]='B0 FA K0020 A:2079 T:2079'},
[28714]={[0]='Fel Moss Corruption',[1]='B0 FA K0030 A:2079 T:502079 P:28713'},
[28715]={[0]='Demonic Thieves',[1]='B0 FA K0030 A:2077 T:2077 P:28713 O:28734'},
[28716]={[0]="Hero's Call: Twilight Highlands!",[1]='B0 FA K0840 L084 M088 A:1009686,1009503,1207320,1207321 T:29611 I:26960'},
[28717]={[0]="Warchief's Command: Twilight Highlands!",[1]='B0 K0840 FH L084 M088 A:1206109,1206116,1207323,1207324 T:39605'},
[28718]={[0]="Where There's Smoke, There's Delicious Meat",[1]='B281 K0530 L051 A:49402 T:49396 P:28710'},
[28719]={[0]='A Little Gamy',[1]='B281 K0530 L051 A:7443,49436 T:49436 P:28637'},
[28721]={[0]='Walk A Mile In Their Shoes',[1]='B0 +D FH K0850 L085 A:48358 T:48358'},
[28722]={[0]='Yetiphobia',[1]='B281 K0520 L050 A:10305 T:10305 P:28629,28631'},
[28723]={[0]='Priestess of the Moon',[1]='B0 FA RE K0030 L003 A:3593,3594,3595,3596,3597,43006 T:49479 P:26940,26945,26946,26947,26948,26949'},
[28724]={[0]="Iverron's Antidote",[1]='B0 FA RE K0030 L003 A:49479 T:49479 P:28723'},
[28725]={[0]='The Woodland Protector',[1]='B0 FA RE K0030 A:49479 T:49480 P:28724'},
[28726]={[0]='Webwood Corruption',[1]='B0 FA RE K0040 L003 A:549480 T:549480 P:28725'},
[28727]={[0]='Vile Touch',[1]='B0 FA RE K0040 L003 A:549480 T:549480 P:28726'},
[28728]={[0]='Signs of Things to Come',[1]='B0 FA RE K0050 L003 A:549480 T:49479 P:28727'},
[28729]={[0]='Teldrassil: Crown of Azeroth',[1]='B0 FA RE K0050 L003 A:49479 T:49479 P:28728'},
[28730]={[0]='Precious Waters',[1]='B0 FA RE K0050 L003 A:49479 T:3514 P:28729'},
[28731]={[0]='Teldrassil: Passing Awareness',[1]='B0 FA RE K0050 L003 A:3514 T:3515 P:28730'},
[28732]={[0]='This Can Only Mean One Thing...',[1]='B504956 K0820 L080 A:49444 T:49476'},
[28733]={[0]='Basic Botany',[1]='B24 K0200 L020 A:49687 T:49687'},
[28734]={[0]='A Favor for Melithar',[1]='B0 FA K0030 A:2079 T:2077 P:28714 I:28715'},
[28735]={[0]='To the Chamber of Incineration!',[1]='B504956 K0820 L080 A:49476 T:49476 P:28732'},
[28736]={[0]='Fire From the Sky',[1]='B0 +D K0830 L083 A:49523 T:49523 P:28497'},
[28737]={[0]='What Is This Place?',[1]='B504956 K0820 L080 A:39679,49476 T:49476'},
[28738]={[0]='The Twilight Forge',[1]='B0 K0820 L080 A:39698,49476 T:49476'},
[28740]={[0]='Do My Eyes Deceive Me?',[1]='B0 K0820 L080 A:39700,49476 T:49476'},
[28741]={[0]='Ascendant Lord Obsidius',[1]='B504956 K0820 L080 A:39705,49476 T:49476'},
[28742]={[0]='Shy-Rotam',[1]='B281 K0530 L051 A:10737,49396 T:49396 P:28641'},
[28744]={[0]='Ghouls Hate My Grains',[1]='B24 K0200 L020 A:49687 T:49687 P:28617'},
[28745]={[0]='Screechy Keen',[1]='B0 K0530 L051 A:7456 P:28638'},
[28746]={[0]='Penetrating Their Defenses',[1]='B0 K0830 L083 A:39908 T:39908 P:28654'},
[28747]={[0]='Someone Setup the Pumpkin Bomb',[1]='B24 K0200 L020 A:49687 T:49687 P:28744'},
[28748]={[0]='Lawn of the Dead',[1]='B0 K0200 L020 A:49687 T:49687 P:28747'},
[28749]={[0]='The Battle for Andorhal',[1]='B22 FA K0350 L034 A:49635 T:44453 I:27158,27159,28505,28576'},
[28750]={[0]='The Battle for Andorhal',[1]='B22 K0350 FH L034 A:49636 T:44452 I:26920,28508,28575'},
[28753]={[0]='Doing it the Hard Way',[1]='B0 K0830 L083 A:39908 T:49941 P:28746'},
[28755]={[0]='Annals of the Silver Hand',[1]='B0 ++ K0460 L042 A:49856 T:49856 P:27464'},
[28756]={[0]='Aberrations of Bone',[1]='B0 ++ K0420 L040 A:49856 T:49856 P:27464'},
[28757]={[0]='Beating Them Back!',[1]='B0 FA RH CM K0030 A:197 T:197'},
[28758]={[0]='Battle of Life and Death',[1]='B700 K0850 L084 A:49810 T:47605 P:28712'},
[28759]={[0]='Lions for Lambs',[1]='B0 CH K0030 A:197 T:197 P:28767'},
[28760]={[0]='Vengeance for Orsis',[1]='B0 K0840 L082 A:49943 T:49943 P:28845'},
[28761]={[0]='Honor the Flame',[1]='B0 I:11834'},
[28762]={[0]='Beating Them Back!',[1]='B0 FA RH CP K0030 A:197 T:197'},
[28763]={[0]='Beating Them Back!',[1]='B0 FA RH CT K0030 A:197 T:197'},
[28764]={[0]='Beating Them Back!',[1]='B0 FA RH CR K0030 A:197 T:197'},
[28765]={[0]='Beating Them Back!',[1]='B0 FA RH CL K0030 A:197 T:197'},
[28766]={[0]='Beating Them Back!',[1]='B0 FA RH CW K0030 A:197 T:197'},
[28767]={[0]='Beating Them Back!',[1]='B0 FA RH CH K0030 A:197 T:197'},
[28768]={[0]='Winterspring!',[1]='B281 K0500 L049 A:15395 T:9298 I:28524,28544,28545 B281'},
[28769]={[0]='Lions for Lambs',[1]='B0 CM K0030 A:197 T:197 P:28757'},
[28770]={[0]='Lions for Lambs',[1]='B0 CP K0030 A:197 T:197 P:28762'},
[28771]={[0]='Lions for Lambs',[1]='B0 CT K0030 A:197 T:197 P:28763'},
[28772]={[0]='Lions for Lambs',[1]='B0 CR K0030 A:197 T:197 P:28764'},
[28773]={[0]='Lions for Lambs',[1]='B0 CL K0030 A:197 T:197 P:28765'},
[28774]={[0]='Lions for Lambs',[1]='B0 CW K0030 A:197 T:197 P:28766'},
[28775]={[0]='Broken Serpent Figurine',[1]='B0 PJ475 A:100065896'},
[28776]={[0]='Broken Earthen Figurine',[1]='B0 PJ475 A:100065897'},
[28777]={[0]='Broken Owl Figurine',[1]='B0 PJ475 A:100065894'},
[28778]={[0]='Broken Boar Figurine',[1]='B0 CW CP CK PJ475 A:100065895'},
[28779]={[0]='A Long Way from Home',[1]='B0 K0840 L082 A:49943 T:49943 P:28845'},
[28780]={[0]='Join the Battle!',[1]='B0 FA K0030 A:43278 T:823 P:26917'},
[28781]={[0]='Targets of Opportunity',[1]='B504956 K08564 L083 A:50038 T:50038'},
[28782]={[0]='A Bird of Legend',[1]='B281 K0530 L051 A:50044 T:49537 P:28745'},
[28783]={[0]='The Source of Their Power',[1]='B0 K08564 L083 A:50038 T:50038 P:28870'},	-- or should the P: be O: ?
[28784]={[0]='Join the Battle!',[1]='B0 FA K0030 A:198 T:823 P:26916'},
[28785]={[0]='Join the Battle!',[1]='B0 FA K0030 A:925 T:823 P:26918'},
[28786]={[0]='Join the Battle!',[1]='B0 FA K0030 A:375 T:823 P:26919'},
[28787]={[0]='Join the Battle!',[1]='B0 FA K0030 A:915 T:823 P:26915'},
[28788]={[0]='Join the Battle!',[1]='B0 FA K0030 A:459 T:823 P:26914'},
[28789]={[0]='Join the Battle!',[1]='B0 FA K0030 A:911 T:823 P:26913'},
[28790]={[0]='A Personal Summons',[1]='B0 FH K0800 L080 AZ:321 T:45244'},
[28791]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28780'},
[28792]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28784'},
[28793]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28785'},
[28794]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28786'},
[28795]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28787'},
[28796]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28788'},
[28797]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:28789'},
[28798]={[0]='Waters of Elune',[1]='B0 +D A:1207406 T:1207406'},
[28799]={[0]='Might of the Earthen',[1]='B0 +D A:1207407 T:1207407'},
[28800]={[0]='Whispers of the Djinn',[1]='B0 A:1207408 T:1207408'},
[28801]={[0]="Tol'vir Heiroglyphics",[1]='B0 +D A:1207409 T:1207409'},
[28802]={[0]='Map of the Architects',[1]='B0 +D A:1207410 T:1207410'},
[28803]={[0]='Vengeance of the Wildhammer',[1]='B0 +D A:1207411 T:1207411'},
[28804]={[0]='Dark Iron Contingency Plan',[1]='B0 +D A:1207412 T:1207412'},
[28805]={[0]='The Eye of the Storm',[1]='B0 K0800 FH L080 A:45244 T:45244 P:28790'},
[28806]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28780'},
[28807]={[0]='Expert Opinion',[1]='B0 FA K0840 L084 A:44293 T:332 P:27060,27064'},
[28808]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28784'},
[28809]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28785'},
[28810]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28786'},
[28811]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28787'},
[28812]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28788'},
[28813]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:28789'},
[28814]={[0]='Followers and Leaders',[1]='B504956 K0840 L082 A:42333,42428,50048 T:50048 P:28815'},
[28815]={[0]='Twilight Documents',[1]='B504956 K0840 L082 A:50048 T:50048'},
[28816]={[0]='To the Depths',[1]='B0 K0800 FH L080 A:45244 T:41621 P:27718'},
[28817]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28791'},
[28818]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28792'},
[28819]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28793'},
[28820]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28794'},
[28821]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28795'},
[28822]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28796'},
[28823]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:28797'},
[28824]={[0]='Wayward Child',[1]='B0 K08464 L082 A:42465,43792 T:42465,43792,44025'},
[28825]={[0]='A Personal Summons',[1]='B0 K0800 FA L080 AZ:301 T:45226'},
[28826]={[0]='The Eye of the Storm',[1]='B0 FA K0800 L080 A:45226 T:45226 P:28825'},
[28827]={[0]='To the Depths',[1]='B0 FA K0800 L080 A:45226 T:36799 P:28826 I:14481,27724'},
[28828]={[0]='You Gotta Have Eggs',[1]='B281 K0530 L051 A:49396 T:49396'},
[28829]={[0]='Razor Beak and Antlers Pointy',[1]='B281 K0540 L053 A:50263 T:50263'},
[28830]={[0]='Chips off the Old Block',[1]='B281 K0540 L053 A:50263 T:50263'},
[28831]={[0]='Damn You, Frostilicus',[1]='B281 K0540 L053 A:50263 T:50263'},
[28832]={[0]='Twilight Shores',[1]='B0 FA K0840 L084 A:544806 T:49022 P:28238'},
[28833]={[0]='Rescue the Earthspeaker!',[1]='B0 K0820 FH L080 A:50272 T:40825'},
[28834]={[0]='Rescue the Earthspeaker!',[1]='B0 K0820 FA L080 A:50270 T:40825'},
[28836]={[0]='Sins of the Sea Witch',[1]='B504956 K0820 FA L080 A:50270 T:50270'},
[28837]={[0]='Altered Beasts',[1]='B281 K0540 L049 A:10929 T:10929 P:28847'},
[28838]={[0]="The Owlbeasts' Defense",[1]='B281 K0540 L053 A:10929 T:10929'},
[28839]={[0]='Magic Prehistoric',[1]='B281 K0540 L053 A:10929 T:10929 P:28838'},
[28840]={[0]='Winterwater',[1]='B281 K0540 L053 A:10929 T:10929 P:28839'},
[28841]={[0]='The Arcane Storm Within',[1]='B281 K0550 L053 A:10929 T:10929'},
[28842]={[0]="Umbranse's Deliverance",[1]='B281 K0550 L053 A:10929 T:10929'},
[28843]={[0]='Sins of the Sea Witch',[1]='B504956 K0820 FH L080 A:50272 T:50272'},
[28845]={[0]='The Vortex Pinnacle',[1]='B504956 K0840 L082 A:45772 T:49943 P:27520'},
[28847]={[0]='The Pursuit of Umbranse',[1]='B281 K0540 L051 A:50366 T:10929'},
[28848]={[0]='Trailing the Spiritspeaker',[1]='B281 K0510 L049 A:10920 T:50366 P:28537'},
[28849]={[0]='Twilight Skies',[1]='B181 K0840 FH L084 A:42640 T:50367 P:26372'},
[28850]={[0]='The Prison Rooftop',[1]='B0 FA RW K0030 A:50371 T:35077 P:14157'},
[28852]={[0]='Soften them Up',[1]='B504956 K08564 L084 A:50390 T:50390'},
[28853]={[0]='Kill the Courier',[1]='B0 K08564 L084 A:50385 T:50385'},
[28854]={[0]='Closing a Dark Chapter',[1]='B0 K08564 L084 A:50387 T:50387'},
[28855]={[0]='Northern Stranglethorn 4.x: PRK - E - Just Hatched FLAG',[1]='B0 '}, -- this completes when 26732 completes in the log
[28856]={[0]='The Sands of Silithus',[1]='B261 K0550 L054 A:11118 T:15191 I:28527,28528,28859'},
[28857]={[0]='Blasted Lands: The Other Side of the World',[1]='B19 FA K0550 L054 A:11118 T:5393 P:28673'},
[28858]={[0]='Blasted Lands: The Other Side of the World',[1]='B19 K0550 FH L054 A:11118 T:41124 I:28671,28553'},
[28859]={[0]='The Dunes of Silithus',[1]='B261 K0550 L054 A:38269 T:15191 I:28527,28528,28856 P:1'},
[28860]={[0]='Keeping the Dragonmaw at Bay',[1]='B0 +D FA K0840 L084 A:46591 T:46591 P:28655'},
[28861]={[0]='Fight Like a Wildhammer',[1]='B0 +D FA K0840 L084 A:48010 T:48010 P:28655'},
[28862]={[0]='Never Leave a Dinner Behind',[1]='B0 +D FA K0840 L084 A:48010 T:48010 P:28655'},
[28863]={[0]='Warlord Halthar is Back',[1]='B0 +D FA K0840 L084 A:49386 T:49386 P:28655'},
[28864]={[0]='Beer Run',[1]='B0 +D FA K0840 L084 A:46591 T:46591 P:28655'},
[28865]={[0]='Call of the Warmatron',[1]='B19 K0540 FH L054 A:50587 T:41124 B19'},
[28866]={[0]='Into the Stonecore',[1]='B504956 K08364 L082 A:44010 T:50048 P:27061'},
[28867]={[0]='Nethergarde Needs You!',[1]='B19 FA K0540 L054 A:50588 T:5393 B19'},
[28868]={[0]='The View from Down Here',[1]='B0 FA K0070 L005 A:50601 T:50601 P:25839'},
[28869]={[0]='Pebble',[1]='B640 FA K0830 L081 A:42469 T:43116 P:26438'},
[28870]={[0]='Return to the Lost City',[1]='B504956 K08564 L081 A:47684 T:50038 P:28520'},
[28871]={[0]='Crushing the Wildhammer',[1]='B0 +D FH K0840 L084 A:50622 T:50622'},
[28872]={[0]='Total War',[1]='B0 +D FH K0840 L084 A:46318 T:46318'},
[28873]={[0]='Another Maw to Feed',[1]='B0 +D FH K0840 L084 A:46319 T:46319'},
[28874]={[0]="Hook 'em High",[1]='B0 +D FH K0840 L084 A:46318 T:46318'},
[28875]={[0]='Bring Down the High Shaman',[1]='B0 +D FH K0840 L084 A:49387 T:49387'},
[28876]={[0]="To the Mor'shan Rampart",[1]='B43 K0200 FH L019 A:3429 T:8582 P:28493'},
[28877]={[0]='They Call Him Swiftdagger. He Kills Harpies.',[1]='B11 K0150 FH L012 A:34698 T:3449'},
[28878]={[0]='A Winter Veil Gift',[1]='B0 HV L010 A:1187236 T:1187236'},
[28879]={[0]='Back To The Orphanage',[1]='B0 HC L070'},	-- Does this exist?  how differ from 13959?
[28880]={[0]='Back To The Orphanage',[1]='B0 HC L070'},	-- Does this exist?  how differ from 13960?
[28881]={[0]='Prospector Gunstan',[1]='B161 FA K0480 L046 A:39059 T:40109 P:25065 I:25420'},
[28882]={[0]='Victory in Tol Barad',[1]='B0 +W FA K0850 L085 A:51288 T:51288'},
[28884]={[0]='Victory in Tol Barad',[1]='B0 +W FH K0850 L085 A:51287 T:51287'},
[28885]={[0]="Mr. Goldmine's Wild Ride",[1]='B0 FH K0850 L084 A:46243 T:46513 P:27712'},
[28909]={[0]='Sauranok Will Point the Way',[1]='B0 K0840 FH L084 A:39605 T:42637'},
[28910]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011374'},
[28911]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011375'},
[28912]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011376'},
[28913]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011377'},
[28914]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011378'},
[28915]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011379'},
[28916]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011380'},
[28917]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011381'},
[28918]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011382'},
[28919]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011383'},
[28920]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011384'},
[28921]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011385'},
[28922]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51574'},
[28923]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51575'},
[28924]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51582'},
[28925]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51585'},
[28926]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51586'},
[28927]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51587'},
[28928]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51588'},
[28929]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51602'},
[28930]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51603'},
[28931]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51604'},
[28932]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51606'},
[28933]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51607'},
[28934]={[0]='Crushing the Crown',[1]='B0 HA FA +D L081 M085 A:38066 T:38066 P:24657'},
[28935]={[0]='Crushing the Crown',[1]='B0 HA FH +D L081 M085 A:37172 T:37172 P:24657'},
[28936]={[0]='Diva Dilemma',[1]='B0 K0300 L028'},
[28937]={[0]='Alliance Breadcrumb',[1]='B0 K0300 L028'},
[28939]={[0]='Beware of Strangers',[1]='B0 K0300 L028 P:29040'},
[28940]={[0]='Get Antidote',[1]='B0 K0300 L028'},
[28943]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011481'},
[28944]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011482'},
[28945]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51650'},
[28946]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51651'},
[28947]={[0]='Desecrate this Fire!',[1]='B0 HM FH SP A:1011485'},
[28948]={[0]='Desecrate this Fire!',[1]='B0 HM FA SP A:1011486'},
[28949]={[0]='Honor the Flame',[1]='B0 HM FH SP A:51652'},
[28950]={[0]='Honor the Flame',[1]='B0 HM FA SP A:51653'},
[28951]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011507 T:1011507'},
[28952]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011508 T:1011508'},
[28953]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011509 T:1011509'},
--[28954]={[0]='Candy Bucket',[1]='HW'},
[28955]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011529 T:1011529'},
[28956]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011513 T:1011513'},
[28957]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011535 T:1011535'},
[28958]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011510 T:1011510'},
[28959]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011536 T:1011536'},
[28960]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011514 T:1011514'},
[28961]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011515 T:1011515'}, --  I:28997 removed because it causes headaches with current implementation
[28962]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011537 T:1011537'},
[28963]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011516 T:1011516'},
[28964]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011517 T:1011517'},
[28965]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011530 T:1011530'},
[28966]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011538 T:1011538'},
[28967]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011531 T:1011531'},
[28968]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011518 T:1011518'},
[28969]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011539 T:1011539'},
[28970]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011519 T:1011519'},
[28971]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011540 T:1011540'},
[28972]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011541 T:1011541'},
[28973]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011542 T:1011542'},
[28974]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011543 T:1011543'},
[28975]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011544 T:1011544'},
[28976]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011545 T:1011545'},
[28977]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011520 T:1011520'},
[28978]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011522 T:1011522'},
[28979]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011523 T:1011523'},
[28980]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011521,500022 T:1011521,500022'},
[28981]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011533 T:1011533'},
[28982]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011534 T:1011534'},
[28983]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011525 T:1011525'},
[28984]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011532 T:1011532'},
[28985]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011524 T:1011524'},
[28986]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011546 T:1011546'},
[28987]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011548 T:1011548'},
[28988]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011526 T:1011526'},
[28989]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011511 T:1011511'},
[28990]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011528 T:1011528'},
[28991]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011527 T:1011527'},
[28992]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011547 T:1011547'},
[28993]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011549 T:1011549'},
[28994]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011550 T:1011550'},
[28995]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011551 T:1011551'},
[28996]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011552 T:1011552'},
--[28997]={[0]='Candy Bucket',[1]='B0 HW I:28961'}, -- this was completed when 28961 was by choosing bucket A:1011515
[28998]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011553 T:101155'},
[28999]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011554 T:1011554'},
[29000]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011555 T:1011555'},
[29001]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011556 T:1011556'},
[29002]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011557 T:1011557'},
[29003]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011558 T:1011558'},
[29004]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011559 T:1011559'},
[29005]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011560 T:1011560'},
[29006]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011561 T:1011561'},
[29007]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011562 T:1011562'},
[29008]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011563 T:1011563'},
[29009]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011564 T:1011564'},
[29010]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011565 T:1011565'},
[29011]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011566 T:1011566'},
[29012]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011567 T:1011567'},
[29013]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011568 T:1011568'},
[29014]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011569 T:1011569'},
[29016]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011570 T:1011570'},
[29017]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011571 T:1011571'},
[29018]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1011572 T:1011572'},
[29019]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FH A:1011573 T:1011573'},
[29020]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:1011575 T:1011575'},
[29029]={[0]='Dying Knowledge',[1]='B0 K0460 L044'},
[29030]={[0]='Honor the Flame',[1]='B0 HM K0850 A:51682 T:1011576'},
[29031]={[0]='Honor the Flame',[1]='B0 HM A:51697 T:1011579'},
[29032]={[0]="Get Them While They're Young",[1]='B281 FA L050 A:10618 T:10618'},
[29035]={[0]="A Cub's Cravings",[1]='B281 +D L050'},
[29036]={[0]='Honor the Flame',[1]='B0 HM A:51698 T:1011580'},
[29037]={[0]="'Borrowing' From the Winterfall",[1]='B281 +D L050'},
[29038]={[0]='Hunting Practice',[1]='B281 +D L050'},
[29039]={[0]='Hunting Practice',[1]='B281 +D L050'},
[29040]={[0]="Cub's First Toy",[1]='B281 +D L050'},
[29051]={[0]="Cub's First Toy",[1]='B281 +D L050'},
[29052]={[0]="A Cub's Cravings",[1]='B281 +D L050'},
[29053]={[0]="'Borrowing' From the Winterfall",[1]='B281 +D L050'},
[29054]={[0]='Stink Bombs Away!',[1]='B0 HW FA +D K0000 A:51934 T:51934'},
[29066]={[0]='Good News... and Bad News',[1]='B606 K0810 A:-606 T:39928 P:25428'},	-- there needs to be an I: for this since Nimhfree cannot get it [basically did 25428 before this quest existed]
--
--	It appears that only one of 29123, 29127, 29149 and 29163 will be given each day.  However, you can have more than one of them
--	in the quest log at the same time.  The I: cannot handle this situation properly.  Therefore, it is probably better to err on
--	the side of showing the possibility instead of denying it.
--	***** 29163 is NOT invalidated with 29201, so I am guessing all four of them are not! *****
--	***** I have a player that has both 29101 and 29147 in the log at the same time.  29101 was from the day earlier. *****
--
[29067]={[0]='Potion Master',[1]='B0 L075'},
[29071]={[0]='Make Haste to Stormwind!',[1]='B0 FA K0800 L080 A:1011708 T:0'},
[29074]={[0]='A Season for Celebration',[1]='B0 HW FA K0000 A:18927,19148,19172,19173,20102 T:51665'},
[29075]={[0]='A Time to Gain',[1]='B0 HW FA K0000 +D A:51665 T:51665'},
[29078]={[0]='Beating Them Back!',[1]='B0 FA SH K0030 A:197 T:197'},
[29079]={[0]='Lions for Lambs',[1]='B0 FA K0030 A:197 T:197 P:29078'},
[29080]={[0]='Join the Battle!',[1]='B0 FA K0030 A:197 T:823 P:29079'},
[29081]={[0]='They Sent Assassins',[1]='B0 FA K0030 A:823 T:823 P:29080'},
[29082]={[0]='Fear No Evil',[1]='B0 FA K0030 A:951 T:951 P:29080'},
[29083]={[0]='The Rear is Clear',[1]='B0 FA K0040 A:823 T:197 P:29081'},
[29086]={[0]='Competition Schmompetition',[1]='B11 K0160 FH L014 A:3442 T:3442'},
[29088]={[0]='Hyena Extermination',[1]='B11 K0160 FH L014 A:34698 T:34698'},
[29090]={[0]='A Burning Threat',[1]='B11 K0160 L014'},
[29091]={[0]='Freedom Movement',[1]='B0 K0170 L015'},
[29092]={[0]='Inform the Elder',[1]='B0 HM L016'},
[29093]={[0]="Cruisin' the Chasm",[1]='B0 HC L010 A:14305 T:500007 P:1468'},
[29095]={[0]='Report to Thork',[1]='B0 FH K0160 L014 A:3449 T:3429 P:876'},
--[29098]={[0]='Demon Seed',[1]='K0170 L015 P:29097'},
[29100]={[0]="Bwemba's Spirit",[1]='B0 FA K0850 L085 A:52654'},
[29101]={[0]='Punting Season',[1]='B0 K0850 L085 +D A:52671 T:0,52671 P:29198 I:29125,29147,29161,29164'},
[29102]={[0]='To Fort Livingston',[1]='B0 FA K0850 L085 A:52654 T:52281 PL:29100'},
[29103]={[0]='Serpents and Poison',[1]='B0 FA K0850 L085 A:52281 T:52281 P:29102'},
[29104]={[0]='Spirits Are With Us',[1]='FA K0850 L085 A:52234 T:52234 P:29103'},
[29105]={[0]='Nesingwary Will Know',[1]='FA K0850 L085 A:52281 T:52294 P:29104'},
[29106]={[0]='The Biggest Diamond Ever!',[1]='B0 HC FA L010 A:14305 T:514305 P:1468'},
[29107]={[0]='Malfurion Has Returned!',[1]='B0 HC FA L010 A:14305 T:500006 P:1468'},
[29109]={[0]="Mor'shan Caravan Pick-Up",[1]='B0 FH K0170 L015 A:3429 T:52207 P:29095'},
[29110]={[0]="Mor'shan Caravan Rescue",[1]='B0 FH K0170 L015 A:52207 T:52309 P:29109'},
[29112]={[0]='Demon Seed',[1]='B0 K0170 FH L015 A:52309 T:52207 P:29110'},
[29114]={[0]='Track the Tracker',[1]='FA K0850 L085 A:52294 T:52346 P:29105'},
[29115]={[0]="The Hunter's Revenge",[1]='FA K0850 L085 A:52346 T:-37 P:29114'},
[29116]={[0]='Follow That Cat',[1]='FA K0850 L085 A:-37 T:52234 P:29115'},
[29117]={[0]="Let's Go Fly a Kite",[1]='B0 HC FA L010 A:14305 T:14305 P:29093+29106+29107'}, -- Craggle Wobbletop wanders up and down 
[29119]={[0]="You Scream, I Scream...",[1]='B0 HC FA L010 A:14305 T:500008 P:29093+29106+29107'},
[29120]={[0]='Mauti',[1]='FA K0850 L085 A:52234 T:52234 P:29116'},
[29121]={[0]='Bury Me With Me Boots...',[1]='FA K0850 L085 A:52371 T:52371 P:29213'},
[29122]={[0]='Echoes of Nemesis',[1]='B0 K0850 +D A:52671,-606 T:52671 P:29101'},
[29123]={[0]='Rage Against the Flames',[1]='B0 +D K0850 L085 A:52669 T:52669 P:29198 I:29127,29149,29163,29166,29246,29247,29248'},
[29124]={[0]='Warn the Rebel Camp',[1]='FA K0850 L085 A:52234 T:52410 P:29121'},
[29125]={[0]='Between the Trees',[1]='B0 K0850 +D A:52669 T:0,52669 P:29198 I:29101,29147,29161,29164'},
[29126]={[0]='The Power of Malorne',[1]='B0 K0850 +D A:52669,-606 T:52669 P:29125'},
[29127]={[0]='Rage Against the Flames',[1]='B0 +D K0850 L085 A:52669 T:52669 P:29198 I:29123,29149,29163,29166,29246,29247,29248'},	-- TODO: Determine whether any of the new stuff needs P: as well
[29128]={[0]='The Protectors of Hyjal',[1]='B0 +D K0850 L085 A:553073 T:52824 P:29201'},
[29131]={[0]='Defend the Rebel Camp',[1]='FA K0850 L085 A:52410 T:52410 P:29124'},
[29133]={[0]='To the Digsite',[1]='FA K085 L085 A:52753 T:552234 P:29131'},
[29137]={[0]='Breach in the Defenses',[1]='B0 +D K0850 L085 A:52824 T:52824 P:29201 I:29141,29142,29304'},
[29138]={[0]='Burn Victims',[1]='B0 +D K0850 L085 A:553080,53080 T:553080 P:29201'},
[29139]={[0]='Aggressive Growth',[1]='B0 +D K0850 L085 A:52467 T:52467 P:29201 I:29143'},
[29141]={[0]='The Harder They Fall',[1]='B0 +D K0850 L085 A:52824 T:52824 P:29201 I:29137,29142,29304'},
[29142]={[0]='Traitors Return',[1]='B0 +D K0850 L085 A:52824 T:52824 P:29201 I:29137,29141,29304'},
[29143]={[0]='Wisp Away',[1]='B0 +D K0850 L085 A:52467 T:52467 P:29201 I:29139'},
[29144]={[0]='Clean Up in Stormwind',[1]='B0 HW FA +D K0000 A:51934 T:51934'},
[29145]={[0]='Opening the Door',[1]='B0 K0850 A:52669 T:52838 O:29387,29388,29389 P:25372'},
[29147]={[0]='Call the Flock',[1]='B0 K0850 +D A:52669 T:0,52669 P:29198 I:29101,29125,29161,29164'},
[29148]={[0]='Wings Aflame',[1]='B0 K0850 +D A:-606,52669 T:52669 P:29147'},
[29149]={[0]='Rage Against the Flames',[1]='B0 +D K0850 L085 A:52669 T:52669 P:29198 I:29123,29127,29163,29166,29246,29247,29248'},
[29150]={[0]='Voodoo Zombies',[1]='FA K0850 L085 A:552234 T:552234 P:29133'},
[29151]={[0]='Bad Supplies',[1]='FA K0850 L085 A:552234 T:552234 P:29150'},
[29152]={[0]='Making Contact',[1]='FA K0850 L085 A:52646 T:52767 P:29151'},
[29153]={[0]="Booty Bay's Interests",[1]='FA K0851088 L085 A:2496 P:29152 I:29154'},
[29154]={[0]="Booty Bay's Interests",[1]='FA K0851088 L085 A:53151 P:29152 I:29153'},
[29156]={[0]='The Troll Incursion',[1]='B0 K0850 FA L085 A:1009503,1009686,1010712,1010713,1010714 T:53352'},
[29159]={[0]='Pyrorachnophobia',[1]='B0 +D K0850 L085 A:52921 T:52921 P:29205'},
[29160]={[0]='Egg-stinction',[1]='B0 +D K0850 L085 A:52921 T:52921,52476 P:29205 I:29189'},
[29161]={[0]='Those Bears Up There',[1]='B0 +D K0850 L085 A:52671 T:0,52671 P:29198 I:29101,29125,29147,29164'},
[29162]={[0]="Nature's Blessing",[1]='B0 +D K0850 L085 A:52671,-606 T:52671 P:29161'},
[29163]={[0]='Rage Against the Flames',[1]='B0 +D K0850 L085 A:52669 T:52669 P:29198 I:29123,29127,29149,29166,29246,29247,29248'},
[29164]={[0]='Perfecting Your Howl',[1]='B0 +D K0850 L085 A:52669 T:0,52669 P:29198 I:29101,29125,29147,29161'},
[29165]={[0]='The Call of the Pack',[1]='B0 +D K0850 L085 A:-606,52669 T:52669 P:29164'},
[29166]={[0]='Supplies for the Other Side',[1]='B0 +D K0850 L085 A:52669 T:52669 P:29198 I:29123,29127,29149,29163,29246,29247,29248'},
[29173]={[0]='Secondary Targets',[1]='K0851088 L085 A:53023'},
[29177]={[0]='Vigilance on Wings',[1]='B0 K0810 +D A:40578 T:40578 P:25560'},
[29179]={[0]='Hostile Elements',[1]='B0 +D K0850 L085 A:52824 T:52824 P:29201'},
[29181]={[0]='Druids of the Talon',[1]='B0 K0850 L085 A:52135 T:50082 PH:29137,29138,29139,29141,29142,29143,29179,29304'},
[29182]={[0]='Flight of the Storm Crows',[1]='B0 K0850 L085 A:52669 T:52490 P:29181'}, -- TODO: Did not show up the first day after 29181 was done
[29189]={[0]='Wicked Webs',[1]='B0 +D K0850 L085 A:52921 T:52921,52476 P:29205 I:29160'},
[29190]={[0]="Let's Go Fly a Kite",[1]='B0 HC FH L010'},
[29192]={[0]='The Wardens are Watching',[1]='B0 +D K0850 L085 L085 A:52494 T:52494 P:29205 I:29211'},
[29193]={[0]='On a Wing and a Prayer',[1]='B0 K0850 L085'},
[29194]={[0]='Through a Glass, Darkly',[1]='B0 K08564 L085 P:29193'},
[29195]={[0]='A Ritual of Flame',[1]='B0 K0850 L085 A:52838 T:52845 P:29145'},
[29196]={[0]='To the Sanctuary!',[1]='B0 K0850 L085 A:52845 T:52669 P:29195'},
[29197]={[0]='Caught Unawares',[1]='B0 K0850 L085 A:52669 T:52838 P:29196'},
[29198]={[0]='The Sanctuary Must Not Fall',[1]='B0 K0850 L085 A:52838 T:552845 P:29197'},
[29199]={[0]='Calling for Reinforcements',[1]='B0 K0850 L085 A:552838 T:552838 P:29198'},
[29200]={[0]='Leyara',[1]='B0 K0850 L085 A:552838 T:52669 P:29199'},
[29201]={[0]='Through the Gates of Hell',[1]='B0 K0850 L085 A:552845 T:53385 P:29200'},
[29202]={[0]='The Fate of Runetotem',[1]='B0 K0850 L085 A:52669 T:52986 P:29201'},
[29203]={[0]='Into the Depths',[1]='B0 K0850 L085 A:52135 T:52135 P:29279'},
[29204]={[0]="The Warden's Charge",[1]='B0 +D K0850 L085'},
--
--	We have a couple of cases where the prerequisites includes an option of multiple quests along with some others that are required.
--	I have shown this in an example of what an entry could look like.  However, in reality the parsing of how it should be done properly
--	is rather complicated and since there seem not to be too many cases like this at the moment, I will be barbaric and unfold the
--	requirements into a simple OR/AND construct that has been used so far.  It makes things a little ugly but should work properly.
--	[29205]={[0]='The Forlorn Spire',[1]='+D K0850 L085 A:52824 T:52494 P:29214+29138+(29137,29141,29142,29304)+(29139,29143)+29179'},
--
[29205]={[0]='The Forlorn Spire',[1]='B0 +D K0850 L085 A:52824 T:52494 P:29214+29138+29137+29139+29179,29214+29138+29137+29143+29179,29214+29138+29141+29139+29179,29214+29138+29141+29143+29179,29214+29138+29142+29139+29179,29214+29138+29142+29143+29179,29214+29138+29304+29139+29179,29214+29138+29304+29143+29179 I:29206'},
[29206]={[0]='Into the Fire',[1]='B0 +D K0850 L085 A:52824 T:52444 P:29181+29138+29137+29139+29179,29181+29138+29137+29143+29179,29181+29138+29141+29139+29179,29181+29138+29141+29143+29179,29181+29138+29142+29139+29179,29181+29138+29142+29143+29179,29181+29138+29304+29139+29179,29181+29138+29304+29143+29179 I:29205'},
[29209]={[0]='Into the Fiery Depths',[1]='B0 +D K0850 L085'},
[29210]={[0]='Enduring the Heat',[1]='B0 +D K0850 L085 A:52494 T:52823,552823 P:29192,29211'},
[29211]={[0]='Solar Core Destruction',[1]='B0 +D K0850 L085 A:52494 T:52494 P:29205 I:29192'},
[29213]={[0]="How's the Hunter Holding Up?",[1]='FA K0850 L085 A:52234 T:52371 P:29120'},
[29214]={[0]='The Shadow Wardens',[1]='B0 K0850 L085 A:52135 T:52844 PH:29137,29138,29139,29141,29142,29143,29179,29304'},
[29215]={[0]='The Hunt Begins',[1]='B0 K0850 L085 A:52669 T:52493 P:29214'}, -- became available the day after it seems, unless I missed it for some reason
--[29216]={[0]="Malfurion's Breach",[1]='K0850 L085'},
[29218]={[0]='Marks of the World Tree',[1]='B0 K0850 L085'},
[29225]={[0]='Actionable Intelligence',[1]='B0 K0850 L085 P:29194'},
[29234]={[0]='Delegation',[1]='B0 K085128 L085 P:29225'},
[29239]={[0]="Nordrassil's Bough",[1]='B0 K0850 L085 P:29234,29432'},
[29240]={[0]='Emergency Extraction',[1]='B0 K0850 L085'},
[29241]={[0]='Break the Godbreaker',[1]='K0851088 L085 A:53024'},
[29242]={[0]='Putting a Price on Priceless',[1]='K0851088 L085 A:53043'},
[29243]={[0]='Strike at the Heart',[1]='B0 +D K0850 L085 A:53056 T:52493 P:29210+29214+29283'},
--[29244]={[0]='A Lieutenant of Flame',[1]='+D K0850 L085'},
[29245]={[0]='The Mysterious Seed',[1]='B0 K0850 L085 A:1208535 T:52489 P:29214'}, -- TODO: Deal with the fact that this only appears after killing 52122
[29246]={[0]='Relieving the Pain',[1]='B0 +D K0850 L085 A:52986 T:52986 P:29198 I:29123,29127,29149,29163,29166,29247,29248'},
[29247]={[0]='Treating the Wounds',[1]='B0 +D K0850 L085 A:52986 T:52986 P:29198 I:29123,29127,29149,29163,29166,29246,29248'},
[29248]={[0]='Releasing the Pressure',[1]='B0 +D K0850 L085 A:52986 T:52986 P:29198 I:29123,29127,29149,29163,29166,29246,29247'},
[29249]={[0]='Planting Season',[1]='B0 K0850 L085 A:52489 T:-795,52489 P:29245'},
[29254]={[0]='Little Lasher',[1]='B0 K0850 L085 A:52489 T:52489 P:29249'},
[29255]={[0]='Embergris',[1]='B0 +D K0850 L085 A:52489 T:52489 P:29254 I:29257,29299'},
[29257]={[0]='Steal Magmolias',[1]='B0 +D K0850 L085 A:52489 T:52489 P:29254 I:29255,29299'},
[29258]={[0]='Meteorite Hunt',[1]='B0 +D K0850 L085'},
[29263]={[0]='A Bitter Pill',[1]='B0 +D K0850 L085 A:53196 T:53214 P:29281 I:29278'},
[29264]={[0]='Flamewakers of the Molten Flow',[1]='B0 +D K0850 L085 A:52444 T:52444 P:29206'},
[29265]={[0]='Fire Flowers',[1]='B0 +D K0850 L085 A:52444 T:52492,52467 P:29206'},
[29267]={[0]='Some Good Will Come',[1]='SP FA K0850 L085 A:52374 T:52374 P:29121'},
[29269]={[0]='At One',[1]='B0 K0850 L085 P:29240'},
[29270]={[0]='Time Grows Short',[1]='B0 K085128 L085 P:29269'},
--[29271]={[0]='Bound for Warmer Weather',[1]='+D K0850 L085 T:53365'},
[29272]={[0]='Need... Water... Badly...',[1]='B0 K08532 L085 A:53233 T:52477 P:29181'},
[29273]={[0]='How Hot',[1]='B0 +D K0850 L085 A:52477 T:552478 P:29206+29272 I:29274'},
[29274]={[0]='Hounds of Shannox',[1]='B0 +D K0850 L085 A:500019,52478 T:500016,52477,552477 P:29206+29272 I:29273'}, -- TODO: Check if all 52477 can be handled by 552477 as well, and 500016
[29275]={[0]="Fandral's Methods",[1]='B0 +D K0850 L085 A:500017,52478 T:500016,52477 P:29192+29272,29211+29272 I:29276'},
[29276]={[0]='The Flame Spider Queen',[1]='B0 +D K0850 L085 A:500018,52477 T:552478 P:29205+29272 I:29275'},
[29278]={[0]='Living Obsidium',[1]='B0 +D K0850 L085 A:53214 T:53214 P:29281 I:29263'},
[29279]={[0]='Filling the Moonwell',[1]='B0 K0850 L085 A:53881 T:52669 P:29181+29214'},
[29280]={[0]='Nourishing Waters',[1]='B0 K0850 L085 A:52669 T:53881 P:29279'},
[29281]={[0]='Additional Armaments',[1]='B0 K0850 L085 A:53214 T:52669 P:29181+29214'},
[29282]={[0]='Well Armed',[1]='B0 FH K0850 L085 A:52669 T:53196 P:29281'},
[29283]={[0]='Calling the Ancients',[1]='B0 K0850 L085 A:53882 T:52906 P:29181+29214'},
[29284]={[0]='Aid of the Ancients',[1]='B0 K0850 L085 A:52669 T:52488 P:29283'},
[29285]={[0]='Alignment',[1]='B0 K0850 L085 P:29270'},
[29287]={[0]='Peaked Interest',[1]='B0 +D K0850 L085 A:52491 T:52491 P:29265 I:29288,29289,29290'},
[29288]={[0]='Starting Young',[1]='B0 +D K0850 L085 A:52491 T:52490,52491 P:29265 I:29287,29289,29290'},
[29289]={[0]="Mother's Malice",[1]='B0 +D K0850 L085 A:52491 T:52491 P:29265 I:29293,29296'},
[29290]={[0]='Fire in the Skies',[1]='B0 +D K0850 L085 A:52491 T:52491,52490 P:29265 I:29287,29288,29289'},
[29291]={[0]='Straight Chuting',[1]='B0 +D K0850 L085'},
[29292]={[0]='Hawk Fire',[1]='B0 +D K0850 L085'},
[29293]={[0]='Singed Wings',[1]='B0 +D K0850 L085 A:53259 T:53259,52467 P:29265 I:29289,29296'},
--[29294]={[0]='Animate Embers',[1]='+D K0850 L085'},
[29295]={[0]='The Bigger They Are',[1]='B0 +D K0850 L085'},
[29296]={[0]='Territorial Birds',[1]='B0 +D K0850 L085 A:53259 T:53259 P:29265 I:29289,29293'},
[29297]={[0]='Bye Bye Burdy',[1]='B0 +D K0850 L085 A:53214 P:1'},
[29298]={[0]='A Smoke-Stained Locket',[1]='B0 K0850 L085 A:100069854 T:11801'}, -- need to have earned the Legacy of Leyara achievement
[29299]={[0]='Some Like It Hot',[1]='B0 +D K0850 L085 A:52489 T:52489 P:29254 I:29255,29257'},
[29302]={[0]='Unlocking the Secrets Within',[1]='B0 K0850 L085 A:11801 T:11801 P:29298'},
[29303]={[0]='Tragedy and Family',[1]='B0 K0850 L085 A:11801 T:-100043 P:29302'},
[29304]={[0]='The Dogs of War',[1]='B0 +D K0850 L085 A:52824 T:52824 P:29201 I:29137,29141,29142'},
[29305]={[0]='Strike at the Heart',[1]='B0 +D K0850 L085 A:52490,52492 T:52490 P:29181+29293+29287+29283,29181+29296+29287+29283,29181+29293+29288+29283,29181+29296+29288+29283,29181+29293+29289+29283,29181+29296+29289+29283,29181+29293+29290+29283,29181+29296+29290+29283'},
[29307]={[0]='Heart of Flame',[1]='B0 K085128 L085'},
[29308]={[0]='Heart of Flame',[1]='B0 K085128 L085'},
[29309]={[0]='The Stuff of Legends',[1]='B0 FH K0850 L085 P:29308'},
[29310]={[0]='The Tipping Point',[1]='B0 K0850 L085 A:-43 T:-100606 P:29303'},
[29311]={[0]='The Rest is History',[1]='B0 K0850 L085 A:-606 T:52135 P:29310'},
[29312]={[0]='The Stuff of Legends',[1]='B0 FA K0850 L085 P:29307'},
[29313]={[0]='The Secret to Perfect Kimchi',[1]='B0 FA +D K0000 L010 A:4210 T:4210 I:26153,26177,26183,26190,26192,29314,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[29314]={[0]='Remembering the Ancestors',[1]='B0 FA +D K0000 L010 A:4210 T:4210 I:26153,26177,26183,26190,26192,29313,29316,29318,29351,29352,29353,29355,29356,29357 PC001'},
[29315]={[0]='Fungus Among Us',[1]='B0 FH +D K0000 L010 A:4552 T:4552 PC001 I:26220,26226,26227,26233,26234,26235,29332,29333,29334,29358,29360,29362,29363,29364,29365'},
[29316]={[0]='Back to Basics',[1]='B0 FA +D K0000 L010 A:4210 T:4210 I:26153,26177,26183,26190,26192,29313,29314,29318,29351,29352,29353,29355,29356,29357 PC001'},
[29317]={[0]='Fish Head',[1]='B0 FH +D K0000 L010 A:4573 T:2055 I:26543,26556,26557,26565,26572,26588,29319,29320,29322,29345,29346,29348,29349,29354,29361 PF001'},
[29318]={[0]='Ribs for the Sentinels',[1]='B0 FA +D K0000 L010 A:4210 T:4210 I:26153,26177,26183,26190,26192,29313,29314,29316,29351,29352,29353,29355,29356,29357 PC001'},
[29319]={[0]='Tadpole Terror',[1]='B0 FH +D K0000 L010 PF001 A:4573 T:4573 I:26543,26556,26557,26565,26572,26588,29317,29320,29322,29345,29346,29348,29349,29354,29361 PF001'},
[29320]={[0]='Like Pike?',[1]='B0 FH +D K0000 L010 PF001 A:4573 T:4573 I:26543,26556,26557,26565,26572,26588,29317,29319,29322,29345,29346,29348,29349,29354,29361'},
[29321]={[0]='Happy as a Clam Digger',[1]='B0 FA +D K0000 L010 A:4156 T:4156 I:29323,29324,29325,29342,29343,29344,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29322]={[0]='Time for Slime',[1]='B0 FH +D K0000 L010 A:4573 T:4573 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29345,29346,29348,29349,29354,29361 PF001'},
[29323]={[0]='Stocking Up',[1]='B0 FA +D K0000 L010 A:4156 T:4156 I:29321,29324,29325,29342,29343,29344,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29324]={[0]="The Sister's Pendant",[1]='B0 FA +D K0000 L010 A:4156 T:4156 I:29321,29323,29325,29342,29343,29344,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29325]={[0]='A Slippery Snack',[1]='B0 FA +D K0000 L010 A:4156 T:4156 I:29321,29323,29324,29342,29343,29344,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29326]={[0]='The Nordrassil Summit',[1]='B0 K0850 L085 A:54313 T:54312 O:29439,29440'},
[29327]={[0]='Elemental Bonds: Doubt',[1]='B0 K0850 L085 A:53524 T:53519 P:29335'},
[29328]={[0]='Elemental Bonds: Desire',[1]='B0 K0850 L085 A:53652 T:53652 P:29336'},
[29329]={[0]='Elemental Bonds: Patience',[1]='B0 K0850 L085 A:53738 T:553738 P:29337'},
[29330]={[0]='Elemental Bonds: Fury',[1]='B0 K0850 L085 A:53925 T:0 P:29338'},
[29331]={[0]='Elemental Bonds: The Vow',[1]='B0 K0850 L085 A:-795 T:54168 P:29330'},
[29332]={[0]='Lily, Oh Lily',[1]='B0 FH +D K0000 L010 A:4552 T:4552 PC001 I:26220,26226,26227,26233,26234,26235,29315,29333,29334,29358,29360,29362,29363,29364,29365'},
[29333]={[0]='Escargot A Go-Go',[1]='B0 FH +D K0000 L010 A:4552 T:4552 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29334,29358,29360,29362,29363,29364,29365'},
[29334]={[0]='Roach Coach',[1]='B0 FH +D K0000 L010 PC001 A:4552 T:53528 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29358,29360,29362,29363,29364,29365'},
[29335]={[0]='Into Slashing Winds',[1]='B0 K0850 L085 A:54312 T:53524 P:29326'},
[29336]={[0]='Into Coaxing Tides',[1]='B0 K0850 L085 A:53519 T:53677 P:29327'},
[29337]={[0]='Into Constant Earth',[1]='B0 K0850 L085 A:53652 T:42465 P:29328'},
[29338]={[0]='Into Unrelenting Flame',[1]='B0 K0850 L085 A:553738 T:54014 P:29329'},
[29342]={[0]='Cold Water Fishing',[1]='B0 FA +D K0000 L010 A:5161 T:5161 I:29321,29323,29324,29325,29343,29344,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29343]={[0]='One fer the Ages',[1]='B0 FA +D K0000 L010 A:5161 T:5161 I:29321,29323,29324,29325,29342,29344,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29344]={[0]='Fish fer Squirky',[1]='B0 FA +D K0000 L010 A:5161 T:5161 I:29321,29323,29324,29325,29342,29343,29347,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29345]={[0]='Pond Predators',[1]='B0 FH +D K0000 L010 A:3028 T:3028 PF001 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29322,29346,29348,29349,29354,29361'},
[29346]={[0]="The Ring's the Thing",[1]='B0 FH +D K0000 L010 A:3028 T:30709 PF001 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29322,29345,29348,29349,29354,29361'},
[29347]={[0]='Live Bait',[1]='B0 FA +D K0000 L010 A:5161 T:1355 I:29321,29323,29324,29325,29342,29343,29344,29350,29359,26414,26420,26442,26488,26536 PF001'},
[29348]={[0]='The Race to Restock',[1]='B0 FH +D K0000 L010 A:3028 T:3028 PF001 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29322,29345,29346,29349,29354,29361'},
[29349]={[0]='Craving Crayfish',[1]='B0 FH +D K0000 L010 A:3028 T:3028 PF001 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29322,29345,29346,29348,29354,29361'},
[29350]={[0]='The Gnomish Bait-o-Matic',[1]='B0 FA +D K0000 L010 A:5161 T:5161 I:29321,29323,29324,29325,29342,29343,29344,29347,29359,26414,26420,26442,26488,26536 PF001'},
[29351]={[0]='A Round for the Guards',[1]='B0 FA +D K0000 L010 A:5159 T:5159 I:26153,26177,26183,26190,26192,29313,29314,29316,29318,29352,29353,29355,29356,29357 PC001'},
[29352]={[0]='A Fowl Shortage',[1]='B0 FA +D K0000 L010 A:5159 T:5159 I:26153,26177,26183,26190,26192,29313,29314,29316,29318,29351,29353,29355,29356,29357 PC001'},
[29353]={[0]="Keepin' the Haggis Flowin'",[1]='B0 FA +D K0000 L010 A:5159 T:5159 I:26153,26177,26183,26190,26192,29313,29314,29316,29318,29351,29352,29355,29356,29357 PC001'},
[29354]={[0]='Shiny Baubles',[1]='B0 FH +D K0000 L010 A:3028 T:52657 PF001 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29322,29345,29346,29348,29349,29361'},
[29355]={[0]="Can't Get Enough Spice Bread",[1]='B0 FA +D K0000 L010 A:5159 T:5159 I:26153,26177,26183,26190,26192,29313,29314,29316,29318,29351,29352,29353,29356,29357 PC001'},
[29356]={[0]='I Need to Cask a Favor',[1]='B0 FA +D K0000 L010 A:5159 T:5159 I:26153,26177,26183,26190,26192,29313,29314,29316,29318,29351,29352,29353,29355,29357 PC001'},
[29357]={[0]='Spice Bread Aplenty',[1]='B0 FA +D K0000 L010 A:4210 T:4210 I:26153,26177,26183,26190,26192,29313,29314,29316,29318,29351,29352,29353,29355,29356 PC001'},
[29358]={[0]='Pining for Nuts',[1]='B0 FH +D K0000 L010 A:3026 T:3026 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29334,29360,29362,29363,29364,29365'},
[29359]={[0]='An Old Favorite',[1]='B0 FA +D K0000 L010 A:4156 T:4156 I:29321,29323,29324,29325,29342,29343,29344,29347,29350,26414,26420,26442,26488,26536 PF001'},
[29360]={[0]='Would You Like Some Flies With That?',[1]='B0 FH +D K0000 L010 A:4552 T:4552 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29334,29358,29362,29363,29364,29365'},
[29361]={[0]='Moat Monster!',[1]='B0 FH +D K0000 L010 PF001 A:4573 T:4573 I:26543,26556,26557,26565,26572,26588,29317,29319,29320,29322,29345,29346,29348,29349,29354'},
[29362]={[0]='"Magic" Mushrooms',[1]='B0 FH +D K0000 L010 A:3026 T:3026 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29334,29358,29360,29363,29364,29365'},
[29363]={[0]='Mulgore Spice Bread',[1]='B0 FH +D K0000 L010 A:3026 T:3026 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29334,29358,29360,29362,29364,29365'},
[29364]={[0]='Corn Mash',[1]='B0 FH +D K0000 L010 A:3026 T:3026 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29334,29358,29360,29362,29363,29365'},
[29365]={[0]='Perfectly Picked Portions',[1]='B0 FH +D K0000 L010 A:3026 T:3026 PC001 I:26220,26226,26227,26233,26234,26235,29315,29332,29333,29334,29358,29360,29362,29363,29364'},
[29371]={[0]='A Time to Lose',[1]='B0 HW FA +D A:52064 T:52064'},
[29372]={[0]='Trouble in Podunk',[1]='B0 K0850'},
[29373]={[0]='Trouble in Podunk',[1]='B0 K0850'},
[29374]={[0]='Stink Bombs Away!',[1]='B0 HW FH +D A:53763 T:53763'},
[29375]={[0]='Clean Up in Undercity',[1]='B0 HW FH +D A:53763 T:53763'},
[29376]={[0]='A Time to Build Up',[1]='B0 HW FH +D A:15197 T:15197 O:29400'},
[29377]={[0]='A Time to Break Down',[1]='B0 HW FH +D A:15197 T:15197'},
[29382]={[0]='Thanks, But No Thanks',[1]='B0 HV'},
[29383]={[0]='Thanks, But No Thanks',[1]='B0 HV'},
[29385]={[0]='A Winter Veil Gift',[1]='B0 HV L010'},
[29386]={[0]="Hero's Call: Mount Hyjal!",[1]='B0 FA K0800 L080 M084'},
[29387]={[0]='Guardians of Hyjal: Firelands Invasion!',[1]='B0 FA K0850 L085 A:1009503,1009686 T:52669 I:29145'},	-- TODO: There is a P: for this
[29388]={[0]='Guardians of Hyjal: Firelands Invasion!',[1]='B0 FH K0850 L085 A:1206116 T:52669 I:29145'},	-- TODO:	Look at 29387 comment
[29389]={[0]='Guardians of Hyjal: Firelands Invasion!',[1]='B0 K0850 L085 A:-606 T:52669 P:29390,29391'},
[29390]={[0]='Guardians of Hyjal: Call of the Ancients',[1]='B0 FH K0850 L085 A:1206109 T:0'},
[29391]={[0]='Guardians of Hyjal: Call of the Ancients',[1]='B0 FA K0850 L085 A:1009501,1009686 T:0'},
[29392]={[0]='Missing Heirlooms',[1]='B0 HW FA K0000 L010 A:53949 T:53950 O:29430'},
[29393]={[0]='Brew For Brewfest',[1]='B0 HB FH +D A:24497 T:24497 P:11412'},
[29394]={[0]='Brew For Brewfest',[1]='B0 HB FA +D A:23558 T:23558 P:11122'},
[29396]={[0]='A New Supplier of Souvenirs',[1]='B0 HB FH A:24510 T:24495 P:11409'},
[29397]={[0]='A New Supplier of Souvenirs',[1]='B0 HB FA A:24468 T:23710 P:11318'},
[29398]={[0]='Fencing the Goods',[1]='B0 HW K0000 L010 A:53950 T:8719 P:29392'},
[29399]={[0]='Shopping Around',[1]='B0 HW K0000 L010 A:8719 T:54021 P:29398'},
[29400]={[0]='A Season for Celebration',[1]='B0 HW FH K00016 A:19169,19175,19176,19177,19178,20102 T:15197'},
[29401]={[0]='Blown Away',[1]='B0 FH K0200 L010 A:54004 T:54004'},
[29402]={[0]='Taking Precautions',[1]='B0 HW K0000 L010 A:54021 T:54021 P:29399'},
[29403]={[0]="The Collector's Agent",[1]='B0 HW L010 A:54021 T:1012464 P:29402'},
[29411]={[0]='What Now?',[1]='B0 HW L010 A:1012464 T:53949,54118 P:29403 I:529411 OTC:53949+529411'},
[29412]={[0]='Blown Away',[1]='B0 FA K0200 L010 A:54117 T:54117'},
[29413]={[0]='The Creepy Crate',[1]='B0 L010 HW A:500024 T:500024 P:529411 I:529413'},
[29415]={[0]='Missing Heirlooms',[1]='B0 HW FH L010 A:54141 T:54142 O:29431'},
[29416]={[0]='Fencing the Goods',[1]='B0 HW L010 A:54142 T:44866 P:29415'},
[29425]={[0]='Shopping Around',[1]='B0 HW L010 A:44866 T:54146 P:29416'},
[29426]={[0]='Taking Precautions',[1]='B0 HW L010 A:54146 T:54146 P:29425'},
[29427]={[0]="The Collector's Agent",[1]='B0 HW L010 A:54146 T:1012486 P:29426'},
[29428]={[0]='What Now?',[1]='B0 HW L010 A:1012486 T:54141,54146 P:29427 I:529428 OTC:54141+529428'},
[29429]={[0]='The Creepy Crate',[1]='B0 HW L010 A:1012487 T:1012487 P:29428 I:29429'},
[29430]={[0]='A Friend in Need',[1]='B0 HW FA K000 L010 A:51934 T:53949 I:29392'},
[29431]={[0]='A Friend in Need',[1]='B0 FH L010 HW A:53763 T:54141'},
[29432]={[0]='Delegation Tracker',[1]='B0 K085128 L085 P:29225'},	-- TODO: Determine if this is just really a Blizzard-ism for 29234
[29433]={[0]='Test Your Strength',[1]='HF +M A:14832 T:14832'},
[29434]={[0]='Tonk Commander',[1]='HF +D A:54605 T:54605'},
[29436]={[0]='The Humanoid Cannonball',[1]='HF +D A:15303 T:15303'},
[29437]={[0]='The Fallen Guardian',[1]='B0 K0850 L085 A:52793 T:0 P:29326'},
[29438]={[0]='He Shoots, He Scores!',[1]='HF +D A:14841 T:14841'},
[29439]={[0]='The Call of the World-Shaman',[1]='B0 FA K0850 L085 A:45226 T:54313 I:29326'},
[29440]={[0]='The Call of the World-Shaman',[1]='B0 FH K0850 L085 A:45244 T:54313 I:29326'},
[29441]={[0]='From the Belly of the Beast',[1]='B0 K0190 L015'},
[29443]={[0]='A Curious Crystal',[1]='L015'},
[29444]={[0]='An Exotic Egg',[1]='L015'},
[29445]={[0]='An Intriguing Grimoire',[1]='L015'},
[29446]={[0]='A Wondrous Weapon',[1]='L015'},
[29447]={[0]='A Curious Crystal',[1]='L015'},
[29448]={[0]='An Exotic Egg',[1]='L015'},
[29449]={[0]='An Intriguing Grimoire',[1]='L015'},
[29450]={[0]='A Woundrous Weapon',[1]='L015'}, -- one assumes this is not spelled correctly
[29451]={[0]='The Master Strategist',[1]=''},
[29452]={[0]='Your Time Has Come',[1]='B0 FH CD CM CT CS CL K0850 L085 AK:53310'}, -- TODO: figure out how to handle this being available to any that have gotten any of the achievements: Bastion of Twilight, Blackwing Descent, or Throne of the Four Winds.  AC here means get it from this NPC if the achievement is satisfied. AC:52382
[29453]={[0]='Your Time Has Come',[1]='B0 FA CD CM CT CS CL K0850 L085 AK:53310'},	-- TODO: See comment in 29452  AC:52408
[29454]={[0]='The Master Strategist',[1]=''},
[29455]={[0]='Target: Turtle',[1]='HF +D A:54485 T:54485'},
[29456]={[0]='A Captured Banner',[1]='L015'},
[29457]={[0]="The Enemy's Insignia",[1]=''},
[29458]={[0]='The Captured Journal',[1]=''},
[29459]={[0]='A Captured Banner',[1]='L015'},
[29460]={[0]="The Enemy's Insignia",[1]=''},
[29461]={[0]='The Captured Journal',[1]=''},
[29463]={[0]="It's Hammer Time",[1]='HF +D A:54601 T:54601'},
[29464]={[0]='Tools of Divination',[1]=''},
[29465]={[0]='Tools of Divination',[1]=''},
[29466]={[0]='Plenty of Plump Frogs',[1]=''}, -- this was also marked complete when undead hunter completed 29513
[29467]={[0]="Talkin' Tonks",[1]='HF FH +M A:14841 T:14841 PN075'},
[29468]={[0]='Baby Needs Two Pair of Shoes',[1]='HF FH +M A:14829 T:14829 PB075'},
[29469]={[0]='Rearm, Reuse, Recycle',[1]='HF FH +M A:14841 T:14841 PM075'},
[29470]={[0]='Tan My Hide',[1]='HF FH +M A:14833 T:14833 PS075'},
[29471]={[0]='Writing the Future',[1]='HF FH +M A:14822 T:14822 PI075'},
[29472]={[0]='Eyes on the Prizes',[1]='HF FH +M A:14841 T:14841 PL075'},
[29473]={[0]='Putting the Carnies Back Together Again',[1]='HF FH +M A:14833 T:14833 P+075 I:29512'},
[29474]={[0]='Putting Trash to Good Use',[1]='HF FH +M A:14822 T:14822 PE075'},
[29475]={[0]='Goblin Engineering',[1]=''},
[29476]={[0]='Gnomish Engineering',[1]=''},
[29477]={[0]='Gnomish Engineering',[1]=''},
[29478]={[0]='A Fizzy Fusion',[1]='HF FH +M A:14844 T:14844 PA075'},
[29479]={[0]='Herbs for Healing',[1]='HF FH +M A:14833 T:14833 PH075'},
[29480]={[0]='Banners, Banners Everywhere!',[1]='HF FH +M A:10445 T:10445 PT075'},
[29481]={[0]='Elixir Master',[1]='PA001'},
[29482]={[0]='Transmutation Master',[1]=''},
[29483]={[0]='Keeping the Faire Sparkling',[1]='HF FH +M A:14833 T:14833 PJ075'},
[29484]={[0]='Putting the Crunch in the Frog',[1]='HF FH +M A:14845 T:14845 PC075'},
[29485]={[0]='Fun for the Little Ones',[1]='HF FH +M A:14847 T:14847 PX075'},
[29506]={[0]='A Fizzy Fusion',[1]='HF FA +M A:14844 T:14844 PA075'},
[29507]={[0]='Fun for the Little Ones',[1]='HF FA +M A:14847 T:14847 PX075'},
[29508]={[0]='Baby Needs Two Pair of Shoes',[1]='HF FA +M A:14829 T:14829 PB075'},
[29509]={[0]='Putting the Crunch in the Frog',[1]='HF FA +M A:14845 T:14845 PC075'},
[29510]={[0]='Putting Trash to Good Use',[1]='HF FA +M A:14822 T:14822 PE075'},
[29511]={[0]="Talkin' Tonks",[1]='HF FA +M A:14841 T:14841 PN075'},
[29512]={[0]='Putting the Carnies Back Together Again',[1]='HF FA +M A:14833 T:14833 P+075 I:29473'},
[29513]={[0]="Spoilin' for Salty Sea Dogs",[1]='HF +M A:14845 T:14845 PF075'},
[29514]={[0]='Herbs for Healing',[1]='HF FA +M A:14833 T:14833 PH075'},
[29515]={[0]='Writing the Future',[1]='HF FA +M A:14822 T:14822 PI075'},
[29516]={[0]='Keeping the Faire Sparkling',[1]='HF FA +M A:14833 T:14833 PJ075'},
[29517]={[0]='Eyes on the Prizes',[1]='HF FA +M A:14841 T:14841 PL075'},
[29518]={[0]='Rearm, Reuse, Recycle',[1]='HF FA +M A:14841 T:14841 PM075'},
[29519]={[0]='Tan My Hide',[1]='HF FA +M A:14833 T:14833 PS075'},
[29520]={[0]='Banners, Banners Everywhere!',[1]='HF FA +M A:10445 T:10445 PT075'},
[29527]={[0]='War on the Ramparts',[1]=''},
[29528]={[0]='War on the Ramparts',[1]=''},
[29529]={[0]='Demons in the Citadel',[1]='K06264 L059'},
[29530]={[0]='Demons in the Citadel',[1]='K06264 L059'},
[29532]={[0]='Dark Tidings',[1]=''},
[29533]={[0]='Dark Tidings',[1]=''},
[29535]={[0]='Make Them Bleed',[1]=''},
[29536]={[0]='Heart of Rage',[1]=''},
[29537]={[0]='Mind the Gap',[1]=''},
[29538]={[0]='Make Them Bleed',[1]=''},
[29539]={[0]='Heart of Rage',[1]=''},
[29540]={[0]='The Breaker',[1]=''},
[29542]={[0]='Invading the Citadel',[1]=''},
[29543]={[0]='Invading the Citadel',[1]=''},
[29544]={[0]='The Blood Furnace',[1]=''},
[29545]={[0]='The Blood Furnace',[1]=''},
[29563]={[0]='Lost in Action',[1]=''},
[29564]={[0]='A Brother Betrayed',[1]='K06564 L062 A:18097 T:18097'},
[29565]={[0]='The Heart of the Matter',[1]=''},
[29566]={[0]='Checking Up',[1]='K06564 L062'},
[29567]={[0]='Stalk the Stalker',[1]=''},
[29568]={[0]='A Necessary Evil',[1]='K06564 L063'},
[29569]={[0]="Warlord Kalithresh's Prized Possession",[1]=''},
[29570]={[0]='Rescuing the Expedition',[1]=''},
[29571]={[0]='Defending the Wilds',[1]='K06564 L063'},
[29572]={[0]='Safety Is Job One',[1]=''},
[29573]={[0]='Safety is Job One',[1]=''},
[29574]={[0]='Intriguing Specimens',[1]=''},
[29575]={[0]='Undercutting the Competition',[1]=''},
[29582]={[0]="Grek's Crazy Night",[1]=''},
[29583]={[0]='Eckert the Mad',[1]='K06664 L064'},
[29590]={[0]='The Dead Watcher',[1]=''},
[29591]={[0]='Raging Spirits',[1]=''},
[29592]={[0]='Caster Legendary BREADCRUMB TRACKER',[1]=''},
[29593]={[0]='Hitting Them Where It Hurts',[1]=''},
[29595]={[0]='Everything Will Be Alright',[1]='K06764 L064'},
[29596]={[0]='The End of the Exarch',[1]=''},
[29597]={[0]='The End of the Exarch',[1]=''},
[29598]={[0]="Taretha's Diversion",[1]=''},
[29599]={[0]='Escape from Durnholde',[1]='K06864 L066 P:29598'},
[29601]={[0]='The Darkmoon Field Guide',[1]=''},
[29605]={[0]='Brother Against Brother',[1]='K06964 L065'},
[29606]={[0]="Terokk's Legacy",[1]=''},
[29607]={[0]='Eyes of Desire',[1]='K06964 L065'},
[29608]={[0]='Allies in Dalaran',[1]='FA K0700 L068'},
[29609]={[0]='Friends in Dalaran',[1]=''},
[29613]={[0]='A Proper Fate',[1]='K07064 L067'},
[29614]={[0]='Containment is Key',[1]='K07064 L067'},
[29615]={[0]='Windcaller Claw and the Water Thief',[1]=''},
[29616]={[0]='Storming the Steamvault',[1]=''},
[29640]={[0]="Find Spy To'gun",[1]='K07064 L068'},
[29641]={[0]='The Soul Devices',[1]=''},
[29642]={[0]='Trouble at Auchindoun',[1]=''},
[29643]={[0]='The Codex of Blood',[1]=''},
[29644]={[0]='Into the Heart of the Labyrinth',[1]=''},
[29645]={[0]='Ambassador Hellmaw',[1]='K07064 L068'},
[29649]={[0]='How to Save a Life',[1]=''},
[29650]={[0]='Fel Ember',[1]='FA K07065 L066'},
[29651]={[0]='Honor the Dying',[1]=''},
[29652]={[0]='One Last Favor',[1]=''},
[29653]={[0]='The Will of the Warchief',[1]=''},
[29654]={[0]='Turning the Tide',[1]=''},
[29655]={[0]='A Very Special Cloth',[1]='K07064 L066'},
[29656]={[0]="O'mrogg's Warcloth",[1]=''},
[29657]={[0]='With Great Power, Comes Great Responsibility',[1]=''},
[29658]={[0]='The Calculator',[1]=''},
[29659]={[0]='Lost Treasure',[1]=''},
[29660]={[0]='Saving the Botanica',[1]=''},
[29667]={[0]='Culling the Herd',[1]='K07064 L067 P:29660'},
[29669]={[0]='A Most Somber Task',[1]='K07064 L067 P:29667'},
[29671]={[0]='The Black Morass',[1]=''},
[29672]={[0]='The Opening of the Dark Portal',[1]=''},
[29673]={[0]='The Black Morass',[1]=''},
[29674]={[0]='Unbound Darkness',[1]=''},
[29675]={[0]='Hey There Dalliah',[1]=''},
[29681]={[0]='Maximum Security Breakout',[1]=''},
[29682]={[0]="Magisters' Terrace",[1]=''},
[29683]={[0]="The Scryer's Scryer",[1]=''},
[29684]={[0]='Severed Communications',[1]=''},
[29685]={[0]='Hard to Kill',[1]=''},
[29686]={[0]='A Radical Notion',[1]='K07064 L070'},
[29687]={[0]='Twisted Associations',[1]=''},
[29688]={[0]='Advancing the Campaign',[1]='K07064 L066'},
[29689]={[0]='Advancing the Campaign',[1]='K07064 L066'},
[29691]={[0]='Bring Me A Shrubbery!',[1]='K06564 L063'},
[29692]={[0]='Bring Me Another Shrubbery!',[1]='K06564 L063'},
[29734]={[0]='Deepforge the Elder',[1]='SP HL +Y'},
[29735]={[0]='Stonebrand the Elder',[1]=''},
[29736]={[0]='Darkfeather the Elder',[1]='SP HL +Y'},
[29737]={[0]='Firebeard the Elder',[1]='SP HL +Y'},
[29738]={[0]='Moonlance the Elder',[1]=''},
[29739]={[0]='Windsong the Elder',[1]=''},
[29740]={[0]='Evershade the Elder',[1]='SP HL +Y'},
[29741]={[0]='Sekhemi the Elder',[1]=''},
[29742]={[0]='Menkhaf the Elder',[1]=''},
[29760]={[0]='Pit Fighter',[1]=''},
[29761]={[0]='Master Pit Fighter',[1]=''},
[29763]={[0]='Stealing Their Thunder',[1]=''},
[29764]={[0]='Disarmament',[1]='K07164 L068'},
[29801]={[0]='Proving Your Worth',[1]='K0850 L085 CR'},
[29802]={[0]='A Hidden Message',[1]='K0850 L085 CR P:29801'},
[29803]={[0]='Ears of the Lich King',[1]='K07164 L068'},
[29807]={[0]='Death to the Traitor King',[1]='K07464 L072'},
[29808]={[0]="Don't Forget the Eggs!",[1]='K07464 L072'},
[29810]={[0]='The Faceless Ones',[1]=''},
[29811]={[0]="The Gatewatcher's Talisman",[1]=''},
[29820]={[0]='Into the Nexus',[1]=''},
[29825]={[0]='Pupil No More',[1]=''},
[29826]={[0]="Reclaiming Ahn'Kahet",[1]=''},
[29828]={[0]='What the Scourge Dred',[1]=''},
[29829]={[0]='Discretion is Key',[1]='K07764 L075'},
[29830]={[0]='Containment',[1]='K07764 L075 P:29829'},
[29833]={[0]='Unfinished Business',[1]=''},
[29834]={[0]="Gal'darah Must Pay",[1]=''},
[29835]={[0]="Gal'darah Must Pay",[1]=''},
[29836]={[0]="Just Checkin'",[1]=''},
[29838]={[0]='One of a Kind',[1]=''},
[29839]={[0]='One of a Kind',[1]=''},
[29840]={[0]='For Posterity',[1]=''},
[29844]={[0]='For Posterity',[1]=''},
[29847]={[0]='To Catch a Thief',[1]='K0850 L085 CR P:29934'},
[29848]={[0]='The Forlorn Watcher',[1]=''},
[29850]={[0]='Corrupt Constructs',[1]='K07864 L076'},
[29851]={[0]='Champion of the Tournament',[1]='K07864 L075'},
[29853]={[0]='Champion of the King',[1]=''},
[29860]={[0]='Diametrically Opposed',[1]='K08064 L077'},
[29861]={[0]='Whatever it Takes!',[1]=''},
[29862]={[0]='Clearing the Way',[1]='K08064 L077'},
[29863]={[0]='Stormherald Eljrrin',[1]=''},
[29864]={[0]='Working at the Source',[1]=''},
[29934]={[0]='To Ravenholdt',[1]='K0850 L085 CR P:29802'},
[30092]={[0]='Our Man in Gilneas',[1]=''},
[30093]={[0]='Assassinate Creed',[1]=''},
[30094]={[0]='The End Time',[1]=''},
[30095]={[0]='The End Time',[1]='FA A:52408 T:54476'},
[30096]={[0]='Murozond',[1]='K08564 A:54476 P:30095'},
[30097]={[0]='Archival Purposes',[1]='K08564 L085 A:57864'},
[30098]={[0]='The Well of Eternity',[1]=''},
[30099]={[0]='In Unending Numbers',[1]=''},
[30100]={[0]='The Vainglorious',[1]=''},
[30101]={[0]='The Path to the Dragon Soul',[1]=''},
[30102]={[0]='The Hour of Twilight',[1]=''},
[30103]={[0]='To Wyrmrest!',[1]=''},
[30104]={[0]='Documenting the Timeways',[1]='K08564 L085'},
[30105]={[0]='The Twilight Prophet',[1]=''},
[30106]={[0]='The Deed is Done',[1]=''},
[30107]={[0]='Cluster Clutch',[1]='K0850 L085 CR'},
[30108]={[0]='Our Man in Karazhan',[1]=''},
[30109]={[0]='Blood of the Betrayer',[1]=''},
[30110]={[0]='Raid Finder (1st)',[1]=''},
[30111]={[0]='Raid Finder (Nth)',[1]=''},
[30112]={[0]='A Score to Settle',[1]=''},
[30113]={[0]='Victory in the Depths',[1]=''},
[30116]={[0]='Sharpening Your Fangs',[1]=''},
[30118]={[0]='Patricide',[1]=''},
[30119]={[0]='Well of Eternity RP Tracker',[1]=''},
[30120]={[0]="Cleansing Drak'Tharon",[1]=''},
[500001]={[0]="Warchief's Command: Hillsbrad Foothills!",[1]='B0 K0200 FH L019 M023 A:45631 T:2215 P:27290 I:27601,28089,28096,28571 Y:28089'},
[500002]={[0]="Warchief's Command: Hillsbrad Foothills!",[1]='B0 K0200 FH L019 M023 A:46125 T:2215 P:27601 I:28089,28096,28571 Y:28089'},
[512340]={[0]='Candy Bucket',[1]='B0 HW SP K00016 FA A:500023 T:500023 I:12340,26322 Y:12340'},
[512404]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059039 T:1059039 V3641999 I:12404 Y:12404'},
[512409]={[0]='Candy Bucket',[1]='B0 HW SP K00016 A:1059044 T:1059044 V3641999 I:12409 Y:12409'},
[524629]={[0]='A Perfect Puff of Perfume',[1]='B0 HA FH +D GF A:537675 T:537675 I:24629,524635,524636 Y:24629'},
[524635]={[0]='A Cloudlet of Classy Cologne',[1]='B0 HA FH +D GM A:537675 T:537675 I:24635,524636,524629 Y:24635'},
[524636]={[0]='Bonbon Blitz',[1]='B0 HA FH +D A:537675 T:537675 I:24636,524635,524629 Y:24636'},
[525542]={[0]='Quest Abandon 25542 Flag',[1]='FA'},
[525543]={[0]='Quest Abandon 25543 Flag',[1]='FA'},
[526738]={[0]='Just Hatched',[1]='B0 K0250 FA L024 A:1422 T:1422 P:28855 I:26738 Y:26738'},
[528089]={[0]="Warchief's Command: Hillsbrad Foothills!",[1]='B0 K0200 FH L019 M023 A:544640 T:2215 P:27098 I:27290,27601,28089,28096,28571 Y:28089'},
[529411]={[0]='What Now?',[1]='B0 HW L010 A:1012464 T:53949,54118 P:29403 I:29411 Y:29411'},
[529413]={[0]='The Creepy Crate',[1]='B0 L010 HW A:1012468 T:1012468 P:29411 I:29413 Y:29413'},
[529428]={[0]='What Now?',[1]='B0 HW L010 A:1012486 T:54141,54146 P:29427 I:29428 Y:29428'}, -- assumption is NPC 54141 is the turnin for this
[529429]={[0]='The Creepy Crate',[1]='B0 HW L010 A:500025 T:500025 P:529428 I:29429 Y:29429'},
	}

if "enGB" == GetLocale() then     -- as if this ever evaluates as true (2011-09-28 client fails to do so)
-- Remove the quests that are not on the European servers
Grail.quests[11117] = nil
Grail.quests[11118] = nil
Grail.quests[11120] = nil
Grail.quests[11431] = nil
end
end

if tonumber(select(4, GetBuildInfo())) >= 40300 then
local G=Grail.quests
-- New quests
--G[29435]={[0]='',[1]=''}
--G[29442]={[0]='',[1]=''}
--G[29462]={[0]='',[1]=''}
--G[29486]={[0]='',[1]=''}
--G[29487]={[0]='',[1]=''}
--G[29488]={[0]='',[1]=''}
--G[29489]={[0]='',[1]=''}
--G[29490]={[0]='',[1]=''}
--G[29491]={[0]='',[1]=''}
--G[29492]={[0]='',[1]=''}
--G[29493]={[0]='',[1]=''}
--G[29494]={[0]='',[1]=''}
--G[29495]={[0]='',[1]=''}
--G[29496]={[0]='',[1]=''}
--G[29497]={[0]='',[1]=''}
--G[29498]={[0]='',[1]=''}
--G[29499]={[0]='',[1]=''}
--G[29500]={[0]='',[1]=''}
--G[29501]={[0]='',[1]=''}
--G[29502]={[0]='',[1]=''}
--G[29503]={[0]='',[1]=''}
--G[29504]={[0]='',[1]=''}
--G[29505]={[0]='',[1]=''}
--G[29521]={[0]='',[1]=''}
--G[29522]={[0]='',[1]=''}
--G[29523]={[0]='',[1]=''}
--G[29524]={[0]='',[1]=''}
--G[29525]={[0]='',[1]=''}
--G[29526]={[0]='',[1]=''}
--G[29531]={[0]='',[1]=''}
--G[29534]={[0]='',[1]=''}
--G[29541]={[0]='',[1]=''}
--G[29546]={[0]='',[1]=''}
--G[29547]={[0]='',[1]=''}
--G[29548]={[0]='',[1]=''}
--G[29549]={[0]='',[1]=''}
--G[29550]={[0]='',[1]=''}
--G[29551]={[0]='',[1]=''}
--G[29552]={[0]='',[1]=''}
--G[29553]={[0]='',[1]=''}
--G[29554]={[0]='',[1]=''}
--G[29555]={[0]='',[1]=''}
--G[29556]={[0]='',[1]=''}
--G[29557]={[0]='',[1]=''}
--G[29558]={[0]='',[1]=''}
--G[29559]={[0]='',[1]=''}
--G[29560]={[0]='',[1]=''}
--G[29561]={[0]='',[1]=''}
--G[29562]={[0]='',[1]=''}
--G[29576]={[0]='',[1]=''}
--G[29577]={[0]='',[1]=''}
--G[29578]={[0]='',[1]=''}
--G[29579]={[0]='',[1]=''}
--G[29580]={[0]='',[1]=''}
--G[29581]={[0]='',[1]=''}
--G[29584]={[0]='',[1]=''}
--G[29585]={[0]='',[1]=''}
--G[29586]={[0]='',[1]=''}
--G[29587]={[0]='',[1]=''}
--G[29588]={[0]='',[1]=''}
--G[29589]={[0]='',[1]=''}
--G[29600]={[0]='',[1]=''}
--G[29602]={[0]='',[1]=''}
--G[29603]={[0]='',[1]=''}
--G[29604]={[0]='',[1]=''}
--G[29610]={[0]='',[1]=''}
--G[29611]={[0]='',[1]=''}
--G[29612]={[0]='',[1]=''}
--G[29617]={[0]='',[1]=''}
--G[29618]={[0]='',[1]=''}
--G[29619]={[0]='',[1]=''}
--G[29620]={[0]='',[1]=''}
--G[29621]={[0]='',[1]=''}
--G[29622]={[0]='',[1]=''}
--G[29623]={[0]='',[1]=''}
--G[29624]={[0]='',[1]=''}
--G[29625]={[0]='',[1]=''}
--G[29626]={[0]='',[1]=''}
--G[29627]={[0]='',[1]=''}
--G[29628]={[0]='',[1]=''}
--G[29629]={[0]='',[1]=''}
--G[29630]={[0]='',[1]=''}
--G[29631]={[0]='',[1]=''}
--G[29632]={[0]='',[1]=''}
--G[29633]={[0]='',[1]=''}
--G[29634]={[0]='',[1]=''}
--G[29635]={[0]='',[1]=''}
--G[29636]={[0]='',[1]=''}
--G[29637]={[0]='',[1]=''}
--G[29638]={[0]='',[1]=''}
--G[29639]={[0]='',[1]=''}
--G[29646]={[0]='',[1]=''}
--G[29647]={[0]='',[1]=''}
--G[29648]={[0]='',[1]=''}
--G[29661]={[0]='',[1]=''}
--G[29662]={[0]='',[1]=''}
--G[29663]={[0]='',[1]=''}
--G[29664]={[0]='',[1]=''}
--G[29665]={[0]='',[1]=''}
--G[29666]={[0]='',[1]=''}
--G[29668]={[0]='',[1]=''}
--G[29670]={[0]='',[1]=''}
--G[29676]={[0]='',[1]=''}
--G[29677]={[0]='',[1]=''}
--G[29678]={[0]='',[1]=''}
--G[29679]={[0]='',[1]=''}
--G[29680]={[0]='',[1]=''}
--G[29690]={[0]='',[1]=''}
--G[29693]={[0]='',[1]=''}
--G[29694]={[0]='',[1]=''}
--G[29695]={[0]='',[1]=''}
--G[29696]={[0]='',[1]=''}
--G[29697]={[0]='',[1]=''}
--G[29698]={[0]='',[1]=''}
--G[29699]={[0]='',[1]=''}
--G[29700]={[0]='',[1]=''}
--G[29701]={[0]='',[1]=''}
--G[29702]={[0]='',[1]=''}
--G[29703]={[0]='',[1]=''}
--G[29704]={[0]='',[1]=''}
--G[29705]={[0]='',[1]=''}
--G[29706]={[0]='',[1]=''}
--G[29707]={[0]='',[1]=''}
--G[29708]={[0]='',[1]=''}
--G[29709]={[0]='',[1]=''}
--G[29710]={[0]='',[1]=''}
--G[29711]={[0]='',[1]=''}
--G[29712]={[0]='',[1]=''}
--G[29713]={[0]='',[1]=''}
--G[29714]={[0]='',[1]=''}
--G[29715]={[0]='',[1]=''}
--G[29716]={[0]='',[1]=''}
--G[29717]={[0]='',[1]=''}
--G[29718]={[0]='',[1]=''}
--G[29719]={[0]='',[1]=''}
--G[29720]={[0]='',[1]=''}
--G[29721]={[0]='',[1]=''}
--G[29722]={[0]='',[1]=''}
--G[29723]={[0]='',[1]=''}
--G[29724]={[0]='',[1]=''}
--G[29725]={[0]='',[1]=''}
--G[29726]={[0]='',[1]=''}
--G[29727]={[0]='',[1]=''}
--G[29728]={[0]='',[1]=''}
--G[29729]={[0]='',[1]=''}
--G[29730]={[0]='',[1]=''}
--G[29731]={[0]='',[1]=''}
--G[29732]={[0]='',[1]=''}
--G[29733]={[0]='',[1]=''}
--G[29743]={[0]='',[1]=''}
--G[29744]={[0]='',[1]=''}
--G[29745]={[0]='',[1]=''}
--G[29746]={[0]='',[1]=''}
--G[29747]={[0]='',[1]=''}
--G[29748]={[0]='',[1]=''}
--G[29749]={[0]='',[1]=''}
--G[29750]={[0]='',[1]=''}
--G[29751]={[0]='',[1]=''}
--G[29752]={[0]='',[1]=''}
--G[29753]={[0]='',[1]=''}
--G[29754]={[0]='',[1]=''}
--G[29755]={[0]='',[1]=''}
--G[29756]={[0]='',[1]=''}
--G[29757]={[0]='',[1]=''}
--G[29758]={[0]='',[1]=''}
--G[29759]={[0]='',[1]=''}
--G[29762]={[0]='',[1]=''}
--G[29765]={[0]='',[1]=''}
--G[29766]={[0]='',[1]=''}
--G[29767]={[0]='',[1]=''}
--G[29768]={[0]='',[1]=''}
--G[29769]={[0]='',[1]=''}
--G[29770]={[0]='',[1]=''}
--G[29771]={[0]='',[1]=''}
--G[29772]={[0]='',[1]=''}
--G[29773]={[0]='',[1]=''}
--G[29774]={[0]='',[1]=''}
--G[29775]={[0]='',[1]=''}
--G[29776]={[0]='',[1]=''}
--G[29777]={[0]='',[1]=''}
--G[29778]={[0]='',[1]=''}
--G[29779]={[0]='',[1]=''}
--G[29780]={[0]='',[1]=''}
--G[29781]={[0]='',[1]=''}
--G[29782]={[0]='',[1]=''}
--G[29783]={[0]='',[1]=''}
--G[29784]={[0]='',[1]=''}
--G[29785]={[0]='',[1]=''}
--G[29786]={[0]='',[1]=''}
--G[29787]={[0]='',[1]=''}
--G[29788]={[0]='',[1]=''}
--G[29789]={[0]='',[1]=''}
--G[29790]={[0]='',[1]=''}
--G[29791]={[0]='',[1]=''}
--G[29792]={[0]='',[1]=''}
--G[29793]={[0]='',[1]=''}
--G[29794]={[0]='',[1]=''}
--G[29795]={[0]='',[1]=''}
--G[29796]={[0]='',[1]=''}
--G[29797]={[0]='',[1]=''}
--G[29798]={[0]='',[1]=''}
--G[29799]={[0]='',[1]=''}
--G[29800]={[0]='',[1]=''}
--G[29804]={[0]='',[1]=''}
--G[29805]={[0]='',[1]=''}
--G[29806]={[0]='',[1]=''}
--G[29809]={[0]='',[1]=''}
--G[29812]={[0]='',[1]=''}
--G[29813]={[0]='',[1]=''}
--G[29814]={[0]='',[1]=''}
--G[29815]={[0]='',[1]=''}
--G[29816]={[0]='',[1]=''}
--G[29817]={[0]='',[1]=''}
--G[29818]={[0]='',[1]=''}
--G[29819]={[0]='',[1]=''}
--G[29821]={[0]='',[1]=''}
--G[29822]={[0]='',[1]=''}
--G[29823]={[0]='',[1]=''}
--G[29824]={[0]='',[1]=''}
--G[29827]={[0]='',[1]=''}
--G[29831]={[0]='',[1]=''}
--G[29832]={[0]='',[1]=''}
--G[29837]={[0]='',[1]=''}
--G[29841]={[0]='',[1]=''}
--G[29842]={[0]='',[1]=''}
--G[29843]={[0]='',[1]=''}
--G[29845]={[0]='',[1]=''}
--G[29846]={[0]='',[1]=''}
--G[29849]={[0]='',[1]=''}
--G[29852]={[0]='',[1]=''}
--G[29854]={[0]='',[1]=''}
--G[29855]={[0]='',[1]=''}
--G[29856]={[0]='',[1]=''}
--G[29857]={[0]='',[1]=''}
--G[29858]={[0]='',[1]=''}
--G[29859]={[0]='',[1]=''}
--G[29865]={[0]='',[1]=''}
--G[29866]={[0]='',[1]=''}
--G[29867]={[0]='',[1]=''}
--G[29868]={[0]='',[1]=''}
--G[29869]={[0]='',[1]=''}
--G[29870]={[0]='',[1]=''}
--G[29871]={[0]='',[1]=''}
--G[29872]={[0]='',[1]=''}
--G[29873]={[0]='',[1]=''}
--G[29874]={[0]='',[1]=''}
--G[29875]={[0]='',[1]=''}
--G[29876]={[0]='',[1]=''}
--G[29877]={[0]='',[1]=''}
--G[29878]={[0]='',[1]=''}
--G[29879]={[0]='',[1]=''}
--G[29880]={[0]='',[1]=''}
--G[29881]={[0]='',[1]=''}
--G[29882]={[0]='',[1]=''}
--G[29883]={[0]='',[1]=''}
--G[29884]={[0]='',[1]=''}
--G[29885]={[0]='',[1]=''}
--G[29886]={[0]='',[1]=''}
--G[29887]={[0]='',[1]=''}
--G[29888]={[0]='',[1]=''}
--G[29889]={[0]='',[1]=''}
--G[29890]={[0]='',[1]=''}
--G[29891]={[0]='',[1]=''}
--G[29892]={[0]='',[1]=''}
--G[29893]={[0]='',[1]=''}
--G[29894]={[0]='',[1]=''}
--G[29895]={[0]='',[1]=''}
--G[29896]={[0]='',[1]=''}
--G[29897]={[0]='',[1]=''}
--G[29898]={[0]='',[1]=''}
--G[29899]={[0]='',[1]=''}
--G[29900]={[0]='',[1]=''}
--G[29901]={[0]='',[1]=''}
--G[29902]={[0]='',[1]=''}
--G[29903]={[0]='',[1]=''}
--G[29904]={[0]='',[1]=''}
--G[29905]={[0]='',[1]=''}
--G[29906]={[0]='',[1]=''}
--G[29907]={[0]='',[1]=''}
--G[29908]={[0]='',[1]=''}
--G[29909]={[0]='',[1]=''}
--G[29910]={[0]='',[1]=''}
--G[29911]={[0]='',[1]=''}
--G[29912]={[0]='',[1]=''}
--G[29913]={[0]='',[1]=''}
--G[29914]={[0]='',[1]=''}
--G[29915]={[0]='',[1]=''}
--G[29916]={[0]='',[1]=''}
--G[29917]={[0]='',[1]=''}
--G[29918]={[0]='',[1]=''}
--G[29919]={[0]='',[1]=''}
--G[29920]={[0]='',[1]=''}
--G[29921]={[0]='',[1]=''}
--G[29922]={[0]='',[1]=''}
--G[29923]={[0]='',[1]=''}
--G[29924]={[0]='',[1]=''}
--G[29925]={[0]='',[1]=''}
--G[29926]={[0]='',[1]=''}
--G[29927]={[0]='',[1]=''}
--G[29928]={[0]='',[1]=''}
--G[29929]={[0]='',[1]=''}
--G[29930]={[0]='',[1]=''}
--G[29931]={[0]='',[1]=''}
--G[29932]={[0]='',[1]=''}
--G[29933]={[0]='',[1]=''}
--G[29935]={[0]='',[1]=''}
--G[29936]={[0]='',[1]=''}
--G[29937]={[0]='',[1]=''}
--G[29938]={[0]='',[1]=''}
--G[29939]={[0]='',[1]=''}
--G[29940]={[0]='',[1]=''}
--G[29941]={[0]='',[1]=''}
--G[29942]={[0]='',[1]=''}
--G[29943]={[0]='',[1]=''}
--G[29944]={[0]='',[1]=''}
--G[29945]={[0]='',[1]=''}
--G[29946]={[0]='',[1]=''}
--G[29947]={[0]='',[1]=''}
--G[29948]={[0]='',[1]=''}
--G[29949]={[0]='',[1]=''}
--G[29950]={[0]='',[1]=''}
--G[29951]={[0]='',[1]=''}
--G[29952]={[0]='',[1]=''}
--G[29953]={[0]='',[1]=''}
--G[29954]={[0]='',[1]=''}
--G[29955]={[0]='',[1]=''}
--G[29956]={[0]='',[1]=''}
--G[29957]={[0]='',[1]=''}
--G[29958]={[0]='',[1]=''}
--G[29959]={[0]='',[1]=''}
--G[29960]={[0]='',[1]=''}
--G[29961]={[0]='',[1]=''}
--G[29962]={[0]='',[1]=''}
--G[29963]={[0]='',[1]=''}
--G[29964]={[0]='',[1]=''}
--G[29965]={[0]='',[1]=''}
--G[29966]={[0]='',[1]=''}
--G[29967]={[0]='',[1]=''}
--G[29968]={[0]='',[1]=''}
--G[29969]={[0]='',[1]=''}
--G[29970]={[0]='',[1]=''}
--G[29971]={[0]='',[1]=''}
--G[29972]={[0]='',[1]=''}
--G[29973]={[0]='',[1]=''}
--G[29974]={[0]='',[1]=''}
--G[29975]={[0]='',[1]=''}
--G[29976]={[0]='',[1]=''}
--G[29977]={[0]='',[1]=''}
--G[29978]={[0]='',[1]=''}
--G[29979]={[0]='',[1]=''}
--G[29980]={[0]='',[1]=''}
--G[29981]={[0]='',[1]=''}
--G[29982]={[0]='',[1]=''}
--G[29983]={[0]='',[1]=''}
--G[29984]={[0]='',[1]=''}
--G[29985]={[0]='',[1]=''}
--G[29986]={[0]='',[1]=''}
--G[29987]={[0]='',[1]=''}
--G[29988]={[0]='',[1]=''}
--G[29989]={[0]='',[1]=''}
--G[29990]={[0]='',[1]=''}
--G[29991]={[0]='',[1]=''}
--G[29992]={[0]='',[1]=''}
--G[29993]={[0]='',[1]=''}
--G[29994]={[0]='',[1]=''}
--G[29995]={[0]='',[1]=''}
--G[29996]={[0]='',[1]=''}
--G[29997]={[0]='',[1]=''}
--G[29998]={[0]='',[1]=''}
--G[29999]={[0]='',[1]=''}
--G[30000]={[0]='',[1]=''}
--G[30001]={[0]='',[1]=''}
--G[30002]={[0]='',[1]=''}
--G[30003]={[0]='',[1]=''}
--G[30004]={[0]='',[1]=''}
--G[30005]={[0]='',[1]=''}
--G[30006]={[0]='',[1]=''}
--G[30007]={[0]='',[1]=''}
--G[30008]={[0]='',[1]=''}
--G[30009]={[0]='',[1]=''}
--G[30010]={[0]='',[1]=''}
--G[30011]={[0]='',[1]=''}
--G[30012]={[0]='',[1]=''}
--G[30013]={[0]='',[1]=''}
--G[30014]={[0]='',[1]=''}
--G[30015]={[0]='',[1]=''}
--G[30016]={[0]='',[1]=''}
--G[30017]={[0]='',[1]=''}
--G[30018]={[0]='',[1]=''}
--G[30019]={[0]='',[1]=''}
--G[30020]={[0]='',[1]=''}
--G[30021]={[0]='',[1]=''}
--G[30022]={[0]='',[1]=''}
--G[30023]={[0]='',[1]=''}
--G[30024]={[0]='',[1]=''}
--G[30025]={[0]='',[1]=''}
--G[30026]={[0]='',[1]=''}
--G[30027]={[0]='',[1]=''}
--G[30028]={[0]='',[1]=''}
--G[30029]={[0]='',[1]=''}
--G[30030]={[0]='',[1]=''}
--G[30031]={[0]='',[1]=''}
--G[30032]={[0]='',[1]=''}
--G[30033]={[0]='',[1]=''}
--G[30034]={[0]='',[1]=''}
--G[30035]={[0]='',[1]=''}
--G[30036]={[0]='',[1]=''}
--G[30037]={[0]='',[1]=''}
--G[30038]={[0]='',[1]=''}
--G[30039]={[0]='',[1]=''}
--G[30040]={[0]='',[1]=''}
--G[30041]={[0]='',[1]=''}
--G[30042]={[0]='',[1]=''}
--G[30043]={[0]='',[1]=''}
--G[30044]={[0]='',[1]=''}
--G[30045]={[0]='',[1]=''}
--G[30046]={[0]='',[1]=''}
--G[30047]={[0]='',[1]=''}
--G[30048]={[0]='',[1]=''}
--G[30049]={[0]='',[1]=''}
--G[30050]={[0]='',[1]=''}
--G[30051]={[0]='',[1]=''}
--G[30052]={[0]='',[1]=''}
--G[30053]={[0]='',[1]=''}
--G[30054]={[0]='',[1]=''}
--G[30055]={[0]='',[1]=''}
--G[30056]={[0]='',[1]=''}
--G[30057]={[0]='',[1]=''}
--G[30058]={[0]='',[1]=''}
--G[30059]={[0]='',[1]=''}
--G[30060]={[0]='',[1]=''}
--G[30061]={[0]='',[1]=''}
--G[30062]={[0]='',[1]=''}
--G[30063]={[0]='',[1]=''}
--G[30064]={[0]='',[1]=''}
--G[30065]={[0]='',[1]=''}
--G[30066]={[0]='',[1]=''}
--G[30067]={[0]='',[1]=''}
--G[30068]={[0]='',[1]=''}
--G[30069]={[0]='',[1]=''}
--G[30070]={[0]='',[1]=''}
--G[30071]={[0]='',[1]=''}
--G[30072]={[0]='',[1]=''}
--G[30073]={[0]='',[1]=''}
--G[30074]={[0]='',[1]=''}
--G[30075]={[0]='',[1]=''}
--G[30076]={[0]='',[1]=''}
--G[30077]={[0]='',[1]=''}
--G[30078]={[0]='',[1]=''}
--G[30079]={[0]='',[1]=''}
--G[30080]={[0]='',[1]=''}
--G[30081]={[0]='',[1]=''}
--G[30082]={[0]='',[1]=''}
--G[30083]={[0]='',[1]=''}
--G[30084]={[0]='',[1]=''}
--G[30085]={[0]='',[1]=''}
--G[30086]={[0]='',[1]=''}
--G[30087]={[0]='',[1]=''}
--G[30088]={[0]='',[1]=''}
--G[30089]={[0]='',[1]=''}
--G[30090]={[0]='',[1]=''}
--G[30091]={[0]='',[1]=''}
--G[30114]={[0]='',[1]=''}
--G[30115]={[0]='',[1]=''}
--G[30117]={[0]='',[1]=''}
--G[30121]={[0]='',[1]=''}
--G[30122]={[0]='',[1]=''}
--G[30123]={[0]='',[1]=''}
--G[30124]={[0]='',[1]=''}
--G[30125]={[0]='',[1]=''}
--G[30126]={[0]='',[1]=''}
--G[30127]={[0]='',[1]=''}
--G[30128]={[0]='',[1]=''}
--G[30129]={[0]='',[1]=''}
--G[30130]={[0]='',[1]=''}
--G[30131]={[0]='',[1]=''}
--G[30132]={[0]='',[1]=''}
--G[30133]={[0]='',[1]=''}
--G[30134]={[0]='',[1]=''}
--G[30135]={[0]='',[1]=''}
--G[30136]={[0]='',[1]=''}
--G[30137]={[0]='',[1]=''}
--G[30138]={[0]='',[1]=''}
--G[30139]={[0]='',[1]=''}
--G[30140]={[0]='',[1]=''}
end

